const plugin = require('tailwindcss/plugin');

module.exports = plugin(function ({ matchUtilities, addComponents }) {
    addComponents({
        '.icon': {
            '--bg-image': 'none',
            '--icon-size': `var(--icon-size-base)`,
            'min-height': `var(--line-height-base)`,
            'display': 'inline-flex',
            'align-items': 'center',
            'flex-flow': 'row',
            'background-image': 'none !important',
            'background-blend-mode': 'initial',

            '&::before': {
                'aspect-ratio': '1 / 1',
                'content': '" "',
                'display': 'inline-block',
                'background-color': 'currentColor',
                'width': `var(--icon-size)`,
                '-webkit-mask': `var(--icon-src)`,
                'mask': `var(--icon-src)`,
                'mask-repeat': 'no-repeat',
                '-webkit-mask-repeat': 'no-repeat',
                'mask-position': 'center',
                '-webkit-mask-position': 'center',
                'background-image': 'var(--bg-image)',
                'background-blend-mode': 'var(--bg-blend-mode)',
            }
        }
    })

    matchUtilities(
        {
            'icon': (value) => ({
                '--icon-src': value
            })
        },
        {
            values: {
                "zoom-out-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.125 5.625c0 1.108-.4 2.122-1.064 2.906l.017.016L10.39 9.86a.375.375 0 0 1-.53.53L8.547 9.078a.386.386 0 0 1-.016-.017 4.5 4.5 0 1 1 1.594-3.436m-6-.375a.375.375 0 1 0 0 .75h3a.375.375 0 1 0 0-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-out-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.5 7.5c0 1.477-.534 2.83-1.42 3.875a.65.65 0 0 1 .024.021l1.75 1.75a.5.5 0 0 1-.708.708l-1.75-1.75a.65.65 0 0 1-.02-.023A6 6 0 1 1 13.5 7.5m-8-.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-out-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.75 5.625c0-.207.168-.375.375-.375h3a.375.375 0 1 1 0 .75h-3a.375.375 0 0 1-.375-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.938 5.625a4.688 4.688 0 1 1 8.256 3.039L10.39 9.86a.375.375 0 0 1-.53.53L8.664 9.194a4.688 4.688 0 0 1-7.726-3.57m4.687-3.937a3.938 3.938 0 1 0 0 7.875 3.938 3.938 0 0 0 0-7.876' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-out": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 7.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.25 7.5a6.25 6.25 0 1 1 11.009 4.052l1.595 1.594a.5.5 0 0 1-.708.708l-1.594-1.595A6.25 6.25 0 0 1 1.25 7.5M7.5 2.25a5.25 5.25 0 1 0 0 10.5 5.25 5.25 0 0 0 0-10.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-in-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 5.5a5.479 5.479 0 0 1-1.38 3.644.374.374 0 0 1 .145.09l2 2a.375.375 0 0 1-.53.531l-2-2a.374.374 0 0 1-.09-.146A5.5 5.5 0 1 1 11 5.5m-5.125-2a.375.375 0 1 0-.75 0v1.625H3.5a.375.375 0 1 0 0 .75h1.625V7.5a.375.375 0 1 0 .75 0V5.875H7.5a.375.375 0 1 0 0-.75H5.875z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-in-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.968 7.484a6.46 6.46 0 0 1-1.586 4.25.499.499 0 0 1 .172.112l2.357 2.358a.5.5 0 1 1-.707.707l-2.358-2.357a.499.499 0 0 1-.112-.172 6.484 6.484 0 1 1 2.234-4.897M7.984 5.126a.5.5 0 1 0-1 0v1.858H5.126a.5.5 0 1 0 0 1h1.858v1.858a.5.5 0 0 0 1 0V7.984h1.858a.5.5 0 0 0 0-1H7.984V5.126' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-in-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.5 3.125c.207 0 .375.168.375.375v1.625H7.5a.375.375 0 1 1 0 .75H5.875V7.5a.375.375 0 1 1-.75 0V5.875H3.5a.375.375 0 1 1 0-.75h1.625V3.5c0-.207.168-.375.375-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.62 9.144a5.5 5.5 0 1 0-.475.475.374.374 0 0 0 .09.146l2 2a.375.375 0 0 0 .53-.53l-2-2a.374.374 0 0 0-.146-.09M5.5 10.25a4.75 4.75 0 1 0 0-9.5 4.75 4.75 0 0 0 0 9.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zoom-in": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.484 4.626a.5.5 0 0 1 .5.5v1.858h1.858a.5.5 0 0 1 0 1H7.984v1.858a.5.5 0 0 1-1 0V7.984H5.126a.5.5 0 1 1 0-1h1.858V5.126a.5.5 0 0 1 .5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.382 11.734a6.484 6.484 0 1 0-.648.648.5.5 0 0 0 .112.172l2.358 2.357a.5.5 0 1 0 .707-.707l-2.357-2.358a.5.5 0 0 0-.172-.112m-4.898 1.234A5.484 5.484 0 1 0 7.484 2a5.484 5.484 0 0 0 0 10.968' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zap-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' d='m7.36.984-.854 4.272-1.709-1.709L7.361.984M9.418 8.168 7.012 5.762l3.863 1.054-1.457 1.352M7.976 9.507l3.196 3.196a.375.375 0 0 0 .53-.53L.829 1.296a.375.375 0 0 0-.53.53l3.11 3.11-2.255 2.255L5.53 8.386l-1.41 4.702 3.856-3.581'/%3e%3c/svg%3e")`,
                "zap-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' d='m9.814.979-1.14 5.696-2.278-2.279L9.814.98ZM12.558 10.558 9.35 7.35l5.15 1.404-1.943 1.803M10.635 12.342l4.261 4.262a.5.5 0 0 0 .708-.708l-14.5-14.5a.5.5 0 1 0-.708.708L4.543 6.25 1.537 9.256l5.837 1.592-1.881 6.27 5.142-4.776'/%3e%3c/svg%3e")`,
                "zap-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m7.36.984-.805 4.027a.375.375 0 0 1-.735-.147l.32-1.598-.812.812a.375.375 0 1 1-.53-.53L7.36.983Zm-7.063.313a.375.375 0 0 1 .53 0l10.876 10.875a.375.375 0 0 1-.53.53L7.975 9.508 4.12 13.088l1.41-4.702-4.377-1.194 2.254-2.255-3.11-3.11a.375.375 0 0 1 0-.53Zm3.64 4.17-1.34 1.341 3.686 1.006-2.346-2.346M6.438 7.97l-.808 2.693 1.816-1.686L6.438 7.97m.747-1.77c.055-.2.26-.318.46-.264l3.23.88-1.467 1.363a.375.375 0 1 1-.51-.55l.477-.444-1.927-.525a.375.375 0 0 1-.263-.46' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zap-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.814.979 8.74 6.348a.5.5 0 1 1-.98-.196l.426-2.13-1.082 1.082a.5.5 0 1 1-.708-.708L9.814.98m-9.418.417a.5.5 0 0 1 .708 0l14.5 14.5a.5.5 0 0 1-.708.707l-4.26-4.26-5.143 4.775 1.88-6.27-5.836-1.592L4.543 6.25.396 2.104a.5.5 0 0 1 0-.708ZM5.25 6.957 3.463 8.744l4.915 1.34L5.25 6.958m3.335 3.335-1.078 3.59 2.42-2.247-1.342-1.343M9.58 7.93a.5.5 0 0 1 .614-.35L14.5 8.753l-1.955 1.816a.5.5 0 1 1-.68-.733l.637-.591-2.57-.701a.5.5 0 0 1-.35-.614' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zap-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m7.36.984-.924 4.621 4.438 1.21-6.755 6.273L5.53 8.386 1.153 7.192 7.36.984M2.598 6.808 6.47 7.864l-.84 2.798 3.745-3.478-3.811-1.04.575-2.878-3.542 3.542' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M9.375 7.184 5.63 10.662l.84-2.798-3.873-1.056L6.14 3.266l-.575 2.879 3.811 1.04'/%3e%3c/svg%3e")`,
                "zap-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.814.979 8.582 7.14l5.917 1.614-9.006 8.364 1.88-6.27-5.836-1.592L9.814.979ZM3.463 8.744l5.163 1.409-1.119 3.73 4.994-4.637L7.418 7.86l.768-3.839-4.723 4.723' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m12.5 9.246-4.993 4.636 1.12-3.73-5.164-1.408 4.723-4.723-.768 3.839 5.083 1.386'/%3e%3c/svg%3e")`,
                "zap-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m7.36.984-.924 4.621 4.439 1.21-6.755 6.273 1.41-4.702-4.377-1.194L7.36.984M2.598 6.808 6.47 7.864l-.84 2.798 3.745-3.478-3.811-1.04.575-2.878-3.542 3.542Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "zap": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.814.979 8.582 7.14l5.917 1.614-9.006 8.364 1.88-6.27-5.836-1.592L9.814.979ZM3.463 8.744l5.163 1.409-1.119 3.73 4.994-4.637L7.418 7.86l.768-3.839-4.723 4.723' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "youtube-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.997 1h.158a65.418 65.418 0 0 1 1.723.032c.497.015 1.025.039 1.486.075.45.035.87.084 1.132.158l.015.005c.314.104.59.3.807.56a2.14 2.14 0 0 1 .442.94c.165 1.07.245 2.156.24 3.242a20.56 20.56 0 0 1-.244 3.215 2.14 2.14 0 0 1-.438.918c-.216.261-.493.457-.807.561l-.006.002c-.264.083-.688.136-1.138.175-.462.04-.99.065-1.487.082A60.175 60.175 0 0 1 6.155 11H6.04L5.999 11h-.154a68.094 68.094 0 0 1-1.725-.035 30.81 30.81 0 0 1-1.487-.082c-.45-.039-.873-.092-1.138-.175h-.003a1.77 1.77 0 0 1-.796-.536 2.122 2.122 0 0 1-.456-.919A20.562 20.562 0 0 1 0 6.012a20.56 20.56 0 0 1 .244-3.24c.073-.34.222-.657.438-.917a1.78 1.78 0 0 1 .807-.561l.006-.002c.265-.083.688-.136 1.138-.175.462-.04.99-.065 1.487-.082A60.323 60.323 0 0 1 5.845 1h.114L5.997 1M4.681 3.629a.382.382 0 0 0-.596.32V8.05a.382.382 0 0 0 .595.32L7.745 6.32a.385.385 0 0 0 0-.64L4.681 3.629' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "youtube-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.946 14h.26a99.934 99.934 0 0 0 2.301-.041 45.88 45.88 0 0 0 1.983-.098c.601-.046 1.16-.11 1.508-.207l.007-.002c.409-.12.777-.35 1.07-.665a2.503 2.503 0 0 0 .604-1.152c.217-1.26.325-2.54.32-3.82a22.008 22.008 0 0 0-.327-3.91c-.1-.42-.306-.806-.598-1.12a2.382 2.382 0 0 0-1.087-.67c-.343-.088-.899-.146-1.5-.188a50.24 50.24 0 0 0-1.98-.09A98.586 98.586 0 0 0 8.053 2h-.108a55.836 55.836 0 0 0-.703.005c-.46.005-1.086.016-1.75.036-.663.02-1.368.052-1.983.099-.601.045-1.16.109-1.508.206l-.007.002c-.409.12-.777.35-1.07.665a2.503 2.503 0 0 0-.604 1.152 22.01 22.01 0 0 0-.32 3.849 22.012 22.012 0 0 0 .33 3.924c.112.407.322.78.613 1.08.292.302.655.521 1.055.635l.003.001c.347.097.907.16 1.508.207.615.046 1.32.077 1.983.098a90.574 90.574 0 0 0 2.3.04h.153M6.765 5.076A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .765.424l4-2.5a.5.5 0 0 0 0-.848z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "youtube-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.708 3.688A.375.375 0 0 0 4.125 4v4a.375.375 0 0 0 .583.312l3-2a.375.375 0 0 0 0-.624l-3-2M6.824 6 4.875 7.3V4.7L6.824 6' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.997 1.125h-.149a58.712 58.712 0 0 0-1.688.034c-.487.017-1.005.042-1.457.08-.44.038-.855.09-1.114.17l-.006.003a1.742 1.742 0 0 0-.79.546 2.081 2.081 0 0 0-.433.917A19.963 19.963 0 0 0 .125 6.01a19.964 19.964 0 0 0 .241 3.193c.079.321.229.62.44.863.212.244.48.427.78.522l.003.001c.259.081.674.133 1.114.17.452.04.97.065 1.457.081a58.982 58.982 0 0 0 1.688.034h.304a63.883 63.883 0 0 0 1.688-.034 30.226 30.226 0 0 0 1.457-.08c.44-.038.855-.09 1.114-.17l.006-.003c.307-.1.578-.292.79-.546a2.083 2.083 0 0 0 .433-.917c.16-1.027.238-2.07.235-3.113a19.966 19.966 0 0 0-.239-3.182 2.083 2.083 0 0 0-.429-.895 1.742 1.742 0 0 0-.805-.551c-.256-.073-.667-.12-1.108-.155a33.075 33.075 0 0 0-1.455-.073 64.836 64.836 0 0 0-1.688-.03H6.04l-.037-.001h-.006m.003.75h.148a63.62 63.62 0 0 1 1.668.03c.48.016.985.038 1.42.072.44.034.777.077.954.126.16.055.314.16.441.312.127.153.222.346.27.563.154 1 .23 2.015.224 3.032v.003a19.21 19.21 0 0 1-.224 2.986 1.33 1.33 0 0 1-.27.563.995.995 0 0 1-.446.313c-.171.053-.508.1-.952.138-.434.037-.938.062-1.419.079a58.13 58.13 0 0 1-1.667.032h-.11l-.028.001h-.157a55.846 55.846 0 0 1-1.666-.033c-.481-.017-.985-.042-1.42-.079-.445-.037-.782-.085-.953-.138a.985.985 0 0 1-.44-.3 1.313 1.313 0 0 1-.275-.535 19.214 19.214 0 0 1-.223-3.026V6.01C.871 5.001.945 3.994 1.1 3a1.33 1.33 0 0 1 .27-.562.994.994 0 0 1 .446-.313c.171-.053.508-.1.952-.138.434-.037.938-.062 1.419-.079a58.517 58.517 0 0 1 1.667-.032h.11l.028-.001H6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "youtube": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.765 5.076A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .765.424l4-2.5a.5.5 0 0 0 0-.848zM9.557 8 7 9.598V6.402L9.557 8' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2h-.054a55.836 55.836 0 0 0-.703.005c-.46.005-1.086.016-1.75.036-.663.02-1.368.052-1.983.099-.601.045-1.16.109-1.508.206l-.007.002c-.409.12-.777.35-1.07.665a2.503 2.503 0 0 0-.604 1.152 22.01 22.01 0 0 0-.32 3.849 22.012 22.012 0 0 0 .33 3.924c.112.407.322.78.613 1.08.292.302.655.521 1.055.635l.003.001c.347.097.907.16 1.508.207.615.046 1.32.077 1.983.098a90.574 90.574 0 0 0 2.3.04h.153L8 14h.206a99.934 99.934 0 0 0 2.301-.041 45.88 45.88 0 0 0 1.983-.098c.601-.046 1.16-.11 1.508-.207l.007-.002c.409-.12.777-.35 1.07-.665a2.503 2.503 0 0 0 .604-1.152c.217-1.26.325-2.54.32-3.82a22.008 22.008 0 0 0-.327-3.91c-.1-.42-.306-.806-.598-1.12a2.382 2.382 0 0 0-1.087-.67c-.343-.088-.899-.146-1.5-.188a50.24 50.24 0 0 0-1.98-.09A98.586 98.586 0 0 0 8.053 2H8m0 1h-.052a61.933 61.933 0 0 0-.694.005c-.456.005-1.075.015-1.73.036-.657.02-1.344.05-1.939.096-.605.046-1.07.104-1.31.17-.232.07-.445.202-.617.387-.169.182-.292.409-.354.658A21.012 21.012 0 0 0 1 8.012v.005a21.01 21.01 0 0 0 .302 3.68c.07.238.194.453.36.626.172.177.383.303.61.368.24.067.706.126 1.313.172.595.046 1.282.076 1.939.096a88.557 88.557 0 0 0 2.275.04h.15l.05.001H8.203a89.108 89.108 0 0 0 2.274-.04c.657-.021 1.344-.051 1.938-.097.606-.046 1.07-.104 1.311-.17.232-.07.445-.202.617-.387.169-.182.292-.408.354-.658.206-1.199.308-2.414.304-3.632V8.01a21.012 21.012 0 0 0-.304-3.687 1.502 1.502 0 0 0-.354-.659 1.382 1.382 0 0 0-.611-.384c-.246-.061-.712-.114-1.313-.156a49.247 49.247 0 0 0-1.94-.088A97.675 97.675 0 0 0 8.052 3H8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2zm1.854 3.146a.5.5 0 1 0-.708.708L5.293 6 4.146 7.146a.5.5 0 1 0 .708.708L6 6.707l1.146 1.147a.5.5 0 1 0 .708-.708L6.707 6l1.147-1.146a.5.5 0 1 0-.708-.708L6 5.293 4.854 4.146' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zm2.354 4.146a.5.5 0 1 0-.708.708L7.293 8l-2.147 2.146a.5.5 0 0 0 .708.708L8 8.707l2.146 2.147a.5.5 0 0 0 .708-.708L8.707 8l2.147-2.146a.5.5 0 0 0-.708-.708L8 7.293 5.854 5.146' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.854 4.146a.5.5 0 1 0-.708.708L5.293 6 4.146 7.146a.5.5 0 1 0 .708.708L6 6.707l1.146 1.147a.5.5 0 1 0 .708-.708L6.707 6l1.147-1.146a.5.5 0 1 0-.708-.708L6 5.293 4.854 4.146'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2zm2-1.25h6c.69 0 1.25.56 1.25 1.25v6c0 .69-.56 1.25-1.25 1.25H3c-.69 0-1.25-.56-1.25-1.25V3c0-.69.56-1.25 1.25-1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.854 5.146a.5.5 0 1 0-.708.708L7.293 8l-2.147 2.146a.5.5 0 0 0 .708.708L8 8.707l2.146 2.147a.5.5 0 0 0 .708-.708L8.707 8l2.147-2.146a.5.5 0 0 0-.708-.708L8 7.293 5.854 5.146'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.25 1A2.25 2.25 0 0 0 1 3.25v9.5A2.25 2.25 0 0 0 3.25 15h9.5A2.25 2.25 0 0 0 15 12.75v-9.5A2.25 2.25 0 0 0 12.75 1zM2 3.25C2 2.56 2.56 2 3.25 2h9.5c.69 0 1.25.56 1.25 1.25v9.5c0 .69-.56 1.25-1.25 1.25h-9.5C2.56 14 2 13.44 2 12.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M4.39 3.86a.375.375 0 1 0-.53.53L5.47 6 3.86 7.61a.375.375 0 0 0 .53.53L6 6.53l1.61 1.61a.375.375 0 0 0 .53-.53L6.53 6l1.61-1.61a.375.375 0 1 0-.53-.53L6 5.47 4.39 3.86' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M5.146 5.146a.5.5 0 0 1 .708 0L8 7.293l2.146-2.147a.5.5 0 0 1 .708.708L8.707 8l2.147 2.146a.5.5 0 0 1-.708.708L8 8.707l-2.146 2.147a.5.5 0 0 1-.708-.708L7.293 8 5.146 5.854a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.39 3.86a.375.375 0 1 0-.53.53L5.47 6 3.86 7.61a.375.375 0 0 0 .53.53L6 6.53l1.61 1.61a.375.375 0 0 0 .53-.53L6.53 6l1.61-1.61a.375.375 0 1 0-.53-.53L6 5.47 4.39 3.86'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a6 6 0 1 0 0 12A6 6 0 0 0 6 0M.75 6a5.25 5.25 0 1 1 10.5 0A5.25 5.25 0 0 1 .75 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.146 5.147a.5.5 0 0 1 .708 0L8 7.293l2.146-2.146a.5.5 0 0 1 .708.707L8.707 8l2.147 2.146a.5.5 0 0 1-.708.708L8 8.707l-2.146 2.147a.5.5 0 1 1-.708-.707L7.293 8 5.146 5.854a.5.5 0 0 1 0-.707'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "x-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9.64 2.89a.375.375 0 0 0-.53-.53L6 5.47 2.89 2.36a.375.375 0 0 0-.53.53L5.47 6 2.36 9.11a.375.375 0 0 0 .53.53L6 6.53l3.11 3.11a.375.375 0 0 0 .53-.53L6.53 6l3.11-3.11'/%3e%3c/svg%3e")`,
                "x": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.854 3.854a.5.5 0 0 0-.708-.708L8 7.293 3.854 3.146a.5.5 0 1 0-.708.708L7.293 8l-4.147 4.146a.5.5 0 0 0 .708.708L8 8.707l4.146 4.147a.5.5 0 0 0 .708-.708L8.707 8l4.147-4.146Z'/%3e%3c/svg%3e")`,
                "wrench-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.107 2.577 1.28 3.775A.75.75 0 0 0 1.815 4H3.25A.75.75 0 0 0 4 3.25V1.815a.75.75 0 0 0-.225-.536L2.577.107a3.429 3.429 0 0 1 4.099 4.426l4.885 4.885a1.5 1.5 0 0 1 .439 1.06v.022a1.5 1.5 0 0 1-1.5 1.5h-.021a1.5 1.5 0 0 1-1.061-.44L4.533 6.677A3.429 3.429 0 0 1 .107 2.577m9.158 6.158a.375.375 0 0 0-.53.53l.857.857a.375.375 0 1 0 .53-.53l-.857-.857' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wrench-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m1.13 3.986.72.721A1 1 0 0 0 2.557 5H4a1 1 0 0 0 1-1V2.557a1 1 0 0 0-.293-.707l-.72-.72a4 4 0 0 1 4.801 5.159l5.694 5.693a1.768 1.768 0 1 1-2.5 2.5L6.288 8.788A4 4 0 0 1 1.13 3.986m10.724 7.16a.5.5 0 0 0-.708.708l1 1a.5.5 0 0 0 .708-.708l-1-1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wrench-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m4.733 5.815 5.215 5.215c.14.141.332.22.53.22h.022a.75.75 0 0 0 .75-.75v-.021a.75.75 0 0 0-.22-.53L5.815 4.732l.15-.442A2.68 2.68 0 0 0 4.492.97a1.5 1.5 0 0 1 .258.842V3.25a1.5 1.5 0 0 1-1.5 1.5H1.81a1.5 1.5 0 0 1-.84-.258A2.68 2.68 0 0 0 4.29 5.965l.442-.15M.003 3.563A3.489 3.489 0 0 1 .1 2.601l1.18 1.18c.14.14.33.219.53.219h1.44A.75.75 0 0 0 4 3.25V1.81a.75.75 0 0 0-.22-.53L2.6.1a3.436 3.436 0 0 1 .962-.097 3.429 3.429 0 0 1 3.113 4.53l4.885 4.885a1.5 1.5 0 0 1 .439 1.06v.022a1.5 1.5 0 0 1-1.5 1.5h-.021a1.5 1.5 0 0 1-1.061-.44L4.533 6.677a3.429 3.429 0 0 1-4.53-3.112Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wrench": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.834 2.005A1 1 0 0 1 5 2.557V4a1 1 0 0 1-1 1H2.557a1 1 0 0 1-.707-.293l-.72-.72a4.006 4.006 0 0 0-.12 1.294 4 4 0 0 0 5.278 3.507l5.694 5.694a1.768 1.768 0 1 0 2.5-2.5L8.788 6.288A4 4 0 0 0 3.987 1.13l.72.72a1 1 0 0 1 .127.156m1.126.152a2 2 0 0 1 .04.4V4a2 2 0 0 1-2 2H2.557a2 2 0 0 1-.4-.04 3.001 3.001 0 0 0 3.81 1.881l.588-.2 6.134 6.134a.768.768 0 1 0 1.086-1.086L7.641 6.555l.2-.589a3.001 3.001 0 0 0-1.882-3.81' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wind-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 3a1.5 1.5 0 1 1 1.5 1.5H1.125a.375.375 0 1 1 0-.75H5.25A.75.75 0 1 0 4.5 3v.071a.375.375 0 0 1-.75 0zM7.5 4.5a1.875 1.875 0 0 1 3.75 0v.188c0 1.139-.923 2.062-2.062 2.062H1.124a.375.375 0 1 1 0-.75h8.063c.724 0 1.312-.588 1.312-1.312V4.5a1.125 1.125 0 0 0-2.25 0v.038a.375.375 0 1 1-.75 0zM.75 8.625c0-.207.168-.375.375-.375H6.75a1.5 1.5 0 1 1-1.5 1.5v-.093a.375.375 0 1 1 .75 0v.093A.75.75 0 1 0 6.75 9H1.125a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wind": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 4a2 2 0 1 1 2 2H1.5a.5.5 0 0 1 0-1H7a1 1 0 1 0-1-1v.095a.5.5 0 0 1-1 0zm5 2a2.5 2.5 0 0 1 5 0v.25A2.75 2.75 0 0 1 12.25 9H1.5a.5.5 0 0 1 0-1h10.75A1.75 1.75 0 0 0 14 6.25V6a1.5 1.5 0 0 0-3 0v.05a.5.5 0 0 1-1 0zm-9 5.5a.5.5 0 0 1 .5-.5H9a2 2 0 1 1-2 2v-.124a.5.5 0 1 1 1 0V13a1 1 0 1 0 1-1H1.5a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wifi-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' d='M1.203 1.047a.375.375 0 0 0-.53.53l1.365 1.366A7.912 7.912 0 0 0 .07 4.567l.548.513a7.155 7.155 0 0 1 1.969-1.587l1.119 1.12a5.642 5.642 0 0 0-1.993 1.494l.548.514a4.885 4.885 0 0 1 2.02-1.434L5.504 6.41A3.372 3.372 0 0 0 3.36 7.649l.549.515a2.62 2.62 0 0 1 2.321-1.03l3.068 3.069a.375.375 0 0 0 .53-.53L1.204 1.046ZM9.738 6.62a4.87 4.87 0 0 0-2.92-1.677L6 4.125c1.717 0 3.254.77 4.286 1.982l-.548.514M6 2.625c-.468 0-.926.045-1.369.131l-.626-.626A7.888 7.888 0 0 1 6 1.875a7.856 7.856 0 0 1 5.929 2.692l-.548.513A7.109 7.109 0 0 0 6 2.625'/%3e%3cpath fill='%230E1011' d='M7.263 8.94a1.499 1.499 0 0 0-2.526 0L6 10.126l1.263-1.184'/%3e%3c/svg%3e")`,
                "wifi-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' d='M1.603 1.396a.5.5 0 1 0-.707.708l1.82 1.82A10.55 10.55 0 0 0 .096 6.089l.73.684A9.54 9.54 0 0 1 3.45 4.658L4.942 6.15a7.523 7.523 0 0 0-2.657 1.993l.73.684a6.514 6.514 0 0 1 2.693-1.912l1.633 1.633a4.496 4.496 0 0 0-2.863 1.65l.733.687a3.494 3.494 0 0 1 3.095-1.372l4.09 4.09a.5.5 0 0 0 .707-.707l-11.5-11.5ZM12.984 8.827A6.493 6.493 0 0 0 9.09 6.591L8 5.5a7.484 7.484 0 0 1 5.714 2.643l-.73.684M8 3.5c-.624 0-1.234.06-1.825.175L5.34 2.84C6.19 2.618 7.08 2.5 8 2.5c3.152 0 5.98 1.39 7.905 3.589l-.73.684A9.478 9.478 0 0 0 8 3.5'/%3e%3cpath fill='%230E1011' d='M9.684 11.921a1.998 1.998 0 0 0-3.368 0L8 13.5l1.684-1.579'/%3e%3c/svg%3e")`,
                "wifi-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' d='M11.929 4.567a7.856 7.856 0 0 0-5.93-2.692A7.856 7.856 0 0 0 .072 4.567l.548.513a7.108 7.108 0 0 1 5.38-2.455c2.15 0 4.076.951 5.382 2.455l.548-.513'/%3e%3cpath fill='%230E1011' d='M10.286 6.107A5.613 5.613 0 0 0 6 4.125c-1.717 0-3.254.77-4.286 1.982l.548.514A4.865 4.865 0 0 1 6 4.875c1.501 0 2.844.678 3.738 1.746l.548-.514'/%3e%3cpath fill='%230E1011' d='M8.641 7.649A3.369 3.369 0 0 0 6 6.375c-1.07 0-2.023.498-2.641 1.274l.549.515A2.62 2.62 0 0 1 6 7.125a2.62 2.62 0 0 1 2.092 1.039l.55-.515'/%3e%3cpath fill='%230E1011' d='M7.263 8.94a1.499 1.499 0 0 0-2.526 0L6 10.126l1.263-1.184'/%3e%3c/svg%3e")`,
                "wifi-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='black' fill-rule='evenodd' d='M15.553 6.447a10 10 0 0 0-15.107 0l1.42 1.418a8 8 0 0 1 12.269 0l1.418-1.418m-2.84 2.84A5.99 5.99 0 0 0 8 7a5.99 5.99 0 0 0-4.713 2.287l1.429 1.429A3.995 3.995 0 0 1 8 9c1.36 0 2.561.679 3.284 1.716l1.43-1.43m-2.89 2.89a2 2 0 0 0-3.646 0L8 14l1.823-1.823' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wifi-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' d='M11.929 4.567a7.856 7.856 0 0 0-5.93-2.692A7.856 7.856 0 0 0 .072 4.567l.548.513a7.108 7.108 0 0 1 5.38-2.455c2.15 0 4.076.951 5.382 2.455l.548-.513'/%3e%3cpath fill='%230E1011' d='M10.286 6.107A5.613 5.613 0 0 0 6 4.125c-1.717 0-3.254.77-4.286 1.982l.548.514A4.865 4.865 0 0 1 6 4.875c1.501 0 2.844.678 3.738 1.746l.548-.514'/%3e%3cpath fill='%230E1011' d='M8.641 7.649A3.369 3.369 0 0 0 6 6.375c-1.07 0-2.023.498-2.641 1.274l.549.515A2.62 2.62 0 0 1 6 7.125a2.62 2.62 0 0 1 2.092 1.039l.55-.515'/%3e%3cpath fill='%230E1011' d='M7.263 8.94a1.499 1.499 0 0 0-2.526 0L6 10.126l1.263-1.184'/%3e%3c/svg%3e")`,
                "wifi": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' d='M15.905 6.089A10.475 10.475 0 0 0 8 2.5C4.847 2.5 2.02 3.89.095 6.089l.73.684A9.478 9.478 0 0 1 8 3.5a9.478 9.478 0 0 1 7.175 3.273l.73-.684'/%3e%3cpath fill='%230E1011' d='M13.715 8.143A7.484 7.484 0 0 0 8 5.5a7.483 7.483 0 0 0-5.715 2.643l.73.684A6.486 6.486 0 0 1 8 6.5c2.001 0 3.792.905 4.984 2.327l.73-.684'/%3e%3cpath fill='%230E1011' d='M11.522 10.198A4.492 4.492 0 0 0 8 8.5a4.492 4.492 0 0 0-3.522 1.698l.733.687A3.494 3.494 0 0 1 8 9.5c1.138 0 2.15.543 2.789 1.385l.733-.687'/%3e%3cpath fill='%230E1011' d='M9.684 11.921a1.998 1.998 0 0 0-3.368 0L8 13.5l1.684-1.579'/%3e%3c/svg%3e")`,
                "watch-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m4.037.966-.152 1.06A4.48 4.48 0 0 1 6 1.5c.764 0 1.484.19 2.115.527L7.963.966A1.125 1.125 0 0 0 6.85 0H5.15c-.56 0-1.034.412-1.113.966M7.963 11.034l.152-1.06A4.48 4.48 0 0 1 6 10.5a4.48 4.48 0 0 1-2.115-.527l.152 1.061c.079.554.554.966 1.113.966h1.7c.56 0 1.034-.412 1.113-.966'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2.25a3.75 3.75 0 1 1 0 7.5 3.75 3.75 0 0 1 0-7.5m-.265 3.485 1.5-1.5.53.53L6.53 6l.86.86-.53.53-1.125-1.125a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "watch-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.382 1.288 5.18 2.703C6.02 2.254 6.98 2 8 2c1.02 0 1.98.254 2.82.702l-.202-1.414A1.5 1.5 0 0 0 9.133 0H6.867a1.5 1.5 0 0 0-1.485 1.288M10.618 14.712l.202-1.415C9.98 13.747 9.02 14 8 14c-1.02 0-1.98-.254-2.82-.703l.202 1.415A1.5 1.5 0 0 0 6.867 16h2.266a1.5 1.5 0 0 0 1.485-1.288'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 3a5 5 0 1 1 0 10A5 5 0 0 1 8 3m-.354 4.646 2-2 .708.708L8.707 8l1.147 1.146-.708.708-1.5-1.5a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "watch-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m7.235 4.235-1.5 1.5a.375.375 0 0 0 0 .53L6.86 7.39l.53-.53L6.53 6l1.235-1.235-.53-.53'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 3c0-.018.001-.035.004-.053L4.037.966C4.116.412 4.59 0 5.15 0h1.7c.56 0 1.034.412 1.113.966l.283 1.981A.378.378 0 0 1 8.25 3c.91.684 1.5 1.773 1.5 3s-.59 2.316-1.5 3a.378.378 0 0 1-.004.053l-.283 1.981c-.079.554-.554.966-1.113.966h-1.7c-.56 0-1.034-.412-1.113-.966l-.283-1.981A.378.378 0 0 1 3.75 9a3.744 3.744 0 0 1-1.5-3c0-1.227.59-2.316 1.5-3m1.03-1.928A.375.375 0 0 1 5.15.75h1.7c.186 0 .344.137.37.322l.21 1.46A3.739 3.739 0 0 0 6 2.25c-.506 0-.989.1-1.43.282l.21-1.46M6 9.75c.506 0 .989-.1 1.43-.282l-.21 1.46a.375.375 0 0 1-.37.322h-1.7a.375.375 0 0 1-.37-.322l-.21-1.46c.441.182.924.282 1.43.282M3 6a3 3 0 1 1 6 0 3 3 0 0 1-6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "watch": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m9.646 5.646-2 2a.5.5 0 0 0 0 .708l1.5 1.5.708-.708L8.707 8l1.647-1.646-.708-.708'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 4c0-.024.002-.047.005-.07l.377-2.642A1.5 1.5 0 0 1 6.867 0h2.266a1.5 1.5 0 0 1 1.485 1.288l.377 2.641A.51.51 0 0 1 11 4c1.214.913 2 2.365 2 4.001a4.992 4.992 0 0 1-2 4 .509.509 0 0 1-.005.07l-.377 2.642A1.5 1.5 0 0 1 9.133 16H6.867a1.5 1.5 0 0 1-1.485-1.288l-.377-2.641A.502.502 0 0 1 5 12 4.992 4.992 0 0 1 3 8c0-1.636.786-3.088 2-4Zm1.372-2.57A.5.5 0 0 1 6.867 1h2.266a.5.5 0 0 1 .495.43l.278 1.946A4.985 4.985 0 0 0 8 3c-.675 0-1.318.134-1.906.376l.278-1.947M8 13c.675 0 1.318-.134 1.906-.376l-.278 1.947a.5.5 0 0 1-.495.429H6.867a.5.5 0 0 1-.495-.43l-.278-1.946A4.986 4.986 0 0 0 8 13M4 8a4 4 0 1 1 8 0 4 4 0 0 1-8 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet-send-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='13' fill='none' viewBox='0 0 13 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.75 2.875C9.75 1.839 8.91 1 7.875 1h-6C.839 1 0 1.84 0 2.875v5.25C0 9.161.84 10 1.875 10h2.759A1 1 0 0 1 5.5 8.5h3.586l-.293-.293a1 1 0 0 1 1.414-1.414l.293.293V4.375c0-.613-.295-1.158-.75-1.5M8.25 6.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0M1 3v-.25A.75.75 0 0 1 1.75 2h6a1 1 0 0 1 1 1zm8.765 4.235a.375.375 0 0 0-.53.53l1.36 1.36H5.5a.375.375 0 0 0 0 .75h5.095l-1.36 1.36a.375.375 0 0 0 .53.53l2-2 .265-.265-.265-.265-2-2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet-send-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13 4.5A2.5 2.5 0 0 0 10.5 2h-8A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h3.585A1.5 1.5 0 0 1 7.5 12h4.585A1.5 1.5 0 0 1 14 10.085V6.5c0-.818-.393-1.544-1-2M12 4H1.72c-.72 0-.332-.592.048-.845A.923.923 0 0 1 2.279 3h8.603a1 1 0 0 1 .895.553L12 4m-2 6a1 1 0 1 0 0-2 1 1 0 0 0 0 2' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13.854 11.146a.5.5 0 0 0-.708.708L14.293 13H7.5a.5.5 0 0 0 0 1h6.793l-1.147 1.146a.5.5 0 0 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2'/%3e%3c/svg%3e")`,
                "wallet-send-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='13' fill='none' viewBox='0 0 13 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.125 2.75c0-.025 0-.05.002-.074A1.486 1.486 0 0 1 1.61 1.125H8c1.036 0 1.875.84 1.875 1.875v.341c.595.315 1 .94 1 1.659v.5a.375.375 0 0 1-.75 0V5c0-.621-.504-1.125-1.125-1.125H1.389a1.26 1.26 0 0 1-.514-.109V9c0 .621.504 1.125 1.125 1.125h1.5a.375.375 0 0 1 0 .75H2A1.875 1.875 0 0 1 .125 9V2.75Zm1.625-.875H8c.621 0 1.125.504 1.125 1.125v.125H1.389a.514.514 0 0 1-.51-.454.875.875 0 0 1 .871-.796' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M7 7.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5M9.765 7.235a.375.375 0 0 0-.53.53l1.36 1.36H5.5a.375.375 0 0 0 0 .75h5.095l-1.36 1.36a.375.375 0 1 0 .53.53L12.03 9.5 9.765 7.235'/%3e%3c/svg%3e")`,
                "wallet-send": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.81 2a1.94 1.94 0 0 1 .087-.002l6.852-.01V2H10.5A2.5 2.5 0 0 1 13 4.5c.607.456 1 1.182 1 2v2a.5.5 0 0 1-1 0v-2A1.5 1.5 0 0 0 11.5 5H1.78c-.288 0-.555-.08-.78-.218V11.5A1.5 1.5 0 0 0 2.5 13h2a.5.5 0 0 1 0 1h-2A2.5 2.5 0 0 1 0 11.5V3.898a1.9 1.9 0 0 1 .939-1.64C1.18 2.095 1.472 2 1.78 2h.028m-.335 1.104A.5.5 0 0 0 1.781 4h10.134A1.5 1.5 0 0 0 10.5 3H1.838a.895.895 0 0 0-.363.104' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M11 9a1 1 0 1 1-2 0 1 1 0 0 1 2 0M15.854 13.146l-2-2a.5.5 0 0 0-.708.708L14.293 13H7.5a.5.5 0 0 0 0 1h6.793l-1.147 1.146a.5.5 0 0 0 .708.708l2-2a.5.5 0 0 0 0-.708'/%3e%3c/svg%3e")`,
                "wallet-receive-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.875 1C8.91 1 9.75 1.84 9.75 2.875c.455.342.75.887.75 1.5v3.75c0 .128-.013.254-.037.375H7.914l.293-.293a1 1 0 0 0-1.414-1.414l-2 2-.707.707.5.5H1.875A1.875 1.875 0 0 1 0 8.125v-5.25C0 1.839.84 1 1.875 1zM1 3v-.25A.75.75 0 0 1 1.75 2h6a1 1 0 0 1 1 1zm6.235 4.235a.375.375 0 0 1 .53.53l-1.36 1.36H11.5a.375.375 0 0 1 0 .75H6.405l1.36 1.36a.375.375 0 0 1-.53.53l-2-2L4.97 9.5l.265-.265 2-2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet-receive-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13 4.5A2.5 2.5 0 0 0 10.5 2h-8A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h3.318l-.44-.44L8.44 10.5a1.5 1.5 0 0 1 2.476 1.56h3.022c.041-.18.063-.367.063-.56v-5c0-.818-.393-1.544-1-2M12 4H2.024a.461.461 0 0 1-.256-.845A.923.923 0 0 1 2.279 3h8.603a1 1 0 0 1 .895.553L12 4m-2 5a1 1 0 1 0 0-2 1 1 0 0 0 0 2m-.854 2.146a.5.5 0 0 1 .708.708L8.707 13H15.5a.5.5 0 0 1 0 1H8.707l1.147 1.146a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet-receive-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.125 2.75c0-.025 0-.05.002-.074A1.486 1.486 0 0 1 1.61 1.125H8c1.036 0 1.875.84 1.875 1.875v.341c.595.315 1 .94 1 1.659v.5a.375.375 0 0 1-.75 0V5c0-.621-.504-1.125-1.125-1.125H1.389a1.26 1.26 0 0 1-.514-.109V9c0 .621.504 1.125 1.125 1.125h1.5a.375.375 0 0 1 0 .75H2A1.875 1.875 0 0 1 .125 9V2.75Zm1.625-.875a.875.875 0 0 0-.871.796c.03.256.246.454.51.454h7.736V3c0-.621-.504-1.125-1.125-1.125H1.75Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M7.235 7.235a.375.375 0 0 1 .53.53l-1.36 1.36H11.5a.375.375 0 0 1 0 .75H6.405l1.36 1.36a.375.375 0 1 1-.53.53L4.97 9.5l2.265-2.265'/%3e%3c/svg%3e")`,
                "wallet-receive": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m1.81 2 .087-.002 6.852-.01V2H10.5A2.5 2.5 0 0 1 13 4.5c.607.456 1 1.182 1 2v2a.5.5 0 0 1-1 0v-2A1.5 1.5 0 0 0 11.5 5H1.78c-.288 0-.555-.08-.78-.218V11.5A1.5 1.5 0 0 0 2.5 13h2a.5.5 0 0 1 0 1h-2A2.5 2.5 0 0 1 0 11.5V3.898a1.9 1.9 0 0 1 .939-1.64C1.18 2.095 1.472 2 1.78 2h.028m-.335 1.104A.5.5 0 0 0 1.781 4h10.134A1.5 1.5 0 0 0 10.5 3H1.838a.895.895 0 0 0-.363.104' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10 10a1 1 0 1 0 0-2 1 1 0 0 0 0 2M9.146 11.146a.5.5 0 0 1 .708.708L8.707 13H15.5a.5.5 0 0 1 0 1H8.707l1.147 1.146a.5.5 0 0 1-.708.708L6.793 13.5l2.353-2.354'/%3e%3c/svg%3e")`,
                "wallet-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1c-.189 0-.372.053-.534.15C.397 1.427 0 2.058 0 2.792v6.125C0 10.067.84 11 1.875 11h8.25C11.161 11 12 10.067 12 8.917V4.75c0-.682-.295-1.37-.75-1.75v-.208C11.25 1.756 10.495 1 9.563 1zm0 2h8.75a1 1 0 0 0-1-1H1.5a.5.5 0 0 0 0 1M9 7a1 1 0 1 1-2 0 1 1 0 0 1 2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.288 1.18A1.5 1.5 0 0 1 2 1h10.75A2.25 2.25 0 0 1 15 3.25v.25c.607.456 1 1.182 1 2v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 0 12.5V3.15c0-.88.53-1.638 1.288-1.97M2.15 2c-.148 0-.29.028-.42.079A.5.5 0 0 0 2 3h11.5c.165 0 .327.016.484.047A1.25 1.25 0 0 0 12.75 2H2.15ZM12 10a1 1 0 1 0 0-2 1 1 0 0 0 0 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9 8a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.766 1.125c-.324 0-.632.114-.875.315-.463.32-.766.855-.766 1.46V9c0 1.036.84 1.875 1.875 1.875h8.002a1.875 1.875 0 0 0 1.875-1.872l.001-.942.001-.028V5c0-.721-.407-1.347-1.004-1.661V3c0-1.036-.84-1.875-1.875-1.875H1.766m-.42.913c.16-.103.35-.163.554-.163H9c.621 0 1.125.504 1.125 1.125v.129a1.898 1.898 0 0 0-.12-.004H1.765a.625.625 0 0 1-.42-1.087m-.471 1.51V9c0 .621.504 1.125 1.125 1.125h8.002c.62 0 1.124-.503 1.125-1.123l.002-1.705V5c0-.621-.503-1.125-1.125-1.125H1.766c-.35 0-.657-.125-.891-.326' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "wallet": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 10a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 1a1.5 1.5 0 0 0-.712.18A2.15 2.15 0 0 0 0 3.15v9.35A2.5 2.5 0 0 0 2.5 15h11a2.5 2.5 0 0 0 2.5-2.5v-7c0-.818-.393-1.544-1-2v-.25A2.25 2.25 0 0 0 12.75 1zm-.27 1.079c.13-.051.272-.079.42-.079h10.6a1.25 1.25 0 0 1 1.234 1.047A2.514 2.514 0 0 0 13.5 3H2a.5.5 0 0 1-.27-.921M1 3.621V12.5A1.5 1.5 0 0 0 2.5 14h11a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 13.5 4H2c-.399 0-.742-.147-1-.38' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-x-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H1.5A1.5 1.5 0 0 1 0 6.75v-1.5a1.5 1.5 0 0 1 1.5-1.5h1.72l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.53 4.5H1.5a.75.75 0 0 0-.75.75v1.5c0 .414.336.75.75.75h2.03l1.72 1.72V2.78m2.36 1.08a.375.375 0 0 1 .53 0l1.61 1.61 1.61-1.61a.375.375 0 0 1 .53.53L10.28 6l1.61 1.61a.375.375 0 0 1-.53.53L9.75 6.53 8.14 8.14a.375.375 0 0 1-.53-.53L9.22 6 7.61 4.39a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 5.25a.75.75 0 0 1 .75-.75h2.03l1.72-1.72v6.44L3.53 7.5H1.5a.75.75 0 0 1-.75-.75v-1.5'/%3e%3c/svg%3e")`,
                "volume-x-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Zm3.146 1.438a.5.5 0 0 1 .708 0L13 7.293l2.146-2.147a.5.5 0 0 1 .708.708L13.707 8l2.147 2.146a.5.5 0 0 1-.708.708L13 8.707l-2.146 2.147a.5.5 0 0 1-.708-.707L12.293 8l-2.147-2.146a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 7a1 1 0 0 1 1-1h2.707L7 3.707v8.586L4.707 10H2a1 1 0 0 1-1-1V7'/%3e%3c/svg%3e")`,
                "volume-x-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H1.5A1.5 1.5 0 0 1 0 6.75v-1.5a1.5 1.5 0 0 1 1.5-1.5h1.72l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.53 4.5H1.5a.75.75 0 0 0-.75.75v1.5c0 .414.336.75.75.75h2.03l1.72 1.72V2.78m2.36 1.08a.375.375 0 0 1 .53 0l1.61 1.61 1.61-1.61a.375.375 0 0 1 .53.53L10.28 6l1.61 1.61a.375.375 0 0 1-.53.53L9.75 6.53 8.14 8.14a.375.375 0 0 1-.53-.53L9.22 6 7.61 4.39a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-x": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Zm3.146 1.438a.5.5 0 0 1 .708 0L13 7.293l2.146-2.147a.5.5 0 0 1 .708.708L13.707 8l2.147 2.146a.5.5 0 0 1-.708.708L13 8.707l-2.146 2.147a.5.5 0 0 1-.708-.707L12.293 8l-2.147-2.146a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H1.5A1.5 1.5 0 0 1 0 6.75v-1.5a1.5 1.5 0 0 1 1.5-1.5h1.72l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.53 4.5H1.5a.75.75 0 0 0-.75.75v1.5c0 .414.336.75.75.75h2.03l1.72 1.72V2.78' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 5.25a.75.75 0 0 1 .75-.75h2.03l1.72-1.72v6.44L3.53 7.5H1.5a.75.75 0 0 1-.75-.75v-1.5'/%3e%3c/svg%3e")`,
                "volume-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 7a1 1 0 0 1 1-1h2.707L7 3.707v8.586L4.707 10H2a1 1 0 0 1-1-1V7'/%3e%3c/svg%3e")`,
                "volume-2-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H.938A.937.937 0 0 1 0 7.313V4.688c0-.518.42-.938.938-.938H3.22l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.64 4.39a.375.375 0 0 1-.265.11H.938a.188.188 0 0 0-.188.188v2.625c0 .103.084.187.188.187h2.437c.1 0 .195.04.265.11l1.61 1.61V2.78m3.86 6.33a4.398 4.398 0 0 0 0-6.22l.53-.53a5.148 5.148 0 0 1 0 7.28l-.53-.53m-1.5-1.5c.889-.89.889-2.33 0-3.22l.53-.53a3.027 3.027 0 0 1 0 4.28l-.53-.53' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m3.64 4.39 1.61-1.61v6.44L3.64 7.61a.375.375 0 0 0-.265-.11H.938a.188.188 0 0 1-.188-.187V4.688c0-.104.084-.188.188-.188h2.437c.1 0 .195-.04.265-.11'/%3e%3c/svg%3e")`,
                "volume-2-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.294V3.707Zm5.146 8.439a5.864 5.864 0 0 0 0-8.293l.708-.708a6.864 6.864 0 0 1 0 9.708l-.708-.707m-2-2a3.035 3.035 0 0 0 0-4.293l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.854 5.854 7 3.707v8.586l-2.146-2.146A.5.5 0 0 0 4.5 10H1.25A.25.25 0 0 1 1 9.75v-3.5A.25.25 0 0 1 1.25 6H4.5a.5.5 0 0 0 .354-.146'/%3e%3c/svg%3e")`,
                "volume-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H.938A.937.937 0 0 1 0 7.313V4.688c0-.518.42-.938.938-.938H3.22l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.64 4.39a.375.375 0 0 1-.265.11H.938a.188.188 0 0 0-.188.188v2.625c0 .103.084.187.188.187h2.437c.1 0 .195.04.265.11l1.61 1.61V2.78m3.86 6.33a4.398 4.398 0 0 0 0-6.22l.53-.53a5.148 5.148 0 0 1 0 7.28l-.53-.53m-1.5-1.5c.889-.89.889-2.33 0-3.22l.53-.53a3.027 3.027 0 0 1 0 4.28l-.53-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.294V3.707Zm5.146 8.439a5.864 5.864 0 0 0 0-8.293l.708-.708a6.864 6.864 0 0 1 0 9.708l-.708-.707m-2-2a3.035 3.035 0 0 0 0-4.293l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-1-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H.938A.937.937 0 0 1 0 7.313V4.688c0-.518.42-.938.938-.938H3.22l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.64 4.39a.375.375 0 0 1-.265.11H.938a.188.188 0 0 0-.188.188v2.625c0 .103.084.187.188.187h2.437c.1 0 .195.04.265.11l1.61 1.61V2.78m2.36 4.83c.889-.89.889-2.33 0-3.22l.53-.53a3.027 3.027 0 0 1 0 4.28l-.53-.53' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m3.64 4.39 1.61-1.61v6.44L3.64 7.61a.375.375 0 0 0-.265-.11H.938a.188.188 0 0 1-.188-.187V4.688c0-.104.084-.188.188-.188h2.437c.1 0 .195-.04.265-.11'/%3e%3c/svg%3e")`,
                "volume-1-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.294V3.707Zm3.146 6.438a3.035 3.035 0 0 0 0-4.292l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.854 5.854 7 3.707v8.586l-2.146-2.146A.5.5 0 0 0 4.5 10H1.25A.25.25 0 0 1 1 9.75v-3.5A.25.25 0 0 1 1.25 6H4.5a.5.5 0 0 0 .354-.146'/%3e%3c/svg%3e")`,
                "volume-1-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H.938A.937.937 0 0 1 0 7.313V4.688c0-.518.42-.938.938-.938H3.22l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.64 4.39a.375.375 0 0 1-.265.11H.938a.188.188 0 0 0-.188.188v2.625c0 .103.084.187.188.187h2.437c.1 0 .195.04.265.11l1.61 1.61V2.78m2.36 4.83c.889-.89.889-2.33 0-3.22l.53-.53a3.027 3.027 0 0 1 0 4.28l-.53-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-1": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.294V3.707Zm3.146 6.438a3.035 3.035 0 0 0 0-4.292l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.769 1.529c.14.058.231.194.231.346v8.25a.375.375 0 0 1-.64.265L3.22 8.25H1.5A1.5 1.5 0 0 1 0 6.75v-1.5a1.5 1.5 0 0 1 1.5-1.5h1.72l2.14-2.14a.375.375 0 0 1 .409-.081M5.25 2.78 3.53 4.5H1.5a.75.75 0 0 0-.75.75v1.5c0 .414.336.75.75.75h2.03l1.72 1.72V2.78' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "volume": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108M7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "voicemail-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 5.5C0 4.12 1.175 3 2.625 3S5.25 4.12 5.25 5.5c0 .7-.302 1.332-.788 1.786h3.076A2.436 2.436 0 0 1 6.75 5.5C6.75 4.12 7.925 3 9.375 3S12 4.12 12 5.5 10.825 8 9.375 8c-.046 0-.091-.001-.136-.003A.397.397 0 0 1 9.187 8H2.814a.397.397 0 0 1-.052-.003c-.045.002-.09.003-.136.003C1.175 8 0 6.88 0 5.5m2.625-1.786C1.589 3.714.75 4.514.75 5.5s.84 1.786 1.875 1.786c1.036 0 1.875-.8 1.875-1.786s-.84-1.786-1.875-1.786M7.5 5.5c0-.986.84-1.786 1.875-1.786 1.036 0 1.875.8 1.875 1.786s-.84 1.786-1.875 1.786c-1.036 0-1.875-.8-1.875-1.786' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "voicemail": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 7.5A3.5 3.5 0 1 1 5.95 10h4.1a3.5 3.5 0 1 1 2.268.995.512.512 0 0 1-.068.005h-8.5a.513.513 0 0 1-.068-.005A3.5 3.5 0 0 1 0 7.5M3.5 5a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5M10 7.5a2.5 2.5 0 1 1 5 0 2.5 2.5 0 0 1-5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "video-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.828.297a.375.375 0 1 0-.53.53L1.72 2.25h-.032C.756 2.25 0 3.006 0 3.938v4.124C0 8.995.756 9.75 1.688 9.75h5.625c.521 0 .988-.237 1.298-.61l2.561 2.563a.375.375 0 0 0 .53-.53L.829.296ZM11.426 8.943l-.622-.389-1.429-1.429V4.339l2.051-1.282a.375.375 0 0 1 .574.318v5.25a.375.375 0 0 1-.574.318M9 3.938V6.75l-4.5-4.5h2.813C8.244 2.25 9 3.006 9 3.938'/%3e%3c/svg%3e")`,
                "video-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.104.396a.5.5 0 1 0-.708.708L2.293 3H2.25A2.25 2.25 0 0 0 0 5.25v5.5A2.25 2.25 0 0 0 2.25 13h7.5c.696 0 1.318-.316 1.73-.812l3.416 3.416a.5.5 0 0 0 .708-.708L1.104.396ZM15.235 11.924l-.83-.518L12.5 9.5V5.785l2.735-1.709A.5.5 0 0 1 16 4.5v7a.5.5 0 0 1-.765.424M12 5.25V9L6 3h3.75A2.25 2.25 0 0 1 12 5.25'/%3e%3c/svg%3e")`,
                "video-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.39.86a.375.375 0 0 0-.53.53l.86.86h-.032C.756 2.25 0 3.006 0 3.938v4.124C0 8.995.756 9.75 1.688 9.75h6.187a.375.375 0 1 0 0-.75H1.688a.937.937 0 0 1-.938-.937V3.936c0-.517.42-.937.938-.937h.782l8.14 8.14a.375.375 0 0 0 .53-.53L1.39.86ZM7.313 2.25H4.874a.375.375 0 1 0 0 .75h2.438c.517 0 .937.42.937.938V6a.375.375 0 0 0 .622.282l2.378-2.08v4.423a.375.375 0 0 0 .75 0v-5.25a.375.375 0 0 0-.622-.282L9 5.173V3.939c0-.932-.756-1.688-1.687-1.688'/%3e%3c/svg%3e")`,
                "video-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.854 1.146a.5.5 0 1 0-.708.708L2.293 3H2.25A2.25 2.25 0 0 0 0 5.25v5.5A2.25 2.25 0 0 0 2.25 13h8.25a.5.5 0 0 0 0-1H2.25C1.56 12 1 11.44 1 10.75v-5.5C1 4.56 1.56 4 2.25 4h1.043l10.853 10.854a.5.5 0 0 0 .708-.708l-13-13ZM9.75 3H6.5a.5.5 0 0 0 0 1h3.25c.69 0 1.25.56 1.25 1.25V8a.5.5 0 0 0 .83.376L15 5.602V11.5a.5.5 0 0 0 1 0v-7a.5.5 0 0 0-.83-.376L12 6.898V5.25A2.25 2.25 0 0 0 9.75 3'/%3e%3c/svg%3e")`,
                "video-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h5.625c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 7.313 3H1.688M0 3.938C0 3.006.756 2.25 1.688 2.25h5.625C8.244 2.25 9 3.006 9 3.938v4.124c0 .932-.756 1.688-1.687 1.688H1.688A1.688 1.688 0 0 1 0 8.063V3.936m11.807-.891c.119.066.193.192.193.328v5.25a.375.375 0 0 1-.574.318L9.375 7.661V4.339l2.051-1.282a.375.375 0 0 1 .38-.01m-1.682 1.708v2.49l1.125.703V4.052l-1.125.703' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.125 7.245v-2.49l1.125-.703v3.896l-1.125-.703M.75 3.938c0-.518.42-.938.938-.938h5.625c.517 0 .937.42.937.938v4.124c0 .518-.42.938-.937.938H1.688a.937.937 0 0 1-.938-.937V3.936'/%3e%3c/svg%3e")`,
                "video-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h7.5c.69 0 1.25-.56 1.25-1.25v-5.5C11 4.56 10.44 4 9.75 4zM0 5.25A2.25 2.25 0 0 1 2.25 3h7.5A2.25 2.25 0 0 1 12 5.25v5.5A2.25 2.25 0 0 1 9.75 13h-7.5A2.25 2.25 0 0 1 0 10.75zm15.742-1.187A.5.5 0 0 1 16 4.5v7a.5.5 0 0 1-.765.424l-2.735-1.71V5.786l2.735-1.709a.5.5 0 0 1 .507-.013M13.5 6.34v3.32l1.5.938V5.402l-1.5.938' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13.5 9.66V6.34l1.5-.938v5.196l-1.5-.938M1 5.25C1 4.56 1.56 4 2.25 4h7.5c.69 0 1.25.56 1.25 1.25v5.5c0 .69-.56 1.25-1.25 1.25h-7.5C1.56 12 1 11.44 1 10.75z'/%3e%3c/svg%3e")`,
                "video-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h5.625c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 7.313 3H1.688M0 3.938C0 3.006.756 2.25 1.688 2.25h5.625C8.244 2.25 9 3.006 9 3.938v.635l2.426-1.516a.375.375 0 0 1 .574.318v5.25a.375.375 0 0 1-.574.318L9 7.427v.636c0 .931-.756 1.687-1.687 1.687H1.688A1.688 1.688 0 0 1 0 8.063V3.936m9 2.604 2.25 1.406V4.052L9 5.458v1.084' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "video": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h7.5c.69 0 1.25-.56 1.25-1.25v-5.5C11 4.56 10.44 4 9.75 4zM0 5.25A2.25 2.25 0 0 1 2.25 3h7.5A2.25 2.25 0 0 1 12 5.25v.848l3.235-2.022A.5.5 0 0 1 16 4.5v7a.5.5 0 0 1-.765.424L12 9.902v.848A2.25 2.25 0 0 1 9.75 13h-7.5A2.25 2.25 0 0 1 0 10.75zm12 3.473 3 1.875V5.402l-3 1.875v1.446' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "users-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.5 7.125a2.625 2.625 0 1 0 0-5.25 2.625 2.625 0 0 0 0 5.25M.17 9.142l-.117.935A5.984 5.984 0 0 0 4.455 12a5.985 5.985 0 0 0 4.481-2.01l-.106-.848A1.875 1.875 0 0 0 6.97 7.5h-.595l-1.179.471a1.875 1.875 0 0 1-1.392 0L2.624 7.5H2.03c-.945 0-1.743.704-1.86 1.642M5.486.88a3.752 3.752 0 0 1 2.713 4.26A2.626 2.626 0 1 0 5.486.88M10.015 9.527a6.02 6.02 0 0 0 1.868-1.412l-.106-.848a1.875 1.875 0 0 0-1.86-1.642h-.595l-1.179.471a1.875 1.875 0 0 1-.29.09c-.047.095-.099.188-.154.278a3 3 0 0 1 2.25 2.539l.066.524'/%3e%3c/svg%3e")`,
                "users-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 9.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7M.226 12.19.07 13.436A7.979 7.979 0 0 0 5.94 16a7.98 7.98 0 0 0 5.975-2.68l-.141-1.13A2.5 2.5 0 0 0 9.293 10H8.5l-1.572.629a2.5 2.5 0 0 1-1.857 0L3.5 10h-.793a2.5 2.5 0 0 0-2.48 2.19ZM7.314 1.173a5.002 5.002 0 0 1 3.618 5.681A3.502 3.502 0 0 0 9.929 0C8.89 0 7.956.453 7.314 1.173M13.354 12.703a8.027 8.027 0 0 0 2.49-1.884l-.141-1.13a2.5 2.5 0 0 0-2.48-2.189h-.794l-1.571.629c-.126.05-.256.09-.386.119-.064.126-.133.25-.207.37a4.001 4.001 0 0 1 3.002 3.386l.087.699'/%3e%3c/svg%3e")`,
                "users-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1.875a2.625 2.625 0 1 0 0 5.25 2.625 2.625 0 0 0 0-5.25M2.625 4.5a1.875 1.875 0 1 1 3.75 0 1.875 1.875 0 0 1-3.75 0M2.03 7.5h.595l1.179.471c.447.18.945.18 1.392 0L6.375 7.5h.595c.945 0 1.743.704 1.86 1.642l.106.848A5.985 5.985 0 0 1 4.455 12c-1.74 0-3.306-.74-4.402-1.923l.117-.935A1.875 1.875 0 0 1 2.03 7.5m2.425 3.75A5.23 5.23 0 0 1 .842 9.81l.072-.575c.07-.563.549-.985 1.116-.985h.45l1.045.418c.626.25 1.324.25 1.95 0l1.044-.418h.45c.568 0 1.047.422 1.117.985l.062.496a5.231 5.231 0 0 1-3.693 1.519' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M6.743.787a1.969 1.969 0 1 1 1.32 3.708.281.281 0 1 0 .175.535A2.531 2.531 0 1 0 5.594.9a.281.281 0 0 0 .412.384c.205-.22.457-.39.737-.497M9.114 5.719l-1.126.41c-.159.057-.327.089-.496.094a.281.281 0 1 0 .016.562c.228-.006.456-.049.673-.128l1.032-.376h.495c.746 0 1.34.503 1.425 1.126l.078.567c-.44.426-.967.778-1.556 1.034a.281.281 0 1 0 .224.516 5.779 5.779 0 0 0 1.83-1.253l.097-.098-.116-.843c-.129-.94-.996-1.611-1.982-1.611h-.594'/%3e%3c/svg%3e")`,
                "users": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2.5a3.5 3.5 0 1 0 0 7 3.5 3.5 0 0 0 0-7M3.5 6a2.5 2.5 0 1 1 5 0 2.5 2.5 0 0 1-5 0M2.707 10H3.5l1.571.629a2.5 2.5 0 0 0 1.857 0L8.5 10h.793a2.5 2.5 0 0 1 2.48 2.19l.142 1.13A7.98 7.98 0 0 1 5.939 16 7.979 7.979 0 0 1 .07 13.436l.156-1.246A2.5 2.5 0 0 1 2.706 10m3.232 5a6.973 6.973 0 0 1-4.816-1.92l.095-.766A1.5 1.5 0 0 1 2.707 11h.6l1.393.557a3.5 3.5 0 0 0 2.6 0L8.692 11h.6a1.5 1.5 0 0 1 1.49 1.314l.082.66A6.975 6.975 0 0 1 5.939 15' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8.99 1.049a2.625 2.625 0 1 1 1.76 4.945.375.375 0 0 0 .234.712 3.375 3.375 0 1 0-3.525-5.505.375.375 0 1 0 .549.511c.273-.293.609-.52.983-.663M12.152 7.625l-1.5.546a2.11 2.11 0 0 1-.662.126.375.375 0 1 0 .021.75 2.86 2.86 0 0 0 .897-.17l1.376-.502h.66c.995 0 1.786.67 1.9 1.5l.104.757a6.98 6.98 0 0 1-2.075 1.378.375.375 0 0 0 .299.688 7.704 7.704 0 0 0 2.44-1.67l.13-.13-.155-1.124c-.172-1.254-1.328-2.149-2.643-2.149h-.792'/%3e%3c/svg%3e")`,
                "user-x-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0M6 6.75V12a5.992 5.992 0 0 1-4.89-2.522l.16-1.118a1.875 1.875 0 0 1 1.856-1.61zM7.765 7.235a.375.375 0 0 0-.53.53l1.61 1.61-1.61 1.61a.375.375 0 0 0 .53.53l1.61-1.61 1.61 1.61a.375.375 0 0 0 .53-.53l-1.61-1.61 1.61-1.61a.375.375 0 0 0-.53-.53l-1.61 1.61-1.61-1.61'/%3e%3c/svg%3e")`,
                "user-x-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0M8 9v7a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9zM10.354 9.646a.5.5 0 0 0-.708.708l2.147 2.146-2.147 2.146a.5.5 0 0 0 .708.708l2.146-2.147 2.146 2.147a.5.5 0 0 0 .708-.708L13.207 12.5l2.147-2.146a.5.5 0 0 0-.708-.708L12.5 11.793l-2.146-2.147'/%3e%3c/svg%3e")`,
                "user-x-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-.75 0a2.25 2.25 0 1 1-4.5 0 2.25 2.25 0 0 1 4.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M6 6.75v.75H3.126c-.56 0-1.034.412-1.113.966l-.116.81A5.239 5.239 0 0 0 6 11.25V12a5.992 5.992 0 0 1-4.89-2.522l.16-1.118a1.875 1.875 0 0 1 1.856-1.61zM7.765 7.235a.375.375 0 0 0-.53.53l1.61 1.61-1.61 1.61a.375.375 0 0 0 .53.53l1.61-1.61 1.61 1.61a.375.375 0 0 0 .53-.53l-1.61-1.61 1.61-1.61a.375.375 0 0 0-.53-.53l-1.61 1.61-1.61-1.61'/%3e%3c/svg%3e")`,
                "user-x": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0m-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 9v1H4.168a1.5 1.5 0 0 0-1.485 1.288l-.154 1.08A6.986 6.986 0 0 0 8 15v1a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9zM10.354 9.646a.5.5 0 0 0-.708.708l2.147 2.146-2.147 2.146a.5.5 0 0 0 .708.708l2.146-2.147 2.146 2.147a.5.5 0 0 0 .708-.708L13.207 12.5l2.147-2.146a.5.5 0 0 0-.708-.708L12.5 11.793l-2.146-2.147'/%3e%3c/svg%3e")`,
                "user-plus-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0M3.126 6.75c-.933 0-1.724.686-1.856 1.61l-.16 1.118a5.993 5.993 0 0 0 6.019 2.416A3.367 3.367 0 0 1 6 9.375c0-1.06.489-2.006 1.253-2.625H3.127Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.375a2.625 2.625 0 1 1-5.25 0 2.625 2.625 0 0 1 5.25 0M9.375 7.5c.207 0 .375.168.375.375V9h1.125a.375.375 0 0 1 0 .75H9.75v1.313a.375.375 0 0 1-.75 0V9.75H7.875a.375.375 0 1 1 0-.75H9V7.875c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-plus-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0M4.168 9a2.5 2.5 0 0 0-2.475 2.146l-.213 1.491A7.99 7.99 0 0 0 8 16a8.05 8.05 0 0 0 1.505-.141A4.49 4.49 0 0 1 8 12.5c0-1.414.652-2.675 1.671-3.5H4.168'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-plus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-.75 0a2.25 2.25 0 1 1-4.5 0 2.25 2.25 0 0 1 4.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M6 11.25a5.24 5.24 0 0 1-4.103-1.974l.116-.81c.079-.554.553-.966 1.113-.966h3.442c.19-.283.421-.536.686-.75H3.125c-.933 0-1.724.686-1.856 1.61l-.16 1.118a5.993 5.993 0 0 0 6.019 2.416 3.394 3.394 0 0 1-.58-.672c-.18.018-.363.028-.549.028'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.375a2.625 2.625 0 1 1-5.25 0 2.625 2.625 0 0 1 5.25 0M9.375 7.5c.207 0 .375.168.375.375V9h1.125a.375.375 0 0 1 0 .75H9.75v1.313a.375.375 0 0 1-.75 0V9.75H7.875a.375.375 0 1 1 0-.75H9V7.875c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-plus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0m-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 15a6.986 6.986 0 0 1-5.47-2.633l.153-1.08A1.5 1.5 0 0 1 4.168 10h4.59c.253-.378.561-.715.913-1H4.168a2.5 2.5 0 0 0-2.475 2.146l-.213 1.491A7.99 7.99 0 0 0 8 16a8.05 8.05 0 0 0 1.505-.141 4.522 4.522 0 0 1-.772-.897C8.492 14.987 8.247 15 8 15'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0M3.126 6.75h.999l1.036.518c.528.264 1.15.264 1.678 0l1.036-.518h.999c.933 0 1.724.686 1.856 1.61l.16 1.118A5.993 5.993 0 0 1 6 12a5.993 5.993 0 0 1-4.89-2.522l.16-1.118a1.875 1.875 0 0 1 1.856-1.61Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0M4.168 9H5.5l1.382.691a2.5 2.5 0 0 0 2.236 0L10.5 9h1.332a2.5 2.5 0 0 1 2.475 2.146l.213 1.491A7.99 7.99 0 0 1 8 16a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m2.641-7.625a2.625 2.625 0 1 1-5.25 0 2.625 2.625 0 0 1 5.25 0m-6.784 4.83.02-.14a1.64 1.64 0 0 1 1.624-1.409h.874l.907.454a1.64 1.64 0 0 0 1.468 0l.906-.454h.874c.817 0 1.51.6 1.625 1.409l.02.14a5.241 5.241 0 0 1-4.16 2.045 5.241 5.241 0 0 1-4.158-2.045' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M8 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6m-.005 5.3c1.937 0 3.67-.875 4.825-2.25l-.088-.442A2 2 0 0 0 10.77 10h-.534a1.5 1.5 0 0 0-.67.159l-.448.223a2.5 2.5 0 0 1-2.236 0l-.447-.223A1.5 1.5 0 0 0 5.764 10H5.23a2 2 0 0 0-1.961 1.608l-.09.452a6.286 6.286 0 0 0 4.816 2.24Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.016 7a2.625 2.625 0 1 0 0-5.25 2.625 2.625 0 0 0 0 5.25m1.875-2.625a1.875 1.875 0 1 1-3.75 0 1.875 1.875 0 0 1 3.75 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.313 10.171A6 6 0 1 0 1.687 1.83a6 6 0 0 0 8.626 8.342M6.068 11.25H6c-1.339 0-2.56-.5-3.488-1.326l.108-.753a.89.89 0 0 1 .882-.765h.696l.749.375a2.39 2.39 0 0 0 2.138 0l.749-.375h.697a.89.89 0 0 1 .881.765l.104.727a5.23 5.23 0 0 1-3.448 1.352m4.104-2.063-.017-.122A1.64 1.64 0 0 0 8.53 7.656h-.874l-.907.454a1.64 1.64 0 0 1-1.468 0l-.907-.454h-.873c-.817 0-1.51.6-1.625 1.409l-.022.157a5.25 5.25 0 1 1 8.317-.035' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-3.326 4.889a6.273 6.273 0 0 1-3.973 1.41 6.273 6.273 0 0 1-3.964-1.403l.218-1.092A1 1 0 0 1 5.23 11h.535a.5.5 0 0 1 .224.053l.447.223a3.5 3.5 0 0 0 3.13 0l.447-.223a.5.5 0 0 1 .224-.053h.534a1 1 0 0 1 .98.804l.218 1.085m.852-.839-.088-.442A2 2 0 0 0 10.77 10h-.534a1.5 1.5 0 0 0-.67.159l-.448.223a2.5 2.5 0 0 1-2.236 0l-.447-.223A1.5 1.5 0 0 0 5.764 10H5.23a2 2 0 0 0-1.961 1.608l-.09.452a6.3 6.3 0 1 1 9.642-.01' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user-check-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0M6 6.75V12a5.992 5.992 0 0 1-4.89-2.522l.16-1.118a1.875 1.875 0 0 1 1.856-1.61zM11.89 8.89a.375.375 0 0 0-.53-.53l-2.735 2.735L7.39 9.86a.375.375 0 1 0-.53.53l1.5 1.5a.375.375 0 0 0 .53 0l3-3'/%3e%3c/svg%3e")`,
                "user-check-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0M8 9v7a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9zM15.854 11.854a.5.5 0 0 0-.708-.708L11.5 14.793l-1.646-1.647a.5.5 0 0 0-.708.708l2 2a.5.5 0 0 0 .708 0l4-4'/%3e%3c/svg%3e")`,
                "user-check-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-.75 0a2.25 2.25 0 1 1-4.5 0 2.25 2.25 0 0 1 4.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M6 6.75v.75H3.126c-.56 0-1.034.412-1.113.966l-.116.81A5.239 5.239 0 0 0 6 11.25V12a5.992 5.992 0 0 1-4.89-2.522l.16-1.118a1.875 1.875 0 0 1 1.856-1.61zM11.89 8.89a.375.375 0 0 0-.53-.53l-2.735 2.735L7.39 9.86a.375.375 0 1 0-.53.53l1.5 1.5a.375.375 0 0 0 .53 0l3-3'/%3e%3c/svg%3e")`,
                "user-check": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0m-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 9v1H4.168a1.5 1.5 0 0 0-1.485 1.288l-.154 1.08A6.986 6.986 0 0 0 8 15v1a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9zM15.854 11.854a.5.5 0 0 0-.708-.708L11.5 14.793l-1.646-1.647a.5.5 0 0 0-.708.708l2 2a.5.5 0 0 0 .708 0l4-4'/%3e%3c/svg%3e")`,
                "user-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-.75 0a2.25 2.25 0 1 1-4.5 0 2.25 2.25 0 0 1 4.5 0M3.126 6.75h.999l1.036.518c.528.264 1.15.264 1.678 0l1.036-.518h.999c.933 0 1.724.686 1.856 1.61l.16 1.118A5.993 5.993 0 0 1 6 12a5.993 5.993 0 0 1-4.89-2.522l.16-1.118a1.875 1.875 0 0 1 1.856-1.61M6 11.25a5.24 5.24 0 0 1-4.103-1.974l.116-.81c.079-.554.553-.966 1.113-.966h.822l.878.44c.74.369 1.609.369 2.348 0l.878-.44h.822c.56 0 1.034.412 1.114.966l.115.81A5.239 5.239 0 0 1 6 11.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "user": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0m-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0M4.168 9H5.5l1.382.691a2.5 2.5 0 0 0 2.236 0L10.5 9h1.332a2.5 2.5 0 0 1 2.475 2.146l.213 1.491A7.99 7.99 0 0 1 8 16a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9M8 15a6.986 6.986 0 0 1-5.47-2.633l.153-1.08A1.5 1.5 0 0 1 4.168 10h1.096l1.17.585a3.5 3.5 0 0 0 3.131 0L10.736 10h1.096a1.5 1.5 0 0 1 1.485 1.288l.154 1.08A6.986 6.986 0 0 1 8 15' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "upload-cloud-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.75 6a3.75 3.75 0 0 1 7.372-.977l.09.34.345-.07a2.25 2.25 0 0 1 1.728 4.053.375.375 0 1 0 .43.616A3 3 0 0 0 8.747 4.51 4.502 4.502 0 0 0 0 6c0 1.58.815 2.97 2.045 3.772a.375.375 0 0 0 .41-.628A3.746 3.746 0 0 1 .75 6'/%3e%3cpath fill='%230E1011' d='M6.75 7.28v4.345a.375.375 0 0 1-.75 0V7.28L4.39 8.89a.375.375 0 1 1-.53-.53l2.515-2.515L8.89 8.36a.375.375 0 0 1-.53.53L6.75 7.28'/%3e%3c/svg%3e")`,
                "upload-cloud": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 2.305 5.405.5.5 0 1 0 .571.82 4 4 0 0 0-2.623-7.269A6.002 6.002 0 0 0 0 8a5.996 5.996 0 0 0 2.727 5.03.5.5 0 0 0 .546-.838A4.995 4.995 0 0 1 1 8'/%3e%3cpath fill='%230E1011' d='M9 9.707V15.5a.5.5 0 0 1-1 0V9.707l-2.146 2.147a.5.5 0 0 1-.708-.708L8.5 7.793l3.354 3.353a.5.5 0 0 1-.708.708L9 9.707'/%3e%3c/svg%3e")`,
                "upload-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.375 2.186V8.78a.375.375 0 1 1-.75 0V2.186l-1.61 1.61a.375.375 0 1 1-.53-.53L6 .75l2.515 2.515a.375.375 0 0 1-.53.53l-1.61-1.61'/%3e%3cpath fill='%230E1011' d='M1.75 7.875a.375.375 0 1 0-.75 0v2.188c0 .517.42.937.938.937h8.124c.518 0 .938-.42.938-.937V7.624a.375.375 0 0 0-.75 0v2.438a.187.187 0 0 1-.187.187H1.937a.187.187 0 0 1-.187-.187z'/%3e%3c/svg%3e")`,
                "upload": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.5 2.914v8.793a.5.5 0 0 1-1 0V2.914L5.354 5.061a.5.5 0 1 1-.708-.707L8 1l3.354 3.354a.5.5 0 0 1-.708.707L8.5 2.914'/%3e%3cpath fill='%230E1011' d='M2 10.5a.5.5 0 0 0-1 0v3.25c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25V10.5a.5.5 0 0 0-1 0v3.25a.25.25 0 0 1-.25.25H2.25a.25.25 0 0 1-.25-.25z'/%3e%3c/svg%3e")`,
                "unlock-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 .875A2.125 2.125 0 0 0 3.875 3v2H9.5A1.5 1.5 0 0 1 11 6.5v4A1.5 1.5 0 0 1 9.5 12h-6A1.5 1.5 0 0 1 2 10.5v-4a1.5 1.5 0 0 1 1.125-1.453V3A2.875 2.875 0 0 1 6 .125h1A2.875 2.875 0 0 1 9.875 3v.5a.375.375 0 1 1-.75 0V3A2.125 2.125 0 0 0 7 .875zM6.5 9.5a1 1 0 1 0 0-2 1 1 0 0 0 0 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "unlock-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H5V4a3 3 0 0 1 6 0v.25a.5.5 0 0 0 1 0V4a4 4 0 0 0-4-4M7 10.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "unlock-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.5 8.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.875 3C3.875 1.826 4.826.875 6 .875h1c1.174 0 2.125.951 2.125 2.125v.5a.375.375 0 1 0 .75 0V3A2.875 2.875 0 0 0 7 .125H6A2.875 2.875 0 0 0 3.125 3v2.047A1.5 1.5 0 0 0 2 6.5v4A1.5 1.5 0 0 0 3.5 12h6a1.5 1.5 0 0 0 1.5-1.5v-4A1.5 1.5 0 0 0 9.5 5H3.875zM2.75 6.5v4c0 .414.336.75.75.75h6a.75.75 0 0 0 .75-.75v-4a.75.75 0 0 0-.75-.75h-6a.75.75 0 0 0-.75.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "unlock": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 10.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H5V4a3 3 0 0 1 6 0v.25a.5.5 0 0 0 1 0V4a4 4 0 0 0-4-4M4 7a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "underline-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2 1.125a.375.375 0 1 0 0 .75h.125V6a3.875 3.875 0 0 0 7.75 0V1.875H10a.375.375 0 0 0 0-.75H9a.375.375 0 1 0 0 .75h.125V6a3.125 3.125 0 1 1-6.25 0V1.875H3a.375.375 0 1 0 0-.75zM2 11.125a.375.375 0 0 0 0 .75h8a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "underline": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.71 7.5a2.344 2.344 0 0 1-2.344 2.344H7.241a.281.281 0 0 0 0 .562h1.125a2.906 2.906 0 0 0 0-5.812H1.9l2.054-2.15a.281.281 0 1 0-.406-.388L.852 4.875l2.695 2.82a.281.281 0 0 0 .406-.39L1.9 5.157h6.467A2.344 2.344 0 0 1 10.71 7.5'/%3e%3c/svg%3e")`,
                "underline": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.25 2a.5.5 0 0 0 0 1h.25v5.5a4.5 4.5 0 1 0 9 0V3h.25a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 0 0 1h.25v5.5a3.5 3.5 0 1 1-7 0V3h.25a.5.5 0 0 0 0-1zM3.5 14a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "underline": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M14.28 10c0 1.726-1.399 3.125-3.125 3.125h-1.5a.375.375 0 0 0 0 .75h1.5a3.875 3.875 0 0 0 0-7.75H2.532l2.74-2.866a.375.375 0 1 0-.543-.518L1.137 6.5l3.592 3.76a.375.375 0 0 0 .542-.52L2.532 6.876h8.623c1.726 0 3.125 1.4 3.125 3.125'/%3e%3c/svg%3e")`,
                "umbrella-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.425 6.75H6v2.625a1.125 1.125 0 0 0 2.25 0v-.187a.375.375 0 1 1 .75 0v.187a1.875 1.875 0 0 1-3.75 0V6.75H.575a.375.375 0 0 1-.374-.35 5.812 5.812 0 1 1 11.598 0 .375.375 0 0 1-.374.35M3.078 3.088A4.111 4.111 0 0 1 6 1.875a.375.375 0 1 0 0-.75c-1.35 0-2.57.549-3.453 1.434a.375.375 0 1 0 .531.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "umbrella-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.233 9H8v3.5a1.5 1.5 0 0 0 3 0v-.25a.5.5 0 0 1 1 0v.25a2.5 2.5 0 0 1-5 0V9H.767a.5.5 0 0 1-.499-.466 7.75 7.75 0 1 1 15.464 0 .5.5 0 0 1-.499.466M4.104 4.118A5.481 5.481 0 0 1 8 2.5a.5.5 0 0 0 0-1 6.481 6.481 0 0 0-4.604 1.912.5.5 0 1 0 .708.706' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "umbrella-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.387 3.397a4.205 4.205 0 0 1 2.988-1.24.281.281 0 0 0 0-.563A4.767 4.767 0 0 0 2.988 3a.281.281 0 0 0 .399.397'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.425 6.75H6v2.625a1.125 1.125 0 0 0 2.25 0v-.187a.375.375 0 1 1 .75 0v.187a1.875 1.875 0 0 1-3.75 0V6.75H.575a.375.375 0 0 1-.374-.35 5.812 5.812 0 1 1 11.598 0 .375.375 0 0 1-.374.35M6 .938A5.063 5.063 0 0 0 .938 6h10.125A5.063 5.063 0 0 0 6 .938' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "umbrella": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.516 4.53A5.606 5.606 0 0 1 8.5 2.874a.375.375 0 1 0 0-.75A6.356 6.356 0 0 0 3.984 4a.375.375 0 1 0 .532.53'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.233 9H8v3.5a1.5 1.5 0 0 0 3 0v-.25a.5.5 0 0 1 1 0v.25a2.5 2.5 0 0 1-5 0V9H.767a.5.5 0 0 1-.499-.466 7.75 7.75 0 1 1 15.464 0 .5.5 0 0 1-.499.466M8 1.25A6.75 6.75 0 0 0 1.25 8h13.5A6.75 6.75 0 0 0 8 1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "type-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.625 2.25v1.125a.375.375 0 1 1-.75 0V2.063c0-.311.252-.563.563-.563h7.124c.311 0 .563.252.563.563v1.312a.375.375 0 1 1-.75 0V2.25h-3v7.5h.75a.375.375 0 1 1 0 .75h-2.25a.375.375 0 0 1 0-.75h.75v-7.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "type": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 3v1.5a.5.5 0 0 1-1 0V2.75A.75.75 0 0 1 3.25 2h9.5a.75.75 0 0 1 .75.75V4.5a.5.5 0 0 1-1 0V3h-4v10h1a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1h1V3z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "twitter-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.182 1.272a2.615 2.615 0 0 1 2.73.544 5.075 5.075 0 0 0 1.247-.642.375.375 0 0 1 .58.395 4.234 4.234 0 0 1-1.006 1.874c.011.095.017.19.017.286v.001c0 3.006-1.445 5.2-3.511 6.3-2.057 1.095-4.692 1.085-7.046-.222a.375.375 0 0 1 .197-.703 5.445 5.445 0 0 0 2.706-.598c-.841-.478-1.43-1.059-1.827-1.686-.488-.77-.673-1.587-.706-2.324-.034-.736.083-1.4.207-1.877a6.417 6.417 0 0 1 .254-.774l.006-.012.001-.004.001-.001.343.151-.343-.151a.377.377 0 0 1 .65-.065A4.955 4.955 0 0 0 5.5 3.866v-.119a2.615 2.615 0 0 1 1.682-2.475M1.512 2.75l-.016.058a5.677 5.677 0 0 0-.184 1.655c.03.638.188 1.32.59 1.957.402.634 1.06 1.244 2.125 1.717a.375.375 0 0 1 .059.653 6.195 6.195 0 0 1-2.212.938c1.76.574 3.56.412 5.012-.36C8.695 8.405 10 6.474 10 3.73c0-.116-.012-.232-.033-.346a.375.375 0 0 1 .105-.337c.216-.213.402-.452.554-.71-.231.104-.47.193-.713.266a.375.375 0 0 1-.39-.113A1.865 1.865 0 0 0 6.25 3.74v.505c0 .203-.162.37-.365.375A5.705 5.705 0 0 1 1.51 2.75Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m1.496 2.808.015-.058a5.705 5.705 0 0 0 4.374 1.87.375.375 0 0 0 .365-.375V3.74a1.865 1.865 0 0 1 3.272-1.249c.097.111.25.156.391.113.244-.073.482-.162.713-.267a3.484 3.484 0 0 1-.554.711.375.375 0 0 0-.105.337c.021.114.033.23.033.346 0 2.743-1.305 4.674-3.114 5.637-1.451.772-3.252.934-5.012.36a6.195 6.195 0 0 0 2.212-.938.375.375 0 0 0-.059-.653C2.962 7.664 2.304 7.054 1.903 6.42c-.403-.636-.562-1.32-.59-1.957-.03-.64.072-1.226.183-1.655'/%3e%3c/svg%3e")`,
                "twitter-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.576 2.23a3.486 3.486 0 0 1 3.64.724 6.768 6.768 0 0 0 1.663-.856.5.5 0 0 1 .774.527 5.648 5.648 0 0 1-1.342 2.498 3.5 3.5 0 0 1 .022.382v.002c0 4.008-1.926 6.933-4.681 8.4-2.743 1.46-6.257 1.447-9.395-.297a.5.5 0 0 1 .263-.936 7.26 7.26 0 0 0 3.608-.798c-1.122-.637-1.906-1.412-2.436-2.248C1.042 8.602.795 7.512.751 6.53a8.568 8.568 0 0 1 .275-2.502 8.558 8.558 0 0 1 .315-.973 3.72 3.72 0 0 1 .025-.059l.007-.017.002-.005v-.002l.458.202-.457-.203a.5.5 0 0 1 .867-.084 6.607 6.607 0 0 0 5.09 2.802V5.53a3.487 3.487 0 0 1 2.243-3.3M2.016 4.2a7.57 7.57 0 0 0-.266 2.284c.038.85.25 1.761.787 2.61.535.844 1.413 1.658 2.833 2.29a.5.5 0 0 1 .077.87 8.26 8.26 0 0 1-2.948 1.25c2.346.765 4.747.55 6.683-.48 2.411-1.284 4.151-3.859 4.151-7.516 0-.155-.015-.309-.044-.46a.5.5 0 0 1 .14-.45c.288-.284.536-.603.74-.948a7.765 7.765 0 0 1-.952.355.5.5 0 0 1-.521-.15A2.486 2.486 0 0 0 8.333 5.52v.673a.5.5 0 0 1-.487.5A7.607 7.607 0 0 1 2.016 4.2' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m1.994 4.278.021-.078a7.607 7.607 0 0 0 5.831 2.493.5.5 0 0 0 .487-.5V5.52a2.487 2.487 0 0 1 4.363-1.665.5.5 0 0 0 .521.15c.325-.097.643-.216.951-.355a4.645 4.645 0 0 1-.74.947.5.5 0 0 0-.14.45c.03.152.045.306.045.46 0 3.658-1.74 6.233-4.151 7.517-1.936 1.03-4.337 1.245-6.683.48a8.26 8.26 0 0 0 2.948-1.25.5.5 0 0 0-.077-.87c-1.42-.632-2.298-1.446-2.833-2.29-.537-.849-.749-1.76-.788-2.61a7.57 7.57 0 0 1 .245-2.206'/%3e%3c/svg%3e")`,
                "twitter-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.182 1.272a2.615 2.615 0 0 1 2.73.544 5.075 5.075 0 0 0 1.247-.642.375.375 0 0 1 .58.395 4.234 4.234 0 0 1-1.006 1.874c.011.095.017.19.017.286v.001c0 3.006-1.445 5.2-3.511 6.3-2.057 1.095-4.692 1.085-7.046-.222a.375.375 0 0 1 .197-.703 5.445 5.445 0 0 0 2.706-.598c-.841-.478-1.43-1.059-1.827-1.686-.488-.77-.673-1.587-.706-2.324-.034-.736.083-1.4.207-1.877a6.417 6.417 0 0 1 .254-.774l.006-.012.001-.004.001-.001.343.151-.343-.151a.377.377 0 0 1 .65-.065A4.955 4.955 0 0 0 5.5 3.866v-.119a2.615 2.615 0 0 1 1.682-2.475M1.512 2.75l-.016.058a5.677 5.677 0 0 0-.184 1.655c.03.638.188 1.32.59 1.957.402.634 1.06 1.244 2.125 1.717a.375.375 0 0 1 .059.653 6.195 6.195 0 0 1-2.212.938c1.76.574 3.56.412 5.012-.36C8.695 8.405 10 6.474 10 3.73c0-.116-.012-.232-.033-.346a.375.375 0 0 1 .105-.337c.216-.213.402-.452.554-.71-.231.104-.47.193-.713.266a.375.375 0 0 1-.39-.113A1.865 1.865 0 0 0 6.25 3.74v.505c0 .203-.162.37-.365.375A5.705 5.705 0 0 1 1.51 2.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "twitter": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.576 2.23a3.486 3.486 0 0 1 3.64.724 6.768 6.768 0 0 0 1.663-.856.5.5 0 0 1 .774.527 5.648 5.648 0 0 1-1.342 2.498 3.5 3.5 0 0 1 .022.382v.002c0 4.008-1.926 6.933-4.681 8.4-2.743 1.46-6.257 1.447-9.395-.297a.5.5 0 0 1 .263-.936 7.26 7.26 0 0 0 3.608-.798c-1.122-.637-1.906-1.412-2.436-2.248C1.042 8.602.795 7.512.751 6.53a8.568 8.568 0 0 1 .275-2.502 8.558 8.558 0 0 1 .315-.973 3.72 3.72 0 0 1 .025-.059l.007-.017.002-.005v-.002l.458.202-.457-.203a.5.5 0 0 1 .867-.084 6.607 6.607 0 0 0 5.09 2.802V5.53a3.487 3.487 0 0 1 2.243-3.3M2.016 4.2a7.57 7.57 0 0 0-.266 2.284c.038.85.25 1.761.787 2.61.535.844 1.413 1.658 2.833 2.29a.5.5 0 0 1 .077.87 8.26 8.26 0 0 1-2.948 1.25c2.346.765 4.747.55 6.683-.48 2.411-1.284 4.151-3.859 4.151-7.516 0-.155-.015-.309-.044-.46a.5.5 0 0 1 .14-.45c.288-.284.536-.603.74-.948a7.765 7.765 0 0 1-.952.355.5.5 0 0 1-.521-.15A2.486 2.486 0 0 0 8.333 5.52v.673a.5.5 0 0 1-.487.5A7.607 7.607 0 0 1 2.016 4.2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tv-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.235.235a.375.375 0 0 1 .53 0l1.5 1.5c.073.073.11.169.11.265h1.25c0-.096.037-.192.11-.265l1.5-1.5a.375.375 0 0 1 .53.53L7.53 2H10a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h2.47L3.235.765a.375.375 0 0 1 0-.53ZM2.75 5.5a.75.75 0 0 1 .75-.75h1a.25.25 0 0 0 0-.5h-1c-.69 0-1.25.56-1.25 1.25v1a.25.25 0 0 0 .5 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tv-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.884.18a.5.5 0 1 0-.768.64L6.932 3H2.25A2.25 2.25 0 0 0 0 5.25v6.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-6.5A2.25 2.25 0 0 0 13.75 3H9.068L10.884.82a.5.5 0 0 0-.768-.64L8 2.719 5.884.179ZM2.625 6.25c0-.345.28-.625.625-.625h1a.375.375 0 1 0 0-.75h-1c-.76 0-1.375.616-1.375 1.375v1a.375.375 0 1 0 .75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tv-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.75 5.5a.75.75 0 0 1 .75-.75h1a.25.25 0 0 0 0-.5h-1c-.69 0-1.25.56-1.25 1.25v1a.25.25 0 0 0 .5 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.235.235a.375.375 0 0 1 .53 0l1.5 1.5c.073.073.11.169.11.265h1.25c0-.096.037-.192.11-.265l1.5-1.5a.375.375 0 0 1 .53.53L7.53 2H10a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h2.47L3.235.765a.375.375 0 0 1 0-.53ZM10 2.75H2C1.31 2.75.75 3.31.75 4v5c0 .69.56 1.25 1.25 1.25h8c.69 0 1.25-.56 1.25-1.25V4c0-.69-.56-1.25-1.25-1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tv": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.625 6.25c0-.345.28-.625.625-.625h1a.375.375 0 1 0 0-.75h-1c-.76 0-1.375.616-1.375 1.375v1a.375.375 0 1 0 .75 0v-1'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.884.18a.5.5 0 1 0-.768.64L6.932 3H2.25A2.25 2.25 0 0 0 0 5.25v6.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-6.5A2.25 2.25 0 0 0 13.75 3H9.068L10.884.82a.5.5 0 0 0-.768-.64L8 2.719 5.884.179ZM1 5.25C1 4.56 1.56 4 2.25 4h11.5c.69 0 1.25.56 1.25 1.25v6.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 13 1 12.44 1 11.75v-6.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "truck-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 7.5V2a1 1 0 0 1 1-1h5.5a1 1 0 0 1 1 1v6.5H1a1 1 0 0 1-1-1m1-5.25a.25.25 0 0 0 0 .5h2.5a.25.25 0 0 0 0-.5zm3.5 0a.25.25 0 0 0 0 .5h1a.25.25 0 0 0 0-.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 4v4.5h4V6a2 2 0 0 0-2-2zM1 9.5V9h3v.5a1.5 1.5 0 0 1-3 0M7 9.5V9h3v.5a1.5 1.5 0 0 1-3 0'/%3e%3c/svg%3e")`,
                "truck-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a1 1 0 0 0-1 1v8h10.5V3a1 1 0 0 0-1-1zm0 2.25A.25.25 0 0 1 1.25 4h3.5a.25.25 0 0 1 0 .5h-3.5A.25.25 0 0 1 1 4.25m4.75 0A.25.25 0 0 1 6 4h1.25a.25.25 0 0 1 0 .5H6a.25.25 0 0 1-.25-.25' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12.5 5.5H11V11h5V9a3.5 3.5 0 0 0-3.5-3.5M6 12.5a2 2 0 1 1-3.937-.5h3.874c.041.16.063.327.063.5M13.5 12.5a2 2 0 1 1-3.937-.5h3.874c.041.16.063.327.063.5'/%3e%3c/svg%3e")`,
                "truck-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.5 3.25a.25.25 0 0 0 0 .5h1a.25.25 0 0 0 0-.5z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.125 9.5c0-.225.054-.437.15-.625H1A.875.875 0 0 1 .125 8V2c0-.483.392-.875.875-.875h6c.483 0 .875.392.875.875v2.125H9.5A2.375 2.375 0 0 1 11.875 6.5V8a.875.875 0 0 1-.875.875H9.725a1.375 1.375 0 1 1-2.45 0h-3.55a1.375 1.375 0 1 1-2.6.625M.875 2c0-.069.056-.125.125-.125h6c.069 0 .125.056.125.125v6.125H1A.125.125 0 0 1 .875 8V3.75H3.5a.25.25 0 0 0 0-.5H.875zM11 8.125H7.875v-3.25H9.5c.898 0 1.625.728 1.625 1.625V8a.125.125 0 0 1-.125.125M7.875 9.5a.625.625 0 1 1 1.25 0 .625.625 0 0 1-1.25 0m-6 0a.625.625 0 1 1 1.25 0 .625.625 0 0 1-1.25 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "truck": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 4a.25.25 0 0 0 0 .5h1.25a.25.25 0 0 0 0-.5z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a1 1 0 0 1 1-1h9a1 1 0 0 1 1 1v2.5h1.5A3.5 3.5 0 0 1 16 9v3h-2.563a2.001 2.001 0 0 1-1.937 2.5A2 2 0 0 1 9.563 12H5.937A2.002 2.002 0 0 1 4 14.5 2 2 0 0 1 2.063 12H1a1 1 0 0 1-1-1zm11 8h4V9a2.5 2.5 0 0 0-2.5-2.5H11zm-.366 1a1 1 0 1 0 1.733 0h-1.733m-7.5 0h1.732a1 1 0 1 1-1.733 0ZM10 11H1V4.5h3.75a.25.25 0 0 0 0-.5H1V3h9z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "triangle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.018.638.154 10.011c-.1.2-.153.428-.154.66 0 .231.051.459.15.66.1.201.243.369.416.486.173.117.37.18.57.183h9.728c.2-.002.397-.066.57-.183.173-.117.316-.285.415-.486.1-.201.152-.429.151-.66 0-.232-.054-.46-.154-.66L6.982.638a1.244 1.244 0 0 0-.419-.467A1.032 1.032 0 0 0 6 0c-.197 0-.391.059-.563.17a1.244 1.244 0 0 0-.419.468'/%3e%3c/svg%3e")`,
                "triangle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.453 1.921C7.111.68 8.89.68 9.547 1.921l6.093 11.51A1.75 1.75 0 0 1 14.093 16H1.907A1.75 1.75 0 0 1 .36 13.431l6.093-11.51Z'/%3e%3c/svg%3e")`,
                "triangle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.49 1.055c.623-1.244 2.397-1.244 3.02 0l4.25 8.503A1.688 1.688 0 0 1 10.252 12H1.75a1.688 1.688 0 0 1-1.51-2.442l4.252-8.503Zm2.349.336a.938.938 0 0 0-1.678 0L.911 9.893a.938.938 0 0 0 .838 1.357h8.502a.938.938 0 0 0 .839-1.357L6.839 1.391Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "triangle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.547.921C8.889-.32 7.11-.32 6.453.921L.36 12.431A1.75 1.75 0 0 0 1.907 15h12.186a1.75 1.75 0 0 0 1.547-2.569L9.547.921Zm5.21 11.978L8.662 1.389a.75.75 0 0 0-1.326 0L1.244 12.9a.75.75 0 0 0 .663 1.1h12.186a.75.75 0 0 0 .663-1.1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-up-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.786C1 1.799 1.8 1 2.786 1h6.428C10.2 1 11 1.8 11 2.786v6.428C11 10.2 10.2 11 9.214 11H2.786C1.799 11 1 10.2 1 9.214V2.786m2.765 4.98a.375.375 0 0 1-.53-.531l1.367-1.368c.22-.22.576-.22.796 0L6 6.47l1.595-1.595H6.5a.375.375 0 1 1 0-.75h2.375V6.5a.375.375 0 1 1-.75 0V5.405L6.398 7.133a.563.563 0 0 1-.796 0L5 6.53 3.765 7.765' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-up-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zm3 7.207-2.646 2.647a.5.5 0 0 1-.708-.708L5.97 7.323a.75.75 0 0 1 1.06 0l1.47 1.47L11.293 6H9.5a.5.5 0 0 1 0-1H13v3.5a.5.5 0 0 1-1 0V6.707l-2.97 2.97a.75.75 0 0 1-1.06 0L6.5 8.207' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-up-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.786 1.714h6.428c.592 0 1.072.48 1.072 1.072v6.428c0 .592-.48 1.072-1.072 1.072H2.786c-.592 0-1.072-.48-1.072-1.072V2.786c0-.592.48-1.072 1.072-1.072M1 2.786C1 1.799 1.8 1 2.786 1h6.428C10.2 1 11 1.8 11 2.786v6.428C11 10.2 10.2 11 9.214 11H2.786C1.799 11 1 10.2 1 9.214V2.786m2.765 4.98a.375.375 0 0 1-.53-.531l1.367-1.368c.22-.22.576-.22.796 0L6 6.47l1.595-1.595H6.5a.375.375 0 1 1 0-.75h2.375V6.5a.375.375 0 1 1-.75 0V5.405L6.398 7.133a.563.563 0 0 1-.796 0L5 6.53 3.765 7.765' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-up-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5zm5.5 4.707-2.646 2.647a.5.5 0 0 1-.708-.708L5.97 7.323a.75.75 0 0 1 1.06 0l1.47 1.47L11.293 6H9.5a.5.5 0 0 1 0-1H13v3.5a.5.5 0 0 1-1 0V6.707l-2.97 2.97a.75.75 0 0 1-1.06 0L6.5 8.207' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.11 9.64a.375.375 0 0 0 .53 0l4.235-4.235L6.86 7.39a.375.375 0 0 0 .53 0l3.86-3.86v2.095a.375.375 0 0 0 .75 0v-3a.375.375 0 0 0-.375-.375h-3a.375.375 0 1 0 0 .75h2.095L7.125 6.595 5.14 4.61a.375.375 0 0 0-.53 0l-4.5 4.5a.375.375 0 0 0 0 .53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.146 12.854a.5.5 0 0 0 .708 0L6.5 7.207l2.646 2.647a.5.5 0 0 0 .708 0L15 4.707V7.5a.5.5 0 0 0 1 0v-4a.5.5 0 0 0-.5-.5h-4a.5.5 0 0 0 0 1h2.793L9.5 8.793 6.854 6.146a.5.5 0 0 0-.708 0l-6 6a.5.5 0 0 0 0 .708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-down-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.786C1 1.799 1.8 1 2.786 1h6.428C10.2 1 11 1.8 11 2.786v6.428C11 10.2 10.2 11 9.214 11H2.786C1.799 11 1 10.2 1 9.214V2.786m2.765 1.449a.375.375 0 0 0-.53.53l1.367 1.368c.22.22.576.22.796 0L6 5.53l1.595 1.595H6.5a.375.375 0 1 0 0 .75h2.375V5.5a.375.375 0 1 0-.75 0v1.095L6.398 4.867a.563.563 0 0 0-.796 0L5 5.47 3.765 4.235' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-down-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zm3 6.793L3.854 5.146a.5.5 0 1 0-.708.708L5.97 8.677a.75.75 0 0 0 1.06 0l1.47-1.47L11.293 10H9.5a.5.5 0 0 0 0 1H13V7.5a.5.5 0 0 0-1 0v1.793l-2.97-2.97a.75.75 0 0 0-1.06 0L6.5 7.793' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-down-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.786 1.714h6.428c.592 0 1.072.48 1.072 1.072v6.428c0 .592-.48 1.072-1.072 1.072H2.786c-.592 0-1.072-.48-1.072-1.072V2.786c0-.592.48-1.072 1.072-1.072M1 2.786C1 1.799 1.8 1 2.786 1h6.428C10.2 1 11 1.8 11 2.786v6.428C11 10.2 10.2 11 9.214 11H2.786C1.799 11 1 10.2 1 9.214V2.786m2.765 1.449a.375.375 0 0 0-.53.53l1.367 1.368c.22.22.576.22.796 0L6 5.53l1.595 1.595H6.5a.375.375 0 1 0 0 .75h2.375V5.5a.375.375 0 1 0-.75 0v1.095L6.398 4.867a.563.563 0 0 0-.796 0L5 5.47 3.765 4.235' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-down-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5zm5.5 4.293L3.854 5.146a.5.5 0 1 0-.708.708L5.97 8.677a.75.75 0 0 0 1.06 0l1.47-1.47L11.293 10H9.5a.5.5 0 0 0 0 1H13V7.5a.5.5 0 0 0-1 0v1.793l-2.97-2.97a.75.75 0 0 0-1.06 0L6.5 7.793' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.11 2.36a.375.375 0 0 1 .53 0l4.235 4.235L6.86 4.61a.375.375 0 0 1 .53 0l3.86 3.86V6.375a.375.375 0 0 1 .75 0v3a.375.375 0 0 1-.375.375h-3a.375.375 0 1 1 0-.75h2.095L7.125 5.405 5.14 7.39a.375.375 0 0 1-.53 0l-4.5-4.5a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trending-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.146 3.146a.5.5 0 0 1 .708 0L6.5 8.793l2.646-2.647a.5.5 0 0 1 .708 0L15 11.293V8.5a.5.5 0 0 1 1 0v4a.5.5 0 0 1-.5.5h-4a.5.5 0 0 1 0-1h2.793L9.5 7.207 6.854 9.854a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trello-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2zm0 3v3a1 1 0 0 0 2 0V4a1 1 0 0 0-2 0m4 0v2a1 1 0 0 0 2 0V4a1 1 0 0 0-2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trello-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zm1 3a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-2m5 0a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trello-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 3.17a.83.83 0 0 0-.83.83v3a.83.83 0 1 0 1.66 0V4A.83.83 0 0 0 4 3.17M3.83 4a.17.17 0 1 1 .34 0v3a.17.17 0 1 1-.34 0zM8 3.17a.83.83 0 0 0-.83.83v2a.83.83 0 1 0 1.66 0V4A.83.83 0 0 0 8 3.17M7.83 4a.17.17 0 1 1 .34 0v2a.17.17 0 1 1-.34 0z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2zm2-1.25h6c.69 0 1.25.56 1.25 1.25v6c0 .69-.56 1.25-1.25 1.25H3c-.69 0-1.25-.56-1.25-1.25V3c0-.69.56-1.25 1.25-1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trello": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.5 4a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-2M9.5 4a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5zM3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trash-2-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 .125A.875.875 0 0 0 4.125 1v.125H.5a.375.375 0 1 0 0 .75h.625V5.5c0 1.772.34 3.658.624 4.827C1.998 11.345 2.923 12 3.942 12h4.116c1.019 0 1.944-.655 2.193-1.673.284-1.169.624-3.055.624-4.827V1.875h.625a.375.375 0 0 0 0-.75H7.875V1A.875.875 0 0 0 7 .125zm2.125 1h-2.25V1c0-.069.056-.125.125-.125h2c.069 0 .125.056.125.125zM4.875 5a.375.375 0 1 0-.75 0v3.5a.375.375 0 1 0 .75 0zm3 0a.375.375 0 1 0-.75 0v3.5a.375.375 0 1 0 .75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trash-2-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.5 0a1 1 0 0 0-1 1v1h-4a.5.5 0 0 0 0 1H2v5c0 1.573.378 3.687.668 5.08.237 1.14 1.25 1.92 2.394 1.92h5.876c1.145 0 2.157-.78 2.394-1.92.29-1.393.668-3.507.668-5.08V3h.5a.5.5 0 0 0 0-1h-4V1a1 1 0 0 0-1-1zm3 2h-3V1h3zM7 6.5a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0zm3 0a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trash-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.875 5a.375.375 0 1 0-.75 0v3.5a.375.375 0 1 0 .75 0zM7.875 5a.375.375 0 1 0-.75 0v3.5a.375.375 0 1 0 .75 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 .125A.875.875 0 0 0 4.125 1v.125H.5a.375.375 0 1 0 0 .75h.625V5.5c0 1.772.34 3.533.624 4.702.249 1.018 1.174 1.673 2.193 1.673h4.116c1.019 0 1.944-.655 2.193-1.673.284-1.169.624-2.93.624-4.702V1.875h.625a.375.375 0 0 0 0-.75H7.875V1A.875.875 0 0 0 7 .125zm-3.125 1.75h8.25V5.5c0 1.686-.325 3.383-.603 4.524-.16.654-.76 1.101-1.464 1.101H3.942c-.704 0-1.305-.447-1.464-1.101C2.2 8.883 1.875 7.187 1.875 5.5V1.875m5.25-.75h-2.25V1c0-.069.056-.125.125-.125h2c.069 0 .125.056.125.125z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "trash-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 6.5a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0zM10 6.5a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.5 0a1 1 0 0 0-1 1v1h-4a.5.5 0 0 0 0 1H2v5c0 1.573.378 3.687.668 5.08.237 1.14 1.25 1.92 2.394 1.92h5.876c1.145 0 2.157-.78 2.394-1.92.29-1.393.668-3.507.668-5.08V3h.5a.5.5 0 0 0 0-1h-4V1a1 1 0 0 0-1-1zm3 2h-3V1h3zM3 3h10v5c0 1.46-.358 3.484-.647 4.876A1.427 1.427 0 0 1 10.938 14H5.062a1.427 1.427 0 0 1-1.415-1.124C3.357 11.484 3 9.46 3 8z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-right-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 2.25a3.75 3.75 0 1 0 0 7.5h4.5a3.75 3.75 0 1 0 0-7.5zm6 3.75a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-right-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10zm8 5a2 2 0 1 0-4 0 2 2 0 0 0 4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.25 4.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M7.5 6A.75.75 0 1 1 9 6a.75.75 0 0 1-1.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 2.25a3.75 3.75 0 1 0 0 7.5h4.5a3.75 3.75 0 1 0 0-7.5zM.75 6a3 3 0 0 1 3-3h4.5a3 3 0 0 1 0 6h-4.5a3 3 0 0 1-3-3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 6a2 2 0 1 0 0 4 2 2 0 0 0 0-4m-1 2a1 1 0 1 1 2 0 1 1 0 0 1-2 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10zM1 8a4 4 0 0 1 4-4h6a4 4 0 0 1 0 8H5a4 4 0 0 1-4-4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-left-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 2.25a3.75 3.75 0 1 0 0 7.5h4.5a3.75 3.75 0 1 0 0-7.5zM5.25 6a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-left-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10zm2 5a2 2 0 1 0-4 0 2 2 0 0 0 4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 4.594a1.406 1.406 0 1 0 0 2.812 1.406 1.406 0 0 0 0-2.812M2.906 6a.844.844 0 1 1 1.688 0 .844.844 0 0 1-1.688 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75 2.25a3.75 3.75 0 1 0 0 7.5h4.5a3.75 3.75 0 1 0 0-7.5zM.75 6a3 3 0 0 1 3-3h4.5a3 3 0 0 1 0 6h-4.5a3 3 0 0 1-3-3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "toggle-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 6.125a1.875 1.875 0 1 0 0 3.75 1.875 1.875 0 0 0 0-3.75M3.875 8a1.125 1.125 0 1 1 2.25 0 1.125 1.125 0 0 1-2.25 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10zM1 8a4 4 0 0 1 4-4h6a4 4 0 0 1 0 8H5a4 4 0 0 1-4-4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thumbs-up-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.737 4.4A.735.735 0 0 0 1 5.133v5.134c0 .405.33.733.737.733h1.105V4.4H1.737M3.21 4.4V11h5.156a1.84 1.84 0 0 0 1.798-1.436l.805-3.602A1.285 1.285 0 0 0 9.709 4.4H6.897l.23-2.294A1.832 1.832 0 0 0 5.977.22L5.422 0 3.21 4.4'/%3e%3c/svg%3e")`,
                "thumbs-up-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.243.897a1 1 0 0 1 1.601-.26l.308.308a3.5 3.5 0 0 1 .921 3.324L9.64 6h3.761a2.5 2.5 0 0 1 2.352 3.35l-1.567 4.339A3.5 3.5 0 0 1 10.894 16H5.5a1.5 1.5 0 0 1-.5-.085v-8.13A.785.785 0 0 0 4.215 7a3.5 3.5 0 0 1 .155-.357L7.243.897ZM3.5 7c.175 0 .344.03.5.085v8.83a1.497 1.497 0 0 1-.5.085h-2A1.5 1.5 0 0 1 0 14.5v-6A1.5 1.5 0 0 1 1.5 7z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thumbs-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.126 2.106 6.896 4.4H9.71c.825 0 1.438.76 1.259 1.562l-.805 3.602A1.84 1.84 0 0 1 8.366 11H1.737A.735.735 0 0 1 1 10.267V5.133c0-.405.33-.733.737-.733h1.474L5.42 0l.556.221a1.832 1.832 0 0 1 1.15 1.885M3.948 4.573 5.776.934c.414.2.663.638.617 1.099l-.312 3.1H9.71a.55.55 0 0 1 .54.67l-.805 3.602a1.104 1.104 0 0 1-1.08.862H3.949V4.573m-.737.56H1.737v5.134h1.474V5.133' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thumbs-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.844.637a1 1 0 0 0-1.601.26L4.37 6.643a3.5 3.5 0 0 0-.207.51A1.494 1.494 0 0 0 3.5 7h-2A1.5 1.5 0 0 0 0 8.5v6A1.5 1.5 0 0 0 1.5 16h2c.384 0 .735-.144 1-.382.265.238.616.382 1 .382h5.394a3.5 3.5 0 0 0 3.292-2.311l1.567-4.34A2.5 2.5 0 0 0 13.4 6h-3.76l.432-1.73a3.5 3.5 0 0 0-.92-3.325L8.843.637M4 14.5v-6a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 0-.5.5v6a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5m1 0a.5.5 0 0 0 .5.5h5.394a2.5 2.5 0 0 0 2.351-1.65l1.567-4.34A1.5 1.5 0 0 0 13.402 7H9a.5.5 0 0 1-.485-.621l.588-2.352a2.5 2.5 0 0 0-.658-2.375l-.308-.308L5.264 7.09A2.5 2.5 0 0 0 5 8.208z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thumbs-down-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.737 7.6A.735.735 0 0 1 1 6.867V1.733C1 1.328 1.33 1 1.737 1h1.105v6.6H1.737M3.21 7.6V1h5.156a1.84 1.84 0 0 1 1.798 1.436l.805 3.602A1.285 1.285 0 0 1 9.709 7.6H6.897l.23 2.294a1.833 1.833 0 0 1-1.149 1.885L5.422 12 3.21 7.6'/%3e%3c/svg%3e")`,
                "thumbs-down-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.243 15.103a1 1 0 0 0 1.601.26l.308-.308a3.5 3.5 0 0 0 .921-3.324L9.64 10h3.761a2.5 2.5 0 0 0 2.352-3.35l-1.567-4.339A3.5 3.5 0 0 0 10.894 0H5.5c-.175 0-.344.03-.5.085v8.13A.785.785 0 0 1 4.215 9a3.5 3.5 0 0 0 .155.357l2.873 5.746M3.5 9c.175 0 .344-.03.5-.085V.085A1.498 1.498 0 0 0 3.5 0h-2A1.5 1.5 0 0 0 0 1.5v6A1.5 1.5 0 0 0 1.5 9h2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thumbs-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.126 9.894 6.896 7.6H9.71c.825 0 1.438-.76 1.259-1.562l-.805-3.602A1.84 1.84 0 0 0 8.366 1H1.737A.735.735 0 0 0 1 1.733v5.134c0 .405.33.733.737.733h1.474L5.42 12l.556-.221a1.833 1.833 0 0 0 1.15-1.885M3.948 7.427l1.828 3.639a1.1 1.1 0 0 0 .617-1.099l-.312-3.1H9.71a.55.55 0 0 0 .54-.67l-.805-3.602a1.104 1.104 0 0 0-1.08-.862H3.949v5.694Zm-.737-.56H1.737V1.733h1.474v5.134' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thumbs-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.844 15.363a1 1 0 0 1-1.601-.26L4.37 9.357a3.5 3.5 0 0 1-.207-.51c-.2.098-.425.153-.663.153h-2A1.5 1.5 0 0 1 0 7.5v-6A1.5 1.5 0 0 1 1.5 0h2c.384 0 .735.144 1 .382A1.494 1.494 0 0 1 5.5 0h5.394a3.5 3.5 0 0 1 3.292 2.311l1.567 4.34A2.5 2.5 0 0 1 13.4 10h-3.76l.432 1.73a3.5 3.5 0 0 1-.92 3.325l-.309.308M4 1.5v6a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-6a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5Zm1 0a.5.5 0 0 1 .5-.5h5.394a2.5 2.5 0 0 1 2.351 1.65l1.567 4.34A1.5 1.5 0 0 1 13.402 9H9a.5.5 0 0 0-.485.621l.588 2.352a2.5 2.5 0 0 1-.658 2.375l-.308.308L5.264 8.91A2.5 2.5 0 0 1 5 7.792V1.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "thermometer-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1.5a1.5 1.5 0 1 1 3 0v4.901a3 3 0 1 1-3 0zm1.688 1.875a.188.188 0 0 0-.375 0v4.137a1.5 1.5 0 1 0 .375 0V3.375' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8.063 1.781a.281.281 0 0 0 0 .563h1.124a.281.281 0 0 0 0-.563H8.063M8.063 3.281a.281.281 0 0 0 0 .563h1.124a.281.281 0 0 0 0-.563H8.063M8.063 4.781a.281.281 0 0 0 0 .563h1.124a.281.281 0 0 0 0-.563H8.063'/%3e%3c/svg%3e")`,
                "thermometer-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2a2 2 0 1 1 4 0v6.535a4 4 0 1 1-4 0zm2.25 2.5a.25.25 0 0 0-.5 0v5.515a2 2 0 1 0 .5 0z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.75 2.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75zM10.75 4.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75zM10.75 6.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "thermometer-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 10.5a1.5 1.5 0 0 0 .188-2.988V3.375a.188.188 0 0 0-.375 0v4.137A1.5 1.5 0 0 0 6 10.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a1.5 1.5 0 0 0-1.5 1.5v4.901a3 3 0 1 0 3 0V1.5A1.5 1.5 0 0 0 6 0m-.75 1.5a.75.75 0 0 1 1.5 0v5.365l.214.101a2.25 2.25 0 1 1-1.928 0l.214-.101z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8.063 1.781a.281.281 0 0 0 0 .563h1.124a.281.281 0 0 0 0-.563H8.063M8.063 3.281a.281.281 0 0 0 0 .563h1.124a.281.281 0 0 0 0-.563H8.063M8.063 4.781a.281.281 0 0 0 0 .563h1.124a.281.281 0 0 0 0-.563H8.063'/%3e%3c/svg%3e")`,
                "thermometer": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 14a2 2 0 0 0 .25-3.985V4.5a.25.25 0 0 0-.5 0v5.515A2 2 0 0 0 8 14'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a2 2 0 0 0-2 2v6.535a4 4 0 1 0 4 0V2a2 2 0 0 0-2-2M7 2a1 1 0 0 1 2 0v7.153l.285.135a3 3 0 1 1-2.57 0L7 9.153z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.75 2.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75zM10.75 4.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75zM10.75 6.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "terminal-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.263 2.17a.375.375 0 1 0-.525.535L4.53 5.44 1.798 8.172a.375.375 0 0 0 .53.53l3-3a.375.375 0 0 0-.003-.532l-3.062-3M6 9a.375.375 0 1 0 0 .75h4.125a.375.375 0 0 0 0-.75H6'/%3e%3c/svg%3e")`,
                "terminal": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.017 2.893a.5.5 0 0 0-.7.714L6.04 7.254l-3.643 3.642a.5.5 0 0 0 .707.708l4-4a.5.5 0 0 0-.004-.711l-4.083-4ZM8 12a.5.5 0 1 0 0 1h5.5a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "target-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 3.765a2.235 2.235 0 1 0 0 4.47 2.235 2.235 0 0 0 0-4.47'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2.031a3.971 3.971 0 1 0 0 7.943A3.971 3.971 0 0 0 6 2.03M3.203 6a2.797 2.797 0 1 1 5.594 0 2.797 2.797 0 0 1-5.594 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-10.534.002a4.534 4.534 0 1 1 9.068 0 4.534 4.534 0 0 1-9.068 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "target-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 5.444a2.556 2.556 0 1 0 0 5.112 2.556 2.556 0 0 0 0-5.112'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.667 8a4.333 4.333 0 1 1 8.666 0 4.333 4.333 0 0 1-8.666 0m1.11 0a3.222 3.222 0 1 1 6.445 0 3.222 3.222 0 0 1-6.444 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M8 3a5 5 0 1 0 0 10A5 5 0 0 0 8 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "target-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.281A2.719 2.719 0 1 0 6 8.72 2.719 2.719 0 0 0 6 3.28M3.844 6a2.156 2.156 0 1 1 4.312 0 2.156 2.156 0 0 1-4.312 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.781 6a4.219 4.219 0 1 1 8.438 0A4.219 4.219 0 0 1 1.78 6M6 2.344a3.656 3.656 0 1 0 0 7.312 3.656 3.656 0 0 0 0-7.312' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.188 6a5.812 5.812 0 1 1 11.624 0A5.812 5.812 0 0 1 .188 6M6 .938a5.063 5.063 0 1 0 0 10.125A5.063 5.063 0 0 0 6 .938' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "target": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.778 8a3.222 3.222 0 1 1 6.444 0 3.222 3.222 0 0 1-6.444 0M8 5.444a2.556 2.556 0 1 0 0 5.112 2.556 2.556 0 0 0 0-5.112' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 3a5 5 0 1 0 0 10A5 5 0 0 0 8 3M3.667 8a4.333 4.333 0 1 1 8.666 0 4.333 4.333 0 0 1-8.666 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tag-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 1.125v3.814c0 .299-.119.585-.33.796l-5.657 5.657a1.875 1.875 0 0 1-2.652 0L.608 8.638a1.875 1.875 0 0 1 0-2.651L6.265.33c.21-.211.497-.33.795-.33h3.815C11.496 0 12 .504 12 1.125M6.75 3.75a1.5 1.5 0 1 0 3 0 1.5 1.5 0 0 0-3 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tag-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 1.5v5.086a1.5 1.5 0 0 1-.44 1.06L8.017 15.19a2.5 2.5 0 0 1-3.535 0L.81 11.518a2.5 2.5 0 0 1 0-3.536L8.353.44A1.5 1.5 0 0 1 9.413 0H14.5A1.5 1.5 0 0 1 16 1.5M9 5a2 2 0 1 0 4 0 2 2 0 0 0-4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tag-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.75 3.75a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0M8.25 3a.75.75 0 1 1 0 1.5.75.75 0 0 1 0-1.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4.94V1.124C12 .504 11.496 0 10.875 0H7.061c-.299 0-.585.119-.796.33L.608 5.987a1.875 1.875 0 0 0 0 2.651l2.754 2.754c.732.732 1.92.732 2.651 0l5.658-5.657c.21-.211.329-.497.329-.796m-.75-3.815v3.814c0 .1-.04.195-.11.266l-5.657 5.657c-.44.439-1.152.439-1.591 0L1.138 8.108a1.125 1.125 0 0 1 0-1.591L6.796.86c.07-.07.165-.11.265-.11h3.814c.207 0 .375.168.375.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tag": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13 5a2 2 0 1 0-4 0 2 2 0 0 0 4 0m-2-1a1 1 0 1 1 0 2 1 1 0 0 1 0-2' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 6.586V1.5A1.5 1.5 0 0 0 14.5 0H9.414a1.5 1.5 0 0 0-1.06.44L.81 7.981a2.5 2.5 0 0 0 0 3.536l3.671 3.671a2.5 2.5 0 0 0 3.536 0l7.543-7.543A1.5 1.5 0 0 0 16 6.586M15 1.5v5.086a.5.5 0 0 1-.146.353L7.31 14.482a1.5 1.5 0 0 1-2.122 0l-3.671-3.671a1.5 1.5 0 0 1 0-2.122L9.06 1.146A.5.5 0 0 1 9.414 1H14.5a.5.5 0 0 1 .5.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tablet-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.688 0C1.756 0 1 .756 1 1.688v8.625C1 11.244 1.756 12 2.688 12h6.624c.933 0 1.688-.755 1.688-1.687V1.688C11 .756 10.245 0 9.313 0H2.686M6 10.5A.75.75 0 1 0 6 9a.75.75 0 0 0 0 1.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tablet-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.25 0A2.25 2.25 0 0 0 1 2.25v11.5A2.25 2.25 0 0 0 3.25 16h9.5A2.25 2.25 0 0 0 15 13.75V2.25A2.25 2.25 0 0 0 12.75 0zM8 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tablet-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 9.438a.563.563 0 1 0 0 1.125.563.563 0 0 0 0-1.126M5.813 10a.188.188 0 1 1 .375 0 .188.188 0 0 1-.375 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 0A1.5 1.5 0 0 0 1 1.5v9A1.5 1.5 0 0 0 2.5 12h7a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 9.5 0zm-.75 1.5A.75.75 0 0 1 2.5.75h7a.75.75 0 0 1 .75.75v9a.75.75 0 0 1-.75.75h-7a.75.75 0 0 1-.75-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "tablet": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 12.25a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5m-.25.75a.25.25 0 1 1 .5 0 .25.25 0 0 1-.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM2 2a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "table-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.5 2.75a.25.25 0 0 0 0 .5h2a.25.25 0 0 0 0-.5zM4.5 2.75a.25.25 0 0 0 0 .5h2a.25.25 0 0 0 0-.5zM7.5 2.75a.25.25 0 0 0 0 .5h2a.25.25 0 0 0 0-.5z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.5A1.5 1.5 0 0 1 1.5 1h9A1.5 1.5 0 0 1 12 2.5v7a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 0 9.5zm1.5-.75h9a.75.75 0 0 1 .75.75v1.7H.75V2.5a.75.75 0 0 1 .75-.75M.75 4.8v1.4H3.2V4.8zm0 2H3.2v1.4H.75zm3.05 0v1.4h2.4V6.8zm-3.05 2H3.2v1.45H1.5a.75.75 0 0 1-.75-.75zm3.05 0v1.45h2.4V8.8zm5.4 1.45H6.8V8.8h2.4zm0-2.05H6.8V6.8h2.4zm0-2H6.8V4.8h2.4zM3.8 4.8h2.4v1.4H3.8zm6 1.4V4.8h1.45v1.4zm0 2V6.8h1.45v1.4zm0 2.05V8.8h1.45v.7a.75.75 0 0 1-.75.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "table": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.75 4A.25.25 0 0 1 2 3.75h2.5a.25.25 0 0 1 0 .5H2A.25.25 0 0 1 1.75 4M6.5 3.75a.25.25 0 0 0 0 .5h3a.25.25 0 0 0 0-.5h-3M11.25 4a.25.25 0 0 1 .25-.25H14a.25.25 0 1 1 0 .5h-2.5a.25.25 0 0 1-.25-.25'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 0 11.5zM2.5 3h11A1.5 1.5 0 0 1 15 4.5v.625H1V4.5A1.5 1.5 0 0 1 2.5 3M1 5.875v3.25h4.125v-3.25H1m0 4V11.5A1.5 1.5 0 0 0 2.5 13h2.625V9.875H1M5.875 13h4.25V9.875h-4.25zm5 0H13.5a1.5 1.5 0 0 0 1.5-1.5V9.875h-4.125zM15 9.125v-3.25h-4.125v3.25H15m-9.125 0h4.25v-3.25h-4.25v3.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "sunset-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 .25c.207 0 .375.168.375.375V2.72l.86-.86a.375.375 0 0 1 .53.53L6 4.155 4.235 2.39a.375.375 0 1 1 .53-.53l.86.86V.625c0-.207.168-.375.375-.375M2.023 3.398a.375.375 0 0 1 .53 0l1.06 1.06a.375.375 0 1 1-.53.53l-1.06-1.06a.375.375 0 0 1 0-.53M9.977 3.398a.375.375 0 0 1 0 .53l-1.06 1.06a.375.375 0 1 1-.53-.53l1.06-1.06a.375.375 0 0 1 .53 0M.375 7.375C.375 7.168.543 7 .75 7h1.5a.375.375 0 1 1 0 .75H.75a.375.375 0 0 1-.375-.375M9.375 7.375c0-.207.168-.375.375-.375h1.5a.375.375 0 0 1 0 .75h-1.5a.375.375 0 0 1-.375-.375M3.375 7.75v-.187a2.438 2.438 0 0 1 2.438-2.438h.375a2.438 2.438 0 0 1 2.437 2.438v.187zM.75 9.25a.375.375 0 1 0 0 .75h10.5a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "sunset-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 1a.5.5 0 0 1 .5.5v2.793l1.146-1.147a.5.5 0 0 1 .708.708L8 6.207 5.646 3.854a.5.5 0 1 1 .708-.708L7.5 4.293V1.5A.5.5 0 0 1 8 1M2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 0 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707M13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0M.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5M12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5M4.5 11v-.25A3.25 3.25 0 0 1 7.75 7.5h.5a3.25 3.25 0 0 1 3.25 3.25V11zM1 13a.5.5 0 0 0 0 1h14a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "sunset-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 .25c.207 0 .375.168.375.375V2.72l.86-.86a.375.375 0 0 1 .53.53L6 4.155 4.235 2.39a.375.375 0 1 1 .53-.53l.86.86V.625c0-.207.168-.375.375-.375M2.023 3.398a.375.375 0 0 1 .53 0l1.06 1.06a.375.375 0 1 1-.53.53l-1.06-1.06a.375.375 0 0 1 0-.53M9.977 3.398a.375.375 0 0 1 0 .53l-1.06 1.06a.375.375 0 1 1-.53-.53l1.06-1.06a.375.375 0 0 1 .53 0M.375 7.375C.375 7.168.543 7 .75 7h1.5a.375.375 0 1 1 0 .75H.75a.375.375 0 0 1-.375-.375M9.375 7.375c0-.207.168-.375.375-.375h1.5a.375.375 0 0 1 0 .75h-1.5a.375.375 0 0 1-.375-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.375 7.188A2.438 2.438 0 0 1 5.813 4.75h.375a2.438 2.438 0 0 1 2.437 2.438v.562h-5.25v-.562M4.135 7h3.73a1.688 1.688 0 0 0-1.678-1.5h-.375c-.868 0-1.583.656-1.677 1.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 9.25a.375.375 0 1 0 0 .75h10.5a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "sunset": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 1a.5.5 0 0 1 .5.5v2.793l1.146-1.147a.5.5 0 0 1 .708.708L8 6.207 5.646 3.854a.5.5 0 1 1 .708-.708L7.5 4.293V1.5A.5.5 0 0 1 8 1M2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 0 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707M13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0M.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5M12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 10.25A3.25 3.25 0 0 1 7.75 7h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7zM5.514 10h4.972A2.25 2.25 0 0 0 8.25 8h-.5a2.25 2.25 0 0 0-2.236 2' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 13a.5.5 0 0 0 0 1h14a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "sunrise-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 .345 7.765 2.11a.375.375 0 0 1-.53.53l-.86-.86v2.095a.375.375 0 0 1-.75 0V1.78l-.86.86a.375.375 0 1 1-.53-.53L6 .345ZM2.023 3.648a.375.375 0 0 1 .53 0l1.06 1.06a.375.375 0 1 1-.53.53l-1.06-1.06a.375.375 0 0 1 0-.53M9.977 3.648a.375.375 0 0 1 0 .53l-1.06 1.06a.375.375 0 1 1-.53-.53l1.06-1.06a.375.375 0 0 1 .53 0M.375 7.625c0-.207.168-.375.375-.375h1.5a.375.375 0 1 1 0 .75H.75a.375.375 0 0 1-.375-.375M9.375 7.625c0-.207.168-.375.375-.375h1.5a.375.375 0 0 1 0 .75h-1.5a.375.375 0 0 1-.375-.375M3.375 8v-.188a2.438 2.438 0 0 1 2.438-2.437h.375a2.438 2.438 0 0 1 2.437 2.437V8h-5.25M.75 9.25a.375.375 0 0 0 0 .75h10.5a.375.375 0 0 0 0-.75H.75'/%3e%3c/svg%3e")`,
                "sunrise-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m8 .793 2.354 2.353a.5.5 0 0 1-.708.708L8.5 2.707V5.5a.5.5 0 1 1-1 0V2.707L6.354 3.854a.5.5 0 1 1-.708-.708L8 .793ZM2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 1 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707M13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0M.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5M12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5M4.5 11v-.25A3.25 3.25 0 0 1 7.75 7.5h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7M1 13a.5.5 0 1 0 0 1h14a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "sunrise-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 .345 7.765 2.11a.375.375 0 0 1-.53.53l-.86-.86v2.095a.375.375 0 0 1-.75 0V1.78l-.86.86a.375.375 0 1 1-.53-.53L6 .345ZM2.023 3.648a.375.375 0 0 1 .53 0l1.06 1.06a.375.375 0 1 1-.53.53l-1.06-1.06a.375.375 0 0 1 0-.53M9.977 3.648a.375.375 0 0 1 0 .53l-1.06 1.06a.375.375 0 1 1-.53-.53l1.06-1.06a.375.375 0 0 1 .53 0M.375 7.625c0-.207.168-.375.375-.375h1.5a.375.375 0 1 1 0 .75H.75a.375.375 0 0 1-.375-.375M9.375 7.625c0-.207.168-.375.375-.375h1.5a.375.375 0 0 1 0 .75h-1.5a.375.375 0 0 1-.375-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.375 7.438A2.437 2.437 0 0 1 5.813 5h.375a2.437 2.437 0 0 1 2.437 2.438V8h-5.25v-.562m.76-.188h3.73a1.688 1.688 0 0 0-1.678-1.5h-.375c-.868 0-1.583.656-1.677 1.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 9.25a.375.375 0 1 0 0 .75h10.5a.375.375 0 0 0 0-.75H.75'/%3e%3c/svg%3e")`,
                "sunrise": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m8 .793 2.354 2.353a.5.5 0 0 1-.708.708L8.5 2.707V5.5a.5.5 0 1 1-1 0V2.707L6.354 3.854a.5.5 0 1 1-.708-.708L8 .793ZM2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 1 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707M13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0M.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5M12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 10.25A3.25 3.25 0 0 1 7.75 7h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7zM5.514 10h4.972A2.25 2.25 0 0 0 8.25 8h-.5a2.25 2.25 0 0 0-2.236 2' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 13a.5.5 0 1 0 0 1h14a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "sun-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.281.563a.281.281 0 0 0-.562 0v2.062a.281.281 0 0 0 .562 0V.563M10.044 2.354a.281.281 0 0 0-.398-.398L8.188 3.415a.281.281 0 0 0 .397.397l1.459-1.458M2.354 1.956a.281.281 0 0 0-.398.398l1.459 1.458a.281.281 0 0 0 .397-.397L2.354 1.956M.563 5.719a.281.281 0 0 0 0 .562h2.062a.281.281 0 0 0 0-.562H.563M9.375 5.719a.281.281 0 0 0 0 .562h2.063a.281.281 0 0 0 0-.562H9.375M3.812 8.585a.281.281 0 0 0-.397-.397L1.956 9.646a.281.281 0 0 0 .398.398l1.458-1.459M8.585 8.188a.281.281 0 0 0-.397.397l1.458 1.459a.281.281 0 0 0 .398-.398L8.585 8.188M6.281 9.375a.281.281 0 0 0-.562 0v2.063a.281.281 0 0 0 .562 0V9.375M6 3.75a2.25 2.25 0 1 0 0 4.5 2.25 2.25 0 0 0 0-4.5'/%3e%3c/svg%3e")`,
                "sun-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.375.75a.375.375 0 1 0-.75 0V3.5a.375.375 0 1 0 .75 0zM13.392 3.139a.375.375 0 0 0-.53-.53l-1.945 1.944a.375.375 0 0 0 .53.53l1.945-1.944M3.139 2.608a.375.375 0 1 0-.53.53l1.944 1.945a.375.375 0 1 0 .53-.53L3.14 2.608M.75 7.625a.375.375 0 1 0 0 .75H3.5a.375.375 0 1 0 0-.75zM12.5 7.625a.375.375 0 0 0 0 .75h2.75a.375.375 0 0 0 0-.75zM5.083 11.447a.375.375 0 1 0-.53-.53L2.608 12.86a.375.375 0 1 0 .53.53l1.945-1.944M11.447 10.917a.375.375 0 0 0-.53.53l1.944 1.945a.375.375 0 0 0 .53-.53l-1.944-1.945M8.375 12.5a.375.375 0 0 0-.75 0v2.75a.375.375 0 0 0 .75 0zM8 5a3 3 0 1 0 0 6 3 3 0 0 0 0-6'/%3e%3c/svg%3e")`,
                "sun-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.281.563a.281.281 0 0 0-.562 0v2.062a.281.281 0 0 0 .562 0V.563M10.044 2.354a.281.281 0 0 0-.398-.398L8.188 3.415a.281.281 0 0 0 .397.397l1.459-1.458M2.354 1.956a.281.281 0 0 0-.398.398l1.459 1.458a.281.281 0 0 0 .397-.397L2.354 1.956M.563 5.719a.281.281 0 0 0 0 .562h2.062a.281.281 0 0 0 0-.562H.563M9.375 5.719a.281.281 0 0 0 0 .562h2.063a.281.281 0 0 0 0-.562H9.375M3.812 8.585a.281.281 0 0 0-.397-.397L1.956 9.646a.281.281 0 0 0 .398.398l1.458-1.459M8.585 8.188a.281.281 0 0 0-.397.397l1.458 1.459a.281.281 0 0 0 .398-.398L8.585 8.188M6.281 9.375a.281.281 0 0 0-.562 0v2.063a.281.281 0 0 0 .562 0V9.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.75a2.25 2.25 0 1 0 0 4.5 2.25 2.25 0 0 0 0-4.5M4.5 6a1.5 1.5 0 1 1 3 0 1.5 1.5 0 0 1-3 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "sun": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.375.75a.375.375 0 1 0-.75 0V3.5a.375.375 0 1 0 .75 0zM13.392 3.139a.375.375 0 0 0-.53-.53l-1.945 1.944a.375.375 0 0 0 .53.53l1.945-1.944M3.139 2.608a.375.375 0 1 0-.53.53l1.944 1.945a.375.375 0 1 0 .53-.53L3.14 2.608M.75 7.625a.375.375 0 1 0 0 .75H3.5a.375.375 0 1 0 0-.75zM12.5 7.625a.375.375 0 0 0 0 .75h2.75a.375.375 0 0 0 0-.75zM5.083 11.447a.375.375 0 1 0-.53-.53L2.608 12.86a.375.375 0 1 0 .53.53l1.945-1.944M11.447 10.917a.375.375 0 0 0-.53.53l1.944 1.945a.375.375 0 0 0 .53-.53l-1.944-1.945M8.375 12.5a.375.375 0 0 0-.75 0v2.75a.375.375 0 0 0 .75 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 5a3 3 0 1 0 0 6 3 3 0 0 0 0-6M6 8a2 2 0 1 1 4 0 2 2 0 0 1-4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "strike-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3 3.75A2.25 2.25 0 0 1 5.25 1.5h1.5A2.25 2.25 0 0 1 9 3.75h-.75a1.5 1.5 0 0 0-1.5-1.5h-1.5a1.5 1.5 0 0 0-1.5 1.5v.06c0 .41.167.79.444 1.065h-.926A2.245 2.245 0 0 1 3 3.809zM8.18 7.125h.927c.172.32.268.684.268 1.066v.059a2.25 2.25 0 0 1-2.25 2.25H5.25A2.25 2.25 0 0 1 3 8.25h.75a1.5 1.5 0 0 0 1.5 1.5h1.875a1.5 1.5 0 0 0 1.5-1.5v-.06c0-.41-.167-.79-.444-1.065M1.875 5.625a.375.375 0 1 0 0 .75h8.25a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "strike": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4 5a3 3 0 0 1 3-3h2a3 3 0 0 1 3 3h-1a2 2 0 0 0-2-2H7a2 2 0 0 0-2 2v.08c0 .547.223 1.054.592 1.42H4.358A2.993 2.993 0 0 1 4 5.08zM10.908 9.5h1.234c.23.426.358.912.358 1.42V11a3 3 0 0 1-3 3H7a3 3 0 0 1-3-3h1a2 2 0 0 0 2 2h2.5a2 2 0 0 0 2-2v-.08c0-.547-.223-1.054-.592-1.42M2.5 7.5a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1z'/%3e%3c/svg%3e")`,
                "stop-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M4.125 3.75a.375.375 0 0 0-.375.375v3.75c0 .207.168.375.375.375h3.75a.375.375 0 0 0 .375-.375v-3.75a.375.375 0 0 0-.375-.375z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "stop-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M5 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "stop-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.125 3.75a.375.375 0 0 0-.375.375v3.75c0 .207.168.375.375.375h3.75a.375.375 0 0 0 .375-.375v-3.75a.375.375 0 0 0-.375-.375zM4.5 7.5v-3h3v3z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "stop-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5zM6 6v4h4V6z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "star-half-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.474 11.854 6 9.652V1L4.441 4.854l-4.147.292L3.478 7.82l-1.004 4.034'/%3e%3c/svg%3e")`,
                "star-half-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.298 15.472 8 12.536V1L5.922 6.14l-5.53.388 4.245 3.565-1.34 5.38'/%3e%3c/svg%3e")`,
                "star-half-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m4.961 5.57-2.765.194L4.32 7.546l-.67 2.69 1.601-1V4.855l-.289.715m-.52-.716-4.147.292L3.478 7.82l-1.004 4.034L6 9.652V1L4.441 4.854' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "star-half": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6.615 7.093-3.687.26 2.83 2.375-.892 3.586L7 11.982V6.14l-.385.953m-.693-.954-5.53.389 4.245 3.565-1.34 5.38L8 12.535V1L5.922 6.14' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "star-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m6 .5 1.56 3.854 4.147.292L8.522 7.32l1.005 4.034L6 9.152l-3.526 2.202L3.478 7.32.294 4.646l4.147-.292L6.001.5'/%3e%3c/svg%3e")`,
                "star-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m8 1 2.079 5.14 5.53.388-4.246 3.565 1.34 5.38L8 12.535l-4.702 2.936 1.34-5.38L.391 6.529l5.53-.389L8 1'/%3e%3c/svg%3e")`,
                "star-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.56 4.354 6 .5 4.441 4.354l-4.147.292L3.478 7.32l-1.004 4.034L6 9.152l3.527 2.202L8.522 7.32l3.185-2.674-4.148-.292m2.244.91L7.04 5.07 6 2.5 4.961 5.07l-2.765.194L4.32 7.046l-.67 2.69L6 8.268l2.351 1.468-.67-2.69 2.123-1.782' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "star": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.078 6.14 8.464 2.145a.5.5 0 0 0-.928 0L5.922 6.14l-4.297.302a.5.5 0 0 0-.287.882l3.3 2.77-1.042 4.18a.5.5 0 0 0 .75.544L8 12.536l3.654 2.281a.5.5 0 0 0 .75-.545l-1.041-4.18 3.299-2.77a.5.5 0 0 0-.287-.88l-4.297-.303m2.994 1.212-3.687-.259L8 3.667 6.615 7.093l-3.687.26 2.83 2.375-.893 3.586L8 11.357l3.134 1.957-.892-3.586 2.83-2.376' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1 3a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2z'/%3e%3c/svg%3e")`,
                "square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2A1.5 1.5 0 0 0 2 3.5v9A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 12.5 2zM1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 3.5A1.5 1.5 0 0 1 3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5z'/%3e%3c/svg%3e")`,
                "square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2zm6 .75H3c-.69 0-1.25.56-1.25 1.25v6c0 .69.56 1.25 1.25 1.25h6c.69 0 1.25-.56 1.25-1.25V3c0-.69-.56-1.25-1.25-1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2A1.5 1.5 0 0 0 2 3.5v9A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 12.5 2zM1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "speaker-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 9.25a1.25 1.25 0 1 0 0-2.5 1.25 1.25 0 0 0 0 2.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2zm5 1.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5M6 10a2 2 0 1 0 0-4 2 2 0 0 0 0 4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "speaker-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.375 10.5a2.625 2.625 0 1 1 5.25 0 2.625 2.625 0 0 1-5.25 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 0A2.5 2.5 0 0 0 2 2.5v11A2.5 2.5 0 0 0 4.5 16h7a2.5 2.5 0 0 0 2.5-2.5v-11A2.5 2.5 0 0 0 11.5 0zM9 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0M8 7.125a3.375 3.375 0 1 0 0 6.75 3.375 3.375 0 0 0 0-6.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "speaker-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a1 1 0 1 1 2 0 1 1 0 0 1-2 0m1-.5a.5.5 0 1 0 0 1 .5.5 0 0 0 0-1M8 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0m-.5 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm6 .75H3c-.69 0-1.25.56-1.25 1.25v8c0 .69.56 1.25 1.25 1.25h6c.69 0 1.25-.56 1.25-1.25V2c0-.69-.56-1.25-1.25-1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "speaker": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 7.125a3.375 3.375 0 1 0 0 6.75 3.375 3.375 0 0 0 0-6.75M5.375 10.5a2.625 2.625 0 1 1 5.25 0 2.625 2.625 0 0 1-5.25 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2.5A2.5 2.5 0 0 1 4.5 0h7A2.5 2.5 0 0 1 14 2.5v11a2.5 2.5 0 0 1-2.5 2.5h-7A2.5 2.5 0 0 1 2 13.5v-11ZM4.5 1h7A1.5 1.5 0 0 1 13 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-7A1.5 1.5 0 0 1 3 13.5v-11A1.5 1.5 0 0 1 4.5 1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smile-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M3.75 4.5a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0Zm3 0a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0M4.015 7.422c.476.477 1.216.734 1.985.734.77 0 1.509-.257 1.985-.734a.375.375 0 0 1 .53.53c-.649.65-1.597.954-2.515.954-.918 0-1.866-.305-2.515-.953a.375.375 0 0 1 .53-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smile-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M5 6.25a1 1 0 1 1 2 0 1 1 0 0 1-2 0m4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0M5.354 9.896c.635.635 1.62.979 2.646.979 1.026 0 2.011-.344 2.646-.979a.5.5 0 0 1 .708.708c-.865.865-2.13 1.271-3.354 1.271-1.224 0-2.489-.406-3.354-1.271a.5.5 0 0 1 .708-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smile-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.75 4.688a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0M6.75 4.688a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0M6 8.156c-.77 0-1.509-.257-1.985-.734a.375.375 0 1 0-.53.53c.649.65 1.597.954 2.515.954.918 0 1.866-.305 2.515-.953a.375.375 0 0 0-.53-.53c-.476.476-1.216.733-1.985.733'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-6 5.25A5.25 5.25 0 1 0 6 .75a5.25 5.25 0 0 0 0 10.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smile": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 6.25a1 1 0 1 1 2 0 1 1 0 0 1-2 0M9 6.25a1 1 0 1 1 2 0 1 1 0 0 1-2 0M5.354 9.897c.635.635 1.62.978 2.646.978 1.026 0 2.011-.343 2.646-.978a.5.5 0 0 1 .708.707c-.865.865-2.13 1.271-3.354 1.271-1.224 0-2.489-.406-3.354-1.271a.5.5 0 0 1 .708-.707'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smartphone-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm.5 1a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smartphone-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 0A2.5 2.5 0 0 0 2 2.5v11A2.5 2.5 0 0 0 4.5 16h7a2.5 2.5 0 0 0 2.5-2.5v-11A2.5 2.5 0 0 0 11.5 0zM5 1h6v.5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5zm0 12.5c0-.207.168-.375.375-.375h5.25a.375.375 0 0 1 0 .75h-5.25A.375.375 0 0 1 5 13.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smartphone-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm-.032.75H8c.69 0 1.25.56 1.25 1.25v8c0 .69-.56 1.25-1.25 1.25H4c-.69 0-1.25-.56-1.25-1.25V2c0-.69.56-1.25 1.25-1.25h.032A1.002 1.002 0 0 0 5 2h2A1 1 0 0 0 7.968.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "smartphone": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 13.5c0-.207.168-.375.375-.375h5.25a.375.375 0 0 1 0 .75h-5.25A.375.375 0 0 1 5 13.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2.5A2.5 2.5 0 0 1 4.5 0h7A2.5 2.5 0 0 1 14 2.5v11a2.5 2.5 0 0 1-2.5 2.5h-7A2.5 2.5 0 0 1 2 13.5zM11 1h.5A1.5 1.5 0 0 1 13 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-7A1.5 1.5 0 0 1 3 13.5v-11A1.5 1.5 0 0 1 4.5 1H5v.5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 .5-.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "sliders-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.5 6a2.5 2.5 0 0 0 2.472-2.126l.028.001h1.5a.375.375 0 0 0 0-.75H10l-.028.001A2.5 2.5 0 1 0 7.5 6M2.028 8.126A.382.382 0 0 0 2 8.125H.5a.375.375 0 1 0 0 .75H2l.028-.001a2.5 2.5 0 1 0 0-.748M.125 3.5c0-.207.168-.375.375-.375H4a.375.375 0 1 1 0 .75H.5A.375.375 0 0 1 .125 3.5M11.5 8.125a.375.375 0 0 1 0 .75H8a.375.375 0 1 1 0-.75z'/%3e%3c/svg%3e")`,
                "sliders-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M10 1.5A3 3 0 0 1 12.959 4h2.291a.5.5 0 0 1 0 1h-2.291A3 3 0 1 1 10 1.5M.25 4.5a.5.5 0 0 1 .5-.5H5.5a.5.5 0 0 1 0 1H.75a.5.5 0 0 1-.5-.5M6 8.5A3 3 0 0 0 3.041 11H.75a.5.5 0 0 0 0 1h2.291A3 3 0 1 0 6 8.5M15.75 11.5a.5.5 0 0 0-.5-.5H10.5a.5.5 0 0 0 0 1h4.75a.5.5 0 0 0 .5-.5'/%3e%3c/svg%3e")`,
                "sliders-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.5 6a2.5 2.5 0 0 0 2.472-2.126l.028.001h.5a.375.375 0 0 0 0-.75H11l-.028.001A2.5 2.5 0 1 0 8.5 6m1.75-2.5a1.75 1.75 0 1 1-3.5 0 1.75 1.75 0 0 1 3.5 0M1.028 8.874a2.5 2.5 0 1 0 0-.748A.382.382 0 0 0 1 8.125H.5a.375.375 0 1 0 0 .75H1l.028-.001M1.75 8.5a1.75 1.75 0 1 0 3.5 0 1.75 1.75 0 0 0-3.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.125 3.5c0-.207.168-.375.375-.375H5a.375.375 0 1 1 0 .75H.5A.375.375 0 0 1 .125 3.5M11.5 8.125a.375.375 0 0 1 0 .75H7a.375.375 0 1 1 0-.75z'/%3e%3c/svg%3e")`,
                "sliders": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 1.5A3 3 0 0 1 12.959 4h2.291a.5.5 0 0 1 0 1h-2.291A3 3 0 1 1 10 1.5m0 1a2 2 0 1 0 0 4 2 2 0 0 0 0-4' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.25 4.5a.5.5 0 0 1 .5-.5H5.5a.5.5 0 0 1 0 1H.75a.5.5 0 0 1-.5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 8.5A3 3 0 0 0 3.041 11H.75a.5.5 0 0 0 0 1h2.291A3 3 0 1 0 6 8.5m0 1a2 2 0 1 1 0 4 2 2 0 0 1 0-4' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M15.75 11.5a.5.5 0 0 0-.5-.5H10.5a.5.5 0 0 0 0 1h4.75a.5.5 0 0 0 .5-.5'/%3e%3c/svg%3e")`,
                "slash-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m3.438-2.032a5.25 5.25 0 0 1-7.406-7.406l7.406 7.406m.53-.53L2.562 2.032a5.25 5.25 0 0 1 7.406 7.406' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "slash": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-3.21 4.792A6.3 6.3 0 0 1 3.203 3.91l8.881 8.88m.707-.708-8.88-8.88a6.3 6.3 0 0 1 8.88 8.88' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "slack-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.75 1.828c0-.16.144-.328.375-.328s.375.169.375.328v2.344c0 .16-.144.328-.375.328s-.375-.169-.375-.328V1.828ZM7.125.75C6.526.75 6 1.21 6 1.828v2.344c0 .618.526 1.078 1.125 1.078S8.25 4.79 8.25 4.172V1.828C8.25 1.21 7.724.75 7.125.75M9.75 4.125c0-.208.167-.375.375-.375s.375.167.375.375a.374.374 0 0 1-.375.375H9.75zM10.125 3C9.503 3 9 3.503 9 4.125v.75c0 .207.168.375.375.375h.75a1.124 1.124 0 1 0 0-2.25m-5.25 4.5c-.231 0-.375.169-.375.328v2.344c0 .16.144.328.375.328s.375-.169.375-.328V7.828c0-.16-.144-.328-.375-.328m-1.125.328c0-.618.526-1.078 1.125-1.078S6 7.21 6 7.828v2.344c0 .618-.526 1.078-1.125 1.078s-1.125-.46-1.125-1.078V7.828m-2.25.047c0-.208.167-.375.375-.375h.375v.375a.374.374 0 0 1-.375.375.374.374 0 0 1-.375-.375m.375-1.125a1.124 1.124 0 1 0 0 2.25C2.497 9 3 8.497 3 7.875v-.75a.375.375 0 0 0-.375-.375zm5.953 0c-.16 0-.328.144-.328.375s.169.375.328.375h2.344c.16 0 .328-.144.328-.375s-.169-.375-.328-.375H7.828m-1.078.375C6.75 6.526 7.21 6 7.828 6h2.344c.618 0 1.078.526 1.078 1.125s-.46 1.125-1.078 1.125H7.828c-.618 0-1.078-.526-1.078-1.125M7.125 9a.375.375 0 0 0-.375.375v.75a1.124 1.124 0 1 0 2.25 0C9 9.503 8.497 9 7.875 9zm.375 1.125V9.75h.375c.208 0 .375.167.375.375a.374.374 0 0 1-.375.375.374.374 0 0 1-.375-.375M.75 4.875c0-.599.46-1.125 1.078-1.125h2.344c.618 0 1.078.526 1.078 1.125S4.79 6 4.172 6H1.828C1.21 6 .75 5.474.75 4.875M1.828 4.5c-.16 0-.328.144-.328.375s.169.375.328.375h2.344c.16 0 .328-.144.328-.375S4.331 4.5 4.172 4.5H1.828ZM4.125.75a1.124 1.124 0 1 0 0 2.25h.75a.375.375 0 0 0 .375-.375v-.75C5.25 1.253 4.747.75 4.125.75M3.75 1.875c0-.208.167-.375.375-.375s.375.167.375.375v.375h-.375a.374.374 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.828 4.5c-.16 0-.328.144-.328.375s.169.375.328.375h2.344c.16 0 .328-.144.328-.375S4.331 4.5 4.172 4.5H1.828ZM6.75 1.828c0-.16.144-.328.375-.328s.375.169.375.328v2.344c0 .16-.144.328-.375.328s-.375-.169-.375-.328V1.828ZM3.75 1.875c0-.208.167-.375.375-.375s.375.167.375.375v.375h-.375a.374.374 0 0 1-.375-.375M1.5 7.875c0-.208.167-.375.375-.375h.375v.375a.374.374 0 0 1-.375.375.374.374 0 0 1-.375-.375M4.875 7.5c-.231 0-.375.169-.375.328v2.344c0 .16.144.328.375.328s.375-.169.375-.328V7.828c0-.16-.144-.328-.375-.328M7.5 10.125V9.75h.375c.208 0 .375.167.375.375a.374.374 0 0 1-.375.375.374.374 0 0 1-.375-.375M7.828 6.75c-.16 0-.328.144-.328.375s.169.375.328.375h2.344c.16 0 .328-.144.328-.375s-.169-.375-.328-.375H7.828M9.75 4.125c0-.208.167-.375.375-.375s.375.167.375.375a.374.374 0 0 1-.375.375H9.75z'/%3e%3c/svg%3e")`,
                "slack-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 2.438C9 2.225 9.192 2 9.5 2s.5.225.5.438v3.125c0 .212-.192.437-.5.437S9 5.775 9 5.563V2.438M9.5 1C8.701 1 8 1.613 8 2.438v3.125C8 6.387 8.701 7 9.5 7S11 6.387 11 5.563V2.438C11 1.613 10.299 1 9.5 1M13 5.5c0-.277.223-.5.5-.5s.5.223.5.5-.223.5-.5.5H13zm.5-1.5c-.83 0-1.5.67-1.5 1.5v1a.5.5 0 0 0 .5.5h1c.83 0 1.5-.67 1.5-1.5S14.33 4 13.5 4m-7 6c-.308 0-.5.225-.5.438v3.124c0 .213.192.438.5.438s.5-.225.5-.437v-3.126c0-.212-.192-.437-.5-.437m-1.5.438C5 9.613 5.701 9 6.5 9S8 9.613 8 10.438v3.124C8 14.388 7.299 15 6.5 15S5 14.387 5 13.563v-3.126M2 10.5c0-.277.223-.5.5-.5H3v.5c0 .277-.223.5-.5.5a.499.499 0 0 1-.5-.5M2.5 9C1.67 9 1 9.67 1 10.5S1.67 12 2.5 12 4 11.33 4 10.5v-1a.5.5 0 0 0-.5-.5zm7.938 0c-.213 0-.438.192-.438.5s.225.5.438.5h3.124c.213 0 .438-.192.438-.5s-.225-.5-.437-.5h-3.126M9 9.5c0-.799.613-1.5 1.438-1.5h3.124C14.388 8 15 8.701 15 9.5s-.613 1.5-1.437 1.5h-3.126C9.614 11 9 10.299 9 9.5m.5 2.5a.5.5 0 0 0-.5.5v1c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm.5 1.5V13h.5c.277 0 .5.223.5.5s-.223.5-.5.5a.499.499 0 0 1-.5-.5m-9-7C1 5.701 1.613 5 2.438 5h3.125C6.387 5 7 5.701 7 6.5S6.387 8 5.563 8H2.438C1.613 8 1 7.299 1 6.5M2.438 6C2.225 6 2 6.192 2 6.5s.225.5.438.5h3.125C5.775 7 6 6.808 6 6.5S5.775 6 5.563 6H2.438M5.5 1C4.67 1 4 1.67 4 2.5S4.67 4 5.5 4h1a.5.5 0 0 0 .5-.5v-1C7 1.67 6.33 1 5.5 1M5 2.5c0-.277.223-.5.5-.5s.5.223.5.5V3h-.5a.499.499 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.438 6C2.225 6 2 6.192 2 6.5s.225.5.438.5h3.125C5.775 7 6 6.808 6 6.5S5.775 6 5.563 6H2.438M9 2.438C9 2.225 9.192 2 9.5 2s.5.225.5.438v3.125c0 .212-.192.437-.5.437S9 5.775 9 5.563V2.438M5 2.5c0-.277.223-.5.5-.5s.5.223.5.5V3h-.5a.499.499 0 0 1-.5-.5M2 10.5c0-.277.223-.5.5-.5H3v.5c0 .277-.223.5-.5.5a.499.499 0 0 1-.5-.5M6.5 10c-.308 0-.5.225-.5.438v3.124c0 .213.192.438.5.438s.5-.225.5-.437v-3.126c0-.212-.192-.437-.5-.437M10 13.5V13h.5c.277 0 .5.223.5.5s-.223.5-.5.5a.499.499 0 0 1-.5-.5M10.438 9c-.213 0-.438.192-.438.5s.225.5.438.5h3.124c.213 0 .438-.192.438-.5s-.225-.5-.437-.5h-3.126M13 5.5c0-.277.223-.5.5-.5s.5.223.5.5-.223.5-.5.5H13z'/%3e%3c/svg%3e")`,
                "slack-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.125.75C6.526.75 6 1.21 6 1.828v2.344c0 .618.526 1.078 1.125 1.078S8.25 4.79 8.25 4.172V1.828C8.25 1.21 7.724.75 7.125.75M6.75 1.828c0-.16.144-.328.375-.328s.375.169.375.328v2.344c0 .16-.144.328-.375.328s-.375-.169-.375-.328V1.828ZM10.125 3C9.503 3 9 3.503 9 4.125v.75c0 .207.168.375.375.375h.75a1.124 1.124 0 1 0 0-2.25M9.75 4.125c0-.208.167-.375.375-.375s.375.167.375.375a.374.374 0 0 1-.375.375H9.75zM3.75 7.828c0-.618.526-1.078 1.125-1.078S6 7.21 6 7.828v2.344c0 .618-.526 1.078-1.125 1.078s-1.125-.46-1.125-1.078V7.828M4.875 7.5c-.231 0-.375.169-.375.328v2.344c0 .16.144.328.375.328s.375-.169.375-.328V7.828c0-.16-.144-.328-.375-.328M1.875 6.75a1.124 1.124 0 1 0 0 2.25C2.497 9 3 8.497 3 7.875v-.75a.375.375 0 0 0-.375-.375zM1.5 7.875c0-.208.167-.375.375-.375h.375v.375a.374.374 0 0 1-.375.375.374.374 0 0 1-.375-.375M6.75 7.125C6.75 6.526 7.21 6 7.828 6h2.344c.618 0 1.078.526 1.078 1.125s-.46 1.125-1.078 1.125H7.828c-.618 0-1.078-.526-1.078-1.125m1.078-.375c-.16 0-.328.144-.328.375s.169.375.328.375h2.344c.16 0 .328-.144.328-.375s-.169-.375-.328-.375H7.828M7.125 9a.375.375 0 0 0-.375.375v.75a1.124 1.124 0 1 0 2.25 0C9 9.503 8.497 9 7.875 9zm.375 1.125V9.75h.375c.208 0 .375.167.375.375a.374.374 0 0 1-.375.375.374.374 0 0 1-.375-.375M.75 4.875c0-.599.46-1.125 1.078-1.125h2.344c.618 0 1.078.526 1.078 1.125S4.79 6 4.172 6H1.828C1.21 6 .75 5.474.75 4.875M1.828 4.5c-.16 0-.328.144-.328.375s.169.375.328.375h2.344c.16 0 .328-.144.328-.375S4.331 4.5 4.172 4.5H1.828ZM4.125.75a1.124 1.124 0 1 0 0 2.25h.75a.375.375 0 0 0 .375-.375v-.75C5.25 1.253 4.747.75 4.125.75M3.75 1.875c0-.208.167-.375.375-.375s.375.167.375.375v.375h-.375a.374.374 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "slack": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.5 1C8.701 1 8 1.613 8 2.438v3.125C8 6.387 8.701 7 9.5 7S11 6.387 11 5.563V2.438C11 1.613 10.299 1 9.5 1M9 2.438C9 2.225 9.192 2 9.5 2s.5.225.5.438v3.125c0 .212-.192.437-.5.437S9 5.775 9 5.563V2.438M13.5 4c-.83 0-1.5.67-1.5 1.5v1a.5.5 0 0 0 .5.5h1c.83 0 1.5-.67 1.5-1.5S14.33 4 13.5 4M13 5.5c0-.277.223-.5.5-.5s.5.223.5.5-.223.5-.5.5H13zM5 10.438C5 9.613 5.701 9 6.5 9S8 9.613 8 10.438v3.124C8 14.388 7.299 15 6.5 15S5 14.387 5 13.563v-3.126M6.5 10c-.308 0-.5.225-.5.438v3.124c0 .213.192.438.5.438s.5-.225.5-.437v-3.126c0-.212-.192-.437-.5-.437M2.5 9C1.67 9 1 9.67 1 10.5S1.67 12 2.5 12 4 11.33 4 10.5v-1a.5.5 0 0 0-.5-.5zM2 10.5c0-.277.223-.5.5-.5H3v.5c0 .277-.223.5-.5.5a.499.499 0 0 1-.5-.5M9 9.5c0-.799.613-1.5 1.438-1.5h3.124C14.388 8 15 8.701 15 9.5s-.613 1.5-1.437 1.5h-3.126C9.614 11 9 10.299 9 9.5m1.438-.5c-.213 0-.438.192-.438.5s.225.5.438.5h3.124c.213 0 .438-.192.438-.5s-.225-.5-.437-.5h-3.126M9.5 12a.5.5 0 0 0-.5.5v1c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm.5 1.5V13h.5c.277 0 .5.223.5.5s-.223.5-.5.5a.499.499 0 0 1-.5-.5M1 6.5C1 5.701 1.613 5 2.438 5h3.125C6.387 5 7 5.701 7 6.5S6.387 8 5.563 8H2.438C1.613 8 1 7.299 1 6.5M2.438 6C2.225 6 2 6.192 2 6.5s.225.5.438.5h3.125C5.775 7 6 6.808 6 6.5S5.775 6 5.563 6H2.438M5.5 1C4.67 1 4 1.67 4 2.5S4.67 4 5.5 4h1a.5.5 0 0 0 .5-.5v-1C7 1.67 6.33 1 5.5 1M5 2.5c0-.277.223-.5.5-.5s.5.223.5.5V3h-.5a.499.499 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "skip-forward-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m2.091 1.917 5.35 3.777a.375.375 0 0 1 0 .612l-5.35 3.777a.375.375 0 0 1-.591-.307V2.224c0-.304.343-.482.591-.307M10.5 2.25a.375.375 0 0 0-.75 0v7.5a.375.375 0 1 0 .75 0v-7.5Z'/%3e%3c/svg%3e")`,
                "skip-forward-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m2.788 2.557 7.133 5.035a.5.5 0 0 1 0 .817l-7.133 5.034A.5.5 0 0 1 2 13.036V2.965a.5.5 0 0 1 .788-.408M14 3a.5.5 0 0 0-1 0v10a.5.5 0 1 0 1 0V3Z'/%3e%3c/svg%3e")`,
                "skip-forward-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m7.441 5.694-5.35-3.777a.375.375 0 0 0-.591.307v7.552c0 .304.343.482.591.307l5.35-3.777a.375.375 0 0 0 0-.612M6.574 6 2.25 9.053V2.948L6.574 6' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.5 2.25a.375.375 0 0 0-.75 0v7.5a.375.375 0 1 0 .75 0v-7.5Z'/%3e%3c/svg%3e")`,
                "skip-forward": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.921 7.592 2.788 2.557A.5.5 0 0 0 2 2.964v10.07a.5.5 0 0 0 .788.409l7.133-5.035a.5.5 0 0 0 0-.817M8.766 8 3 12.07V3.93L8.766 8' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M14 3a.5.5 0 0 0-1 0v10a.5.5 0 1 0 1 0V3Z'/%3e%3c/svg%3e")`,
                "skip-back-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m9.909 1.917-5.35 3.777a.375.375 0 0 0 0 .612l5.35 3.777a.375.375 0 0 0 .591-.307V2.224a.375.375 0 0 0-.591-.307M1.5 2.25a.375.375 0 1 1 .75 0v7.5a.375.375 0 1 1-.75 0v-7.5Z'/%3e%3c/svg%3e")`,
                "skip-back-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.212 2.557 6.079 7.592a.5.5 0 0 0 0 .817l7.133 5.034a.5.5 0 0 0 .788-.408V2.965a.5.5 0 0 0-.788-.408M2 3a.5.5 0 1 1 1 0v10a.5.5 0 1 1-1 0V3Z'/%3e%3c/svg%3e")`,
                "skip-back-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m4.559 5.694 5.35-3.777a.375.375 0 0 1 .591.307v7.552a.375.375 0 0 1-.591.307l-5.35-3.777a.375.375 0 0 1 0-.612M5.426 6 9.75 9.053V2.948L5.426 6' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 2.25a.375.375 0 1 1 .75 0v7.5a.375.375 0 1 1-.75 0v-7.5Z'/%3e%3c/svg%3e")`,
                "skip-back": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6.079 7.592 7.133-5.035a.5.5 0 0 1 .788.408v10.07a.5.5 0 0 1-.788.409L6.079 8.409a.5.5 0 0 1 0-.817M7.234 8 13 12.07V3.93L7.234 8' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 3a.5.5 0 1 1 1 0v10a.5.5 0 1 1-1 0V3Z'/%3e%3c/svg%3e")`,
                "sidebar-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.875 1C.839 1 0 1.84 0 2.875v6.25C0 10.161.84 11 1.875 11h8.25C11.161 11 12 10.16 12 9.125v-6.25C12 1.839 11.16 1 10.125 1zM5 1.75v8.5h5.125c.621 0 1.125-.504 1.125-1.125v-6.25c0-.621-.504-1.125-1.125-1.125z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "sidebar-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2zM6 3v10h7.5a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 13.5 3z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "sidebar-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.875 1C.839 1 0 1.84 0 2.875v6.25C0 10.161.84 11 1.875 11h8.25C11.161 11 12 10.16 12 9.125v-6.25C12 1.839 11.16 1 10.125 1zM.75 2.875c0-.621.504-1.125 1.125-1.125h2.563v8.5H1.874A1.125 1.125 0 0 1 .75 9.125zM5 10.25h5.125c.621 0 1.125-.504 1.125-1.125v-6.25c0-.621-.504-1.125-1.125-1.125H5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "sidebar": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2zM1 4.5A1.5 1.5 0 0 1 2.5 3h2.625v10H2.5A1.5 1.5 0 0 1 1 11.5zM5.875 13H13.5a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 13.5 3H5.875z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shuffle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='13' fill='none' viewBox='0 0 13 12'%3e%3cpath fill='%230E1011' d='M.375 9a.375.375 0 1 1 0-.75h1.473a1.5 1.5 0 0 0 1.061-.44l.95-.95a.375.375 0 1 1 .531.53l-.95.951A2.25 2.25 0 0 1 1.847 9zM6.64 5.14a.375.375 0 0 1-.53-.53l.95-.951A2.25 2.25 0 0 1 8.653 3h2.068l-.86-.86a.375.375 0 0 1 .53-.53l1.765 1.765L10.39 5.14a.375.375 0 0 1-.53-.53l.86-.86H8.652a1.5 1.5 0 0 0-1.061.44l-.95.95'/%3e%3cpath fill='%230E1011' d='M.375 3a.375.375 0 1 0 0 .75h1.473a1.5 1.5 0 0 1 1.061.44L7.061 8.34A2.25 2.25 0 0 0 8.65 9h2.069l-.86.86a.375.375 0 0 0 .53.53l1.765-1.765L10.39 6.86a.375.375 0 0 0-.53.53l.86.86H8.652a1.5 1.5 0 0 1-1.061-.44L3.439 3.66A2.25 2.25 0 0 0 1.85 3z'/%3e%3c/svg%3e")`,
                "shuffle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='17' fill='none' viewBox='0 0 17 16'%3e%3cpath fill='%230E1011' d='M.5 12a.5.5 0 0 1 0-1h1.964a2 2 0 0 0 1.415-.586l1.267-1.268a.5.5 0 1 1 .708.708L4.586 11.12A3 3 0 0 1 2.464 12zM8.854 6.854a.5.5 0 1 1-.708-.708L9.414 4.88A3 3 0 0 1 11.536 4h2.757l-1.147-1.146a.5.5 0 0 1 .708-.708L16.207 4.5l-2.353 2.354a.5.5 0 0 1-.708-.708L14.293 5h-2.757a2 2 0 0 0-1.415.586L8.854 6.854'/%3e%3cpath fill='%230E1011' d='M.5 4a.5.5 0 0 0 0 1h1.964a2 2 0 0 1 1.415.586l5.535 5.535a3 3 0 0 0 2.122.879h2.757l-1.147 1.146a.5.5 0 0 0 .708.708l2.353-2.354-2.353-2.354a.5.5 0 0 0-.708.708L14.293 11h-2.757a2 2 0 0 1-1.415-.586L4.586 4.88A3 3 0 0 0 2.464 4z'/%3e%3c/svg%3e")`,
                "shuffle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='13' fill='none' viewBox='0 0 13 12'%3e%3cpath fill='%230E1011' d='M.375 9a.375.375 0 1 1 0-.75h1.473a1.5 1.5 0 0 0 1.061-.44l.95-.95a.375.375 0 1 1 .531.53l-.95.951A2.25 2.25 0 0 1 1.847 9zM6.64 5.14a.375.375 0 0 1-.53-.53l.95-.951A2.25 2.25 0 0 1 8.653 3h2.068l-.86-.86a.375.375 0 0 1 .53-.53l1.765 1.765L10.39 5.14a.375.375 0 0 1-.53-.53l.86-.86H8.652a1.5 1.5 0 0 0-1.061.44l-.95.95'/%3e%3cpath fill='%230E1011' d='M.375 3a.375.375 0 1 0 0 .75h1.473a1.5 1.5 0 0 1 1.061.44L7.061 8.34A2.25 2.25 0 0 0 8.65 9h2.069l-.86.86a.375.375 0 0 0 .53.53l1.765-1.765L10.39 6.86a.375.375 0 0 0-.53.53l.86.86H8.652a1.5 1.5 0 0 1-1.061-.44L3.439 3.66A2.25 2.25 0 0 0 1.85 3z'/%3e%3c/svg%3e")`,
                "shuffle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='17' fill='none' viewBox='0 0 17 16'%3e%3cpath fill='%230E1011' d='M.5 12a.5.5 0 0 1 0-1h1.964a2 2 0 0 0 1.415-.586l1.267-1.268a.5.5 0 1 1 .708.708L4.586 11.12A3 3 0 0 1 2.464 12zM8.854 6.854a.5.5 0 1 1-.708-.708L9.414 4.88A3 3 0 0 1 11.536 4h2.757l-1.147-1.146a.5.5 0 0 1 .708-.708L16.207 4.5l-2.353 2.354a.5.5 0 0 1-.708-.708L14.293 5h-2.757a2 2 0 0 0-1.415.586L8.854 6.854'/%3e%3cpath fill='%230E1011' d='M.5 4a.5.5 0 0 0 0 1h1.964a2 2 0 0 1 1.415.586l5.535 5.535a3 3 0 0 0 2.122.879h2.757l-1.147 1.146a.5.5 0 0 0 .708.708l2.353-2.354-2.353-2.354a.5.5 0 0 0-.708.708L14.293 11h-2.757a2 2 0 0 1-1.415-.586L4.586 4.88A3 3 0 0 0 2.464 4z'/%3e%3c/svg%3e")`,
                "shopping-cart-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.38 0A.39.39 0 0 0 0 .4c0 .22.17.4.38.4H1.6l1.537 6.485c.212.89.97 1.515 1.84 1.515h4.737c.927 0 1.718-.707 1.87-1.671l.4-2.532c.116-.731-.419-1.397-1.122-1.397H2.95L2.336.606A.767.767 0 0 0 1.6 0H.38Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.93 9.6c-.628 0-1.137.537-1.137 1.2 0 .663.51 1.2 1.138 1.2.628 0 1.137-.537 1.137-1.2 0-.663-.51-1.2-1.137-1.2m-.379 1.2c0-.22.17-.4.38-.4.209 0 .379.18.379.4 0 .22-.17.4-.38.4a.39.39 0 0 1-.379-.4M9.482 9.6c-.629 0-1.138.537-1.138 1.2 0 .663.51 1.2 1.138 1.2.628 0 1.138-.537 1.138-1.2 0-.663-.51-1.2-1.138-1.2m-.38 1.2c0-.22.17-.4.38-.4s.379.18.379.4c0 .22-.17.4-.38.4a.39.39 0 0 1-.379-.4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-cart-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M.5 1a.5.5 0 0 0 0 1h1.61l2.026 8.106A2.5 2.5 0 0 0 6.562 12h6.244a2.5 2.5 0 0 0 2.466-2.089l.527-3.164A1.5 1.5 0 0 0 14.32 5H3.89l-.81-3.243A1 1 0 0 0 2.11 1z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M6 14.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0M12.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-.5 1.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-cart-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.38 0A.39.39 0 0 0 0 .4c0 .22.17.4.38.4H1.6l1.537 6.485c.212.89.97 1.515 1.84 1.515h4.737c.927 0 1.718-.707 1.87-1.671l.4-2.532c.116-.731-.419-1.397-1.122-1.397H2.95L2.336.606A.767.767 0 0 0 1.6 0H.38Zm3.493 7.091L3.141 4h7.72c.235 0 .413.222.375.466l-.4 2.531C10.745 7.576 10.27 8 9.714 8H4.977C4.455 8 4 7.625 3.873 7.091M4.93 9.6c-.628 0-1.137.537-1.137 1.2 0 .663.51 1.2 1.138 1.2.628 0 1.137-.537 1.137-1.2 0-.663-.51-1.2-1.137-1.2m-.379 1.2c0-.22.17-.4.38-.4.209 0 .379.18.379.4 0 .22-.17.4-.38.4a.39.39 0 0 1-.379-.4M9.482 9.6c-.629 0-1.138.537-1.138 1.2 0 .663.51 1.2 1.138 1.2.628 0 1.138-.537 1.138-1.2 0-.663-.51-1.2-1.138-1.2m-.38 1.2c0-.22.17-.4.38-.4s.379.18.379.4c0 .22-.17.4-.38.4a.39.39 0 0 1-.379-.4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-cart": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.5 1a.5.5 0 0 0 0 1h1.61l2.026 8.106A2.5 2.5 0 0 0 6.562 12h6.244a2.5 2.5 0 0 0 2.466-2.089l.527-3.164A1.5 1.5 0 0 0 14.32 5H3.89l-.81-3.243A1 1 0 0 0 2.11 1zm4.606 8.864L4.14 6h10.18a.5.5 0 0 1 .493.582l-.528 3.165A1.5 1.5 0 0 1 12.805 11H6.563a1.5 1.5 0 0 1-1.456-1.136M6.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M6 14.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0M12.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-.5 1.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-bag-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.934 0a.697.697 0 0 0-.505.22L1 1.72v7.655C1 10.825 2.12 12 3.5 12h5c1.38 0 2.5-1.175 2.5-2.625V1.72L9.571.22A.697.697 0 0 0 9.066 0H2.934m0 .75h6.132l.715.75H2.219l.715-.75m4.137 4.5c.987 0 1.786-.84 1.786-1.875v-1.5h-.714v1.5c0 .621-.48 1.125-1.072 1.125H4.93c-.592 0-1.072-.504-1.072-1.125v-1.5h-.714v1.5c0 1.036.8 1.875 1.786 1.875H7.07' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-bag-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.707 0A1 1 0 0 0 3 .293l-2 2V12.5A3.5 3.5 0 0 0 4.5 16h7a3.5 3.5 0 0 0 3.5-3.5V2.293l-2-2A1 1 0 0 0 12.293 0H3.707m0 1h8.586l1 1H2.707l1-1M9.5 7A2.5 2.5 0 0 0 12 4.5v-2h-1v2A1.5 1.5 0 0 1 9.5 6h-3A1.5 1.5 0 0 1 5 4.5v-2H4v2A2.5 2.5 0 0 0 6.5 7z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-bag-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.429.22A.697.697 0 0 1 2.934 0h6.132c.19 0 .371.079.505.22L11 1.72v7.655C11 10.825 9.88 12 8.5 12h-5C2.12 12 1 10.825 1 9.375V1.72L2.429.22Zm6.637.53H2.934l-.715.75h7.562L9.066.75m1.22 1.5H8.857v1.125c0 1.036-.8 1.875-1.786 1.875H4.93c-.987 0-1.786-.84-1.786-1.875V2.25H1.714v7.125c0 1.036.8 1.875 1.786 1.875h5c.986 0 1.786-.84 1.786-1.875V2.25m-6.429 0v1.125c0 .621.48 1.125 1.072 1.125H7.07c.592 0 1.072-.504 1.072-1.125V2.25H3.857' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shopping-bag": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 .293A1 1 0 0 1 3.707 0h8.586A1 1 0 0 1 13 .293l2 2V12.5a3.5 3.5 0 0 1-3.5 3.5h-7A3.5 3.5 0 0 1 1 12.5V2.293l2-2ZM12.293 1H3.707l-1 1h10.586l-1-1M14 3h-2v1.5A2.5 2.5 0 0 1 9.5 7h-3A2.5 2.5 0 0 1 4 4.5V3H2v9.5A2.5 2.5 0 0 0 4.5 15h7a2.5 2.5 0 0 0 2.5-2.5zM5 3v1.5A1.5 1.5 0 0 0 6.5 6h3A1.5 1.5 0 0 0 11 4.5V3z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shield-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' d='m6 .98 4.478 1.48c.46.152.772.583.772 1.068v2.255c0 1.195-.3 2.35-.847 3.37L3.166 1.916 6 .98M9.227 10.757l1.945 1.946a.375.375 0 1 0 .53-.53L.829 1.296a.375.375 0 0 0-.53.53l.845.847C.9 2.883.75 3.192.75 3.528v2.255a7.125 7.125 0 0 0 3.22 5.96L6 13.073l2.03-1.33a7.125 7.125 0 0 0 1.197-.986'/%3e%3c/svg%3e")`,
                "shield-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' d='m8 .973 5.97 1.974A1.5 1.5 0 0 1 15 4.37v3.007a9.496 9.496 0 0 1-1.13 4.493L4.223 2.222 8 .973ZM12.303 14.01l2.593 2.594a.5.5 0 0 0 .708-.708l-14.5-14.5a.5.5 0 1 0-.708.708L1.524 3.23A1.5 1.5 0 0 0 1 4.371v3.007a9.5 9.5 0 0 0 4.293 7.946L8 17.098l2.707-1.774a9.502 9.502 0 0 0 1.596-1.314'/%3e%3c/svg%3e")`,
                "shield-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.882.019a.375.375 0 0 1 .236 0l4.36 1.441c.46.152.772.583.772 1.068v2.256c0 1.153-.279 2.269-.791 3.263l-.667-.343c.458-.89.708-1.889.708-2.92V2.528a.375.375 0 0 0-.257-.356L6 .77l-2.419.8-.235-.713L5.882.02ZM1.143 1.674.11.64.64.11l11.25 11.25-.53.53-2.133-2.133a7.125 7.125 0 0 1-1.197.986L6.206 11.94a.375.375 0 0 1-.412 0L3.97 10.743a7.125 7.125 0 0 1-3.22-5.96V2.529c0-.336.149-.645.393-.854m.535.535a.375.375 0 0 0-.178.32v2.255a6.375 6.375 0 0 0 2.881 5.332L6 11.176l1.619-1.06a6.375 6.375 0 0 0 1.078-.89L1.678 2.21Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shield-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.843.025a.5.5 0 0 1 .314 0l5.814 1.922A1.5 1.5 0 0 1 15 3.37v3.007a9.495 9.495 0 0 1-1.055 4.351l-.89-.458A8.495 8.495 0 0 0 14 6.378V3.371a.5.5 0 0 0-.343-.475L8 1.026 4.775 2.094l-.314-.95L7.843.025ZM1.524 2.231.146.854.854.146l15 15-.708.708-2.843-2.844a9.502 9.502 0 0 1-1.596 1.314l-2.433 1.594a.5.5 0 0 1-.548 0l-2.433-1.594A9.5 9.5 0 0 1 1 6.378V3.371c0-.448.199-.86.524-1.14m.714.714A.5.5 0 0 0 2 3.371v3.007a8.5 8.5 0 0 0 3.841 7.11L8 14.902l2.159-1.414a8.495 8.495 0 0 0 1.436-1.185L2.238 2.944Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shield-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6 .98 4.478 1.48c.46.152.772.583.772 1.068v2.255a7.125 7.125 0 0 1-3.22 5.96L6 13.073l-2.03-1.33a7.125 7.125 0 0 1-3.22-5.96V3.528c0-.485.311-.916.772-1.068L6 .98Zm0 .79L1.757 3.172a.375.375 0 0 0-.257.356v2.255a6.375 6.375 0 0 0 2.881 5.333L6 12.176l1.619-1.06A6.375 6.375 0 0 0 10.5 5.783V3.528a.375.375 0 0 0-.257-.356L6 1.77' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.757 3.172 6 1.77l4.243 1.402c.153.05.257.194.257.356v2.255a6.375 6.375 0 0 1-2.881 5.333L6 12.176l-1.619-1.06A6.375 6.375 0 0 1 1.5 5.783V3.528c0-.162.104-.305.257-.356'/%3e%3c/svg%3e")`,
                "shield-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 .973 5.97 1.974A1.5 1.5 0 0 1 15 4.37v3.007a9.5 9.5 0 0 1-4.293 7.946L8 17.098l-2.707-1.774A9.5 9.5 0 0 1 1 7.378V4.371a1.5 1.5 0 0 1 1.03-1.424L8 .973Zm0 1.054-5.657 1.87A.5.5 0 0 0 2 4.37v3.007a8.5 8.5 0 0 0 3.841 7.11L8 15.902l2.159-1.414A8.5 8.5 0 0 0 14 7.378V4.371a.5.5 0 0 0-.343-.475L8 2.026' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.343 3.896 8 2.026l5.657 1.87a.5.5 0 0 1 .343.475v3.007a8.5 8.5 0 0 1-3.841 7.11L8 15.902l-2.159-1.414A8.5 8.5 0 0 1 2 7.378V4.371a.5.5 0 0 1 .343-.475'/%3e%3c/svg%3e")`,
                "shield-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='14' fill='none' viewBox='0 0 12 14'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6 .98 4.478 1.48c.46.152.772.583.772 1.068v2.255a7.125 7.125 0 0 1-3.22 5.96L6 13.073l-2.03-1.33a7.125 7.125 0 0 1-3.22-5.96V3.528c0-.485.311-.916.772-1.068L6 .98Zm0 .79L1.757 3.172a.375.375 0 0 0-.257.356v2.255a6.375 6.375 0 0 0 2.881 5.333L6 12.176l1.619-1.06A6.375 6.375 0 0 0 10.5 5.783V3.528a.375.375 0 0 0-.257-.356L6 1.77' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "shield": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='18' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 .973 5.97 1.974A1.5 1.5 0 0 1 15 4.37v3.007a9.5 9.5 0 0 1-4.293 7.946L8 17.098l-2.707-1.774A9.5 9.5 0 0 1 1 7.378V4.371a1.5 1.5 0 0 1 1.03-1.424L8 .973Zm0 1.054-5.657 1.87A.5.5 0 0 0 2 4.37v3.007a8.5 8.5 0 0 0 3.841 7.11L8 15.902l2.159-1.414A8.5 8.5 0 0 0 14 7.378V4.371a.5.5 0 0 0-.343-.475L8 2.026' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "share-2-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.4.407a2.25 2.25 0 1 1-.312 3.423L5.243 5.825a2.283 2.283 0 0 1 .004.284l2.844 2.057a2.25 2.25 0 1 1-.431.614L5.062 6.9a2.25 2.25 0 1 1-.021-1.85l2.617-1.835A2.25 2.25 0 0 1 8.4.407Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "share-2-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.2.543a3 3 0 1 1-.416 4.564L6.99 7.767a3.041 3.041 0 0 1 .006.379l3.792 2.742a3 3 0 1 1-.576.818L6.75 9.201a3 3 0 1 1-.03-2.467l3.49-2.446A3 3 0 0 1 11.2.543Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "share-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.4.407a2.25 2.25 0 1 1-.312 3.423L5.243 5.825a2.283 2.283 0 0 1 .004.284l2.844 2.057a2.25 2.25 0 1 1-.431.614L5.062 6.9a2.25 2.25 0 1 1-.021-1.85l2.617-1.835A2.25 2.25 0 0 1 8.4.407Zm2.519.983A1.5 1.5 0 1 0 8.46 3.11a1.5 1.5 0 0 0 2.458-1.72m0 9.22A1.5 1.5 0 1 1 8.46 8.89a1.5 1.5 0 0 1 2.458 1.72M1.5 6a1.5 1.5 0 1 1 3 0 1.5 1.5 0 0 1-3 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "share-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.2.543a3 3 0 1 1-.416 4.564L6.99 7.767a3.041 3.041 0 0 1 .006.379l3.792 2.742a3 3 0 1 1-.576.818L6.75 9.201a3 3 0 1 1-.03-2.467l3.49-2.446A3 3 0 0 1 11.2.543Zm3.359 1.31a2 2 0 1 0-3.277 2.294 2 2 0 0 0 3.277-2.294m0 12.294a2 2 0 1 1-3.277-2.294 2 2 0 0 1 3.277 2.294M2 8a2 2 0 1 1 4 0 2 2 0 0 1-4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "share-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.688 10.25a.938.938 0 0 1-.938-.937v-3.5c0-.518.42-.938.938-.938h.187a.375.375 0 0 0 0-.75h-.187C2.756 4.125 2 4.881 2 5.813v3.5C2 10.244 2.756 11 3.688 11h4.624C9.245 11 10 10.245 10 9.313v-3.5c0-.932-.756-1.688-1.687-1.688h-.188a.375.375 0 1 0 0 .75h.188c.517 0 .937.42.937.938v3.5c0 .517-.42.937-.937.937H3.686M6 8.25a.375.375 0 0 0 .375-.375v-6.22l1.61 1.61a.375.375 0 0 0 .53-.53L6 .22 3.485 2.735a.375.375 0 1 0 .53.53l1.61-1.61v6.22c0 .207.168.375.375.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "share": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 14C3.56 14 3 13.44 3 12.75v-5c0-.69.56-1.25 1.25-1.25h.25a.5.5 0 1 0 0-1h-.25A2.25 2.25 0 0 0 2 7.75v5A2.25 2.25 0 0 0 4.25 15h7.5A2.25 2.25 0 0 0 14 12.75v-5a2.25 2.25 0 0 0-2.25-2.25h-.25a.5.5 0 0 0 0 1h.25c.69 0 1.25.56 1.25 1.25v5c0 .69-.56 1.25-1.25 1.25zM8 11a.5.5 0 0 0 .5-.5V2.207l2.146 2.147a.5.5 0 0 0 .708-.708L8 .293 4.646 3.646a.5.5 0 1 0 .708.708L7.5 2.207V10.5a.5.5 0 0 0 .5.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "settings-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.221 1.362c-.315-.225-.74-.238-1.038.008a6.037 6.037 0 0 0-.813.813c-.246.298-.233.723-.008 1.038a.934.934 0 0 1-.607 1.465c-.381.063-.691.355-.728.74a6.074 6.074 0 0 0 0 1.148c.037.385.347.677.728.74a.934.934 0 0 1 .607 1.465c-.225.315-.238.74.008 1.038.245.296.517.568.813.813.298.246.723.233 1.038.008a.934.934 0 0 1 1.465.607c.063.381.355.691.74.728a6.09 6.09 0 0 0 1.148 0c.385-.037.677-.347.74-.728a.934.934 0 0 1 1.465-.607c.315.225.74.238 1.038-.008.296-.245.568-.517.813-.813.246-.298.233-.723.008-1.038a.934.934 0 0 1 .607-1.465c.381-.063.691-.355.728-.74a6.09 6.09 0 0 0 0-1.148c-.037-.385-.347-.677-.728-.74a.934.934 0 0 1-.607-1.465c.225-.315.238-.74-.008-1.038a6.036 6.036 0 0 0-.813-.813c-.298-.246-.723-.233-1.038-.008A.934.934 0 0 1 7.314.755C7.251.374 6.96.064 6.574.027a6.074 6.074 0 0 0-1.148 0c-.385.037-.677.347-.74.728a.934.934 0 0 1-1.465.607M7.716 6a1.716 1.716 0 1 1-3.432 0 1.716 1.716 0 0 1 3.432 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "settings-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m2.485 11.203-.182.254c-.241.337-.254.791.005 1.114.332.413.708.789 1.12 1.12.323.26.778.247 1.115.006l.254-.182a1 1 0 0 1 1.568.65l.051.309c.068.408.38.739.792.784a7.404 7.404 0 0 0 1.584 0c.412-.045.724-.376.792-.784l.05-.31a1 1 0 0 1 1.569-.649l.254.182c.337.24.792.254 1.114-.005a7.339 7.339 0 0 0 1.12-1.12c.26-.323.247-.778.006-1.115l-.182-.254a1 1 0 0 1 .65-1.568l.309-.051c.408-.068.74-.38.784-.792a7.4 7.4 0 0 0 0-1.584c-.045-.412-.376-.724-.784-.792l-.31-.051a1 1 0 0 1-.649-1.568l.182-.254c.24-.337.254-.792-.005-1.114a7.346 7.346 0 0 0-1.12-1.121c-.323-.26-.778-.246-1.115-.005l-.254.182a1 1 0 0 1-1.568-.65l-.051-.309c-.068-.408-.38-.74-.792-.784a7.382 7.382 0 0 0-1.584 0c-.412.045-.724.376-.792.784l-.051.309a1 1 0 0 1-1.568.65l-.254-.182c-.337-.24-.792-.254-1.114.005a7.344 7.344 0 0 0-1.121 1.12c-.26.323-.246.778-.005 1.115l.182.254a1 1 0 0 1-.65 1.568l-.309.051c-.408.068-.74.38-.784.792a7.382 7.382 0 0 0 0 1.584c.045.412.376.724.784.792l.309.05a1 1 0 0 1 .65 1.569M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "settings-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.466 6a2.466 2.466 0 1 1-4.932 0 2.466 2.466 0 0 1 4.932 0m-.75 0a1.716 1.716 0 1 1-3.432 0 1.716 1.716 0 0 1 3.432 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.183 1.37c.298-.246.723-.233 1.038-.008A.934.934 0 0 0 4.686.755c.063-.381.355-.691.74-.728a6.074 6.074 0 0 1 1.148 0c.385.037.677.347.74.728a.934.934 0 0 0 1.465.607c.315-.225.74-.238 1.038.008.296.245.568.517.813.813.246.298.233.723.008 1.038a.934.934 0 0 0 .607 1.465c.381.063.691.355.728.74a6.09 6.09 0 0 1 0 1.148c-.037.385-.347.677-.728.74a.934.934 0 0 0-.607 1.465c.225.315.238.74-.008 1.038a6.038 6.038 0 0 1-.813.813c-.298.246-.723.233-1.038.008a.934.934 0 0 0-1.465.607c-.063.381-.355.691-.74.728a6.09 6.09 0 0 1-1.148 0c-.385-.037-.677-.347-.74-.728a.934.934 0 0 0-1.465-.607c-.315.225-.74.238-1.038-.008a6.036 6.036 0 0 1-.813-.813c-.246-.298-.233-.723-.008-1.038a.934.934 0 0 0-.607-1.465c-.381-.063-.691-.355-.728-.74a6.074 6.074 0 0 1 0-1.148c.037-.385.347-.677.728-.74a.934.934 0 0 0 .607-1.465c-.225-.315-.238-.74.008-1.038.245-.296.517-.568.813-.813M5.497.774a5.324 5.324 0 0 1 1.006 0c.006 0 .016.002.03.016a.164.164 0 0 1 .041.088 1.684 1.684 0 0 0 2.641 1.094.164.164 0 0 1 .092-.032c.02 0 .028.005.032.009.26.214.498.452.712.711.004.005.01.013.01.033a.164.164 0 0 1-.033.092 1.684 1.684 0 0 0 1.094 2.64.164.164 0 0 1 .088.042c.014.014.016.024.016.03a5.328 5.328 0 0 1 0 1.006c0 .006-.002.016-.017.03a.164.164 0 0 1-.087.041 1.684 1.684 0 0 0-1.094 2.641.164.164 0 0 1 .032.092c0 .02-.005.028-.009.032-.214.26-.452.498-.712.712-.004.004-.012.01-.032.01a.164.164 0 0 1-.092-.033 1.684 1.684 0 0 0-2.64 1.094.164.164 0 0 1-.042.088c-.014.014-.024.016-.03.016a5.328 5.328 0 0 1-1.006 0c-.006 0-.016-.002-.03-.017a.164.164 0 0 1-.041-.087 1.684 1.684 0 0 0-2.641-1.094.164.164 0 0 1-.092.032c-.02 0-.028-.005-.033-.009a5.288 5.288 0 0 1-.711-.712c-.004-.004-.01-.012-.01-.032 0-.024.009-.058.033-.092a1.684 1.684 0 0 0-1.094-2.64.164.164 0 0 1-.088-.042c-.014-.014-.016-.024-.016-.03a5.323 5.323 0 0 1 0-1.006c0-.006.002-.016.016-.03a.164.164 0 0 1 .088-.041 1.684 1.684 0 0 0 1.094-2.641.164.164 0 0 1-.032-.092c0-.02.005-.028.009-.032.214-.26.452-.498.712-.712.004-.004.012-.01.032-.01.024 0 .058.009.092.033A1.684 1.684 0 0 0 5.425.878.164.164 0 0 1 5.468.79c.014-.014.024-.016.03-.016' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "settings": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m2.303 11.457.182-.254a1 1 0 0 0-.65-1.568l-.309-.051c-.408-.068-.74-.38-.784-.792a7.382 7.382 0 0 1 0-1.584c.045-.412.376-.724.784-.792l.309-.051a1 1 0 0 0 .65-1.568l-.182-.254c-.241-.337-.254-.792.005-1.114a7.344 7.344 0 0 1 1.12-1.12c.323-.26.778-.247 1.115-.006l.254.182a1 1 0 0 0 1.568-.65l.051-.309c.068-.408.38-.74.792-.784a7.382 7.382 0 0 1 1.584 0c.412.045.724.376.792.784l.05.309a1 1 0 0 0 1.569.65l.254-.182c.337-.241.791-.254 1.114.005.413.332.789.708 1.12 1.12.26.323.247.778.006 1.115l-.182.254a1 1 0 0 0 .65 1.568l.309.051c.408.068.739.38.784.792a7.404 7.404 0 0 1 0 1.584c-.045.412-.376.724-.784.792l-.31.05a1 1 0 0 0-.649 1.569l.182.254c.24.337.254.792-.005 1.114a7.339 7.339 0 0 1-1.12 1.12c-.323.26-.778.247-1.115.006l-.254-.182a1 1 0 0 0-1.568.65l-.051.309c-.068.408-.38.74-.792.784a7.374 7.374 0 0 1-1.584 0c-.412-.045-.724-.376-.792-.784l-.051-.31a1 1 0 0 0-1.568-.649l-.254.182c-.337.24-.792.254-1.114-.005a7.346 7.346 0 0 1-1.121-1.12c-.26-.323-.246-.778-.005-1.115m.836-7.465c.256-.31.542-.597.853-.853l.223.159a2 2 0 0 0 3.136-1.299l.045-.27a6.389 6.389 0 0 1 1.207 0l.045.27a2 2 0 0 0 3.137 1.299l.223-.16c.31.257.596.543.853.854l-.16.223a2 2 0 0 0 1.3 3.136l.27.045a6.398 6.398 0 0 1 0 1.207l-.27.045a2 2 0 0 0-1.3 3.137l.16.223c-.257.31-.543.597-.854.853l-.223-.16a2 2 0 0 0-3.136 1.3l-.045.27a6.395 6.395 0 0 1-1.207 0l-.045-.27a2 2 0 0 0-3.136-1.3l-.223.16a6.348 6.348 0 0 1-.853-.854l.159-.223a2 2 0 0 0-1.299-3.136l-.27-.045a6.389 6.389 0 0 1 0-1.207l.27-.045a2 2 0 0 0 1.299-3.136l-.16-.223Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "server-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.5 1A1.5 1.5 0 0 1 12 2.5v1A1.5 1.5 0 0 1 10.5 5h-9A1.5 1.5 0 0 1 0 3.5v-1A1.5 1.5 0 0 1 1.5 1zM4.75 2H4v.75h.75zM2 2h.75v.75H2zM10.5 7A1.5 1.5 0 0 1 12 8.5v1a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 0 9.5v-1A1.5 1.5 0 0 1 1.5 7zM4 8h.75v.75H4zM2 8h.75v.75H2z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "server-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm2 1V3h1v1zm2 0V3h1v1zM0 11a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm2 1v-1h1v1zm2 0v-1h1v1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "server-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2 2h.75v.75H2zM4 2h.75v.75H4z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.5 1A1.5 1.5 0 0 1 12 2.5v1A1.5 1.5 0 0 1 10.5 5h-9A1.5 1.5 0 0 1 0 3.5v-1A1.5 1.5 0 0 1 1.5 1zm.75 1.5v1a.75.75 0 0 1-.75.75h-9a.75.75 0 0 1-.75-.75v-1a.75.75 0 0 1 .75-.75h9a.75.75 0 0 1 .75.75' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.75 8H2v.75h.75zM4.75 8H4v.75h.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.5 7A1.5 1.5 0 0 1 12 8.5v1a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 0 9.5v-1A1.5 1.5 0 0 1 1.5 7zm.75 1.5v1a.75.75 0 0 1-.75.75h-9a.75.75 0 0 1-.75-.75v-1a.75.75 0 0 1 .75-.75h9a.75.75 0 0 1 .75.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "server": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2 3v1h1V3zM4 3v1h1V3z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm2-1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 11v1h1v-1zM4 11v1h1v-1z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 9a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2zm-1 2a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "send-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.419 1.055a.375.375 0 0 0-.487-.47L.622 4.336a.375.375 0 0 0-.011.7l4.538 1.816 1.815 4.538a.375.375 0 0 0 .7-.01l3.75-10.311a.297.297 0 0 0 .005-.013m-.841.898a.375.375 0 0 0-.53-.53L5.36 6.11a.375.375 0 1 0 .53.53l4.688-4.687Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "send-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.225 1.407a.5.5 0 0 0-.649-.626l-13.747 5a.5.5 0 0 0-.015.933l6.051 2.42 2.42 6.052a.5.5 0 0 0 .935-.015l4.999-13.747a.527.527 0 0 0 .006-.017m-1.121 1.197a.5.5 0 0 0-.708-.707l-6.25 6.25a.5.5 0 1 0 .708.707l6.25-6.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "send-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.419 1.055a.375.375 0 0 0-.487-.47L.622 4.336a.375.375 0 0 0-.011.7l4.538 1.816 1.815 4.538a.375.375 0 0 0 .7-.01l3.75-10.311a.297.297 0 0 0 .005-.013M5.878 6.653l1.418 3.546 2.836-7.801-4.254 4.255m-.53-.53 4.254-4.255-7.8 2.836 3.545 1.419' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "send": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.225 1.407a.5.5 0 0 0-.649-.626l-13.747 5a.5.5 0 0 0-.015.933l6.051 2.42 2.42 6.052a.5.5 0 0 0 .935-.015l4.999-13.747a.527.527 0 0 0 .006-.017M7.837 8.871l1.89 4.727 3.783-10.4L7.837 8.87m-.707-.708 5.673-5.673L2.402 6.272 7.13 8.163' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "search-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.5 2.875A2.625 2.625 0 0 0 2.875 5.5h-.75A3.375 3.375 0 0 1 5.5 2.125z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.62 9.144a5.5 5.5 0 1 0-.475.475.374.374 0 0 0 .09.146l2 2a.375.375 0 0 0 .53-.53l-2-2a.374.374 0 0 0-.146-.09M5.5 10.25a4.75 4.75 0 1 0 0-9.5 4.75 4.75 0 0 0 0 9.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "search": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 2.625A3.375 3.375 0 0 0 2.625 6h.75A2.625 2.625 0 0 1 6 3.375z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.5a6.5 6.5 0 1 1 11.399 4.273.5.5 0 0 1 .205.123L15 14.293a.5.5 0 1 1-.707.707l-3.397-3.396a.5.5 0 0 1-.123-.205A6.5 6.5 0 0 1 0 6.5M6.5 1a5.5 5.5 0 1 0 0 11 5.5 5.5 0 0 0 0-11' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "screwdriver-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.5 2.793V1.5L1 0 0 1l1.5 2.5h1.293l2.484 2.484A1.99 1.99 0 0 0 5 7v.249a2 2 0 0 0 .495 1.317l2.407 2.751A2 2 0 0 0 9.408 12H10a2 2 0 0 0 2-2v-.592a2 2 0 0 0-.683-1.506L8.566 5.495A2 2 0 0 0 7.249 5H7c-.37 0-.718.101-1.016.277L3.5 2.793'/%3e%3c/svg%3e")`,
                "screwdriver-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.5v1.293l3.484 3.484A1.99 1.99 0 0 1 9 7h.233a2 2 0 0 1 1.337.513l3.768 3.391A2 2 0 0 1 15 12.391V13a2 2 0 0 1-2 2h-.61a2 2 0 0 1-1.486-.662l-3.39-3.767A2 2 0 0 1 7 9.232V9c0-.37.101-.718.277-1.016L3.793 4.5H2.5L1 2l1-1zm4.788 6.212a.3.3 0 1 1 .424-.424l3.207 3.207a1.3 1.3 0 0 1 .381.92v.085a.3.3 0 1 1-.6 0v-.086a.7.7 0 0 0-.205-.495L9.288 8.712' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "screwdriver-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2.793V1.5L1 0 0 1l1.5 2.5h1.293l2.573 2.573a2.325 2.325 0 0 0 .194 2.765l1.962 2.289A2.5 2.5 0 0 0 9.42 12h.08A2.5 2.5 0 0 0 12 9.5v-.08a2.5 2.5 0 0 0-.873-1.898L8.838 5.56a2.325 2.325 0 0 0-2.765-.194L3.5 2.793M7.325 6a1.325 1.325 0 0 0-1.006 2.187l1.962 2.29A1.5 1.5 0 0 0 9.42 11h.08A1.5 1.5 0 0 0 11 9.5v-.08a1.5 1.5 0 0 0-.524-1.139L8.187 6.319A1.325 1.325 0 0 0 7.325 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "screwdriver": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.288 8.712a.3.3 0 1 1 .424-.424l3.207 3.207a1.3 1.3 0 0 1 .381.92v.085a.3.3 0 1 1-.6 0v-.086a.7.7 0 0 0-.205-.495L9.288 8.712'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.5v1.293l3.354 3.353a.498.498 0 0 1 .138.267 2.311 2.311 0 0 1 2.854.17l3.315 2.947A2.5 2.5 0 0 1 15 12.398v.102a2.5 2.5 0 0 1-2.5 2.5h-.102a2.5 2.5 0 0 1-1.868-.84l-2.946-3.313a2.311 2.311 0 0 1-.171-2.855.498.498 0 0 1-.267-.138L3.793 4.5H2.5L1 2l1-1zM8 9.311a1.311 1.311 0 0 1 2.182-.98l3.314 2.946A1.5 1.5 0 0 1 14 12.398v.102a1.5 1.5 0 0 1-1.5 1.5h-.102a1.5 1.5 0 0 1-1.121-.504l-2.946-3.314A1.311 1.311 0 0 1 8 9.313' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "scissors-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1.125a1.875 1.875 0 1 0 1.034 3.44L5.47 6 4.034 7.436a1.875 1.875 0 1 0 .53.53l6.201-6.2a.375.375 0 0 0-.53-.531L6 5.47 4.564 4.034A1.875 1.875 0 0 0 3 1.125M1.875 3a1.125 1.125 0 1 1 2.25 0 1.125 1.125 0 0 1-2.25 0M3 7.875a1.125 1.125 0 1 0 0 2.25 1.125 1.125 0 0 0 0-2.25' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M7.235 7.235a.375.375 0 0 1 .53 0l3 3a.375.375 0 0 1-.53.53l-3-3a.375.375 0 0 1 0-.53'/%3e%3c/svg%3e")`,
                "scissors": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.268 1.732a2.5 2.5 0 1 0-.39 3.854L7.294 8l-2.414 2.414a2.5 2.5 0 1 0 .707.707l8.268-8.267a.5.5 0 0 0-.708-.708L8 7.293 5.586 4.879a2.5 2.5 0 0 0-.318-3.147m-2.829.707a1.5 1.5 0 1 1 2.122 2.122 1.5 1.5 0 0 1-2.122-2.122m0 9a1.5 1.5 0 1 1 2.122 2.122 1.5 1.5 0 0 1-2.122-2.122' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.854 10.146a.5.5 0 0 0-.708.708l3 3a.5.5 0 0 0 .708-.708l-3-3'/%3e%3c/svg%3e")`,
                "scan": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 2a1 1 0 0 0-1 1v2a.5.5 0 0 1-1 0V3a2 2 0 0 1 2-2h2a.5.5 0 0 1 0 1zm7.5-.5A.5.5 0 0 1 11 1h2a2 2 0 0 1 2 2v2a.5.5 0 0 1-1 0V3a1 1 0 0 0-1-1h-2a.5.5 0 0 1-.5-.5m-9 9a.5.5 0 0 1 .5.5v2a1 1 0 0 0 1 1h2a.5.5 0 0 1 0 1H3a2 2 0 0 1-2-2v-2a.5.5 0 0 1 .5-.5m13 0a.5.5 0 0 1 .5.5v2a2 2 0 0 1-2 2h-2a.5.5 0 0 1 0-1h2a1 1 0 0 0 1-1v-2a.5.5 0 0 1 .5-.5M3 8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 8m2-2.75A.25.25 0 0 1 5.25 5h5.5a.25.25 0 0 1 .25.25V6a.5.5 0 0 0 1 0v-.75C12 4.56 11.44 4 10.75 4h-5.5C4.56 4 4 4.56 4 5.25V6a.5.5 0 0 0 1 0zM5 10a.5.5 0 0 0-1 0v.75c0 .69.56 1.25 1.25 1.25h5.5c.69 0 1.25-.56 1.25-1.25V10a.5.5 0 0 0-1 0v.75a.25.25 0 0 1-.25.25h-5.5a.25.25 0 0 1-.25-.25z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "scan-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2zm0 2.25A.25.25 0 0 1 3.25 3H5a.5.5 0 0 0 0-1H3.25C2.56 2 2 2.56 2 3.25V5a.5.5 0 0 0 1 0zM11 2a.5.5 0 0 0 0 1h1.75a.25.25 0 0 1 .25.25V5a.5.5 0 0 0 1 0V3.25C14 2.56 13.44 2 12.75 2zm-8 9a.5.5 0 0 0-1 0v1.75c0 .69.56 1.25 1.25 1.25H5a.5.5 0 0 0 0-1H3.25a.25.25 0 0 1-.25-.25zm11 0a.5.5 0 0 0-1 0v1.75a.25.25 0 0 1-.25.25H11a.5.5 0 0 0 0 1h1.75c.69 0 1.25-.56 1.25-1.25zM3.5 7.5a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1zM6.05 6a.05.05 0 0 0-.05.05v.45a.5.5 0 0 1-1 0v-.45C5 5.47 5.47 5 6.05 5h3.9c.58 0 1.05.47 1.05 1.05v.45a.5.5 0 0 1-1 0v-.45A.05.05 0 0 0 9.95 6zM5.5 9a.5.5 0 0 1 .5.5v.45c0 .028.022.05.05.05h3.9a.05.05 0 0 0 .05-.05V9.5a.5.5 0 0 1 1 0v.45c0 .58-.47 1.05-1.05 1.05h-3.9C5.47 11 5 10.53 5 9.95V9.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "save-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.5 11h-7A1.5 1.5 0 0 1 1 9.5v-7A1.5 1.5 0 0 1 2.5 1H9l2 2v6.5A1.5 1.5 0 0 1 9.5 11M4 3.5V2h4v1.5a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5m-1 3V10h6V6.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0-.5.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "save-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9 5V3h1v2z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.293L12.707 1zm2.75 5A.75.75 0 0 1 5 5.25V2h6v3.25a.75.75 0 0 1-.75.75zm-1 2a.75.75 0 0 0-.75.75V14h8V8.75a.75.75 0 0 0-.75-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "save-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m9 1 2 2v6.5A1.5 1.5 0 0 1 9.5 11h-7A1.5 1.5 0 0 1 1 9.5v-7A1.5 1.5 0 0 1 2.5 1zm-.125 9.25H9.5a.75.75 0 0 0 .75-.75V3.31L8.69 1.75H8.5V4a.75.75 0 0 1-.75.75h-3.5A.75.75 0 0 1 3.5 4V1.75h-1a.75.75 0 0 0-.75.75v7c0 .414.336.75.75.75h.625V7c0-.483.392-.875.875-.875h4c.483 0 .875.392.875.875zm-.75 0V7A.125.125 0 0 0 8 6.875H4A.125.125 0 0 0 3.875 7v3.25zM8 4V1.75H4V4c0 .138.112.25.25.25h3.5A.25.25 0 0 0 8 4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "save": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.125 3v2h.75V3z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v10.5A1.5 1.5 0 0 0 2.5 15h11a1.5 1.5 0 0 0 1.5-1.5V3.293L12.707 1zM2 3a1 1 0 0 1 1-1h1.125v3.5c0 .76.616 1.375 1.375 1.375h5c.76 0 1.375-.616 1.375-1.375V2h.418L14 3.707V13.5a.5.5 0 0 1-.5.5h-.625V9.5c0-.76-.616-1.375-1.375-1.375h-7c-.76 0-1.375.616-1.375 1.375V14H2.5a.5.5 0 0 1-.5-.5zm9.125-1h-6.25v3.5c0 .345.28.625.625.625h5c.345 0 .625-.28.625-.625zm1 7.5V14h-8.25V9.5c0-.345.28-.625.625-.625h7c.345 0 .625.28.625.625' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "rss-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.083 1.75a.75.75 0 0 1 .75-.75A9.167 9.167 0 0 1 11 10.167a.75.75 0 0 1-1.5 0A7.667 7.667 0 0 0 1.833 2.5a.75.75 0 0 1-.75-.75'/%3e%3cpath fill='%230E1011' d='M1.083 5.917a.75.75 0 0 1 .75-.75 5 5 0 0 1 5 5 .75.75 0 0 1-1.5 0 3.5 3.5 0 0 0-3.5-3.5.75.75 0 0 1-.75-.75M1.833 11a.833.833 0 1 0 0-1.667.833.833 0 0 0 0 1.667'/%3e%3c/svg%3e")`,
                "rss-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2 3a1 1 0 0 1 1-1 11 11 0 0 1 11 11 1 1 0 1 1-2 0 9 9 0 0 0-9-9 1 1 0 0 1-1-1'/%3e%3cpath fill='%230E1011' d='M2 8a1 1 0 0 1 1-1 6 6 0 0 1 6 6 1 1 0 1 1-2 0 4 4 0 0 0-4-4 1 1 0 0 1-1-1M3 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3c/svg%3e")`,
                "rss-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.458 1.375c0-.207.168-.375.375-.375A9.167 9.167 0 0 1 11 10.167a.375.375 0 0 1-.75 0A8.417 8.417 0 0 0 1.833 1.75a.375.375 0 0 1-.375-.375M1.458 5.542c0-.207.168-.375.375-.375a5 5 0 0 1 5 5 .375.375 0 0 1-.75 0 4.25 4.25 0 0 0-4.25-4.25.375.375 0 0 1-.375-.375M1.833 11a.833.833 0 1 0 0-1.667.833.833 0 0 0 0 1.667'/%3e%3c/svg%3e")`,
                "rss": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 2.5A.5.5 0 0 1 3 2a11 11 0 0 1 11 11 .5.5 0 0 1-1 0A10 10 0 0 0 3 3a.5.5 0 0 1-.5-.5M2.5 7.5A.5.5 0 0 1 3 7a6 6 0 0 1 6 6 .5.5 0 0 1-1 0 5 5 0 0 0-5-5 .5.5 0 0 1-.5-.5M3 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3c/svg%3e")`,
                "rows-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M12 2.5A1.5 1.5 0 0 0 10.5 1h-9A1.5 1.5 0 0 0 0 2.5v1A1.5 1.5 0 0 0 1.5 5h9A1.5 1.5 0 0 0 12 3.5zM12 8.5A1.5 1.5 0 0 0 10.5 7h-9A1.5 1.5 0 0 0 0 8.5v1A1.5 1.5 0 0 0 1.5 11h9A1.5 1.5 0 0 0 12 9.5z'/%3e%3c/svg%3e")`,
                "rows-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.5 5.5v-3a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-11a1 1 0 0 1-1-1M1.5 13.5v-3a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-11a1 1 0 0 1-1-1'/%3e%3c/svg%3e")`,
                "rows-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.5 1A1.5 1.5 0 0 1 12 2.5v1A1.5 1.5 0 0 1 10.5 5h-9A1.5 1.5 0 0 1 0 3.5v-1A1.5 1.5 0 0 1 1.5 1zm.5 1.5v1a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5M10.5 7A1.5 1.5 0 0 1 12 8.5v1a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 0 9.5v-1A1.5 1.5 0 0 1 1.5 7zm.5 1.5v1a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "rows": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zM1 2.5A1.5 1.5 0 0 1 2.5 1h11A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-11A1.5 1.5 0 0 1 1 5.5zM2.5 10a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 2.5 9h11a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 13.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "rotate-cw-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.89.235a.375.375 0 1 0-.53.53L7.595 2H6a5 5 0 1 0 4.382 2.591.375.375 0 1 0-.658.362A4.25 4.25 0 1 1 6 2.75h1.595L6.36 3.985a.375.375 0 1 0 .53.53l2.14-2.14L6.89.235Z'/%3e%3c/svg%3e")`,
                "rotate-cw": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.95 2.853a.5.5 0 0 0 0-.707l-2-2a.5.5 0 0 0-.707.707L9.389 2H8.096a7 7 0 1 0 5.9 3.23.5.5 0 0 0-.842.54A6 6 0 1 1 8.096 3H9.39L8.243 4.146a.5.5 0 1 0 .707.708l2-2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "rotate-ccw-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.11.235a.375.375 0 1 1 .53.53L4.405 2H6a5 5 0 1 1-4.382 2.591.375.375 0 0 1 .658.362A4.25 4.25 0 1 0 6 2.75H4.405L5.64 3.985a.375.375 0 1 1-.53.53l-2.14-2.14L5.11.235Z'/%3e%3c/svg%3e")`,
                "rotate-ccw": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.146 2.853a.5.5 0 0 1 0-.707l2-2a.5.5 0 0 1 .708.707L6.707 2H8a7 7 0 1 1-5.9 3.23.5.5 0 1 1 .842.54A6 6 0 1 0 8 3H6.707l1.147 1.146a.5.5 0 1 1-.708.708l-2-2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "rewind-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.025 8.925 6.525 6.3c-.2-.15-.2-.45 0-.6l3.5-2.625a.375.375 0 0 1 .6.3v5.25a.375.375 0 0 1-.6.3M4.775 8.925 1.275 6.3c-.2-.15-.2-.45 0-.6l3.5-2.625a.375.375 0 0 1 .6.3v5.25a.375.375 0 0 1-.6.3'/%3e%3c/svg%3e")`,
                "rewind-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.367 11.9 8.7 8.4a.5.5 0 0 1 0-.8l4.667-3.5a.5.5 0 0 1 .8.4v7a.5.5 0 0 1-.8.4M6.367 11.9 1.7 8.4a.5.5 0 0 1 0-.8l4.667-3.5a.5.5 0 0 1 .8.4v7a.5.5 0 0 1-.8.4'/%3e%3c/svg%3e")`,
                "rewind-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2.625a.375.375 0 0 0-.588-.308L.537 5.692a.375.375 0 0 0 0 .616l4.875 3.375A.375.375 0 0 0 6 9.375V6.456l4.662 3.227a.375.375 0 0 0 .588-.308v-6.75a.375.375 0 0 0-.588-.308L6 5.544zm-.75 6.034L1.409 6 5.25 3.34v5.32m5.25 0L6.659 6 10.5 3.34v5.32' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "rewind": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 3.5a.5.5 0 0 0-.785-.411l-6.5 4.5a.5.5 0 0 0 0 .822l6.5 4.5A.5.5 0 0 0 8 12.5V8.608l6.215 4.303A.5.5 0 0 0 15 12.5v-9a.5.5 0 0 0-.785-.411L8 7.392zm-1 8.046L1.878 8 7 4.454v7.092m7 0L8.878 8 14 4.454v7.092' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "repeat-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.125 5.5a.375.375 0 1 0 .75 0v-1c0-.897.728-1.625 1.625-1.625h6.095l-1.36 1.36a.375.375 0 1 0 .53.53L11.03 2.5 8.765.235a.375.375 0 1 0-.53.53l1.36 1.36H3.5A2.375 2.375 0 0 0 1.125 4.5v1M10.875 7.5v-1a.375.375 0 0 0-.75 0v1c0 .897-.727 1.625-1.625 1.625H2.405l1.36-1.36a.375.375 0 1 0-.53-.53L.97 9.5l2.265 2.265a.375.375 0 0 0 .53-.53l-1.36-1.36H8.5A2.375 2.375 0 0 0 10.875 7.5'/%3e%3c/svg%3e")`,
                "repeat": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.147.146a.5.5 0 0 1 .707 0L14.207 3.5l-3.353 3.354a.5.5 0 1 1-.707-.708L12.293 4H5.5A2.5 2.5 0 0 0 3 6.5v1a.5.5 0 1 1-1 0v-1A3.5 3.5 0 0 1 5.5 3h6.793L10.147.854a.5.5 0 0 1 0-.708M13 9.5v-1a.5.5 0 0 1 1 0v1a3.5 3.5 0 0 1-3.5 3.5H3.707l2.147 2.146a.5.5 0 0 1-.708.708L1.793 12.5l3.353-3.354a.5.5 0 1 1 .708.708L3.707 12H10.5A2.5 2.5 0 0 0 13 9.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "refresh-cw-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.644 2.846a.375.375 0 0 1-.41-.08l-1-1a.375.375 0 0 1 0-.531l1-1A.375.375 0 0 1 5.876.5v.625H6a4.875 4.875 0 0 1 3.756 7.982.375.375 0 1 1-.578-.478A4.125 4.125 0 0 0 6 1.875h-.125V2.5a.375.375 0 0 1-.231.346M6 10.125h.125V9.5a.375.375 0 0 1 .64-.265l1 1a.375.375 0 0 1 0 .53l-1 1a.375.375 0 0 1-.64-.265v-.625H6a4.875 4.875 0 0 1-3.756-7.982.375.375 0 0 1 .578.478A4.125 4.125 0 0 0 6 10.125'/%3e%3c/svg%3e")`,
                "refresh-cw": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.854.854a.5.5 0 1 0-.708-.708L5.793 2.5l2.353 2.354a.5.5 0 1 0 .708-.708L7.707 3H8a5 5 0 0 1 2.939 9.045.5.5 0 0 0 .588.81A6 6 0 0 0 8 2h-.293L8.854.854M8 13a5 5 0 0 1-2.939-9.045.5.5 0 0 0-.588-.81A6 6 0 0 0 8 14h.293l-1.147 1.146a.5.5 0 0 0 .708.708l2.353-2.354-2.353-2.354a.5.5 0 0 0-.708.708L8.293 13z'/%3e%3c/svg%3e")`,
                "refresh-ccw-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.357 2.846c.14.059.3.026.408-.08l1-1a.375.375 0 0 0 0-.531l-1-1a.375.375 0 0 0-.64.265v.625H6a4.875 4.875 0 0 0-3.756 7.982.375.375 0 1 0 .578-.478A4.125 4.125 0 0 1 6 1.875h.125V2.5c0 .152.091.288.231.346M6 10.125h-.125V9.5a.375.375 0 0 0-.64-.265l-1 1a.375.375 0 0 0 0 .53l1 1a.375.375 0 0 0 .64-.265v-.625H6a4.875 4.875 0 0 0 3.756-7.982.375.375 0 0 0-.578.478A4.125 4.125 0 0 1 6 10.125'/%3e%3c/svg%3e")`,
                "refresh-ccw": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.146.854a.5.5 0 1 1 .708-.708L10.207 2.5 7.854 4.854a.5.5 0 1 1-.708-.708L8.293 3H8a5 5 0 0 0-2.939 9.045.5.5 0 1 1-.588.81A6 6 0 0 1 8 2h.293L7.146.854M8 13a5 5 0 0 0 2.939-9.045.5.5 0 0 1 .588-.81A6 6 0 0 1 8 14h-.293l1.147 1.146a.5.5 0 0 1-.708.708L5.793 13.5l2.353-2.354a.5.5 0 0 1 .708.708L7.707 13z'/%3e%3c/svg%3e")`,
                "radio-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.914 1.282c.125.165.092.4-.074.525a5.25 5.25 0 0 0 .149 8.494.375.375 0 1 1-.43.614 6 6 0 0 1-.17-9.707.375.375 0 0 1 .525.074M9.086 1.282a.375.375 0 0 0 .074.525 5.25 5.25 0 0 1-.149 8.494.375.375 0 1 0 .43.614 6 6 0 0 0 .17-9.707.375.375 0 0 0-.525.074'/%3e%3cpath fill='%230E1011' d='M4.044 3.404a.375.375 0 0 0-.451-.599 4 4 0 0 0 .113 6.472.375.375 0 0 0 .43-.615 3.25 3.25 0 0 1-.092-5.258M7.882 2.88a.375.375 0 0 0 .074.524 3.25 3.25 0 0 1-.092 5.258.375.375 0 0 0 .43.615 4 4 0 0 0 .113-6.472.375.375 0 0 0-.525.074'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 6a2 2 0 1 1-4 0 2 2 0 0 1 4 0m-.75 0a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "radio": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.886 1.69a.5.5 0 0 1-.099.7 7 7 0 0 0 .198 11.325.5.5 0 0 1-.574.819 8 8 0 0 1-.226-12.942.5.5 0 0 1 .7.098M12.114 1.69a.5.5 0 0 0 .099.7 7 7 0 0 1-.198 11.325.5.5 0 0 0 .574.819 8 8 0 0 0 .226-12.942.5.5 0 0 0-.7.098'/%3e%3cpath fill='%230E1011' d='M5.593 4.805a.5.5 0 1 0-.602-.798 5 5 0 0 0 .141 8.089.5.5 0 0 0 .574-.82 4 4 0 0 1-.113-6.47M10.309 4.105a.5.5 0 0 0 .098.7 4 4 0 0 1-.113 6.472.5.5 0 0 0 .574.819 5 5 0 0 0 .141-8.09.5.5 0 0 0-.7.1'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0M9 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "quote-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.5 4.5c0-.716-.333-1.432-1.333-2.149C3.5 2.351 5.5 4.135 5.5 7h-.011A2.75 2.75 0 1 1 2.5 4.511V4.5M9 4.5c0-.716-.333-1.432-1.333-2.149C10 2.351 12 4.135 12 7h-.011A2.75 2.75 0 1 1 9 4.511V4.5'/%3e%3c/svg%3e")`,
                "quote-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3 6c0-1-.5-2-2-3 3.5 0 6 2.5 6 6.5a3.5 3.5 0 1 1-4-3.465zM12 6c0-1-.5-2-2-3 3.5 0 6 2.5 6 6.5a3.5 3.5 0 1 1-4-3.465z'/%3e%3c/svg%3e")`,
                "quote-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.49 6.643A5.52 5.52 0 0 0 5.412 6C5.131 4.425 4.185 3.28 2.95 2.727a4.348 4.348 0 0 0-1.783-.376c.549.394.897.787 1.099 1.18v.001A2.085 2.085 0 0 1 2.5 4.5v.011a2.75 2.75 0 1 0 3 2.77V7.22c-.001-.074-.005-.148-.011-.22h.01l-.086-1 .087.999c0-.12-.004-.239-.01-.356M3.5 4.5c0-.067-.002-.133-.006-.199.426.432.746 1.004.901 1.704l.098 1.085A1.75 1.75 0 1 1 2.59 5.507l.912-.082-.002-.916V4.5M11.99 6.643A5.548 5.548 0 0 0 11.912 6c-.282-1.575-1.228-2.719-2.463-3.273a4.348 4.348 0 0 0-1.783-.376c.549.394.897.787 1.099 1.18v.001A2.085 2.085 0 0 1 9 4.5v.011a2.75 2.75 0 1 0 3 2.77V7.22a2.8 2.8 0 0 0-.011-.22h.01l-.086-1 .087.999c0-.12-.004-.239-.01-.356M10 4.5c0-.067-.002-.133-.006-.199.426.432.746 1.004.901 1.704l.098 1.085A1.75 1.75 0 1 1 9.09 5.507l.912-.082L10 4.509V4.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "quote": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 9.5a3.5 3.5 0 0 1 3-3.465V6a2.743 2.743 0 0 0-.167-.95c-.11-.301-.28-.602-.523-.903C2.001 3.765 1.574 3.382 1 3c.66 0 1.284.089 1.863.26C5.353 3.996 7 6.254 7 9.5a3.5 3.5 0 1 1-7 0M4 6c0-.42-.065-.827-.2-1.221.288.189.55.41.785.658C5.444 6.345 6 7.71 6 9.5a2.5 2.5 0 1 1-2.858-2.475A1 1 0 0 0 4 6.028zM9 9.5a3.5 3.5 0 0 1 3-3.465V6a2.743 2.743 0 0 0-.167-.95c-.11-.301-.28-.602-.523-.903-.309-.382-.736-.765-1.31-1.147.66 0 1.284.089 1.863.26C14.353 3.996 16 6.254 16 9.5a3.5 3.5 0 1 1-7 0M13 6c0-.42-.065-.827-.2-1.221.288.189.55.41.785.658C14.445 6.345 15 7.71 15 9.5a2.5 2.5 0 1 1-2.858-2.475A1 1 0 0 0 13 6.03z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "printer-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.125 4.125V1.5C2.125.74 2.741.125 3.5.125h5c.76 0 1.375.616 1.375 1.375v2.625h.5c.898 0 1.625.728 1.625 1.625v2.5c0 .897-.727 1.625-1.625 1.625h-.5v1c0 .621-.504 1.125-1.125 1.125h-5.5a1.125 1.125 0 0 1-1.125-1.125v-1h-.5A1.625 1.625 0 0 1 0 8.25v-2.5c0-.897.728-1.625 1.625-1.625zM3.5.875a.625.625 0 0 0-.625.625v2.625h6.25V1.5A.625.625 0 0 0 8.5.875zm-.25 7a.375.375 0 0 0-.375.375v2.625c0 .207.168.375.375.375h5.5a.375.375 0 0 0 .375-.375V8.25a.375.375 0 0 0-.375-.375zm5.25-1.75a.375.375 0 1 0 0 .75h1a.375.375 0 1 0 0-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "printer-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2a.5.5 0 0 0-.5.5V6h8V2.5a.5.5 0 0 0-.5-.5zM13 6V2.5A1.5 1.5 0 0 0 11.5 1h-7A1.5 1.5 0 0 0 3 2.5V6H2a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h1v1.5A1.5 1.5 0 0 0 4.5 16h7a1.5 1.5 0 0 0 1.5-1.5V13h1a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2zm-8.5 5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm7-3a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "printer-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.5 6.125a.375.375 0 1 0 0 .75h1a.375.375 0 1 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.125 1.5v2.625H1.75c-.897 0-1.625.728-1.625 1.625v2.5c0 .897.728 1.625 1.625 1.625h.375v.875c0 .621.504 1.125 1.125 1.125h5.5c.621 0 1.125-.504 1.125-1.125v-.875h.375c.898 0 1.625-.728 1.625-1.625v-2.5c0-.897-.727-1.625-1.625-1.625h-.375V1.5C9.875.74 9.259.125 8.5.125h-5c-.76 0-1.375.616-1.375 1.375M3.5.875a.625.625 0 0 0-.625.625v2.625h6.25V1.5A.625.625 0 0 0 8.5.875zm-1.75 4h8.5c.483 0 .875.392.875.875v2.5a.875.875 0 0 1-.875.875h-.375V8.25c0-.621-.504-1.125-1.125-1.125h-5.5c-.621 0-1.125.504-1.125 1.125v.875H1.75a.875.875 0 0 1-.875-.875v-2.5c0-.483.392-.875.875-.875m1.5 3a.375.375 0 0 0-.375.375v2.5c0 .207.168.375.375.375h5.5a.375.375 0 0 0 .375-.375v-2.5a.375.375 0 0 0-.375-.375z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "printer": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2a.5.5 0 0 0-.5.5V6h8V2.5a.5.5 0 0 0-.5-.5zM13 6V2.5A1.5 1.5 0 0 0 11.5 1h-7A1.5 1.5 0 0 0 3 2.5V6H2a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h1v1.5A1.5 1.5 0 0 0 4.5 16h7a1.5 1.5 0 0 0 1.5-1.5V13h1a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2zm0 6h1a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h1v-.5A1.5 1.5 0 0 1 4.5 10h7a1.5 1.5 0 0 1 1.5 1.5zm-2-3.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5M4.5 11a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "power-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0c.207 0 .375.168.375.375v4.327a.375.375 0 1 1-.75 0V.375C5.625.168 5.793 0 6 0M4.154 1.556a.375.375 0 0 1-.187.497c-1.68.762-2.842 2.438-2.842 4.38 0 2.656 2.179 4.817 4.875 4.817s4.875-2.16 4.875-4.817c0-1.942-1.163-3.618-2.842-4.38a.375.375 0 0 1 .31-.683c1.934.878 3.282 2.813 3.282 5.063C11.625 9.51 9.103 12 6 12S.375 9.511.375 6.433c0-2.25 1.348-4.185 3.283-5.063a.375.375 0 0 1 .496.186' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "power": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a.5.5 0 0 1 .5.5v5.77a.5.5 0 0 1-1 0V.5A.5.5 0 0 1 8 0M5.539 2.075a.5.5 0 0 1-.249.662C3.05 3.754 1.5 5.989 1.5 8.577 1.5 12.119 4.405 15 8 15s6.5-2.88 6.5-6.423c0-2.588-1.55-4.823-3.79-5.84a.5.5 0 0 1 .413-.91c2.58 1.17 4.377 3.75 4.377 6.75C15.5 12.682 12.137 16 8 16 3.863 16 .5 12.682.5 8.577c0-3 1.797-5.58 4.377-6.75a.5.5 0 0 1 .662.248' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pocket-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 1.357v5A4.643 4.643 0 0 0 5.643 11h.714A4.643 4.643 0 0 0 11 6.357v-5A.357.357 0 0 0 10.643 1H1.357A.357.357 0 0 0 1 1.357M3.857 4.93v.357a2.143 2.143 0 1 0 4.286 0v-.357h-.714v.357a1.429 1.429 0 1 1-2.858 0v-.357h-.714' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pocket-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 1.5v7A6.5 6.5 0 0 0 7.5 15h1A6.5 6.5 0 0 0 15 8.5v-7a.5.5 0 0 0-.5-.5h-13a.5.5 0 0 0-.5.5m4 5V7a3 3 0 0 0 6 0v-.5h-1V7a2 2 0 1 1-4 0v-.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pocket-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 1.714C1 1.32 1.32 1 1.714 1h8.572c.394 0 .714.32.714.714V6A5 5 0 0 1 1 6V1.714m9.286 0H1.714V6a4.286 4.286 0 0 0 8.572 0V1.714M3.857 5.286v-.357h.714v.357a1.429 1.429 0 1 0 2.858 0v-.357h.714v.357a2.143 2.143 0 1 1-4.286 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pocket": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v6A7 7 0 1 1 1 8zm13 0H2v6a6 6 0 0 0 12 0zM5 7v-.5h1V7a2 2 0 1 0 4 0v-.5h1V7a3 3 0 0 1-6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.625C1 1.728 1.728 1 2.625 1h6.75C10.273 1 11 1.728 11 2.625v6.75C11 10.273 10.273 11 9.375 11h-6.75A1.625 1.625 0 0 1 1 9.375zM6.4 4a.4.4 0 0 0-.8 0v1.6H4a.4.4 0 0 0 0 .8h1.6V8a.4.4 0 0 0 .8 0V6.4H8a.4.4 0 0 0 0-.8H6.4z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zm5 4a.5.5 0 0 0-1 0v2.5H5a.5.5 0 0 0 0 1h2.5V11a.5.5 0 0 0 1 0V8.5H11a.5.5 0 0 0 0-1H8.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.4 4a.4.4 0 0 0-.8 0v1.6H4a.4.4 0 0 0 0 .8h1.6V8a.4.4 0 0 0 .8 0V6.4H8a.4.4 0 0 0 0-.8H6.4z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.75 1.125c-.897 0-1.625.728-1.625 1.625v6.5c0 .898.728 1.625 1.625 1.625h6.5c.898 0 1.625-.727 1.625-1.625v-6.5c0-.897-.727-1.625-1.625-1.625zM1.875 2.75c0-.483.392-.875.875-.875h6.5c.483 0 .875.392.875.875v6.5a.875.875 0 0 1-.875.875h-6.5a.875.875 0 0 1-.875-.875z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.375 5a.375.375 0 1 0-.75 0v2.625H5a.375.375 0 1 0 0 .75h2.625V11a.375.375 0 0 0 .75 0V8.375H11a.375.375 0 0 0 0-.75H8.375z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zM2 3.5A1.5 1.5 0 0 1 3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1.75a.75.75 0 0 1 .75.75v2.75H9.5a.75.75 0 0 1 0 1.5H6.75V9.5a.75.75 0 0 1-1.5 0V6.75H2.5a.75.75 0 0 1 0-1.5h2.75V2.5A.75.75 0 0 1 6 1.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2a1 1 0 0 1 1 1v4h4a1 1 0 1 1 0 2H9v4a1 1 0 1 1-2 0V9H3a1 1 0 0 1 0-2h4V3a1 1 0 0 1 1-1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a6 6 0 1 0 0 12A6 6 0 0 0 6 0m.5 3.5a.5.5 0 0 0-1 0v2h-2a.5.5 0 0 0 0 1h2v2a.5.5 0 0 0 1 0v-2h2a.5.5 0 0 0 0-1h-2z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M8 4.5a.5.5 0 0 1 .5.5v2.5H11a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V8.5H5a.5.5 0 0 1 0-1h2.5V5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.5 3.5a.5.5 0 0 0-1 0v2h-2a.5.5 0 0 0 0 1h2v2a.5.5 0 0 0 1 0v-2h2a.5.5 0 0 0 0-1h-2z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 .125a5.875 5.875 0 1 0 0 11.75A5.875 5.875 0 0 0 6 .125M.875 6a5.125 5.125 0 1 1 10.25 0A5.125 5.125 0 0 1 .875 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v2.5H11a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V8.5H5a.5.5 0 0 1 0-1h2.5V5a.5.5 0 0 1 .5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2.125c.207 0 .375.168.375.375v3.125H9.5a.375.375 0 1 1 0 .75H6.375V9.5a.375.375 0 1 1-.75 0V6.375H2.5a.375.375 0 1 1 0-.75h3.125V2.5c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "plus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2.5a.5.5 0 0 1 .5.5v4.5H13a.5.5 0 0 1 0 1H8.5V13a.5.5 0 0 1-1 0V8.5H3a.5.5 0 0 1 0-1h4.5V3a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "play-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9.673 5.69 3.587 1.527a.375.375 0 0 0-.587.31v8.328c0 .302.338.48.587.31L9.673 6.31a.375.375 0 0 0 0-.62'/%3e%3c/svg%3e")`,
                "play-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4 12.705v-9.41a1 1 0 0 1 1.526-.85l7.6 4.705a1 1 0 0 1 0 1.7l-7.6 4.705A1 1 0 0 1 4 12.705'/%3e%3c/svg%3e")`,
                "play-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a6 6 0 1 0 0 12A6 6 0 0 0 6 0m-.917 3.438a.375.375 0 0 0-.583.312v4.5a.375.375 0 0 0 .583.312l3.375-2.25a.375.375 0 0 0 0-.624l-3.375-2.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "play-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-9.03-3.44a.5.5 0 0 1 .513.024l4.5 3a.5.5 0 0 1 0 .832l-4.5 3A.5.5 0 0 1 6 11V5a.5.5 0 0 1 .264-.44' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "play-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.083 3.438a.375.375 0 0 0-.583.312v4.5a.375.375 0 0 0 .583.312l3.375-2.25a.375.375 0 0 0 0-.624l-3.375-2.25M7.574 6 5.25 7.55v-3.1L7.574 6' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "play-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.264 4.56a.5.5 0 0 1 .513.024l4.5 3a.5.5 0 0 1 0 .832l-4.5 3A.5.5 0 0 1 6 11V5a.5.5 0 0 1 .264-.44M7 10.065 10.099 8 7 5.934v4.132' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "play-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.45.793a.375.375 0 0 1 .387.023L9.962 5.69a.375.375 0 0 1 0 .618l-7.125 4.876a.375.375 0 0 1-.587-.31v-9.75c0-.14.077-.267.2-.332M3 1.836v8.328L9.086 6 3 1.836' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "play": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.267 1.058a.5.5 0 0 1 .515.03l9.5 6.5a.5.5 0 0 1 0 .825l-9.5 6.5A.5.5 0 0 1 3 14.5v-13a.5.5 0 0 1 .267-.442M4 2.448v11.104L12.115 8 4 2.448' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pinterest-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M12 6a6 6 0 0 1-7.855 5.708c.236-.32.673-.97.852-1.62.068-.248.391-1.53.391-1.53.193.369.758.694 1.36.694 1.788 0 3.002-1.631 3.002-3.814 0-1.65-1.398-3.188-3.523-3.188-2.644 0-3.977 1.896-3.977 3.476 0 .957.362 1.809 1.14 2.126.127.052.241.002.278-.14.013-.046.033-.129.054-.213l.06-.233c.037-.14.023-.188-.08-.31-.224-.264-.368-.606-.368-1.091 0-1.407 1.053-2.665 2.74-2.665 1.495 0 2.316.913 2.316 2.132 0 1.605-.71 2.959-1.765 2.959-.582 0-1.018-.482-.878-1.072.06-.255.142-.517.22-.772.14-.45.271-.878.271-1.203 0-.455-.244-.835-.75-.835-.595 0-1.073.615-1.073 1.44 0 .526.177.88.177.88l-.716 3.033c-.155.657-.1 1.422-.054 1.83A6.002 6.002 0 0 1 6 0a6 6 0 0 1 6 6'/%3e%3c/svg%3e")`,
                "pinterest-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.294 8a7.3 7.3 0 0 1-9.357 7.006c.276-.441.572-.998.725-1.556.091-.33.522-2.04.522-2.04.258.492 1.011.926 1.813.926C11.382 12.336 13 10.16 13 7.25 13 5.05 11.136 3 8.303 3 4.777 3 3 5.527 3 7.635c0 1.276.483 2.412 1.52 2.835.17.07.322.002.37-.186l.073-.285c.03-.119.06-.24.08-.31.05-.187.03-.252-.107-.414-.3-.353-.49-.809-.49-1.455 0-1.875 1.403-3.554 3.653-3.554 1.993 0 3.087 1.218 3.087 2.843 0 2.14-.947 3.946-2.352 3.946-.776 0-1.357-.643-1.171-1.43.08-.34.189-.69.294-1.03.185-.6.36-1.17.36-1.603 0-.607-.325-1.114-1-1.114-.793 0-1.43.821-1.43 1.921 0 .7.236 1.174.236 1.174l-.954 4.043c-.13.547-.15 1.15-.132 1.66A7.301 7.301 0 0 1 7.995.7 7.3 7.3 0 0 1 15.295 8'/%3e%3c/svg%3e")`,
                "pinterest-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.822 11.593A6.002 6.002 0 0 1 6 0a6 6 0 1 1-2.178 11.593M11.25 6a5.25 5.25 0 0 1-6.677 5.054c.168-.292.33-.629.424-.966.068-.248.391-1.53.391-1.53.193.369.758.694 1.36.694 1.788 0 3.002-1.631 3.002-3.814 0-1.65-1.398-3.188-3.523-3.188-2.644 0-3.977 1.896-3.977 3.476 0 .957.362 1.809 1.14 2.126.127.052.241.002.278-.14.013-.046.033-.129.054-.213l.06-.233c.037-.14.023-.188-.08-.31-.224-.264-.368-.606-.368-1.091 0-1.407 1.053-2.665 2.74-2.665 1.495 0 2.316.913 2.316 2.132 0 1.605-.71 2.959-1.765 2.959-.582 0-1.018-.482-.878-1.072.06-.255.142-.517.22-.772.14-.45.271-.878.271-1.203 0-.455-.244-.835-.75-.835-.595 0-1.073.615-1.073 1.44 0 .526.177.88.177.88l-.716 3.033a4.452 4.452 0 0 0-.102.994A5.25 5.25 0 1 1 11.25 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pinterest": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0a6.3 6.3 0 0 1-7.87 6.102c.095-.212.178-.432.238-.652.091-.33.522-2.04.522-2.04.258.492 1.011.926 1.813.926C11.382 12.336 13 10.16 13 7.25 13 5.05 11.136 3 8.303 3 4.777 3 3 5.527 3 7.635c0 1.276.483 2.412 1.52 2.835.17.07.322.002.37-.186l.073-.285c.03-.119.06-.24.08-.31.05-.187.03-.252-.107-.414-.3-.353-.49-.809-.49-1.455 0-1.875 1.403-3.554 3.653-3.554 1.993 0 3.087 1.218 3.087 2.843 0 2.14-.947 3.946-2.352 3.946-.776 0-1.357-.643-1.171-1.43.08-.34.189-.69.294-1.03.185-.6.36-1.17.36-1.603 0-.607-.325-1.114-1-1.114-.793 0-1.43.821-1.43 1.921 0 .7.236 1.174.236 1.174l-.954 4.043a4.803 4.803 0 0 0-.097.566A6.3 6.3 0 1 1 14.294 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pie-chart-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M12 5.625c0 .126-.004.251-.012.375H6V.012a5.625 5.625 0 0 1 6 5.613'/%3e%3cpath fill='%230E1011' d='M0 6.375C0 3.395 2.318.955 5.25.762V6.75h5.988A5.625 5.625 0 0 1 0 6.375'/%3e%3c/svg%3e")`,
                "pie-chart-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M16 7.5c0 .168-.005.335-.016.5H8V.016A7.5 7.5 0 0 1 16 7.5'/%3e%3cpath fill='%230E1011' d='M0 8.5a7.5 7.5 0 0 1 7-7.484V9h7.984A7.5 7.5 0 0 1 0 8.5'/%3e%3c/svg%3e")`,
                "pie-chart-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 5.625c0 .126-.004.251-.012.375H6V.012a5.71 5.71 0 0 1 .75 0A5.626 5.626 0 0 1 12 5.625m-.764-.375H6.75V.764a4.876 4.876 0 0 1 4.486 4.486' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.238 6.75H5.25V.762A5.627 5.627 0 0 0 5.625 12a5.627 5.627 0 0 0 5.613-5.25m-6.738 0c0 .414.336.75.75.75h5.12A4.875 4.875 0 1 1 4.5 1.63v5.12' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pie-chart": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 7.5c0 .168-.005.335-.016.5H8V.016a7.612 7.612 0 0 1 1 0A7.501 7.501 0 0 1 16 7.5M14.981 7H9V1.019A6.501 6.501 0 0 1 14.981 7' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.984 9H7V1.016A7.503 7.503 0 0 0 0 8.5a7.5 7.5 0 0 0 14.984.5M6 9a1 1 0 0 0 1 1h6.826A6.5 6.5 0 1 1 6 2.174V9' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-outgoing-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.625 0a.375.375 0 0 0 0 .75h2.094L7.61 3.86a.375.375 0 1 0 .53.53l3.11-3.11v2.095a.375.375 0 0 0 .75 0V0H8.626'/%3e%3cpath fill='%230E1011' d='M11.25 9.75c0 .828-.675 1.511-1.495 1.394a10.433 10.433 0 0 1-3.786-1.316 10.552 10.552 0 0 1-3.724-3.674 10.432 10.432 0 0 1-1.39-3.909C.738 1.425 1.421.75 2.25.75h1.5c.414 0 .745.337.79.749.073.657.24 1.286.488 1.872L3.817 4.582a.365.365 0 0 0-.062.439A8.666 8.666 0 0 0 7.11 8.319c.143.078.319.049.433-.066L8.768 7.03a6.708 6.708 0 0 0 1.733.43c.412.045.749.377.749.791v1.5'/%3e%3c/svg%3e")`,
                "phone-outgoing-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 0a.5.5 0 0 0 0 1h2.793l-4.147 4.146a.5.5 0 0 0 .707.708L15 1.707V4.5a.5.5 0 0 0 1 0V0h-4.5'/%3e%3cpath fill='%230E1011' d='M15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.398c.19.103.424.065.577-.088l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2'/%3e%3c/svg%3e")`,
                "phone-outgoing-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.625 0a.375.375 0 1 0 0 .75h2.095L7.61 3.86a.375.375 0 1 0 .53.53l3.11-3.11v2.095a.375.375 0 0 0 .75 0V0H8.625'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.453 6.973C1.628 5.765 1.066 3.95.85 2.246.745 1.424 1.422.75 2.25.75H4.2c.414 0 .75.336.786.749.064.729.21 1.584.427 2.163a.411.411 0 0 1-.085.436l-.642.642a.362.362 0 0 0-.055.45A7.036 7.036 0 0 0 6.93 7.441c.143.087.325.06.443-.058l.658-.658c.111-.11.279-.14.427-.088.548.19 1.354.318 2.043.377.413.034.749.37.749.785v1.95c0 .828-.674 1.505-1.496 1.401-1.662-.21-3.434-.745-4.617-1.53a9.854 9.854 0 0 1-2.684-2.648m1.703-2.764a1.112 1.112 0 0 0-.158 1.382A7.786 7.786 0 0 0 6.54 8.084c.454.275 1.013.18 1.363-.17l.505-.505c.61.183 1.387.299 2.029.353a.085.085 0 0 1 .053.024.05.05 0 0 1 .009.012V9.75c0 .44-.338.697-.652.657-1.595-.201-3.243-.712-4.296-1.411a9.104 9.104 0 0 1-2.48-2.447c-.735-1.076-1.271-2.763-1.479-4.398-.04-.312.216-.651.657-.651h1.952s.006.003.012.009a.09.09 0 0 1 .025.055c.06.684.192 1.512.402 2.16l-.485.485' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-outgoing": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 0a.5.5 0 0 0 0 1h2.793l-4.146 4.146a.5.5 0 1 0 .707.708L15 1.707V4.5a.5.5 0 0 0 1 0V0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531m2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M11.172.297a.375.375 0 0 1 .53.53l-6.28 6.281a8.65 8.65 0 0 0 1.689 1.21c.142.079.318.05.433-.065L8.768 7.03a6.708 6.708 0 0 0 1.733.43c.412.045.749.377.749.791v1.5c0 .828-.675 1.511-1.495 1.394a10.433 10.433 0 0 1-3.786-1.316 10.537 10.537 0 0 1-1.874-1.393L.828 11.703a.375.375 0 0 1-.53-.53L11.171.296ZM2.245 6.154c.168.279.349.55.54.81L4.13 5.62a8.63 8.63 0 0 1-.375-.6.365.365 0 0 1 .062-.438l1.21-1.21a6.706 6.706 0 0 1-.486-1.873C4.496 1.087 4.164.75 3.75.75h-1.5C1.422.75.739 1.425.856 2.245a10.432 10.432 0 0 0 1.39 3.909'/%3e%3c/svg%3e")`,
                "phone-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M14.896.396a.5.5 0 0 1 .708.708L7.229 9.478a11.53 11.53 0 0 0 2.252 1.614c.19.103.424.065.577-.088l1.633-1.632a8.944 8.944 0 0 0 2.311.573c.549.06.998.503.998 1.055v2c0 1.105-.9 2.015-1.993 1.86a13.908 13.908 0 0 1-5.048-1.757 14.052 14.052 0 0 1-2.499-1.856l-4.356 4.357a.5.5 0 0 1-.708-.708l14.5-14.5ZM2.994 8.205c.224.372.464.733.72 1.08l1.793-1.792a11.503 11.503 0 0 1-.5-.799.486.486 0 0 1 .083-.584l1.614-1.615a8.941 8.941 0 0 1-.65-2.497C5.995 1.449 5.553 1 5 1H3c-1.105 0-2.015.9-1.86 1.993a13.91 13.91 0 0 0 1.854 5.212'/%3e%3c/svg%3e")`,
                "phone-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.703.297a.375.375 0 0 1 0 .53L6.012 6.52c.409.299.938.555 1.214.68l.769-.512a.75.75 0 0 1 .622-.097l2.089.597a.75.75 0 0 1 .544.72V9.75c0 .815-.672 1.533-1.54 1.434a10.09 10.09 0 0 1-5.724-2.64L.828 11.704a.375.375 0 0 1-.53-.53l4.63-4.631.003-.003L11.172.297a.375.375 0 0 1 .53 0M5.459 7.071a.037.037 0 0 1 .012-.002c.014 0 .031.005.045.016.58.438 1.364.784 1.555.866.15.064.316.043.442-.042l.898-.598 2.089.597V9.75c0 .427-.34.73-.705.688a9.34 9.34 0 0 1-5.279-2.424l.942-.941-.265-.266.266.264M2.25 1.5c-.427 0-.73.34-.688.705a9.325 9.325 0 0 0 1.843 4.586.375.375 0 0 1-.597.454A10.075 10.075 0 0 1 .816 2.291C.716 1.422 1.435.75 2.25.75h1.842a.75.75 0 0 1 .721.544l.597 2.089a.75.75 0 0 1-.097.622l-.512.769c.054.12.134.289.232.476a.375.375 0 0 1-.665.348 9.821 9.821 0 0 1-.319-.67.466.466 0 0 1 .042-.441l.598-.898L4.092 1.5H2.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.604.396a.5.5 0 0 1 0 .708L8.016 8.69c.545.4 1.25.741 1.619.908l1.025-.683a1 1 0 0 1 .83-.13l2.785.796a1 1 0 0 1 .725.962V13c0 1.087-.896 2.044-2.055 1.911a13.454 13.454 0 0 1-7.63-3.518l-4.211 4.21a.5.5 0 0 1-.708-.707l6.175-6.174.001-.002h.001l.001-.001L14.896.396a.5.5 0 0 1 .708 0M7.279 9.428c-.001 0 0 0 0 0a.05.05 0 0 1 .016-.002.1.1 0 0 1 .06.02c.773.585 1.818 1.046 2.073 1.155.2.085.42.057.59-.055l1.197-.798 2.785.796V13c0 .57-.453.974-.94.918a12.453 12.453 0 0 1-7.038-3.233L7.277 9.43l-.353-.354.355.352ZM3 2c-.57 0-.974.453-.918.94a12.434 12.434 0 0 0 2.459 6.115.5.5 0 1 1-.797.605A13.434 13.434 0 0 1 1.09 3.054C.956 1.896 1.913 1 3 1h2.456a1 1 0 0 1 .962.725l.796 2.786a1 1 0 0 1-.13.83l-.683 1.024c.072.16.178.386.31.636a.5.5 0 1 1-.887.464 13.102 13.102 0 0 1-.425-.893.621.621 0 0 1 .055-.59l.798-1.197L5.456 2H3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-missed-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.89.11a.375.375 0 1 0-.53.53l1.234 1.235L8.36 3.11a.375.375 0 1 0 .53.53l1.235-1.235L11.36 3.64a.375.375 0 1 0 .53-.53l-1.235-1.235L11.89.64a.375.375 0 1 0-.53-.53l-1.235 1.235L8.89.11ZM11.25 9.75c0 .828-.675 1.511-1.495 1.394a10.433 10.433 0 0 1-3.786-1.316 10.552 10.552 0 0 1-3.724-3.674 10.432 10.432 0 0 1-1.39-3.909C.738 1.425 1.421.75 2.25.75h1.5c.414 0 .745.337.79.749.073.657.24 1.286.488 1.872L3.817 4.582a.365.365 0 0 0-.062.439A8.666 8.666 0 0 0 7.11 8.319c.143.078.319.049.433-.066L8.768 7.03a6.708 6.708 0 0 0 1.733.43c.412.045.749.377.749.791v1.5'/%3e%3c/svg%3e")`,
                "phone-missed-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.853.146a.5.5 0 1 0-.707.708L12.792 2.5l-1.646 1.646a.5.5 0 1 0 .707.708L13.5 3.207l1.646 1.647a.5.5 0 1 0 .707-.708L14.207 2.5 15.853.854a.5.5 0 1 0-.707-.708L13.5 1.793 11.853.146M15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.398c.19.103.424.065.577-.088l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2'/%3e%3c/svg%3e")`,
                "phone-missed-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.89.11a.375.375 0 1 0-.53.53l1.235 1.235L8.36 3.11a.375.375 0 1 0 .53.53l1.235-1.235L11.36 3.64a.375.375 0 1 0 .53-.53l-1.235-1.235L11.89.64a.375.375 0 0 0-.53-.53l-1.235 1.235L8.89.11Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.453 6.973C1.628 5.765 1.066 3.95.85 2.246.745 1.424 1.422.75 2.25.75H4.2c.414 0 .75.336.786.749.064.729.21 1.584.427 2.163a.411.411 0 0 1-.085.436l-.642.642a.362.362 0 0 0-.055.45A7.036 7.036 0 0 0 6.93 7.441c.143.087.325.06.443-.058l.658-.658c.111-.11.279-.14.427-.088.548.19 1.354.318 2.043.377.413.034.749.37.749.785v1.95c0 .828-.674 1.505-1.496 1.401-1.662-.21-3.434-.745-4.617-1.53a9.854 9.854 0 0 1-2.684-2.648m1.703-2.764a1.112 1.112 0 0 0-.158 1.382A7.786 7.786 0 0 0 6.54 8.084c.454.275 1.013.18 1.363-.17l.505-.505c.61.183 1.387.299 2.029.353a.085.085 0 0 1 .053.024.05.05 0 0 1 .009.012V9.75c0 .44-.338.697-.652.657-1.595-.201-3.243-.712-4.296-1.411a9.104 9.104 0 0 1-2.48-2.447c-.735-1.076-1.271-2.763-1.479-4.398-.04-.312.216-.651.657-.651h1.952s.006.003.012.009a.09.09 0 0 1 .025.055c.06.684.192 1.512.402 2.16l-.485.485' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-missed": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.854.146a.5.5 0 1 0-.707.708L12.793 2.5l-1.646 1.646a.5.5 0 1 0 .707.708L13.5 3.207l1.646 1.647a.5.5 0 1 0 .708-.708L14.207 2.5 15.854.854a.5.5 0 1 0-.707-.708L13.5 1.793 11.854.146'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531m2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-incoming-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M11.89.64a.375.375 0 1 0-.53-.53L8.25 3.22V1.125a.375.375 0 1 0-.75 0V4.5h3.375a.375.375 0 0 0 0-.75H8.78L11.89.64Z'/%3e%3cpath fill='%230E1011' d='M11.25 9.75c0 .828-.675 1.511-1.495 1.394a10.433 10.433 0 0 1-3.786-1.316 10.552 10.552 0 0 1-3.724-3.674 10.432 10.432 0 0 1-1.39-3.909C.738 1.425 1.421.75 2.25.75h1.5c.414 0 .745.337.79.749.073.657.24 1.286.488 1.872L3.817 4.582a.365.365 0 0 0-.062.439A8.666 8.666 0 0 0 7.11 8.319c.143.078.319.049.433-.066L8.768 7.03a6.708 6.708 0 0 0 1.733.43c.412.045.749.377.749.791v1.5'/%3e%3c/svg%3e")`,
                "phone-incoming-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.853.854a.5.5 0 1 0-.707-.708L11 4.293V1.5a.5.5 0 0 0-1 0V6h4.5a.5.5 0 0 0 0-1h-2.793L15.853.854Z'/%3e%3cpath fill='%230E1011' d='M15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.398c.19.103.424.065.577-.088l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2'/%3e%3c/svg%3e")`,
                "phone-incoming-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M11.89.64a.375.375 0 0 0-.53-.53L8.25 3.22V1.125a.375.375 0 1 0-.75 0V4.5h3.375a.375.375 0 0 0 0-.75H8.78L11.89.64Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.453 6.973C1.628 5.765 1.066 3.95.85 2.246.745 1.424 1.422.75 2.25.75H4.2c.414 0 .75.336.786.749.064.729.21 1.584.427 2.163a.411.411 0 0 1-.085.436l-.642.642a.362.362 0 0 0-.055.45A7.036 7.036 0 0 0 6.93 7.441c.143.087.325.06.443-.058l.658-.658c.111-.11.279-.14.427-.088.548.19 1.354.318 2.043.377.413.034.749.37.749.785v1.95c0 .828-.674 1.505-1.496 1.401-1.662-.21-3.434-.745-4.617-1.53a9.854 9.854 0 0 1-2.684-2.648m1.703-2.764a1.112 1.112 0 0 0-.158 1.382A7.786 7.786 0 0 0 6.54 8.084c.454.275 1.013.18 1.363-.17l.505-.505c.61.183 1.387.299 2.029.353a.085.085 0 0 1 .053.024.05.05 0 0 1 .009.012V9.75c0 .44-.338.697-.652.657-1.595-.201-3.243-.712-4.296-1.411a9.104 9.104 0 0 1-2.48-2.447c-.735-1.076-1.271-2.763-1.479-4.398-.04-.312.216-.651.657-.651h1.952s.006.003.012.009a.09.09 0 0 1 .025.055c.06.684.192 1.512.402 2.16l-.485.485' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-incoming": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.854.854a.5.5 0 1 0-.707-.708L11 4.293V1.5a.5.5 0 1 0-1 0V6h4.5a.5.5 0 1 0 0-1h-2.793L15.854.854Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531m2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-forwarded-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9.265.11a.375.375 0 1 0-.53.53l1.61 1.61H6.75a.375.375 0 1 0 0 .75h3.594l-1.61 1.61a.375.375 0 1 0 .53.53l2.516-2.515L9.265.11ZM11.25 9.75c0 .828-.675 1.511-1.495 1.394a10.433 10.433 0 0 1-3.786-1.316 10.552 10.552 0 0 1-3.724-3.674 10.432 10.432 0 0 1-1.39-3.909C.738 1.425 1.421.75 2.25.75h1.5c.414 0 .745.337.79.749.073.657.24 1.286.488 1.872L3.817 4.582a.365.365 0 0 0-.062.439A8.666 8.666 0 0 0 7.11 8.319c.143.078.319.049.433-.066L8.768 7.03a6.708 6.708 0 0 0 1.733.43c.412.045.749.377.749.791v1.5'/%3e%3c/svg%3e")`,
                "phone-forwarded-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.353.146a.5.5 0 1 0-.707.708L13.792 3H9a.5.5 0 0 0 0 1h4.793l-2.147 2.146a.5.5 0 1 0 .707.708L15.707 3.5 12.353.146ZM15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.398c.19.103.424.065.577-.088l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2'/%3e%3c/svg%3e")`,
                "phone-forwarded-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='13' fill='none' viewBox='0 0 13 12'%3e%3cpath fill='%230E1011' d='M9.64.11a.375.375 0 1 0-.53.53l1.61 1.61H7.125a.375.375 0 1 0 0 .75h3.595L9.11 4.61a.375.375 0 1 0 .53.53l2.515-2.515L9.64.11Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.453 6.973C1.628 5.765 1.066 3.95.85 2.246.745 1.424 1.422.75 2.25.75H4.2c.414 0 .75.336.786.749.064.729.21 1.584.427 2.163a.411.411 0 0 1-.085.436l-.642.642a.362.362 0 0 0-.055.45A7.036 7.036 0 0 0 6.93 7.441c.143.087.325.06.443-.058l.658-.658c.111-.11.279-.14.427-.088.548.19 1.354.318 2.043.377.413.034.749.37.749.785v1.95c0 .828-.674 1.505-1.496 1.401-1.662-.21-3.434-.745-4.617-1.53a9.854 9.854 0 0 1-2.684-2.648m1.703-2.764a1.112 1.112 0 0 0-.158 1.382A7.786 7.786 0 0 0 6.54 8.084c.454.275 1.013.18 1.363-.17l.505-.505c.61.183 1.387.299 2.029.353a.085.085 0 0 1 .053.024.05.05 0 0 1 .009.012V9.75c0 .44-.338.697-.652.657-1.595-.201-3.243-.712-4.296-1.411a9.104 9.104 0 0 1-2.48-2.447c-.735-1.076-1.271-2.763-1.479-4.398-.04-.312.216-.651.657-.651h1.952s.006.003.012.009a.09.09 0 0 1 .025.055c.06.684.192 1.512.402 2.16l-.485.485' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-forwarded": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='17' fill='none' viewBox='0 0 17 16'%3e%3cpath fill='%230E1011' d='M12.854.146a.5.5 0 1 0-.707.708L14.293 3H9.5a.5.5 0 0 0 0 1h4.793l-2.146 2.146a.5.5 0 1 0 .707.708L16.207 3.5 12.854.146Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531m2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9.755 11.144c.82.117 1.495-.566 1.495-1.394v-1.5c0-.414-.337-.746-.748-.791a6.708 6.708 0 0 1-1.734-.43L7.544 8.253a.365.365 0 0 1-.433.066A8.666 8.666 0 0 1 3.755 5.02a.365.365 0 0 1 .062-.439l1.21-1.21a6.706 6.706 0 0 1-.486-1.873C4.496 1.087 4.164.75 3.75.75h-1.5C1.422.75.739 1.425.856 2.245a10.432 10.432 0 0 0 1.39 3.909 10.553 10.553 0 0 0 3.723 3.674 10.433 10.433 0 0 0 3.786 1.316'/%3e%3c/svg%3e")`,
                "phone-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.007 14.86C14.1 15.014 15 14.104 15 13v-2c0-.552-.45-.994-.998-1.055a8.943 8.943 0 0 1-2.312-.573l-1.632 1.632a.486.486 0 0 1-.577.088 11.554 11.554 0 0 1-4.475-4.398.486.486 0 0 1 .084-.584l1.614-1.615a8.941 8.941 0 0 1-.65-2.497C5.995 1.449 5.553 1 5 1H3c-1.105 0-2.015.9-1.86 1.993a13.91 13.91 0 0 0 1.854 5.212 14.07 14.07 0 0 0 4.965 4.898 13.908 13.908 0 0 0 5.048 1.756'/%3e%3c/svg%3e")`,
                "phone-call-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.423.19a.375.375 0 0 0-.083.745 4.125 4.125 0 0 1 3.644 3.64.375.375 0 1 0 .745-.084A4.875 4.875 0 0 0 7.423.19ZM7.453 2.194a.375.375 0 0 0-.144.737 2.125 2.125 0 0 1 1.68 1.678.375.375 0 1 0 .735-.143 2.875 2.875 0 0 0-2.27-2.272M11.25 9.75c0 .829-.675 1.511-1.495 1.394a10.43 10.43 0 0 1-3.786-1.316 10.552 10.552 0 0 1-3.724-3.674 10.432 10.432 0 0 1-1.39-3.909C.738 1.425 1.421.75 2.25.75h1.5c.414 0 .745.337.79.749.073.657.24 1.286.488 1.872L3.817 4.582a.365.365 0 0 0-.062.439A8.666 8.666 0 0 0 7.11 8.319c.143.078.319.049.433-.066L8.768 7.03a6.707 6.707 0 0 0 1.733.43c.412.045.749.377.749.791v1.5'/%3e%3c/svg%3e")`,
                "phone-call-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.897.253a.5.5 0 1 0-.11.994 5.5 5.5 0 0 1 4.858 4.852.5.5 0 1 0 .994-.111A6.5 6.5 0 0 0 9.897.253M9.938 2.926a.5.5 0 1 0-.192.981 2.833 2.833 0 0 1 2.238 2.239.5.5 0 0 0 .982-.192 3.833 3.833 0 0 0-3.028-3.028M15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.994C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.877.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.555 11.555 0 0 0 4.475 4.398c.19.104.424.065.577-.088l1.632-1.632a8.943 8.943 0 0 0 2.312.573c.549.06.998.503.998 1.055v2'/%3e%3c/svg%3e")`,
                "phone-call-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.423.19a.375.375 0 1 0-.083.745 4.125 4.125 0 0 1 3.644 3.64.375.375 0 1 0 .745-.084A4.875 4.875 0 0 0 7.423.19ZM7.453 2.194a.375.375 0 0 0-.143.737 2.125 2.125 0 0 1 1.679 1.678.375.375 0 1 0 .736-.143 2.875 2.875 0 0 0-2.272-2.272'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.453 6.973C1.628 5.765 1.066 3.95.85 2.246.745 1.424 1.422.75 2.25.75H4.2c.414 0 .75.336.786.749.064.729.21 1.584.427 2.163a.411.411 0 0 1-.085.436l-.642.642a.362.362 0 0 0-.055.45A7.036 7.036 0 0 0 6.93 7.441c.143.087.325.06.443-.058l.658-.658c.111-.11.279-.14.427-.088.548.19 1.354.318 2.043.377.413.035.749.37.749.785v1.95c0 .829-.674 1.505-1.496 1.401-1.662-.21-3.434-.745-4.617-1.53a9.854 9.854 0 0 1-2.684-2.648M4.156 4.21a1.112 1.112 0 0 0-.158 1.38A7.786 7.786 0 0 0 6.54 8.085c.454.275 1.013.18 1.363-.17l.505-.504c.61.182 1.387.298 2.029.352a.085.085 0 0 1 .053.024.05.05 0 0 1 .009.012V9.75c0 .44-.338.697-.652.657-1.595-.2-3.243-.712-4.296-1.411a9.104 9.104 0 0 1-2.48-2.447c-.735-1.076-1.271-2.763-1.479-4.398-.04-.312.216-.651.657-.651h1.952s.006.003.012.009a.09.09 0 0 1 .025.055c.06.684.192 1.512.402 2.16l-.485.486' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-call": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.897.253a.5.5 0 0 0-.11.994 5.5 5.5 0 0 1 4.858 4.852.5.5 0 0 0 .994-.111A6.5 6.5 0 0 0 9.897.253M9.938 2.926a.5.5 0 1 0-.192.981 2.834 2.834 0 0 1 2.239 2.239.5.5 0 1 0 .981-.192 3.834 3.834 0 0 0-3.028-3.028'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.077l.877-.878a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.279-4.579-.993-6.157-2.04a13.14 13.14 0 0 1-3.578-3.531m2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.381 10.381 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.138 12.138 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.998 5.59a1.112 1.112 0 0 1 .158-1.38l.484-.485c-.21-.649-.34-1.477-.4-2.16a.09.09 0 0 0-.026-.056.042.042 0 0 0-.012-.009H2.25c-.44 0-.696.339-.657.651.208 1.635.744 3.322 1.48 4.398a9.104 9.104 0 0 0 2.479 2.447c1.053.7 2.7 1.21 4.296 1.411.314.04.652-.217.652-.657V7.798a.04.04 0 0 0-.009-.012.086.086 0 0 0-.053-.024c-.642-.054-1.418-.17-2.03-.353l-.504.505c-.35.35-.91.445-1.363.17A7.786 7.786 0 0 1 3.998 5.59M.849 2.247c.217 1.704.779 3.519 1.604 4.727A9.854 9.854 0 0 0 5.137 9.62c1.183.785 2.955 1.32 4.617 1.53.822.104 1.496-.573 1.496-1.401V7.8c0-.414-.336-.75-.749-.785-.689-.059-1.495-.188-2.043-.377a.412.412 0 0 0-.427.088l-.658.658a.362.362 0 0 1-.443.058A7.036 7.036 0 0 1 4.63 5.19a.362.362 0 0 1 .055-.45l.642-.641a.411.411 0 0 0 .085-.436c-.217-.579-.363-1.434-.427-2.163C4.95 1.086 4.614.75 4.2.75H2.25c-.828 0-1.505.674-1.4 1.496' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "phone": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.33 7.454a1.483 1.483 0 0 1 .21-1.841l.647-.647c-.28-.865-.455-1.968-.535-2.88a.119.119 0 0 0-.034-.074A.055.055 0 0 0 5.603 2L5.6 2H3c-.588 0-.929.451-.876.868.277 2.18.992 4.43 1.972 5.865a12.139 12.139 0 0 0 3.306 3.261c1.405.933 3.602 1.614 5.729 1.882.418.053.869-.289.869-.876v-2.603a.055.055 0 0 0-.012-.015.113.113 0 0 0-.07-.033c-.857-.072-1.892-.226-2.707-.47l-.673.674a1.483 1.483 0 0 1-1.816.226A10.382 10.382 0 0 1 5.33 7.454m-4.198-4.46c.289 2.273 1.038 4.693 2.139 6.303a13.138 13.138 0 0 0 3.578 3.53c1.578 1.048 3.94 1.762 6.157 2.041C14.102 15.007 15 14.105 15 13v-2.6c0-.552-.448-1-.998-1.047-.919-.078-1.995-.25-2.725-.503a.549.549 0 0 0-.569.118l-.877.877a.483.483 0 0 1-.591.078A9.382 9.382 0 0 1 6.175 6.92a.483.483 0 0 1 .073-.6l.856-.855a.549.549 0 0 0 .113-.58c-.288-.773-.483-1.914-.568-2.886C6.6 1.448 6.152 1 5.6 1H3c-1.105 0-2.007.898-1.868 1.994Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "percent-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.39 1.797a.375.375 0 0 1 0 .53l-8.25 8.25a.375.375 0 0 1-.53-.53l8.25-8.25a.375.375 0 0 1 .53 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.188a1.5 1.5 0 1 1 3 0 1.5 1.5 0 0 1-3 0m1.5-.75a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5M9 7.688a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-.75 1.5a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "percent": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.854 2.396a.5.5 0 0 1 0 .708l-11 11a.5.5 0 0 1-.708-.708l11-11a.5.5 0 0 1 .708 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 4.25a2 2 0 1 1 4 0 2 2 0 0 1-4 0m2-1a1 1 0 1 0 0 2 1 1 0 0 0 0-2M12 10.25a2 2 0 1 0 0 4 2 2 0 0 0 0-4m-1 2a1 1 0 1 1 2 0 1 1 0 0 1-2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pen-tool-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.653 4.653a1.015 1.015 0 1 0 1.436 1.436 1.015 1.015 0 0 0-1.436-1.436'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.135.135A.375.375 0 0 1 .5.04l8.224 2.224a.375.375 0 0 1 .264.263L10 6.241a.936.936 0 0 1 .788.267l.704.704a.938.938 0 0 1 0 1.326l-2.954 2.954a.938.938 0 0 1-1.326 0l-.704-.704A.936.936 0 0 1 6.24 10L2.526 8.987a.375.375 0 0 1-.263-.264L.039.499A.375.375 0 0 1 .135.135m.067.067c.11-.11.288-.11.398 0l3.872 3.872a1.578 1.578 0 1 1-.398.397L.202.6a.281.281 0 0 1 0-.397Zm9.56 6.162c.11.11.11.288 0 .397l-3 3a.281.281 0 1 1-.398-.397l3-3c.11-.11.288-.11.397 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pen-tool-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.204 6.204a1.354 1.354 0 1 0 1.914 1.914 1.354 1.354 0 0 0-1.914-1.914'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.18.18A.5.5 0 0 1 .666.053L11.63 3.017a.5.5 0 0 1 .351.351l1.351 4.954c.373-.05.764.068 1.05.355l.94.94a1.25 1.25 0 0 1 0 1.767l-3.94 3.94a1.25 1.25 0 0 1-1.767 0l-.94-.94a1.248 1.248 0 0 1-.354-1.05l-4.954-1.352a.5.5 0 0 1-.35-.351L.051.665A.5.5 0 0 1 .18.18ZM.27.27a.375.375 0 0 1 .53 0l5.163 5.163a2.104 2.104 0 1 1-.53.53L.269.799a.375.375 0 0 1 0-.53m12.746 8.216a.375.375 0 0 1 0 .53l-4 4a.375.375 0 1 1-.53-.53l4-4a.375.375 0 0 1 .53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pen-tool-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.135.135A.375.375 0 0 1 .5.04l8.224 2.224a.375.375 0 0 1 .264.263L10 6.241a.936.936 0 0 1 .788.267l.704.704a.938.938 0 0 1 0 1.326l-2.954 2.954a.937.937 0 0 1-1.326 0l-.704-.704A.936.936 0 0 1 6.24 10L2.526 8.987a.375.375 0 0 1-.263-.264L.039.499A.375.375 0 0 1 .135.135M6.64 9.331 9.33 6.639 8.32 2.93 1.478 1.08l2.994 2.993a1.578 1.578 0 1 1-.398.398L1.08 1.478 2.93 8.32 6.639 9.33Zm.399.661a.187.187 0 0 0 0 .266l.704.704a.188.188 0 0 0 .266 0l2.954-2.954a.188.188 0 0 0 0-.266l-.704-.704a.188.188 0 0 0-.266 0L7.038 9.992m-2.385-5.34A1.015 1.015 0 1 0 6.089 6.09a1.015 1.015 0 0 0-1.436-1.436' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pen-tool": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.18.18A.5.5 0 0 1 .666.053L11.63 3.017a.5.5 0 0 1 .351.351l1.351 4.954c.373-.05.764.068 1.05.355l.94.94a1.25 1.25 0 0 1 0 1.767l-3.94 3.94a1.25 1.25 0 0 1-1.767 0l-.94-.94a1.248 1.248 0 0 1-.354-1.05l-4.954-1.352a.5.5 0 0 1-.35-.351L.051.665A.5.5 0 0 1 .18.18Zm8.672 12.261 3.59-3.59-1.349-4.943L1.971 1.44l3.991 3.99a2.104 2.104 0 1 1-.53.531L1.44 1.972l2.467 9.121 4.944 1.348m.532.882a.25.25 0 0 0 0 .354l.94.94a.25.25 0 0 0 .353 0l3.94-3.94a.25.25 0 0 0 0-.354l-.94-.94a.25.25 0 0 0-.354 0l-3.94 3.94m-3.18-7.12a1.354 1.354 0 1 0 1.914 1.915 1.354 1.354 0 0 0-1.914-1.914' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pause-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.5 1A1.5 1.5 0 0 0 1 2.5v7A1.5 1.5 0 0 0 2.5 11h1A1.5 1.5 0 0 0 5 9.5v-7A1.5 1.5 0 0 0 3.5 1zM8.5 1A1.5 1.5 0 0 0 7 2.5v7A1.5 1.5 0 0 0 8.5 11h1A1.5 1.5 0 0 0 11 9.5v-7A1.5 1.5 0 0 0 9.5 1z'/%3e%3c/svg%3e")`,
                "pause-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 3.25C3 2.56 3.56 2 4.25 2h1.5C6.44 2 7 2.56 7 3.25v9.5C7 13.44 6.44 14 5.75 14h-1.5C3.56 14 3 13.44 3 12.75zM4.25 3a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5A.25.25 0 0 0 5.75 3zm6 0a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5a.25.25 0 0 0-.25-.25zM9 3.25C9 2.56 9.56 2 10.25 2h1.5c.69 0 1.25.56 1.25 1.25v9.5c0 .69-.56 1.25-1.25 1.25h-1.5C9.56 14 9 13.44 9 12.75z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4 3.25A.25.25 0 0 1 4.25 3h1.5a.25.25 0 0 1 .25.25v9.5a.25.25 0 0 1-.25.25h-1.5a.25.25 0 0 1-.25-.25zM10 3.25a.25.25 0 0 1 .25-.25h1.5a.25.25 0 0 1 .25.25v9.5a.25.25 0 0 1-.25.25h-1.5a.25.25 0 0 1-.25-.25z'/%3e%3c/svg%3e")`,
                "pause-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M5.25 4.5a.375.375 0 1 0-.75 0v3a.375.375 0 1 0 .75 0zm2.25 0a.375.375 0 1 0-.75 0v3a.375.375 0 1 0 .75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pause-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M6.5 5.5A.5.5 0 0 1 7 6v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5m3 0a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pause-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.25 4.5a.375.375 0 1 0-.75 0v3a.375.375 0 1 0 .75 0zM7.5 4.5a.375.375 0 1 0-.75 0v3a.375.375 0 1 0 .75 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 .188a5.812 5.812 0 1 0 0 11.624A5.812 5.812 0 0 0 6 .188M.938 6a5.063 5.063 0 1 1 10.125 0A5.063 5.063 0 0 1 .938 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pause-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 5.5A.5.5 0 0 1 7 6v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5M9.5 5.5a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pause-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.5A1.5 1.5 0 0 1 2.5 1h1A1.5 1.5 0 0 1 5 2.5v7A1.5 1.5 0 0 1 3.5 11h-1A1.5 1.5 0 0 1 1 9.5zM2.5 2h1a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-7a.5.5 0 0 1 .5-.5M7 2.5A1.5 1.5 0 0 1 8.5 1h1A1.5 1.5 0 0 1 11 2.5v7A1.5 1.5 0 0 1 9.5 11h-1A1.5 1.5 0 0 1 7 9.5zM8.5 2h1a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-7a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "pause": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 3.25C3 2.56 3.56 2 4.25 2h1.5C6.44 2 7 2.56 7 3.25v9.5C7 13.44 6.44 14 5.75 14h-1.5C3.56 14 3 13.44 3 12.75zM4.25 3a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5A.25.25 0 0 0 5.75 3zm6 0a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5a.25.25 0 0 0-.25-.25zM9 3.25C9 2.56 9.56 2 10.25 2h1.5c.69 0 1.25.56 1.25 1.25v9.5c0 .69-.56 1.25-1.25 1.25h-1.5C9.56 14 9 13.44 9 12.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "paperclip-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='13' fill='none' viewBox='0 0 12 13'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.95 1.3a1.875 1.875 0 0 0-2.65 0L2.011 6.586a2.625 2.625 0 0 0 0 3.712l.257.258a2.625 2.625 0 0 0 3.712 0l4.072-4.072.53.53-4.071 4.072a3.375 3.375 0 0 1-4.773 0l-.258-.258a3.375 3.375 0 0 1 0-4.772L6.77.769A2.625 2.625 0 0 1 10.48 4.48L5.42 9.543a1.765 1.765 0 0 1-2.497-2.497l4.13-4.13.53.531-4.13 4.13A1.015 1.015 0 1 0 4.89 9.012l5.062-5.061a1.875 1.875 0 0 0 0-2.652Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "paperclip": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='17' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.268 1.732a2.5 2.5 0 0 0-3.536 0l-7.05 7.05a3.5 3.5 0 0 0 0 4.95l.343.343a3.5 3.5 0 0 0 4.95 0l5.429-5.429.707.708-5.429 5.429a4.5 4.5 0 0 1-6.364 0l-.343-.344a4.5 4.5 0 0 1 0-6.364l7.05-7.05a3.5 3.5 0 0 1 4.95 4.95l-6.749 6.749a2.354 2.354 0 1 1-3.328-3.329L9.404 3.89l.707.707-5.506 5.506a1.354 1.354 0 1 0 1.914 1.914l6.749-6.748a2.5 2.5 0 0 0 0-3.536' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "package-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m3.017 1.612-2.18.904a.749.749 0 0 0-.206.128.374.374 0 0 1 .275.015l5.089 2.33 1.783-.868-4.57-2.286a.374.374 0 0 1-.19-.223M3.794 1.29l4.843 2.422 2.465-1.057a.373.373 0 0 1 .267-.01.749.749 0 0 0-.207-.129L6.287.494a.75.75 0 0 0-.574 0l-1.92.796M11.615 3.086a.374.374 0 0 1-.217.259L8.78 4.466 6.375 5.639v5.61c0 .129-.064.242-.161.31a.736.736 0 0 0 .073-.027l4.875-2.022a.75.75 0 0 0 .463-.693V3.21a.743.743 0 0 0-.01-.123M5.786 11.558a.375.375 0 0 1-.161-.308V5.645L.594 3.341a.374.374 0 0 1-.209-.255.75.75 0 0 0-.01.123v5.608a.75.75 0 0 0 .463.693l4.875 2.022c.024.01.048.019.073.026'/%3e%3c/svg%3e")`,
                "package-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.023 2.15 1.117 3.354a.999.999 0 0 0-.275.17.498.498 0 0 1 .366.02l6.785 3.108 2.378-1.159-6.095-3.047a.498.498 0 0 1-.253-.298M5.058 1.72l6.458 3.229 3.287-1.409a.498.498 0 0 1 .355-.014.998.998 0 0 0-.275-.171L8.383.659a1 1 0 0 0-.766 0L5.058 1.72M15.487 4.115a.5.5 0 0 1-.29.344l-3.489 1.496L8.5 7.518V15a.5.5 0 0 1-.215.41c.033-.009.066-.02.098-.034l6.5-2.696a1 1 0 0 0 .617-.924V4.278c0-.055-.005-.11-.013-.163M7.715 15.41A.5.5 0 0 1 7.5 15V7.527L.792 4.455a.5.5 0 0 1-.279-.34 1.001 1.001 0 0 0-.013.163v7.478a1 1 0 0 0 .617.924l6.5 2.696c.032.013.065.025.098.035'/%3e%3c/svg%3e")`,
                "package-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.431.148a1.125 1.125 0 0 0-.862 0L.694 2.17C.274 2.344 0 2.754 0 3.209v5.608c0 .455.274.865.694 1.04l4.875 2.021c.276.115.586.115.862 0l4.875-2.022c.42-.174.694-.584.694-1.039V3.21c0-.455-.274-.865-.694-1.04L6.431.149ZM5.856.84a.375.375 0 0 1 .288 0l4.41 1.829-1.924.824-4.359-1.996L5.856.84M3.326 1.89l-1.88.78L6 4.62l1.7-.728L3.326 1.89ZM.751 3.188l-.001.02v5.61c0 .15.091.288.231.346l4.644 1.926V5.277L.751 3.187Zm5.624 7.902 4.644-1.926a.375.375 0 0 0 .231-.347V3.188L6.374 5.277v5.813' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "package": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.575.197a1.5 1.5 0 0 0-1.15 0l-6.5 2.696A1.5 1.5 0 0 0 0 4.278v7.478a1.5 1.5 0 0 0 .925 1.386l6.5 2.696a1.5 1.5 0 0 0 1.15 0l6.5-2.696A1.5 1.5 0 0 0 16 11.756V4.278a1.5 1.5 0 0 0-.925-1.385L8.575.197Zm-.767.924a.5.5 0 0 1 .384 0l5.88 2.439-2.565 1.1-5.812-2.663 2.113-.876M4.435 2.52 1.928 3.56 8 6.162l2.266-.971L4.435 2.52M1 4.25 1 4.278v7.478a.5.5 0 0 0 .308.462L7.5 14.786v-7.75L1 4.25M8.5 14.786l6.192-2.568a.5.5 0 0 0 .308-.462V4.25L8.5 7.036v7.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "octagon-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.671 0c-.1 0-.195.04-.265.11L.11 3.406a.375.375 0 0 0-.11.265V8.33c0 .1.04.195.11.265l3.296 3.296c.07.07.166.11.265.11H8.33c.1 0 .195-.04.265-.11l3.296-3.296c.07-.07.11-.166.11-.265V3.67c0-.1-.04-.195-.11-.265L8.594.11A.375.375 0 0 0 8.329 0H3.67Zm.898 4.098a.333.333 0 0 0-.471.471L5.528 6l-1.43 1.431a.333.333 0 0 0 .471.471L6 6.472l1.431 1.43a.333.333 0 0 0 .471-.471L6.472 6l1.43-1.431a.333.333 0 0 0-.471-.471L6 5.528l-1.431-1.43' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "octagon-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.406.11c.07-.07.166-.11.265-.11H8.33c.1 0 .195.04.265.11l3.296 3.296c.07.07.11.166.11.265V8.33c0 .1-.04.195-.11.265L8.594 11.89a.375.375 0 0 1-.265.11H3.67c-.1 0-.195-.04-.265-.11L.11 8.594A.375.375 0 0 1 0 8.329V3.67c0-.1.04-.195.11-.265L3.406.11Zm.42.64L.75 3.827v4.346l3.077 3.077h4.346l3.077-3.077V3.827L8.173.75H3.827' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 3.827 3.827.75h4.346l3.077 3.077v4.346L8.173 11.25H3.827L.75 8.173V3.827'/%3e%3c/svg%3e")`,
                "octagon-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.25 4.997 11.003.75H4.997L.75 4.997v6.006l4.247 4.247h6.006l4.247-4.247V4.997m-10.104.15a.5.5 0 0 1 .708 0L8 7.292l2.146-2.147a.5.5 0 0 1 .708.708L8.707 8l2.147 2.146a.5.5 0 0 1-.708.708L8 8.707l-2.146 2.147a.5.5 0 0 1-.708-.708L7.293 8 5.146 5.854a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "octagon-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.541.146A.5.5 0 0 1 4.895 0h6.21a.5.5 0 0 1 .354.146l4.395 4.395a.5.5 0 0 1 .146.354v6.21a.5.5 0 0 1-.146.354l-4.395 4.395a.5.5 0 0 1-.354.146h-6.21a.5.5 0 0 1-.354-.146L.146 11.459A.5.5 0 0 1 0 11.105v-6.21a.5.5 0 0 1 .146-.354L4.541.146ZM5.102 1 1 5.102v5.796L5.102 15h5.796L15 10.898V5.102L10.898 1H5.102' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 5.102 5.102 1h5.796L15 5.102v5.796L10.898 15H5.102L1 10.898V5.102'/%3e%3c/svg%3e")`,
                "octagon-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.406.11c.07-.07.166-.11.265-.11H8.33c.1 0 .195.04.265.11l3.296 3.296c.07.07.11.166.11.265V8.33c0 .1-.04.195-.11.265L8.594 11.89a.375.375 0 0 1-.265.11H3.67c-.1 0-.195-.04-.265-.11L.11 8.594A.375.375 0 0 1 0 8.329V3.67c0-.1.04-.195.11-.265L3.406.11Zm.42.64L.75 3.827v4.346l3.077 3.077h4.346l3.077-3.077V3.827L8.173.75H3.827' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.569 4.098a.333.333 0 0 0-.471.471L5.528 6l-1.43 1.431a.333.333 0 0 0 .471.471L6 6.472l1.431 1.43a.333.333 0 0 0 .471-.471L6.472 6l1.43-1.431a.333.333 0 0 0-.471-.471L6 5.528l-1.431-1.43'/%3e%3c/svg%3e")`,
                "octagon": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.406.11c.07-.07.166-.11.265-.11H8.33c.1 0 .195.04.265.11l3.296 3.296c.07.07.11.166.11.265V8.33c0 .1-.04.195-.11.265L8.594 11.89a.375.375 0 0 1-.265.11H3.67c-.1 0-.195-.04-.265-.11L.11 8.594A.375.375 0 0 1 0 8.329V3.67c0-.1.04-.195.11-.265L3.406.11Zm.42.64L.75 3.827v4.346l3.077 3.077h4.346l3.077-3.077V3.827L8.173.75H3.827' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "octagon": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.146 5.146a.5.5 0 0 1 .708 0L8 7.293l2.146-2.147a.5.5 0 0 1 .708.708L8.707 8l2.147 2.146a.5.5 0 0 1-.708.708L8 8.707l-2.146 2.147a.5.5 0 0 1-.708-.708L7.293 8 5.146 5.854a.5.5 0 0 1 0-.708'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m11.003.75 4.247 4.247v6.006l-4.247 4.247H4.997L.75 11.003V4.997L4.997.75h6.006Zm-5.592 1h5.178L14.25 5.41v5.178l-3.661 3.66H5.41L1.75 10.59V5.41L5.411 1.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "octagon": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.541.146A.5.5 0 0 1 4.895 0h6.21a.5.5 0 0 1 .354.146l4.395 4.395a.5.5 0 0 1 .146.354v6.21a.5.5 0 0 1-.146.354l-4.395 4.395a.5.5 0 0 1-.354.146h-6.21a.5.5 0 0 1-.354-.146L.146 11.459A.5.5 0 0 1 0 11.105v-6.21a.5.5 0 0 1 .146-.354L4.541.146ZM5.102 1 1 5.102v5.796L5.102 15h5.796L15 10.898V5.102L10.898 1H5.102' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "navigation-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.14.86c.111.11.141.28.075.422l-4.5 9.75a.375.375 0 0 1-.71-.095L5.3 6.7l-4.236-.706a.375.375 0 0 1-.095-.71l9.75-4.5a.375.375 0 0 1 .422.075M2.388 5.455l3.299.55c.158.026.282.15.308.308l.55 3.3 3.563-7.721-7.72 3.563Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m5.687 6.005-3.3-.55 7.721-3.563-3.563 7.72-.55-3.299a.375.375 0 0 0-.308-.308'/%3e%3c/svg%3e")`,
                "navigation-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 1.146a.5.5 0 0 1 .1.564l-6 13a.5.5 0 0 1-.947-.128l-.941-5.648-5.648-.94a.5.5 0 0 1-.128-.948l13-6a.5.5 0 0 1 .564.1M3.184 7.274l4.398.733a.5.5 0 0 1 .411.41l.733 4.4 4.751-10.294-10.293 4.75' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m7.582 8.007-4.398-.733 10.293-4.751-4.75 10.294-.734-4.4a.5.5 0 0 0-.41-.41'/%3e%3c/svg%3e")`,
                "navigation-2-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.125.75c.157 0 .298.098.352.245l3.5 9.5a.375.375 0 0 1-.538.456L6.125 9.057 2.811 10.95a.375.375 0 0 1-.538-.456l3.5-9.5A.375.375 0 0 1 6.125.75M3.333 9.789l2.606-1.49a.375.375 0 0 1 .372 0l2.606 1.49-2.792-7.58-2.792 7.58' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M5.939 8.3 3.333 9.788l2.792-7.58 2.792 7.58-2.606-1.49a.375.375 0 0 0-.372 0'/%3e%3c/svg%3e")`,
                "navigation-2-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.167 1a.5.5 0 0 1 .469.327l4.667 12.667a.5.5 0 0 1-.718.607l-4.418-2.525L3.748 14.6a.5.5 0 0 1-.717-.607L7.698 1.327A.5.5 0 0 1 8.167 1M4.444 13.052l3.475-1.986a.5.5 0 0 1 .496 0l3.475 1.986L8.167 2.946 4.444 13.052' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m7.919 11.066-3.475 1.986L8.167 2.946l3.723 10.106-3.475-1.986a.5.5 0 0 0-.496 0'/%3e%3c/svg%3e")`,
                "navigation-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.125.75c.157 0 .298.098.352.245l3.5 9.5a.375.375 0 0 1-.538.456L6.125 9.057 2.811 10.95a.375.375 0 0 1-.538-.456l3.5-9.5A.375.375 0 0 1 6.125.75M3.333 9.789l2.606-1.49a.375.375 0 0 1 .372 0l2.606 1.49-2.792-7.58-2.792 7.58' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "navigation-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.167 1a.5.5 0 0 1 .469.327l4.667 12.667a.5.5 0 0 1-.718.607l-4.418-2.525L3.748 14.6a.5.5 0 0 1-.717-.607L7.697 1.327A.5.5 0 0 1 8.167 1M4.444 13.052l3.475-1.986a.5.5 0 0 1 .496 0l3.475 1.986L8.167 2.946 4.444 13.052' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "navigation-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.14.86c.111.11.141.28.075.422l-4.5 9.75a.375.375 0 0 1-.71-.095L5.3 6.7l-4.236-.706a.375.375 0 0 1-.095-.71l9.75-4.5a.375.375 0 0 1 .422.075M2.388 5.455l3.299.55c.158.026.282.15.308.308l.55 3.3 3.563-7.721-7.72 3.563' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "navigation": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 1.146a.5.5 0 0 1 .1.564l-6 13a.5.5 0 0 1-.947-.128l-.941-5.648-5.648-.94a.5.5 0 0 1-.128-.948l13-6a.5.5 0 0 1 .564.1M3.184 7.274l4.398.733a.5.5 0 0 1 .411.41l.733 4.4 4.751-10.294-10.294 4.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "music-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.5.628V8.25A1.5 1.5 0 0 1 9 9.75h-.75a1.5 1.5 0 0 1 0-3h1.5V1.622L5.522 2.83a.375.375 0 0 0-.272.36v6.56a1.5 1.5 0 0 1-1.5 1.5H3a1.5 1.5 0 0 1 0-3h1.5V3.19c0-.502.333-.943.816-1.081L10.5.628ZM4.5 9H3a.75.75 0 1 0 0 1.5h.75a.75.75 0 0 0 .75-.75V9m5.25-1.5h-1.5a.75.75 0 1 0 0 1.5H9a.75.75 0 0 0 .75-.75V7.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3 9h1.5v.75a.75.75 0 0 1-.75.75H3A.75.75 0 0 1 3 9M8.25 7.5h1.5v.75A.75.75 0 0 1 9 9h-.75a.75.75 0 0 1 0-1.5'/%3e%3c/svg%3e")`,
                "music-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14 .837V11a2 2 0 0 1-2 2h-1a2 2 0 1 1 0-4h2V2.163l-5.637 1.61A.5.5 0 0 0 7 4.255V13a2 2 0 0 1-2 2H4a2 2 0 1 1 0-4h2V4.254a1.5 1.5 0 0 1 1.088-1.442L14 .837ZM6 12H4a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1zm7-2h-2a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4 12h2v1a1 1 0 0 1-1 1H4a1 1 0 1 1 0-2M11 10h2v1a1 1 0 0 1-1 1h-1a1 1 0 1 1 0-2'/%3e%3c/svg%3e")`,
                "music-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.5.628V8.25A1.5 1.5 0 0 1 9 9.75h-.75a1.5 1.5 0 0 1 0-3h1.5V1.622L5.522 2.83a.375.375 0 0 0-.272.36v6.56a1.5 1.5 0 0 1-1.5 1.5H3a1.5 1.5 0 0 1 0-3h1.5V3.19c0-.502.333-.943.816-1.081L10.5.628ZM4.5 9H3a.75.75 0 1 0 0 1.5h.75a.75.75 0 0 0 .75-.75V9m5.25-1.5h-1.5a.75.75 0 1 0 0 1.5H9a.75.75 0 0 0 .75-.75V7.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "music": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14 .837V11a2 2 0 0 1-2 2h-1a2 2 0 1 1 0-4h2V2.163l-5.637 1.61A.5.5 0 0 0 7 4.255V13a2 2 0 0 1-2 2H4a2 2 0 1 1 0-4h2V4.254a1.5 1.5 0 0 1 1.088-1.442L14 .837ZM6 12H4a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1zm7-2h-2a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "move-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6 .22 1.765 1.765a.375.375 0 0 1-.53.53l-.86-.86v3.97h3.97l-.86-.86a.375.375 0 1 1 .53-.53L11.78 6l-1.765 1.765a.375.375 0 0 1-.53-.53l.86-.86h-3.97v3.97l.86-.86a.375.375 0 0 1 .53.53L6 11.78l-1.765-1.765a.375.375 0 1 1 .53-.53l.86.86v-3.97h-3.97l.86.86a.375.375 0 0 1-.53.53L.22 6l1.765-1.765a.375.375 0 1 1 .53.53l-.86.86h3.97v-3.97l-.86.86a.375.375 0 1 1-.53-.53L6 .22' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "move": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 .293 2.354 2.353a.5.5 0 0 1-.708.708L8.5 2.207V7.5h5.293l-1.147-1.146a.5.5 0 0 1 .708-.708L15.707 8l-2.353 2.354a.5.5 0 0 1-.708-.708L13.793 8.5H8.5v5.293l1.146-1.147a.5.5 0 1 1 .708.707L8 15.708l-2.354-2.354a.5.5 0 1 1 .708-.707L7.5 13.793V8.5H2.207l1.147 1.146a.5.5 0 0 1-.708.707L.293 8l2.353-2.354a.5.5 0 1 1 .708.708L2.207 7.5H7.5V2.207L6.354 3.354a.5.5 0 1 1-.708-.708L8 .293Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mouse-pointer-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.27.779a.375.375 0 0 0-.491.49l4.062 9.75a.375.375 0 0 0 .701-.023l1.145-3.371 2.681 2.68a.663.663 0 1 0 .938-.937l-2.681-2.68 3.37-1.146a.375.375 0 0 0 .024-.701L1.27.779Z'/%3e%3c/svg%3e")`,
                "mouse-pointer-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.692 1.038a.5.5 0 0 0-.654.654l5.417 13a.5.5 0 0 0 .934-.031l1.527-4.495 3.575 3.575a.884.884 0 1 0 1.25-1.25l-3.575-3.575 4.495-1.527a.5.5 0 0 0 .031-.934l-13-5.417Z'/%3e%3c/svg%3e")`,
                "mouse-pointer-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.86.86a.375.375 0 0 1 .41-.081l9.75 4.062a.375.375 0 0 1-.024.701L8.02 6.552l2.176 2.176a1.038 1.038 0 0 1-1.468 1.468L6.553 8.02l-1.01 2.976a.375.375 0 0 1-.702.023L.779 1.27a.375.375 0 0 1 .08-.41m.961.961 3.33 7.993.885-2.606a.375.375 0 0 1 .62-.144l2.602 2.602a.288.288 0 1 0 .408-.408L7.064 6.658a.375.375 0 0 1 .144-.62l2.606-.886-7.993-3.33Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mouse-pointer": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.146 1.146a.5.5 0 0 1 .546-.108l13 5.417a.5.5 0 0 1-.031.934l-3.967 1.348 2.9 2.9a1.384 1.384 0 1 1-1.957 1.958l-2.9-2.901-1.348 3.967a.5.5 0 0 1-.935.031l-5.416-13a.5.5 0 0 1 .108-.546m1.282 1.282 4.44 10.658 1.18-3.475a.5.5 0 0 1 .827-.193l3.47 3.47a.384.384 0 1 0 .542-.543l-3.469-3.47a.5.5 0 0 1 .193-.827l3.474-1.18-10.657-4.44Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "more-vertical-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.875 1.5a1.125 1.125 0 1 0 2.25 0 1.125 1.125 0 0 0-2.25 0M6 7.125a1.125 1.125 0 1 1 0-2.25 1.125 1.125 0 0 1 0 2.25M6 11.625a1.125 1.125 0 1 1 0-2.25 1.125 1.125 0 0 1 0 2.25'/%3e%3c/svg%3e")`,
                "more-vertical": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 2a1.5 1.5 0 1 0 3 0 1.5 1.5 0 0 0-3 0M8 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3M8 15.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3'/%3e%3c/svg%3e")`,
                "more-horizontal-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.5 7.125a1.125 1.125 0 1 0 0-2.25 1.125 1.125 0 0 0 0 2.25M7.125 6a1.125 1.125 0 1 1-2.25 0 1.125 1.125 0 0 1 2.25 0M11.625 6a1.125 1.125 0 1 1-2.25 0 1.125 1.125 0 0 1 2.25 0'/%3e%3c/svg%3e")`,
                "more-horizontal": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3M9.5 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0M15.5 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0'/%3e%3c/svg%3e")`,
                "more-cirle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M3.938 6a.937.937 0 1 1-1.875 0 .937.937 0 0 1 1.874 0M6 6.938a.937.937 0 1 0 0-1.875.937.937 0 0 0 0 1.875m3 0a.937.937 0 1 0 0-1.875.937.937 0 0 0 0 1.875' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "more-cirle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0M5.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0M8 9.25a1.25 1.25 0 1 0 0-2.5 1.25 1.25 0 0 0 0 2.5M13.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "more-cirle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.938 6a.937.937 0 1 1-1.875 0 .937.937 0 0 1 1.874 0M6 6.938a.937.937 0 1 0 0-1.875.937.937 0 0 0 0 1.875M9 6.938a.937.937 0 1 0 0-1.875.937.937 0 0 0 0 1.875'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "more-cirle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0M8 9.25a1.25 1.25 0 1 0 0-2.5 1.25 1.25 0 0 0 0 2.5M13.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0m-1 0A6.3 6.3 0 1 0 1.695 8a6.3 6.3 0 0 0 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "moon-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.871.218a.429.429 0 0 1-.028.465 3.914 3.914 0 0 0 5.474 5.474.428.428 0 0 1 .681.384 6.012 6.012 0 1 1-6.54-6.54c.169-.015.33.07.413.217' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "moon-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.85 1.255a.5.5 0 0 1-.034.542 4.566 4.566 0 0 0 6.387 6.387.5.5 0 0 1 .795.448 7.014 7.014 0 1 1-7.63-7.63.5.5 0 0 1 .482.253m-1.418.93a6.014 6.014 0 1 0 7.384 7.383 5.565 5.565 0 0 1-7.384-7.384' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.335 3.229a6.014 6.014 0 0 1 2.097-1.045 5.566 5.566 0 0 0 7.384 7.384 6.015 6.015 0 1 1-9.48-6.34'/%3e%3c/svg%3e")`,
                "moon-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.871.218a.429.429 0 0 1-.028.465 3.914 3.914 0 0 0 5.474 5.474.428.428 0 0 1 .681.384 6.012 6.012 0 1 1-6.54-6.54c.169-.015.33.07.413.217m-1.215.797a5.155 5.155 0 1 0 6.33 6.329 4.771 4.771 0 0 1-6.33-6.33' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "moon": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.85 1.255a.5.5 0 0 1-.034.542 4.566 4.566 0 0 0 6.387 6.387.5.5 0 0 1 .795.448 7.014 7.014 0 1 1-7.63-7.63.5.5 0 0 1 .482.253m-1.418.93a6.014 6.014 0 1 0 7.384 7.383 5.565 5.565 0 0 1-7.384-7.384' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "monitor-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.5 1A1.5 1.5 0 0 0 0 2.5v6A1.5 1.5 0 0 0 1.5 10h9A1.5 1.5 0 0 0 12 8.5v-6A1.5 1.5 0 0 0 10.5 1zM4.5 10.125a.375.375 0 0 0 0 .75h3a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "monitor-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 4.25C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25v6.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 12 1 11.44 1 10.75zM8.5 13h5.25A2.25 2.25 0 0 0 16 10.75v-6.5A2.25 2.25 0 0 0 13.75 2H2.25A2.25 2.25 0 0 0 0 4.25v6.5A2.25 2.25 0 0 0 2.25 13H7.5v1h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.25 3C1.56 3 1 3.56 1 4.25v6.5c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25v-6.5C15 3.56 14.44 3 13.75 3z'/%3e%3c/svg%3e")`,
                "monitor-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.5A1.5 1.5 0 0 1 1.5 1h9A1.5 1.5 0 0 1 12 2.5v6a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 0 8.5zm1.5-.75h9a.75.75 0 0 1 .75.75v6a.75.75 0 0 1-.75.75h-9a.75.75 0 0 1-.75-.75v-6a.75.75 0 0 1 .75-.75' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.5 10.125a.375.375 0 0 0 0 .75h3a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "monitor": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.5 13h5.25A2.25 2.25 0 0 0 16 10.75v-6.5A2.25 2.25 0 0 0 13.75 2H2.25A2.25 2.25 0 0 0 0 4.25v6.5A2.25 2.25 0 0 0 2.25 13H7.5v1h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2zM1 4.25C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25v6.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 12 1 11.44 1 10.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2zm1 4.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9ZM5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4 5.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2zm2-1.25h6c.69 0 1.25.56 1.25 1.25v6c0 .69-.56 1.25-1.25 1.25H3c-.69 0-1.25-.56-1.25-1.25V3c0-.69.56-1.25 1.25-1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9ZM3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12M4 5.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4 5.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-.75 0A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.913 6c0-.186.15-.338.337-.338h7.5a.337.337 0 0 1 0 .675h-7.5A.338.338 0 0 1 1.913 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.55 8A.45.45 0 0 1 3 7.55h10a.45.45 0 0 1 0 .9H3A.45.45 0 0 1 2.55 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "minimize-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.375 5a.375.375 0 0 0 0-.75H8.28l2.923-2.922a.375.375 0 0 0-.53-.53L7.75 3.72V1.625a.375.375 0 1 0-.75 0V5zM1.625 7a.375.375 0 1 0 0 .75H3.72L.797 10.672a.375.375 0 1 0 .53.53L4.25 8.28v2.095a.375.375 0 0 0 .75 0V7H1.625Z'/%3e%3c/svg%3e")`,
                "minimize-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.5 7a.5.5 0 0 0 0-1h-2.793l3.897-3.896a.5.5 0 0 0-.708-.708L10 5.293V2.5a.5.5 0 0 0-1 0V7zM2.5 9a.5.5 0 0 0 0 1h2.793l-3.897 3.896a.5.5 0 0 0 .708.708L6 10.707V13.5a.5.5 0 0 0 1 0V9z'/%3e%3c/svg%3e")`,
                "minimize-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.875 1.875a.375.375 0 1 0-.75 0v1.5a.75.75 0 0 1-.75.75h-1.5a.375.375 0 1 0 0 .75h1.5a1.5 1.5 0 0 0 1.5-1.5zM4.875 10.125a.375.375 0 0 1-.75 0v-1.5a.75.75 0 0 0-.75-.75h-1.5a.375.375 0 1 1 0-.75h1.5a1.5 1.5 0 0 1 1.5 1.5zM7.5 1.5a.375.375 0 0 0-.375.375v1.5a1.5 1.5 0 0 0 1.5 1.5h1.5a.375.375 0 0 0 0-.75h-1.5a.75.75 0 0 1-.75-.75v-1.5A.375.375 0 0 0 7.5 1.5M7 10a.375.375 0 0 0 .75 0V8.5a.75.75 0 0 1 .75-.75H10A.375.375 0 0 0 10 7H8.5A1.5 1.5 0 0 0 7 8.5z'/%3e%3c/svg%3e")`,
                "minimize": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 2a.5.5 0 0 0-1 0v2a1 1 0 0 1-1 1H2a.5.5 0 0 0 0 1h2a2 2 0 0 0 2-2zM6 14a.5.5 0 0 1-1 0v-2a1 1 0 0 0-1-1H2a.5.5 0 0 1 0-1h2a2 2 0 0 1 2 2zM10.5 1.5a.5.5 0 0 0-.5.5v2a2 2 0 0 0 2 2h2a.5.5 0 0 0 0-1h-2a1 1 0 0 1-1-1V2a.5.5 0 0 0-.5-.5M10 14a.5.5 0 0 0 1 0v-2a1 1 0 0 1 1-1h2a.5.5 0 0 0 0-1h-2a2 2 0 0 0-2 2z'/%3e%3c/svg%3e")`,
                "mic-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 0C4.98 0 4.079.509 3.537 1.287l5.198 5.198A2.99 2.99 0 0 0 9 5.25V3a3 3 0 0 0-3-3M3 3.53v1.72a3 3 0 0 0 4.383 2.663l.75.75A2.987 2.987 0 0 1 6.75 9h-1.5a3 3 0 0 1-3-3v-.187a.375.375 0 1 0-.75 0V6a3.75 3.75 0 0 0 3.75 3.75h.375v1.5H4.5a.375.375 0 0 0 0 .75h3a.375.375 0 0 0 0-.75H6.375v-1.5h.375c.707 0 1.369-.196 1.933-.536l2.49 2.489a.375.375 0 0 0 .53-.53L.828.296a.375.375 0 1 0-.53.53L3 3.53M10.5 6c0 .65-.165 1.261-.456 1.794l-.56-.56A2.99 2.99 0 0 0 9.75 6v-.187a.375.375 0 1 1 .75 0z'/%3e%3c/svg%3e")`,
                "mic-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 0C6.64 0 5.439.679 4.716 1.716l6.93 6.93C11.875 8.144 12 7.586 12 7V4a4 4 0 0 0-4-4M4 4.707V7a4 4 0 0 0 5.844 3.55l1 1A3.982 3.982 0 0 1 9 12H7a4 4 0 0 1-4-4v-.25a.5.5 0 0 0-1 0V8a5 5 0 0 0 5 5h.5v2H6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H8.5v-2H9c.943 0 1.825-.261 2.578-.715l3.318 3.319a.5.5 0 0 0 .708-.708L1.104.396a.5.5 0 1 0-.708.708L4 4.707M14 8c0 .866-.22 1.681-.608 2.392l-.745-.746C12.874 9.144 13 8.586 13 8v-.25a.5.5 0 0 1 1 0z'/%3e%3c/svg%3e")`,
                "mic-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 3.53.297.828a.375.375 0 1 1 .53-.53l10.876 10.874a.375.375 0 0 1-.53.53l-2.49-2.488a3.733 3.733 0 0 1-1.933.536h-.375v1.5H7.5a.375.375 0 0 1 0 .75h-3a.375.375 0 0 1 0-.75h1.125v-1.5H5.25A3.75 3.75 0 0 1 1.5 6v-.187a.375.375 0 1 1 .75 0V6a3 3 0 0 0 3 3h1.5c.499 0 .969-.122 1.383-.337l-.75-.75A3 3 0 0 1 3 5.25V3.53m3.817 3.817A2.25 2.25 0 0 1 3.75 5.25v-.97l3.067 3.067' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m8.735 6.485-.581-.581a2.25 2.25 0 0 0 .096-.654V3a2.25 2.25 0 0 0-4.171-1.171l-.542-.542A3 3 0 0 1 9 3v2.25c0 .44-.095.858-.265 1.235M9.485 7.235l.559.559c.29-.533.456-1.144.456-1.794v-.187a.375.375 0 0 0-.75 0V6c0 .44-.095.858-.265 1.235'/%3e%3c/svg%3e")`,
                "mic-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 4.707.396 1.104a.5.5 0 1 1 .708-.708l14.5 14.5a.5.5 0 0 1-.708.708l-3.318-3.319A4.977 4.977 0 0 1 9 13h-.5v2H10a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1h1.5v-2H7a5 5 0 0 1-5-5v-.25a.5.5 0 0 1 1 0V8a4 4 0 0 0 4 4h2c.665 0 1.292-.162 1.844-.45l-1-1A4 4 0 0 1 4 7V4.707m5.09 5.09A3 3 0 0 1 5 7V5.706l4.09 4.09' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m11.647 8.646-.776-.775A3 3 0 0 0 11 7V4a3 3 0 0 0-5.562-1.562l-.722-.722A4 4 0 0 1 12 4v3c0 .587-.126 1.144-.354 1.646M12.647 9.646l.745.746C13.78 9.682 14 8.866 14 8v-.25a.5.5 0 0 0-1 0V8c0 .587-.126 1.144-.354 1.646'/%3e%3c/svg%3e")`,
                "mic-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 0a3 3 0 0 0-3 3v2.25a3 3 0 0 0 6 0V3a3 3 0 0 0-3-3'/%3e%3cpath fill='%230E1011' d='M2.25 5.813a.375.375 0 1 0-.75 0V6a3.75 3.75 0 0 0 3.75 3.75h.375v1.5H4.5a.375.375 0 0 0 0 .75h3a.375.375 0 0 0 0-.75H6.375v-1.5h.375A3.75 3.75 0 0 0 10.5 6v-.187a.375.375 0 0 0-.75 0V6a3 3 0 0 1-3 3h-1.5a3 3 0 0 1-3-3v-.187'/%3e%3c/svg%3e")`,
                "mic-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 0a4 4 0 0 0-4 4v3a4 4 0 1 0 8 0V4a4 4 0 0 0-4-4'/%3e%3cpath fill='%230E1011' d='M3 7.75a.5.5 0 0 0-1 0V8a5 5 0 0 0 5 5h.5v2H6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H8.5v-2H9a5 5 0 0 0 5-5v-.25a.5.5 0 0 0-1 0V8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4z'/%3e%3c/svg%3e")`,
                "mic-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a3 3 0 0 0-3 3v2.25a3 3 0 0 0 6 0V3a3 3 0 0 0-3-3M3.75 3a2.25 2.25 0 0 1 4.5 0v2.25a2.25 2.25 0 0 1-4.5 0z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.25 5.813a.375.375 0 1 0-.75 0V6a3.75 3.75 0 0 0 3.75 3.75h.375v1.5H4.5a.375.375 0 0 0 0 .75h3a.375.375 0 0 0 0-.75H6.375v-1.5h.375A3.75 3.75 0 0 0 10.5 6v-.187a.375.375 0 0 0-.75 0V6a3 3 0 0 1-3 3h-1.5a3 3 0 0 1-3-3v-.187'/%3e%3c/svg%3e")`,
                "mic": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v3a4 4 0 1 0 8 0V4a4 4 0 0 0-4-4M5 4a3 3 0 0 1 6 0v3a3 3 0 0 1-6 0z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3 7.75a.5.5 0 0 0-1 0V8a5 5 0 0 0 5 5h.5v2H6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H8.5v-2H9a5 5 0 0 0 5-5v-.25a.5.5 0 0 0-1 0V8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4z'/%3e%3c/svg%3e")`,
                "message-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.875 2.25C1.254 2.25.75 2.754.75 3.375V9.97l.86-.86c.07-.07.166-.11.265-.11h8.25c.621 0 1.125-.504 1.125-1.125v-4.5c0-.621-.504-1.125-1.125-1.125zM0 3.375C0 2.339.84 1.5 1.875 1.5h8.25C11.161 1.5 12 2.34 12 3.375v4.5c0 1.036-.84 1.875-1.875 1.875H2.03L0 11.78z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 3.375c0-.621.504-1.125 1.125-1.125h8.25c.621 0 1.125.504 1.125 1.125v4.5c0 .621-.504 1.125-1.125 1.125h-8.25c-.1 0-.195.04-.265.11l-.86.86z'/%3e%3c/svg%3e")`,
                "message-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 3A1.5 1.5 0 0 0 1 4.5v8.793l1.146-1.147A.5.5 0 0 1 2.5 12h11a1.5 1.5 0 0 0 1.5-1.5v-6A1.5 1.5 0 0 0 13.5 3zM0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v6a2.5 2.5 0 0 1-2.5 2.5H2.707L0 15.707z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 4.5A1.5 1.5 0 0 1 2.5 3h11A1.5 1.5 0 0 1 15 4.5v6a1.5 1.5 0 0 1-1.5 1.5h-11a.5.5 0 0 0-.354.146L1 13.293z'/%3e%3c/svg%3e")`,
                "message-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.875 2.25C1.254 2.25.75 2.754.75 3.375V9.97l.86-.86c.07-.07.166-.11.265-.11h8.25c.621 0 1.125-.504 1.125-1.125v-4.5c0-.621-.504-1.125-1.125-1.125zM0 3.375C0 2.339.84 1.5 1.875 1.5h8.25C11.161 1.5 12 2.34 12 3.375v4.5c0 1.036-.84 1.875-1.875 1.875H2.03L0 11.78z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "message-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 3A1.5 1.5 0 0 0 1 4.5v8.793l1.146-1.147A.5.5 0 0 1 2.5 12h11a1.5 1.5 0 0 0 1.5-1.5v-6A1.5 1.5 0 0 0 13.5 3zM0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v6a2.5 2.5 0 0 1-2.5 2.5H2.707L0 15.707z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "message-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.875A4.125 4.125 0 0 1 4.125.75h3.75A4.125 4.125 0 0 1 12 4.875v.75A4.125 4.125 0 0 1 7.875 9.75h-3.75c-.189 0-.375-.013-.557-.037L1.5 11.78V8.807A4.117 4.117 0 0 1 0 5.625zM4.125 1.5A3.375 3.375 0 0 0 .75 4.875v.75a3.37 3.37 0 0 0 1.35 2.7l.15.113V9.97l1.062-1.062.194.035c.2.038.407.057.619.057h3.75a3.375 3.375 0 0 0 3.375-3.375v-.75A3.375 3.375 0 0 0 7.875 1.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 4.875A3.375 3.375 0 0 1 4.125 1.5h3.75a3.375 3.375 0 0 1 3.375 3.375v.75A3.375 3.375 0 0 1 7.875 9h-3.75c-.212 0-.419-.02-.619-.057l-.194-.035L2.25 9.97V8.438l-.15-.113a3.37 3.37 0 0 1-1.35-2.7z'/%3e%3c/svg%3e")`,
                "message-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.5A5.5 5.5 0 0 1 5.5 1h5A5.5 5.5 0 0 1 16 6.5v1a5.5 5.5 0 0 1-5.5 5.5h-5c-.252 0-.5-.017-.743-.05L2 15.707v-3.964A5.49 5.49 0 0 1 0 7.5zM5.5 2A4.5 4.5 0 0 0 1 6.5v1c0 1.472.706 2.779 1.8 3.6l.2.15v2.043l1.416-1.416.259.048c.267.05.543.075.825.075h5A4.5 4.5 0 0 0 15 7.5v-1A4.5 4.5 0 0 0 10.5 2z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 6.5A4.5 4.5 0 0 1 5.5 2h5A4.5 4.5 0 0 1 15 6.5v1a4.5 4.5 0 0 1-4.5 4.5h-5c-.282 0-.558-.026-.825-.075l-.259-.048L3 13.293V11.25l-.2-.15A4.493 4.493 0 0 1 1 7.5z'/%3e%3c/svg%3e")`,
                "message-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.469 1.125h3.062c.435 0 .686 0 .903.024a3.875 3.875 0 0 1 3.417 3.417c.024.217.024.468.024.903v.062c0 .435 0 .686-.024.903A3.875 3.875 0 0 1 8.434 9.85c-.217.024-.468.024-.903.024H4.469c-.435 0-.686 0-.903-.024a3.881 3.881 0 0 1-.732-.155l-1.709 1.71V8.597a3.868 3.868 0 0 1-.976-2.164C.125 6.217.125 5.966.125 5.53v-.062c0-.435 0-.686.024-.903A3.875 3.875 0 0 1 3.566 1.15c.217-.024.468-.024.903-.024m.031.75c-.475 0-.68 0-.85.02A3.125 3.125 0 0 0 .895 4.65c-.02.17-.02.375-.02.85s0 .68.02.85c.08.713.398 1.352.873 1.837l.107.11v1.298l.768-.769.228.088c.246.096.507.16.78.191.168.02.374.02.849.02h3c.475 0 .68 0 .85-.02a3.125 3.125 0 0 0 2.755-2.755c.02-.17.02-.375.02-.85s0-.68-.02-.85A3.125 3.125 0 0 0 8.35 1.895c-.17-.02-.375-.02-.85-.02z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "message-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.5A5.5 5.5 0 0 1 5.5 1h5A5.5 5.5 0 0 1 16 6.5v1a5.5 5.5 0 0 1-5.5 5.5h-5c-.252 0-.5-.017-.743-.05L2 15.707v-3.964A5.49 5.49 0 0 1 0 7.5zM5.5 2A4.5 4.5 0 0 0 1 6.5v1c0 1.472.706 2.779 1.8 3.6l.2.15v2.043l1.416-1.416.259.048c.267.05.543.075.825.075h5A4.5 4.5 0 0 0 15 7.5v-1A4.5 4.5 0 0 0 10.5 2z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "menu-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.125 3.5c0-.207.168-.375.375-.375h11a.375.375 0 0 1 0 .75H.5A.375.375 0 0 1 .125 3.5m0 3c0-.207.168-.375.375-.375h11a.375.375 0 0 1 0 .75H.5A.375.375 0 0 1 .125 6.5m0 3c0-.207.168-.375.375-.375h7a.375.375 0 1 1 0 .75h-7A.375.375 0 0 1 .125 9.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "menu": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.5 3.5A.5.5 0 0 1 1 3h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 1 6h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 1 9h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 1 12h9a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "meh-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M3.75 4.5a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0m3 0a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0m-3 3.375c0-.207.168-.375.375-.375h3.75a.375.375 0 1 1 0 .75h-3.75a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "meh-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M5 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0m4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0m-4 4.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "meh-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.75 4.5a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0M6.75 4.5a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0M4.125 7.5a.375.375 0 1 0 0 .75h3.75a.375.375 0 1 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.188 6a5.812 5.812 0 1 1 11.624 0A5.812 5.812 0 0 1 .188 6M6 .938a5.063 5.063 0 1 0 0 10.125A5.063 5.063 0 0 0 6 .938' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "meh": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0M9 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0M5 10.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "maximize-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.25 1.375c0-.207.168-.375.375-.375H11v3.375a.375.375 0 0 1-.75 0V2.28L7.14 5.39a.375.375 0 0 1-.53-.53l3.11-3.11H7.625a.375.375 0 0 1-.375-.375M5.39 6.61a.375.375 0 0 1 0 .53l-3.11 3.11h2.095a.375.375 0 0 1 0 .75H1V7.625a.375.375 0 1 1 .75 0V9.72l3.11-3.11a.375.375 0 0 1 .53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "maximize-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 1.5a.5.5 0 0 1 .5-.5H15v4.5a.5.5 0 0 1-1 0V2.707L9.854 6.854a.5.5 0 1 1-.708-.708L13.293 2H10.5a.5.5 0 0 1-.5-.5M6.854 9.146a.5.5 0 0 1 0 .708L2.707 14H5.5a.5.5 0 0 1 0 1H1v-4.5a.5.5 0 0 1 1 0v2.793l4.146-4.147a.5.5 0 0 1 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "maximize-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.875 2.75c0-.483.392-.875.875-.875H4a.375.375 0 1 0 0-.75H2.75c-.897 0-1.625.728-1.625 1.625V4a.375.375 0 1 0 .75 0zM1.875 9.25c0 .483.392.875.875.875H4a.375.375 0 0 1 0 .75H2.75A1.625 1.625 0 0 1 1.125 9.25V8a.375.375 0 1 1 .75 0zM10.125 2.75a.875.875 0 0 0-.875-.875H8a.375.375 0 1 1 0-.75h1.25c.898 0 1.625.728 1.625 1.625V4a.375.375 0 0 1-.75 0zM9.25 10.125a.875.875 0 0 0 .875-.875V8a.375.375 0 0 1 .75 0v1.25c0 .898-.727 1.625-1.625 1.625H8a.375.375 0 0 1 0-.75z'/%3e%3c/svg%3e")`,
                "maximize": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3H1v-3A1.5 1.5 0 0 1 2.5 1h3v1zm11 0h-3V1h3A1.5 1.5 0 0 1 15 2.5v3h-1v-3a.5.5 0 0 0-.5-.5M2 10.5v3a.5.5 0 0 0 .5.5h3v1h-3A1.5 1.5 0 0 1 1 13.5v-3zm12 3v-3h1v3a1.5 1.5 0 0 1-1.5 1.5h-3v-1h3a.5.5 0 0 0 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-pin-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.5 12S10 8.5 10 4.5a4.5 4.5 0 0 0-9 0c0 4 4.5 7.5 4.5 7.5m0-6a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-pin-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 6c0 5 6 10 6 10s6-5 6-10A6 6 0 1 0 2 6m6 2a2 2 0 1 0 0-4 2 2 0 0 0 0 4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-pin-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.5 6a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 4.5c0 4-4.5 7.5-4.5 7.5S1 8.5 1 4.5a4.5 4.5 0 0 1 9 0m-.75 0c0 1.736-.989 3.441-2.08 4.775a15.813 15.813 0 0 1-1.67 1.742l-.194-.177c-.403-.373-.94-.91-1.476-1.565C2.74 7.941 1.75 6.236 1.75 4.5a3.75 3.75 0 1 1 7.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-pin": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 16S2 11 2 6a6 6 0 1 1 12 0c0 5-6 10-6 10m-.24-1.576c.085.082.165.16.24.23.075-.07.155-.148.24-.23a23.929 23.929 0 0 0 1.98-2.174C11.69 10.412 13 8.142 13 6A5 5 0 1 0 3 6c0 2.142 1.31 4.412 2.78 6.25a23.935 23.935 0 0 0 1.98 2.174M11 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 1.125a.375.375 0 0 0-.514-.348L7.875 2.22 4.265.777a.375.375 0 0 0-.28 0l-3.75 1.5A.375.375 0 0 0 0 2.625V11a.375.375 0 0 0 .524.344l3.601-1.56 3.6 1.56a.375.375 0 0 0 .3 0l3.75-1.625A.375.375 0 0 0 12 9.375zm-7.875.469c.155 0 .281.126.281.281v6.75a.281.281 0 0 1-.562 0v-6.75c0-.155.126-.281.281-.281m3.75 1.5c.155 0 .281.126.281.281v6.75a.281.281 0 1 1-.562 0v-6.75c0-.155.126-.281.281-.281' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 1.5a.5.5 0 0 0-.686-.464L10.5 2.96 5.686 1.036a.5.5 0 0 0-.372 0l-5 2A.5.5 0 0 0 0 3.5v11.167a.5.5 0 0 0 .699.459L5.5 13.045l4.801 2.08a.5.5 0 0 0 .398 0l5-2.166A.5.5 0 0 0 16 12.5zm-10.5.625c.207 0 .375.168.375.375v9a.375.375 0 0 1-.75 0v-9c0-.207.168-.375.375-.375m5 2c.207 0 .375.168.375.375v9a.375.375 0 0 1-.75 0v-9c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.835.814c.103.07.165.187.165.311v8.25c0 .15-.089.285-.226.344l-3.75 1.625a.375.375 0 0 1-.298 0l-3.601-1.56-3.6 1.56A.375.375 0 0 1 0 11V2.625c0-.153.093-.291.236-.348l3.75-1.5a.375.375 0 0 1 .278 0L7.875 2.22l3.61-1.444a.375.375 0 0 1 .35.037M.75 2.88v7.55l3.094-1.34V1.64L.75 2.88m6.844 7.59L4.406 9.09V1.64l3.188 1.275v7.553m.562 0 3.094-1.34v-7.45L8.156 2.916v7.553' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "map": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.78 1.086A.5.5 0 0 1 16 1.5v11a.5.5 0 0 1-.301.459l-5 2.167a.5.5 0 0 1-.398 0L5.5 13.045l-4.801 2.08A.5.5 0 0 1 0 14.668V3.5a.5.5 0 0 1 .314-.464l5-2a.5.5 0 0 1 .372 0L10.5 2.96l4.814-1.925a.5.5 0 0 1 .466.05M1 3.839v10.066l4.125-1.787v-9.93L1 3.839m9.125 10.12-4.25-1.841v-9.93l4.25 1.7V13.96Zm.75 0L15 12.172V2.239l-4.125 1.65v10.07' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "maintenance-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m11.889 2.56-.575.576a1 1 0 0 1-.708.293H9.572a1 1 0 0 1-1-1V1.394a1 1 0 0 1 .292-.707L9.44.11a3.434 3.434 0 0 0-4.276 2.932l2.17 2.17a2.825 2.825 0 0 1 2.456.607l.6.515A3.426 3.426 0 0 0 11.89 2.56'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.444 9.413 3.868 5.99l1.344 1.345a2.825 2.825 0 0 0 .077 1.52l-2.702 2.702A1.515 1.515 0 1 1 .444 9.413m1.345.09.857-.857a.5.5 0 1 1 .708.708l-.858.857a.5.5 0 1 1-.707-.707' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3 1.286V2.47l3.84 3.84a1.87 1.87 0 0 1 2.26.153l2.217 1.94A2 2 0 0 1 12 9.907V10a2 2 0 0 1-2 2h-.092a2 2 0 0 1-1.506-.683L6.462 9.1a1.87 1.87 0 0 1-.153-2.26L2.469 3H1.287L0 .857.857 0 3 1.286'/%3e%3c/svg%3e")`,
                "maintenance-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m14.87 3.986-.72.721a1 1 0 0 1-.707.293H12a1 1 0 0 1-1-1V2.557a1 1 0 0 1 .293-.707l.72-.72A4 4 0 0 0 7.002 4.88l2.22 2.22C9.47 7.035 9.732 7 10 7h.39a3 3 0 0 1 1.953.722l.78.669a3.997 3.997 0 0 0 1.749-4.405'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m1.518 11.982 4.171-4.171 1.412 1.411a3.004 3.004 0 0 0-.102.778v.39a3 3 0 0 0 .156.955l-3.137 3.137a1.767 1.767 0 1 1-2.5-2.5m1.628.164 1-1a.5.5 0 0 1 .708.708l-1 1a.5.5 0 0 1-.708-.708' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 3.793V2.5L2 1 1 2l1.5 2.5h1.293l4.484 4.484A1.99 1.99 0 0 0 8 10v.248a2 2 0 0 0 .495 1.318l2.407 2.751a2 2 0 0 0 1.506.683H13a2 2 0 0 0 2-2v-.592a2 2 0 0 0-.683-1.506l-2.751-2.407A2 2 0 0 0 10.248 8H10c-.37 0-.718.101-1.016.277L4.5 3.793m6.288 6.42 1.707 1.706a.7.7 0 0 1 .205.495v.086a.3.3 0 1 0 .6 0v-.086a1.3 1.3 0 0 0-.38-.919l-1.708-1.707a.3.3 0 1 0-.424.424' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "maintenance-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.973 1.275v1.168l3.79 3.79a2.05 2.05 0 0 1 2.495.134l1.928 1.653a2.246 2.246 0 1 1-3.167 3.167l-1.653-1.93a2.05 2.05 0 0 1-.134-2.494l-3.789-3.79H1.274L0 .85.85 0l2.123 1.275Zm3.9 6.648a1.05 1.05 0 0 1 1.734-.797l1.928 1.653a1.246 1.246 0 1 1-1.757 1.757L7.125 8.607a1.05 1.05 0 0 1-.253-.684' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8.717.759a1 1 0 0 0-.22.626V2.4a1 1 0 0 0 1 1h1.013a1 1 0 0 0 .707-.293l.569-.568A3.405 3.405 0 0 1 10.3 6.28l-.596-.51-.01-.008a2.654 2.654 0 0 0 1.368-1.703 1.75 1.75 0 0 1-.553.09H9.497a1.75 1.75 0 0 1-1.75-1.75V1.385c0-.19.03-.375.09-.552A2.65 2.65 0 0 0 5.87 3.75L5.121 3A3.4 3.4 0 0 1 9.358.11L8.79.678a1 1 0 0 0-.073.081M5.098 7.889c0 .304.05.604.145.888l-2.679 2.679A1.502 1.502 0 0 1 .44 9.332l3.385-3.385.53.53L.97 9.862a.752.752 0 0 0 1.064 1.063l3.064-3.064v.028'/%3e%3c/svg%3e")`,
                "maintenance": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.166 2.005a1 1 0 0 0-.166.552V4a1 1 0 0 0 1 1h1.443a1 1 0 0 0 .707-.293l.72-.72a4.008 4.008 0 0 1-1.747 4.404l-.781-.67-.029-.023a3.01 3.01 0 0 0 1.53-1.739 2 2 0 0 1-.4.041H12a2 2 0 0 1-2-2V2.557a2 2 0 0 1 .04-.4 3.001 3.001 0 0 0-1.881 3.81l.036.107L7.002 4.88a4 4 0 0 1 5.011-3.75l-.72.72a.997.997 0 0 0-.127.155M7 10.39a3 3 0 0 0 .155.955l-3.137 3.137a1.767 1.767 0 1 1-2.5-2.5l4.171-4.171.708.707-4.172 4.171a.768.768 0 0 0 1.086 1.086L7 10.086v.304M10.788 9.788a.3.3 0 0 0 0 .424l1.707 1.707a.7.7 0 0 1 .205.495v.086a.3.3 0 1 0 .6 0v-.086a1.3 1.3 0 0 0-.38-.919l-1.708-1.707a.3.3 0 0 0-.424 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 3.793V2.5L2 1 1 2l1.5 2.5h1.293l4.573 4.573a2.325 2.325 0 0 0 .194 2.765l1.962 2.289A2.5 2.5 0 0 0 12.42 15h.08a2.5 2.5 0 0 0 2.5-2.5v-.08a2.5 2.5 0 0 0-.873-1.898L11.838 8.56a2.325 2.325 0 0 0-2.765-.194L4.5 3.793M10.325 9a1.325 1.325 0 0 0-1.006 2.187l1.962 2.29A1.5 1.5 0 0 0 12.42 14h.08a1.5 1.5 0 0 0 1.5-1.5v-.08a1.5 1.5 0 0 0-.524-1.139l-2.289-1.962A1.325 1.325 0 0 0 10.325 9' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-open-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.441.11a.938.938 0 0 0-.882 0L.993 2.546A1.875 1.875 0 0 0 0 4.2v4.925C0 10.161.84 11 1.875 11h8.25C11.161 11 12 10.16 12 9.125V4.2c0-.692-.382-1.329-.993-1.654L6.441.11Zm-.53.662a.187.187 0 0 1 .177 0l4.566 2.435c.367.196.596.578.596.993v4.925c0 .621-.504 1.125-1.125 1.125h-8.25A1.125 1.125 0 0 1 .75 9.125V4.2c0-.415.229-.797.596-.993L5.912.772Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.088.772a.187.187 0 0 0-.176 0L1.346 3.207A1.125 1.125 0 0 0 .75 4.2v4.925c0 .621.504 1.125 1.125 1.125h8.25c.621 0 1.125-.504 1.125-1.125V4.2c0-.415-.229-.797-.596-.993L6.088.772M2.076 4.11a.375.375 0 0 0-.402.632l4.329 2.755 4.212-2.757a.375.375 0 1 0-.41-.628L5.996 6.604l-3.92-2.495Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-open-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.588.747a1.25 1.25 0 0 0-1.176 0L1.324 3.994A2.5 2.5 0 0 0 0 6.2v6.3A2.5 2.5 0 0 0 2.5 15h11a2.5 2.5 0 0 0 2.5-2.5V6.2a2.5 2.5 0 0 0-1.323-2.206L8.588.747Zm-5.82 5.831a.5.5 0 1 0-.536.844l5.772 3.673 5.616-3.677a.5.5 0 1 0-.548-.836L7.996 9.905 2.768 6.578' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-open-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.076 4.109a.375.375 0 0 0-.402.632l4.329 2.755 4.212-2.757a.375.375 0 1 0-.41-.628L5.996 6.604l-3.92-2.495'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.441.11a.938.938 0 0 0-.882 0L.993 2.546A1.875 1.875 0 0 0 0 4.2v4.925C0 10.161.84 11 1.875 11h8.25C11.161 11 12 10.16 12 9.125V4.2c0-.692-.382-1.329-.993-1.654L6.441.11Zm-.53.662a.187.187 0 0 1 .177 0l4.566 2.435c.367.196.596.578.596.993v4.925c0 .621-.504 1.125-1.125 1.125h-8.25A1.125 1.125 0 0 1 .75 9.125V4.2c0-.415.229-.797.596-.993L5.912.772Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-open": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.768 6.578a.5.5 0 1 0-.536.844l5.772 3.673 5.616-3.677a.5.5 0 1 0-.548-.836L7.996 9.905 2.768 6.578'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.588.747a1.25 1.25 0 0 0-1.176 0L1.324 3.994A2.5 2.5 0 0 0 0 6.2v6.3A2.5 2.5 0 0 0 2.5 15h11a2.5 2.5 0 0 0 2.5-2.5V6.2a2.5 2.5 0 0 0-1.323-2.206L8.588.747Zm-.706.882a.25.25 0 0 1 .236 0l6.088 3.247c.489.261.794.77.794 1.324v6.3a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 12.5V6.2a1.5 1.5 0 0 1 .794-1.324L7.882 1.63Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.875 1C.839 1 0 1.84 0 2.875v6.25C0 10.161.84 11 1.875 11h8.25C11.161 11 12 10.16 12 9.125v-6.25C12 1.839 11.16 1 10.125 1zm.201 2.809a.375.375 0 0 0-.402.632l4.329 2.755 4.212-2.757a.375.375 0 1 0-.41-.628L5.996 6.304l-3.92-2.495' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2zm-.422 3.232a.5.5 0 0 1 .69-.154l5.228 3.327 5.076-3.323a.5.5 0 0 1 .548.836L8.004 9.595 2.232 5.922a.5.5 0 0 1-.154-.69' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.076 3.809a.375.375 0 1 0-.402.632l4.329 2.755 4.212-2.757a.375.375 0 1 0-.41-.628L5.996 6.304l-3.92-2.495'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.875 1.25C.839 1.25 0 2.09 0 3.125v5.75c0 1.036.84 1.875 1.875 1.875h8.25c1.036 0 1.875-.84 1.875-1.875v-5.75c0-1.036-.84-1.875-1.875-1.875zM.75 3.125C.75 2.504 1.254 2 1.875 2h8.25c.621 0 1.125.504 1.125 1.125v5.75c0 .621-.504 1.125-1.125 1.125h-8.25A1.125 1.125 0 0 1 .75 8.875v-5.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "mail": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.078 5.232a.5.5 0 0 1 .69-.154l5.228 3.327 5.076-3.323a.5.5 0 0 1 .548.836L8.004 9.595 2.232 5.922a.5.5 0 0 1-.154-.69'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 0 11.5zM2.5 3h11A1.5 1.5 0 0 1 15 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 11.5v-7A1.5 1.5 0 0 1 2.5 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "log-out-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.75 9.5c0 .414.336.75.75.75h1.875a.375.375 0 0 1 0 .75H2.5A1.5 1.5 0 0 1 1 9.5v-7A1.5 1.5 0 0 1 2.5 1h1.875a.375.375 0 1 1 0 .75H2.5a.75.75 0 0 0-.75.75zM2.875 6c0-.207.168-.375.375-.375h7.095l-1.61-1.61a.375.375 0 0 1 .53-.53L11.78 6 9.265 8.515a.375.375 0 0 1-.53-.53l1.61-1.61H3.25A.375.375 0 0 1 2.875 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "log-out": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 13a1 1 0 0 0 1 1h2.5a.5.5 0 0 1 0 1H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h2.5a.5.5 0 0 1 0 1H3a1 1 0 0 0-1 1zm1.5-5a.5.5 0 0 1 .5-.5h9.793l-2.147-2.146a.5.5 0 0 1 .708-.708L15.707 8l-3.353 3.354a.5.5 0 0 1-.708-.708L13.793 8.5H4a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "log-in-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.03 9.5a.75.75 0 0 1-.75.75H7.405a.375.375 0 0 0 0 .75H9.28a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 9.28 1H7.405a.375.375 0 1 0 0 .75H9.28a.75.75 0 0 1 .75.75v7M.375 5.985c0-.207.168-.375.375-.375h7.095L6.235 4a.375.375 0 0 1 .53-.53L9.28 5.985 6.765 8.5a.375.375 0 0 1-.53-.53l1.61-1.61H.75a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "log-in": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.5 8a.5.5 0 0 1 .5-.5h9.793L8.646 5.354a.5.5 0 1 1 .708-.708L12.707 8l-3.353 3.354a.5.5 0 0 1-.708-.708L10.793 8.5H1A.5.5 0 0 1 .5 8m9.5 6.5a.5.5 0 0 1 .5-.5H13a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1h-2.5a.5.5 0 0 1 0-1H13a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-2.5a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "lock-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.15 3.5v1.54A1.5 1.5 0 0 0 2 6.5v4A1.5 1.5 0 0 0 3.5 12h6a1.5 1.5 0 0 0 1.5-1.5v-4a1.5 1.5 0 0 0-1.15-1.46V3.5a3.35 3.35 0 0 0-6.7 0M6.5.85A2.65 2.65 0 0 0 3.85 3.5V5h5.3V3.5A2.65 2.65 0 0 0 6.5.85m0 8.65a1 1 0 1 0 0-2 1 1 0 0 0 0 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "lock-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2V4a4 4 0 0 0-4-4m3 6V4a3 3 0 0 0-6 0v2zm-4 4.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "lock-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.5 9.5a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.85 3.5v1.696c.576.154 1 .68 1 1.304v4a1.35 1.35 0 0 1-1.35 1.35h-6a1.35 1.35 0 0 1-1.35-1.35v-4c0-.625.424-1.15 1-1.304V3.5a3.35 3.35 0 0 1 6.7 0m-6 0a2.65 2.65 0 0 1 5.3 0v1.65h-5.3V3.5m-1 3a.65.65 0 0 1 .65-.65h6a.65.65 0 0 1 .65.65v4a.65.65 0 0 1-.65.65h-6a.65.65 0 0 1-.65-.65v-4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "lock": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 10.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2V4a4 4 0 0 0-4-4m3 6V4a3 3 0 0 0-6 0v2zM4 7a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "list-ordered-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1 1.17a.33.33 0 1 0 0 .66h.17v1.34H1a.33.33 0 1 0 0 .66h1a.33.33 0 1 0 0-.66h-.17v-2H1ZM4.5 2.125a.375.375 0 0 0 0 .75h5a.375.375 0 0 0 0-.75h-5M4.5 5.625a.375.375 0 0 0 0 .75h7a.375.375 0 0 0 0-.75h-7M4.5 9.125a.375.375 0 0 0 0 .75h3a.375.375 0 0 0 0-.75h-3M.5 4.67a.33.33 0 1 0 0 .66h1.42v.018L.285 6.75A.33.33 0 0 0 .5 7.33h2a.33.33 0 0 0 0-.66H1.392l1.003-.86a.53.53 0 0 0 .185-.402V5.2a.53.53 0 0 0-.53-.53H.5ZM.17 8.5a.33.33 0 0 1 .33-.33h1.8a.53.53 0 0 1 .53.53v.176a.53.53 0 0 1-.293.474l-.3.15.3.15a.53.53 0 0 1 .293.474v.176a.53.53 0 0 1-.53.53H.5a.33.33 0 1 1 0-.66h1.602l-.75-.375a.33.33 0 0 1 0-.59l.75-.375H.5a.33.33 0 0 1-.33-.33'/%3e%3c/svg%3e")`,
                "list-ordered": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 2.1a.4.4 0 1 0 0 .8h.1v1.2H1a.4.4 0 1 0 0 .8h1a.4.4 0 0 0 0-.8h-.1v-2H1M4.5 3.1a.4.4 0 1 0 0 .8h9a.4.4 0 0 0 0-.8h-9ZM4.5 7.6a.4.4 0 1 0 0 .8h11a.4.4 0 0 0 0-.8h-11ZM4.5 12.1a.4.4 0 0 0 0 .8h6a.4.4 0 0 0 0-.8h-6M.5 6.6a.4.4 0 1 0 0 .8h1.252L.24 8.696A.4.4 0 0 0 .5 9.4h2a.4.4 0 0 0 0-.8h-.919l.86-.736a.6.6 0 0 0 .21-.456V7.2a.6.6 0 0 0-.6-.6H.5ZM.1 11.5c0-.22.18-.4.4-.4h1.8a.6.6 0 0 1 .6.6v.177a.6.6 0 0 1-.332.536l-.173.087.173.087a.6.6 0 0 1 .332.537v.176a.6.6 0 0 1-.6.6H.5a.4.4 0 0 1 0-.8h1.306l-.485-.242a.4.4 0 0 1 0-.716l.485-.242H.5a.4.4 0 0 1-.4-.4Z'/%3e%3c/svg%3e")`,
                "list-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.625c0-.207.168-.375.375-.375h.75a.375.375 0 1 1 0 .75h-.75A.375.375 0 0 1 0 2.625m2.25 0c0-.207.168-.375.375-.375h7.5a.375.375 0 0 1 0 .75h-7.5a.375.375 0 0 1-.375-.375M0 6c0-.207.168-.375.375-.375h.75a.375.375 0 1 1 0 .75h-.75A.375.375 0 0 1 0 6m2.25 0c0-.207.168-.375.375-.375h9a.375.375 0 0 1 0 .75h-9A.375.375 0 0 1 2.25 6M0 9.375C0 9.168.168 9 .375 9h.75a.375.375 0 1 1 0 .75h-.75A.375.375 0 0 1 0 9.375m2.25 0c0-.207.168-.375.375-.375h5.25a.375.375 0 1 1 0 .75h-5.25a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "list": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3.5A.5.5 0 0 1 .5 3h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5m4 0a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5M0 8a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1A.5.5 0 0 1 0 8m4 0a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11A.5.5 0 0 1 4 8m-4 4.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5m4 0a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "linkedin-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.75 2.063a1.313 1.313 0 1 1 2.625 0 1.313 1.313 0 0 1-2.625 0m3.75 5.25a3.187 3.187 0 1 1 6.375 0v3.937H8.25V7.313a.563.563 0 0 0-1.125 0v3.937H4.5V7.313M.75 5.25a.75.75 0 0 1 .75-.75h1.125a.75.75 0 0 1 .75.75v5.25a.75.75 0 0 1-.75.75H1.5a.75.75 0 0 1-.75-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "linkedin-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.75a1.75 1.75 0 1 1 3.5 0 1.75 1.75 0 0 1-3.5 0m5 7a4.25 4.25 0 0 1 8.5 0V15H11V9.75a.75.75 0 0 0-1.5 0V15H6zM1 7a1 1 0 0 1 1-1h1.5a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "linkedin-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.571 1.714c-.434 0-.785.32-.785.715 0 .394.351.714.785.714.434 0 .786-.32.786-.714 0-.395-.352-.715-.786-.715M1 2.43C1 1.639 1.704 1 2.571 1c.868 0 1.572.64 1.572 1.429S3.439 3.857 2.57 3.857C1.704 3.857 1 3.217 1 2.43M4.929 7.07c0-1.775 1.583-3.214 3.535-3.214 1.953 0 3.536 1.44 3.536 3.214V11H8.857V7.071c0-.197-.176-.357-.393-.357-.217 0-.393.16-.393.357V11H4.93V7.071Zm3.535-2.5c-1.519 0-2.75 1.12-2.75 2.5v3.215h1.572V7.07C7.286 6.48 7.813 6 8.464 6c.651 0 1.179.48 1.179 1.071v3.215h1.571V7.07c0-1.38-1.23-2.5-2.75-2.5M1 5.286c0-.395.352-.715.786-.715h1.571c.434 0 .786.32.786.715v5c0 .394-.352.714-.786.714H1.786C1.352 11 1 10.68 1 10.286v-5m.786 0v5h1.571v-5H1.786' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "linkedin": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 2a1 1 0 1 0 0 2 1 1 0 0 0 0-2M1 3a2 2 0 1 1 4 0 2 2 0 0 1-4 0m5 6.5a4.5 4.5 0 0 1 9 0V15h-4V9.5a.5.5 0 0 0-1 0V15H6zM10.5 6A3.5 3.5 0 0 0 7 9.5V14h2V9.5a1.5 1.5 0 1 1 3 0V14h2V9.5A3.5 3.5 0 0 0 10.5 6M1 7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1zm1 0v7h2V7z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "link-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6c0-1.657 1.511-3 3.375-3h.75c.207 0 .375.15.375.333 0 .184-.168.334-.375.334h-.75C1.925 3.667.75 4.71.75 6c0 1.289 1.175 2.333 2.625 2.333h.75c.207 0 .375.15.375.334 0 .184-.168.333-.375.333h-.75C1.511 9 0 7.657 0 6m6.75-2.667c0-.184.168-.333.375-.333h1.5C10.489 3 12 4.343 12 6s-1.511 3-3.375 3h-1.5c-.207 0-.375-.15-.375-.333 0-.184.168-.334.375-.334h1.5c1.45 0 2.625-1.044 2.625-2.333 0-1.289-1.175-2.333-2.625-2.333h-1.5c-.207 0-.375-.15-.375-.334M3.75 6c0-.184.168-.333.375-.333h3.75c.207 0 .375.149.375.333 0 .184-.168.333-.375.333h-3.75c-.207 0-.375-.149-.375-.333' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "link-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 8a4.5 4.5 0 0 1 4.5-4.5h1a.5.5 0 0 1 0 1h-1a3.5 3.5 0 1 0 0 7h1a.5.5 0 0 1 0 1h-1A4.5 4.5 0 0 1 0 8m9-4a.5.5 0 0 1 .5-.5h2a4.5 4.5 0 1 1 0 9h-2a.5.5 0 0 1 0-1h2a3.5 3.5 0 1 0 0-7h-2A.5.5 0 0 1 9 4M5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "link-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.231 1.488A2.52 2.52 0 0 1 8.014.75h.107c1.728 0 3.129 1.4 3.129 3.129a2.44 2.44 0 0 1-.715 1.725L8.981 7.16a2.625 2.625 0 0 1-3.712 0l-.66-.66a.375.375 0 1 1 .531-.53l.66.66c.731.731 1.919.731 2.65 0l1.555-1.555A1.69 1.69 0 0 0 10.5 3.88 2.379 2.379 0 0 0 8.121 1.5h-.107c-.47 0-.92.187-1.252.519l-.872.871a.375.375 0 1 1-.53-.53l.871-.872m-.03 3.743a1.875 1.875 0 0 0-2.652 0l-1.53 1.53A1.77 1.77 0 0 0 1.5 8.015 2.486 2.486 0 0 0 3.986 10.5c.47 0 .92-.187 1.252-.519l.872-.871a.375.375 0 1 1 .53.53l-.871.872a2.521 2.521 0 0 1-1.783.738A3.236 3.236 0 0 1 .75 8.014c0-.669.266-1.31.738-1.783l1.53-1.53a2.625 2.625 0 0 1 3.713 0l.66.659a.375.375 0 1 1-.531.53l-.66-.659' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "link": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.308 1.984A3.361 3.361 0 0 1 10.685 1h.143A4.172 4.172 0 0 1 15 5.172c0 .863-.343 1.69-.953 2.3l-2.072 2.073a3.5 3.5 0 0 1-4.95 0l-.879-.879a.5.5 0 1 1 .708-.707l.878.879a2.5 2.5 0 0 0 3.536 0l2.072-2.072c.422-.423.66-.996.66-1.594A3.172 3.172 0 0 0 10.828 2h-.143c-.626 0-1.227.249-1.67.692L7.855 3.854a.5.5 0 1 1-.708-.708l1.162-1.162m-.04 4.99a2.5 2.5 0 0 0-3.536 0l-2.04 2.042A2.361 2.361 0 0 0 2 10.686 3.315 3.315 0 0 0 5.315 14c.626 0 1.227-.249 1.67-.692l1.161-1.162a.5.5 0 0 1 .708.708l-1.162 1.162A3.36 3.36 0 0 1 5.315 15 4.315 4.315 0 0 1 1 10.685c0-.891.354-1.746.984-2.377l2.041-2.04a3.5 3.5 0 0 1 4.95 0l.879.878a.5.5 0 0 1-.708.708l-.878-.88Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "life-buoy-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12M4.125 7.875a2.652 2.652 0 1 1 3.75-3.75 2.652 2.652 0 0 1-3.75 3.75m5.89-5.36a.375.375 0 0 0-.53-.53l-1.11 1.11a.375.375 0 0 0 .53.53l1.11-1.11Zm-7.5-.53a.375.375 0 1 0-.53.53l1.11 1.11a.375.375 0 1 0 .53-.53l-1.11-1.11m6.39 6.39a.375.375 0 1 0-.53.53l1.11 1.11a.375.375 0 0 0 .53-.53l-1.11-1.11m-5.28.53a.375.375 0 0 0-.53-.53l-1.11 1.11a.375.375 0 0 0 .53.53l1.11-1.11Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "life-buoy-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-3.62-1.585 2.034-2.112a6.837 6.837 0 0 0-2.011-2.011L9.585 4.326a4.015 4.015 0 0 1 2.089 2.09m-7.348 0L2.292 4.303a6.836 6.836 0 0 1 2.011-2.011l2.112 2.034a4.014 4.014 0 0 0-2.089 2.09m2.09 5.259-2.113 2.034a6.837 6.837 0 0 1-2.011-2.011l2.034-2.112a4.014 4.014 0 0 0 2.09 2.089m7.292.023a6.836 6.836 0 0 1-2.011 2.011l-2.112-2.034a4.014 4.014 0 0 0 2.089-2.089l2.034 2.112M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "life-buoy-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m3.438-2.032A5.23 5.23 0 0 1 6 11.25a5.23 5.23 0 0 1-3.438-1.282l1.866-1.865c.929.696 2.215.696 3.144 0l1.866 1.865m.53-.53A5.23 5.23 0 0 0 11.25 6a5.23 5.23 0 0 0-1.282-3.438L8.103 4.428c.696.929.696 2.215 0 3.144l1.865 1.866m-.53-7.406L7.572 3.897a2.627 2.627 0 0 0-3.144 0L2.562 2.032A5.23 5.23 0 0 1 6 .75a5.23 5.23 0 0 1 3.438 1.282m-7.406.53A5.23 5.23 0 0 0 .75 6a5.23 5.23 0 0 0 1.282 3.438l1.865-1.866a2.627 2.627 0 0 1 0-3.144L2.032 2.562m2.642 2.112a1.875 1.875 0 1 1 2.652 2.652 1.875 1.875 0 0 1-2.652-2.652' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "life-buoy": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-4.369 5.578a6.272 6.272 0 0 1-2.93.722c-1.056 0-2.05-.26-2.924-.719l2.165-2.164a3.513 3.513 0 0 0 1.528 0l2.162 2.16m.66-.401c.62-.431 1.16-.971 1.59-1.592L11.14 9.549c-.34.69-.901 1.25-1.59 1.591l2.036 2.037m1.99-2.252A6.272 6.272 0 0 0 14.296 8c0-1.055-.26-2.05-.719-2.924l-2.16 2.16a3.513 3.513 0 0 1 0 1.53l2.16 2.159m-.4-6.51a6.334 6.334 0 0 0-1.59-1.591L9.55 4.86c.69.34 1.25.901 1.59 1.59l2.037-2.035m-2.249-1.992L8.765 4.584a3.512 3.512 0 0 0-1.53 0L5.07 2.42a6.272 6.272 0 0 1 2.925-.718c1.058 0 2.056.26 2.931.722m-6.516.396c-.621.43-1.16.97-1.592 1.59L4.86 6.453c.34-.69.902-1.25 1.591-1.591L4.41 2.819M2.417 5.07A6.272 6.272 0 0 0 1.695 8c0 1.058.261 2.056.722 2.931l2.167-2.166a3.512 3.512 0 0 1 0-1.529L2.417 5.069m.401 6.522c.432.62.972 1.16 1.592 1.59l2.042-2.041A3.515 3.515 0 0 1 4.86 9.55L2.818 11.59M8 5.501a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "layout-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 1C.756 1 0 1.84 0 2.875v6.25C0 10.161.756 11 1.688 11h8.625C11.244 11 12 10.16 12 9.125v-6.25C12 1.839 11.245 1 10.313 1H1.688M.375 5.063h3.469v5.52h.562v-5.52h7.219v-.625H.375v.625' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "layout-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2zM.5 6.875h4.625V13.5h.75V6.875H15.5v-.75H.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "layout-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.125 1C.504 1 0 1.56 0 2.25v7.5C0 10.44.504 11 1.125 11h9.75C11.496 11 12 10.44 12 9.75v-7.5C12 1.56 11.496 1 10.875 1zM.75 2.25c0-.23.168-.417.375-.417h9.75c.207 0 .375.187.375.417v2.188H.75zm0 2.813V9.75c0 .23.168.417.375.417h2.719V5.063H.75m3.656 5.104h6.469c.207 0 .375-.187.375-.417V5.063H4.406v5.104' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "layout": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 2A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2zM1 3.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v2.625H1zm0 3.375V12.5a.5.5 0 0 0 .5.5h3.625V6.875zM5.875 13H14.5a.5.5 0 0 0 .5-.5V6.875H5.875z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "layers-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.832.665a.375.375 0 0 1 .336 0l5 2.5a.375.375 0 0 1 0 .67l-5 2.5a.375.375 0 0 1-.336 0l-5-2.5a.375.375 0 0 1 0-.67l5-2.5M.664 8.332a.375.375 0 0 1 .504-.167L6 10.58l4.832-2.416a.375.375 0 1 1 .335.67l-5 2.5a.375.375 0 0 1-.335 0l-5-2.5a.375.375 0 0 1-.168-.503'/%3e%3cpath fill='%230E1011' d='M1.168 5.665a.375.375 0 0 0-.336.67l5 2.5c.106.053.23.053.336 0l5-2.5a.375.375 0 1 0-.336-.67L6 8.08 1.168 5.665Z'/%3e%3c/svg%3e")`,
                "layers-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.776.886a.5.5 0 0 1 .447 0L14.89 4.22a.5.5 0 0 1 0 .895L8.223 8.447a.5.5 0 0 1-.447 0L1.11 5.114a.5.5 0 0 1 0-.895L7.776.886ZM.886 11.11a.5.5 0 0 1 .67-.224L8 14.108l6.443-3.222a.5.5 0 0 1 .447.895l-6.667 3.333a.5.5 0 0 1-.447 0L1.11 11.78a.5.5 0 0 1-.224-.671'/%3e%3cpath fill='%230E1011' d='M1.557 7.553a.5.5 0 1 0-.447.894l6.666 3.334a.5.5 0 0 0 .447 0l6.667-3.334a.5.5 0 0 0-.447-.894L8 10.774 1.557 7.553Z'/%3e%3c/svg%3e")`,
                "layers-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.832.665a.375.375 0 0 1 .336 0l5 2.5a.375.375 0 0 1 0 .67l-5 2.5a.375.375 0 0 1-.336 0l-5-2.5a.375.375 0 0 1 0-.67l5-2.5M1.838 3.5 6 5.58 10.16 3.5 6 1.42 1.838 3.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.664 8.332a.375.375 0 0 1 .504-.167L6 10.58l4.832-2.416a.375.375 0 1 1 .335.67l-5 2.5a.375.375 0 0 1-.335 0l-5-2.5a.375.375 0 0 1-.168-.503'/%3e%3cpath fill='%230E1011' d='M1.168 5.665a.375.375 0 0 0-.336.67l5 2.5c.106.053.23.053.336 0l5-2.5a.375.375 0 1 0-.336-.67L6 8.08 1.168 5.665Z'/%3e%3c/svg%3e")`,
                "layers": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.776.886a.5.5 0 0 1 .447 0l6.667 3.333a.5.5 0 0 1 0 .895L8.223 8.447a.5.5 0 0 1-.447 0L1.11 5.114a.5.5 0 0 1 0-.895L7.776.886Zm-5.325 3.78L8 7.442l5.548-2.774L8 1.892 2.45 4.667' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.886 11.11a.5.5 0 0 1 .67-.224L8 14.108l6.443-3.222a.5.5 0 0 1 .447.895l-6.667 3.333a.5.5 0 0 1-.447 0L1.11 11.78a.5.5 0 0 1-.224-.67'/%3e%3cpath fill='%230E1011' d='M1.557 7.553a.5.5 0 1 0-.447.894l6.666 3.334a.5.5 0 0 0 .447 0l6.667-3.334a.5.5 0 0 0-.447-.894L8 10.774 1.557 7.553Z'/%3e%3c/svg%3e")`,
                "key-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.625 3.938a3.563 3.563 0 0 1-5.218 3.155L5.25 8.25V9a.375.375 0 0 1-.375.375h-.75v.75a.375.375 0 0 1-.375.375H3v.75a.375.375 0 0 1-.375.375H.375v-2.25l4.308-4.308a3.563 3.563 0 1 1 6.942-1.13m-3 .187a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "key-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.5 5.25a4.75 4.75 0 0 1-6.957 4.207L7 11v1a.5.5 0 0 1-.5.5h-1v1a.5.5 0 0 1-.5.5H4v1a.5.5 0 0 1-.5.5h-3v-3l5.744-5.744A4.75 4.75 0 1 1 15.5 5.25m-4 .25a1 1 0 1 0 0-2 1 1 0 0 0 0 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "key-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.625 4.125a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.063 0a3.938 3.938 0 0 0-3.804 4.96L0 9.22V12h2.625a.75.75 0 0 0 .75-.75v-.375h.375a.75.75 0 0 0 .75-.75V9.75h.375a.75.75 0 0 0 .75-.75v-.595l.86-.86A3.938 3.938 0 1 0 8.062 0M4.874 3.938A3.187 3.187 0 1 1 6.582 6.76l-.245-.129-1.462 1.463V9H3.75v1.125H2.625v1.125H.75V9.53l4.362-4.362-.073-.22a3.184 3.184 0 0 1-.164-1.01' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "key": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 5.5a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.75 0a5.25 5.25 0 0 0-5.071 6.614L0 12.293V16h3.5a1 1 0 0 0 1-1v-.5H5a1 1 0 0 0 1-1V13h.5a1 1 0 0 0 1-1v-.793l1.146-1.146A5.25 5.25 0 1 0 10.75 0M6.5 5.25a4.25 4.25 0 1 1 2.276 3.765l-.326-.172-1.95 1.95V12H5v1.5H3.5V15H1v-2.293l5.816-5.816-.098-.293A4.245 4.245 0 0 1 6.5 5.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "italic-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.509 1.5h1.678a.375.375 0 1 1 0 .75H7.764l-2.728 7.5h1.527a.375.375 0 0 1 0 .75H2.814a.375.375 0 0 1 0-.75h1.424l2.728-7.5H5.438a.375.375 0 1 1 0-.75H7.509'/%3e%3c/svg%3e")`,
                "italic": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M10.012 2h2.238a.5.5 0 0 1 0 1h-1.9L6.714 13H8.75a.5.5 0 0 1 0 1H6.012a.45.45 0 0 1-.024 0H3.75a.5.5 0 1 1 0-1h1.9L9.286 3H7.25a.5.5 0 1 1 0-1h2.762'/%3e%3c/svg%3e")`,
                "instagram-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v5A2.5 2.5 0 0 0 3.5 11h5A2.5 2.5 0 0 0 11 8.5v-5A2.5 2.5 0 0 0 8.5 1zm5.714 2.321a.536.536 0 1 1-1.071 0 .536.536 0 0 1 1.071 0M8.143 6a2.143 2.143 0 1 1-4.286 0 2.143 2.143 0 0 1 4.286 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "instagram-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1A3.5 3.5 0 0 0 1 4.5v7A3.5 3.5 0 0 0 4.5 15h7a3.5 3.5 0 0 0 3.5-3.5v-7A3.5 3.5 0 0 0 11.5 1zm8 3.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "instagram-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 8.143a2.143 2.143 0 1 0 0-4.286 2.143 2.143 0 0 0 0 4.286m0-.536a1.607 1.607 0 1 0 0-3.214 1.607 1.607 0 0 0 0 3.214' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8.679 3.857a.536.536 0 1 0 0-1.071.536.536 0 0 0 0 1.071'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v5A2.5 2.5 0 0 0 3.5 11h5A2.5 2.5 0 0 0 11 8.5v-5A2.5 2.5 0 0 0 8.5 1zm5 .714h-5c-.986 0-1.786.8-1.786 1.786v5c0 .986.8 1.786 1.786 1.786h5c.986 0 1.786-.8 1.786-1.786v-5c0-.986-.8-1.786-1.786-1.786' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "instagram": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6m0-.75a2.25 2.25 0 1 0 0-4.5 2.25 2.25 0 0 0 0 4.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M11.75 5a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1A3.5 3.5 0 0 0 1 4.5v7A3.5 3.5 0 0 0 4.5 15h7a3.5 3.5 0 0 0 3.5-3.5v-7A3.5 3.5 0 0 0 11.5 1zm7 1h-7A2.5 2.5 0 0 0 2 4.5v7A2.5 2.5 0 0 0 4.5 14h7a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 11.5 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "info-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M6.656 8.25a.656.656 0 1 1-1.312 0V6a.656.656 0 1 1 1.312 0v2.25m0-4.125a.656.656 0 1 1-1.312 0V3.75a.656.656 0 0 1 1.312 0v.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "info-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M8 6.5a.5.5 0 0 0 .5-.5v-.5a.5.5 0 0 0-1 0V6a.5.5 0 0 0 .5.5m0 5a.5.5 0 0 0 .5-.5V8a.5.5 0 0 0-1 0v3a.5.5 0 0 0 .5.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "info-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.75a.5.5 0 0 1 .5.5v.25a.5.5 0 0 1-1 0v-.25a.5.5 0 0 1 .5-.5M6 5.5a.5.5 0 0 1 .5.5v2.241a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "info": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 6.5a.5.5 0 0 0 .5-.5v-.5a.5.5 0 0 0-1 0V6a.5.5 0 0 0 .5.5M8 11.5a.5.5 0 0 0 .5-.5V8a.5.5 0 0 0-1 0v3a.5.5 0 0 0 .5.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "inbox-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.613c0-.194.04-.385.119-.559l1.86-4.133C2.233 1.357 2.752 1 3.32 1h5.36c.568 0 1.087.357 1.341.921l1.86 4.133c.078.174.119.365.119.56v2.511C12 10.161 11.245 11 10.313 11H1.688C.756 11 0 10.16 0 9.125V6.613m2.65-4.319c.127-.282.386-.46.67-.46h5.36c.284 0 .543.178.67.46l1.762 3.914H7.5v.625C7.5 7.753 6.828 8.5 6 8.5s-1.5-.746-1.5-1.667v-.625H.888l1.761-3.914' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "inbox-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 8.736a1.5 1.5 0 0 1 .158-.67l2.48-4.96A2 2 0 0 1 4.428 2h7.145a2 2 0 0 1 1.789 1.106l2.48 4.96a1.5 1.5 0 0 1 .158.67v3.014A2.25 2.25 0 0 1 13.75 14H2.25A2.25 2.25 0 0 1 0 11.75V8.736m3.533-5.183A1 1 0 0 1 4.427 3h7.146a1 1 0 0 1 .894.553l2.349 4.697H10V9a2 2 0 1 1-4 0v-.75H1.184l2.349-4.697' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "inbox-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.32 1c-.568 0-1.087.357-1.341.921L.119 6.054a1.365 1.365 0 0 0-.119.56v2.303C0 10.067.84 11 1.875 11h8.25C11.161 11 12 10.067 12 8.917V6.613c0-.194-.04-.385-.119-.559l-1.86-4.133C9.767 1.357 9.248 1 8.68 1H3.32m-.67 1.294c.127-.282.386-.46.67-.46h5.36c.284 0 .543.178.67.46l1.809 4.018H7.594v.521c0 .978-.714 1.771-1.594 1.771-.88 0-1.594-.793-1.594-1.77v-.521H.841L2.65 2.294M.75 6.937v1.98c0 .69.504 1.25 1.125 1.25h8.25c.621 0 1.125-.56 1.125-1.25v-1.98H8.154C8.105 8.213 7.16 9.23 6 9.23c-1.16 0-2.105-1.017-2.154-2.291H.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "inbox": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.427 2a2 2 0 0 0-1.789 1.106l-2.48 4.96a1.5 1.5 0 0 0-.158.67V11.5A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5V8.736a1.5 1.5 0 0 0-.158-.67l-2.48-4.96A2 2 0 0 0 11.572 2H4.428m-.894 1.553A1 1 0 0 1 4.427 3h7.146a1 1 0 0 1 .894.553l2.412 4.822h-4.754V9a2.125 2.125 0 0 1-4.25 0v-.625H1.122l2.41-4.822M1 9.125V11.5A1.5 1.5 0 0 0 2.5 13h11a1.5 1.5 0 0 0 1.5-1.5V9.125h-4.128a2.875 2.875 0 0 1-5.744 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.75 1A1.75 1.75 0 0 0 0 2.75v6.5C0 10.216.784 11 1.75 11h8.5A1.75 1.75 0 0 0 12 9.25v-6.5A1.75 1.75 0 0 0 10.25 1zM4 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0m4.017-.013 3.248 3.248a.375.375 0 0 1-.53.53L7.983 5.013l-4 3.5L2.5 7.03 1.265 8.265a.375.375 0 0 1-.53-.53L2.5 5.97l1.517 1.517 4-3.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.5 6.25a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h5.756a4.5 4.5 0 0 1 4.214-6L10.5 6.03l-5 5-2-2-2.235 2.235a.375.375 0 0 1-.53-.53L3.5 7.97l2 2 5-5 3.19 3.189c.921.252 1.725.79 2.31 1.512V4.5A2.5 2.5 0 0 0 13.5 2zm1 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0m-3.5-2a.5.5 0 0 1 .5.5v1h1a.5.5 0 0 1 0 1h-1v1a.5.5 0 0 1-1 0v-1h-1a.5.5 0 0 1 0-1h1v-1a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.75 1A1.75 1.75 0 0 0 0 2.75v6.5C0 10.216.784 11 1.75 11h8.5A1.75 1.75 0 0 0 12 9.25v-6.5A1.75 1.75 0 0 0 10.25 1zM4 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0m4.017-.013 3.248 3.248a.375.375 0 0 1-.53.53L7.983 5.013l-4 3.5L2.5 7.03 1.265 8.265a.375.375 0 0 1-.53-.53L2.5 5.97l1.517 1.517 4-3.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.5 6.25a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h5.756a4.5 4.5 0 0 1 4.214-6L10.5 6.03l-5 5-2-2-2.235 2.235a.375.375 0 0 1-.53-.53L3.5 7.97l2 2 5-5 3.19 3.189c.921.252 1.725.79 2.31 1.512V4.5A2.5 2.5 0 0 0 13.5 2zm1 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0m-3.5-2a.5.5 0 0 1 .5.5v1h1a.5.5 0 0 1 0 1h-1v1a.5.5 0 0 1-1 0v-1h-1a.5.5 0 0 1 0-1h1v-1a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.25 1.75h-8.5a1 1 0 0 0-1 1v4.97L2.5 5.97l1.517 1.517 4-3.5 2.06 2.06a3.524 3.524 0 0 0-1.073-.012L7.983 5.013l-4 3.5L2.5 7.03.765 8.765a.378.378 0 0 1-.015.015v.47a1 1 0 0 0 1 1h4.33c.058.262.144.513.257.75H1.75A1.75 1.75 0 0 1 0 9.25v-6.5C0 1.784.784 1 1.75 1h8.5c.966 0 1.75.784 1.75 1.75v4.3a3.514 3.514 0 0 0-.75-.582V2.75a1 1 0 0 0-1-1'/%3e%3cpath fill='%230E1011' d='M3 5a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0M9.5 7.6c.22 0 .4.18.4.4v1.1H11a.4.4 0 0 1 0 .8H9.9V11a.4.4 0 0 1-.8 0V9.9H8a.4.4 0 0 1 0-.8h1.1V8c0-.22.18-.4.4-.4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h5a.5.5 0 0 0 0-1h-5A1.5 1.5 0 0 1 1 11.53l2.5-2.5 2 2 5-5 1.735 1.735a.375.375 0 0 0 .53-.53L10.5 4.97l-5 5-2-2-2.5 2.5V4.5A1.5 1.5 0 0 1 2.5 3h11A1.5 1.5 0 0 1 15 4.5v3a.5.5 0 0 0 1 0v-3A2.5 2.5 0 0 0 13.5 2z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 7a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3m0-.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0m-3.5-2a.5.5 0 0 1 .5.5v1h1a.5.5 0 0 1 0 1h-1v1a.5.5 0 0 1-1 0v-1h-1a.5.5 0 0 1 0-1h1v-1a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-plus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.25 1.75h-8.5a1 1 0 0 0-1 1v4.97L2.5 5.97l1.517 1.517 4-3.5 2.06 2.06a3.524 3.524 0 0 0-1.073-.012L7.983 5.013l-4 3.5L2.5 7.03.765 8.765a.378.378 0 0 1-.015.015v.47a1 1 0 0 0 1 1h4.33c.058.262.144.513.257.75H1.75A1.75 1.75 0 0 1 0 9.25v-6.5C0 1.784.784 1 1.75 1h8.5c.966 0 1.75.784 1.75 1.75v4.3a3.514 3.514 0 0 0-.75-.582V2.75a1 1 0 0 0-1-1'/%3e%3cpath fill='%230E1011' d='M3 5a1 1 0 1 0 0-2 1 1 0 0 0 0 2M9.9 8a.4.4 0 0 0-.8 0v1.1H8a.4.4 0 0 0 0 .8h1.1V11a.4.4 0 0 0 .8 0V9.9H11a.4.4 0 0 0 0-.8H9.9z'/%3e%3c/svg%3e")`,
                "image-plus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h7a.5.5 0 0 0 0-1h-7A1.5 1.5 0 0 1 1 11.53l2.5-2.5 2 2 5-5 3.235 3.235a.375.375 0 0 0 .53-.53L10.5 4.97l-5 5-2-2-2.5 2.5V4.5A1.5 1.5 0 0 1 2.5 3h11A1.5 1.5 0 0 1 15 4.5v5a.5.5 0 0 0 1 0v-5A2.5 2.5 0 0 0 13.5 2z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 7a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3m0-.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M14 11.5a.5.5 0 0 0-1 0V13h-1.5a.5.5 0 0 0 0 1H13v1.5a.5.5 0 0 0 1 0V14h1.5a.5.5 0 0 0 0-1H14z'/%3e%3c/svg%3e")`,
                "image-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.75 1A1.75 1.75 0 0 0 0 2.75v6.5C0 10.216.784 11 1.75 11h8.5A1.75 1.75 0 0 0 12 9.25v-6.5A1.75 1.75 0 0 0 10.25 1zM4 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0m4.017-.013 3.248 3.248a.375.375 0 0 1-.53.53L7.983 5.013l-4 3.5L2.5 7.03 1.265 8.265a.375.375 0 0 1-.53-.53L2.5 5.97l1.517 1.517 4-3.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.5 6.25a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2zm1 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3m7-2.03 4.765 4.765a.375.375 0 0 1-.53.53L10.5 6.03l-5 5-2-2-2.235 2.235a.375.375 0 0 1-.53-.53L3.5 7.97l2 2 5-5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3 5a1 1 0 1 0 0-2 1 1 0 0 0 0 2'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.75 1A1.75 1.75 0 0 0 0 2.75v6.5C0 10.216.784 11 1.75 11h8.5A1.75 1.75 0 0 0 12 9.25v-6.5A1.75 1.75 0 0 0 10.25 1zm8.5.75h-8.5a1 1 0 0 0-1 1v4.97L2.5 5.97l1.517 1.517 4-3.5L11.25 7.22V2.75a1 1 0 0 0-1-1m-9.5 7.5v-.47a.378.378 0 0 0 .015-.015L2.5 7.03l1.483 1.483 4-3.5 3.252 3.252.015.015v.97a1 1 0 0 1-1 1h-8.5a1 1 0 0 1-1-1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "image": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0m-.75 0a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2zm11 1h-11A1.5 1.5 0 0 0 1 4.5v5.97l2.5-2.5 2 2 5-5 4.5 4.5V4.5A1.5 1.5 0 0 0 13.5 3m-11 10A1.5 1.5 0 0 1 1 11.53l2.5-2.5 2 2 5-5 4.5 4.5v.97a1.5 1.5 0 0 1-1.5 1.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "home-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 10.25c0 .966.784 1.75 1.75 1.75h6.5A1.75 1.75 0 0 0 11 10.25V4.5L6 0 1 4.5zm3 .5V7.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3.25a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "home-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.34.133a.5.5 0 0 0-.68 0l-6.5 6A.5.5 0 0 0 1 6.5v8A1.5 1.5 0 0 0 2.5 16h11a1.5 1.5 0 0 0 1.5-1.5v-8a.5.5 0 0 0-.16-.367l-6.5-6ZM6 9.5V15h4V9.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "home-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.75 12A1.75 1.75 0 0 1 1 10.25V4.5L6 0l5 4.5v5.75A1.75 1.75 0 0 1 9.25 12zM6 1.009l4.25 3.825v5.416a1 1 0 0 1-1 1H8V7.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v3.75H2.75a1 1 0 0 1-1-1V4.834L6 1.009ZM4.75 11.25h2.5v-3.5h-2.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "home": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.66.133a.5.5 0 0 1 .68 0l6.5 6A.5.5 0 0 1 15 6.5v7a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 13.5v-7a.5.5 0 0 1 .16-.367l6.5-6ZM2 6.719V13.5A1.5 1.5 0 0 0 3.5 15H6v-4.5a.5.5 0 0 1 .5-.5h3.028a.5.5 0 0 1 .5.5V15H12.5a1.5 1.5 0 0 0 1.5-1.5V6.719L8 1.18 2 6.72M9.028 15v-4H7v4h2.028' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "help-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M4.875 4.5a1.125 1.125 0 0 1 2.25 0v.091c0 .322-.128.632-.356.86l-.814.814c-.211.211-.33.497-.33.796V7.5a.375.375 0 1 0 .75 0v-.44c0-.099.04-.194.11-.264l.814-.815c.369-.369.576-.869.576-1.39V4.5a1.875 1.875 0 0 0-3.75 0 .375.375 0 1 0 .75 0m1.12 4.125a.375.375 0 1 0 0 .75H6a.375.375 0 1 0 0-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "help-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M6.5 5.75c0-.69.56-1.25 1.25-1.25h.5c.69 0 1.25.56 1.25 1.25v.422a1.5 1.5 0 0 1-.44 1.06l-.828.829A2.5 2.5 0 0 0 7.5 9.828V10a.5.5 0 0 0 1 0v-.172c0-.397.158-.779.44-1.06l.828-.829a2.5 2.5 0 0 0 .732-1.767V5.75A2.25 2.25 0 0 0 8.25 3.5h-.5A2.25 2.25 0 0 0 5.5 5.75V6a.5.5 0 0 0 1 0zM8.6 12a.6.6 0 1 1-1.2 0 .6.6 0 0 1 1.2 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "help-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.875 4.5a1.125 1.125 0 0 1 2.25 0v.091c0 .322-.128.632-.356.86l-.814.814c-.211.211-.33.497-.33.796V7.5a.375.375 0 1 0 .75 0v-.44c0-.099.04-.194.11-.264l.814-.815c.369-.369.576-.869.576-1.39V4.5a1.875 1.875 0 0 0-3.75 0 .375.375 0 1 0 .75 0M5.995 8.625a.375.375 0 1 0 0 .75H6a.375.375 0 1 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a6 6 0 1 0 0 12A6 6 0 0 0 6 0M.75 6a5.25 5.25 0 1 1 10.5 0A5.25 5.25 0 0 1 .75 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "help-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 5.75c0-.69.56-1.25 1.25-1.25h.5c.69 0 1.25.56 1.25 1.25v.422a1.5 1.5 0 0 1-.44 1.06l-.828.829A2.5 2.5 0 0 0 7.5 9.828V10a.5.5 0 0 0 1 0v-.172c0-.397.158-.779.44-1.06l.828-.829a2.5 2.5 0 0 0 .732-1.767V5.75A2.25 2.25 0 0 0 8.25 3.5h-.5A2.25 2.25 0 0 0 5.5 5.75V6a.5.5 0 0 0 1 0zM8.6 12a.6.6 0 1 1-1.2 0 .6.6 0 0 1 1.2 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "heart-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 11.624c-1.876-1.5-6-4.874-6-7.874a3.75 3.75 0 0 1 6-3 3.75 3.75 0 0 1 6 3c0 3-4.125 6.374-6 7.874'/%3e%3c/svg%3e")`,
                "heart-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 15.5C5.5 13.498 0 9 0 5a5 5 0 0 1 8-4 5 5 0 0 1 8 4c0 4-5.5 8.499-8 10.5'/%3e%3c/svg%3e")`,
                "heart-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.001 11.623C7.878 10.123 12 6.749 12 3.75a3.75 3.75 0 0 0-6-3 3.75 3.75 0 0 0-6 3c0 3 4.124 6.374 6 7.874L6 11.623M6 10.661c-.913-.742-2.114-1.767-3.146-2.913C1.601 6.355.75 4.947.75 3.75a3 3 0 0 1 4.8-2.4l.45.338.45-.339a3 3 0 0 1 4.8 2.4c0 1.198-.85 2.606-2.104 3.999C8.114 8.894 6.913 9.919 6 10.66' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "heart": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.002 15.497C10.504 13.497 16 8.998 16 5a5 5 0 0 0-8-4 5 5 0 0 0-8 4c0 4 5.5 8.499 8 10.5l.002-.003M8 14.215c-1.217-.99-2.819-2.356-4.195-3.885C2.135 8.473 1 6.596 1 5a4 4 0 0 1 6.4-3.2l.6.45.6-.45A4 4 0 0 1 15 5c0 1.596-1.134 3.473-2.806 5.33-1.376 1.53-2.977 2.895-4.194 3.885' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "headphones-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 5.643A4.643 4.643 0 0 1 5.643 1h.714A4.643 4.643 0 0 1 11 5.643V9.77c0 .461-.295.87-.733 1.016l-.418.14a1.43 1.43 0 0 1-.451.073h-.184c-.591 0-1.071-.48-1.071-1.071V7.786c0-.592.48-1.072 1.071-1.072h.184c.153 0 .306.025.451.074l.437.145v-1.29a3.929 3.929 0 0 0-3.929-3.929h-.714a3.929 3.929 0 0 0-3.929 3.929v1.29l.437-.145c.145-.049.298-.074.451-.074h.184c.591 0 1.071.48 1.071 1.072v2.143c0 .591-.48 1.071-1.071 1.071h-.184a1.43 1.43 0 0 1-.451-.073l-.418-.14A1.071 1.071 0 0 1 1 9.771V5.643m.714 2.678h1.072v-.357H1.714v.357m7.5 0h1.072v-.357H9.214v.357m-7.5.715h1.072v-.357H1.714v.357m7.5 0h1.072v-.357H9.214v.357' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "headphones-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 7.5A6.5 6.5 0 0 1 7.5 1h1A6.5 6.5 0 0 1 15 7.5v5.78a1.5 1.5 0 0 1-1.026 1.422l-.585.195a2.002 2.002 0 0 1-.632.103H12.5a1.5 1.5 0 0 1-1.5-1.5v-3A1.5 1.5 0 0 1 12.5 9h.257a2 2 0 0 1 .632.103l.611.203V7.5A5.5 5.5 0 0 0 8.5 2h-1A5.5 5.5 0 0 0 2 7.5v1.806l.611-.203A2 2 0 0 1 3.243 9H3.5A1.5 1.5 0 0 1 5 10.5v3A1.5 1.5 0 0 1 3.5 15h-.257c-.215 0-.428-.035-.632-.103l-.585-.195A1.5 1.5 0 0 1 1 13.28zm1 3.75h1.5v-.5H2zm10.5 0H14v-.5h-1.5zm-10.5 1h1.5v-.5H2zm10.5 0H14v-.5h-1.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "headphones-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.643 1A4.643 4.643 0 0 0 1 5.643V9.77c0 .461.295.87.733 1.016l.418.14c.145.048.298.073.451.073h.184c.591 0 1.071-.48 1.071-1.071V7.786c0-.592-.48-1.072-1.071-1.072h-.184c-.153 0-.306.025-.451.074l-.437.145v-1.29a3.929 3.929 0 0 1 3.929-3.929h.714a3.929 3.929 0 0 1 3.929 3.929v1.29l-.437-.145a1.428 1.428 0 0 0-.451-.074h-.184c-.591 0-1.071.48-1.071 1.072v2.143c0 .591.48 1.071 1.071 1.071h.184c.153 0 .306-.025.451-.073l.418-.14c.438-.146.733-.555.733-1.016V5.643A4.643 4.643 0 0 0 6.357 1h-.714M1.714 7.964v-.278l.663-.22a.714.714 0 0 1 .225-.037h.184c.197 0 .357.16.357.357v2.143c0 .197-.16.357-.357.357h-.184a.717.717 0 0 1-.225-.037l-.419-.14a.357.357 0 0 1-.244-.338v-.735h1.072v-.357H1.714V8.32h1.072v-.357H1.714m7.91-.499.662.221v.278H9.214v.357h1.072v.358H9.214v.357h1.072v.735c0 .154-.099.29-.245.339l-.418.14a.717.717 0 0 1-.225.036h-.184a.357.357 0 0 1-.357-.357V7.786c0-.198.16-.357.357-.357h.184c.076 0 .153.012.225.036' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "headphones": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.5 1A6.5 6.5 0 0 0 1 7.5v5.78a1.5 1.5 0 0 0 1.026 1.422l.585.195c.204.068.417.103.632.103H3.5A1.5 1.5 0 0 0 5 13.5v-3A1.5 1.5 0 0 0 3.5 9h-.257a2 2 0 0 0-.632.103L2 9.306V7.5A5.5 5.5 0 0 1 7.5 2h1A5.5 5.5 0 0 1 14 7.5v1.806l-.611-.203A2 2 0 0 0 12.757 9H12.5a1.5 1.5 0 0 0-1.5 1.5v3a1.5 1.5 0 0 0 1.5 1.5h.257c.215 0 .428-.035.632-.103l.585-.195A1.5 1.5 0 0 0 15 13.28V7.5A6.5 6.5 0 0 0 8.5 1zM2 10.75v-.39l.927-.309A1 1 0 0 1 3.243 10H3.5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-.257a1 1 0 0 1-.316-.051l-.585-.195A.5.5 0 0 1 2 13.279V12.25h1.5v-.5H2v-.5h1.5v-.5zm11.073-.699.927.31v.389h-1.5v.5H14v.5h-1.5v.5H14v1.03a.5.5 0 0 1-.342.474l-.585.195a1 1 0 0 1-.316.051H12.5a.5.5 0 0 1-.5-.5v-3a.5.5 0 0 1 .5-.5h.257a1 1 0 0 1 .316.051' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "hash-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.932.754a.375.375 0 0 1 .314.428L4.85 3.75h3.74l.413-2.682a.375.375 0 0 1 .742.114L9.35 3.75h1.899a.375.375 0 0 1 0 .75H9.235l-.461 3H10.5a.375.375 0 0 1 0 .75H8.658l-.412 2.682a.375.375 0 1 1-.742-.114L7.9 8.25H4.16l-.413 2.682a.375.375 0 1 1-.742-.114L3.4 8.25H1.125a.375.375 0 1 1 0-.75h2.39l.461-3H1.875a.375.375 0 1 1 0-.75h2.217l.412-2.682a.375.375 0 0 1 .428-.314M8.015 7.5l.461-3h-3.74l-.462 3h3.74' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "hash": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.576 1.006a.5.5 0 0 1 .418.57L6.467 5h4.989l.55-3.576a.5.5 0 0 1 .988.152L12.467 5H15a.5.5 0 0 1 0 1h-2.686l-.616 4H14a.5.5 0 1 1 0 1h-2.456l-.55 3.576a.5.5 0 0 1-.988-.152L10.533 11H5.544l-.55 3.576a.5.5 0 0 1-.988-.152L4.533 11H1.5a.5.5 0 0 1 0-1h3.186l.616-4H2.5a.5.5 0 0 1 0-1h2.956l.55-3.576a.5.5 0 0 1 .57-.418M10.686 10l.616-4H6.314l-.616 4h4.988' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "hard-drive-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.57 2.25a1.5 1.5 0 0 0-1.341.83L.277 4.981a2.624 2.624 0 0 0-.104.236 2.053 2.053 0 0 1 1.14-.343h9.375c.42 0 .812.126 1.139.343a2.671 2.671 0 0 0-.104-.236L10.77 3.08A1.5 1.5 0 0 0 9.43 2.25H2.57'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6.938c0-.725-.588-1.313-1.312-1.313H1.313C.588 5.625 0 6.213 0 6.938V8.25a1.5 1.5 0 0 0 1.5 1.5h9a1.5 1.5 0 0 0 1.5-1.5V6.938m-3.75.187c0-.207.168-.375.375-.375h1.5a.375.375 0 0 1 0 .75h-1.5a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "hard-drive-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.427 3a2 2 0 0 0-1.789 1.106L.37 6.643a3.5 3.5 0 0 0-.139.314A2.737 2.737 0 0 1 1.75 6.5h12.5c.561 0 1.084.168 1.519.457a3.494 3.494 0 0 0-.139-.314l-1.268-2.537A2 2 0 0 0 12.572 3H3.428Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 9.25a1.75 1.75 0 0 0-1.75-1.75H1.75A1.75 1.75 0 0 0 0 9.25V11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-5 .25a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "hard-drive-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.625 6.75a.375.375 0 1 0 0 .75h1.5a.375.375 0 0 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.57 2.25a1.5 1.5 0 0 0-1.341.83L.277 4.981A2.625 2.625 0 0 0 0 6.156V8.25a1.5 1.5 0 0 0 1.5 1.5h9a1.5 1.5 0 0 0 1.5-1.5V6.156c0-.407-.095-.81-.277-1.174L10.77 3.08A1.5 1.5 0 0 0 9.43 2.25H2.57M1.9 3.415A.75.75 0 0 1 2.57 3h6.86a.75.75 0 0 1 .67.415l.952 1.903a1.9 1.9 0 0 1 .076.174 1.4 1.4 0 0 0-.628-.148h-9a1.4 1.4 0 0 0-.628.148c.022-.06.048-.118.076-.174l.951-1.903M.75 6.363V8.25c0 .414.336.75.75.75h9a.75.75 0 0 0 .75-.75V6.363a.844.844 0 0 0-.75-.457h-9a.844.844 0 0 0-.75.457' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "hard-drive": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 9a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.427 3a2 2 0 0 0-1.789 1.106L.37 6.643A3.5 3.5 0 0 0 0 8.208V11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8.208a3.5 3.5 0 0 0-.37-1.565l-1.268-2.537A2 2 0 0 0 12.572 3H3.428Zm-.894 1.553A1 1 0 0 1 3.427 4h9.146a1 1 0 0 1 .894.553l1.27 2.537c.037.076.07.153.1.232A1.867 1.867 0 0 0 14 7.125H2c-.301 0-.586.071-.838.197a2.5 2.5 0 0 1 .102-.232l1.269-2.537M1 8.484V11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V8.484a1.125 1.125 0 0 0-1-.609H2c-.435 0-.813.247-1 .61' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "grid-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.286.857a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V1.286a.429.429 0 0 0-.429-.429H1.286M0 1.286C0 .576.576 0 1.286 0h2.428C4.424 0 5 .576 5 1.286v2.428C5 4.424 4.424 5 3.714 5H1.286C.576 5 0 4.424 0 3.714V1.286Zm7 0C7 .576 7.576 0 8.286 0h2.428C11.424 0 12 .576 12 1.286v2.428C12 4.424 11.424 5 10.714 5H8.286C7.576 5 7 4.424 7 3.714V1.286ZM8.286.857a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V1.286a.429.429 0 0 0-.429-.429H8.286m-7 7a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V8.286a.429.429 0 0 0-.429-.429H1.286M0 8.286C0 7.576.576 7 1.286 7h2.428C4.424 7 5 7.576 5 8.286v2.428C5 11.424 4.424 12 3.714 12H1.286C.576 12 0 11.424 0 10.714V8.286m8.286-.429a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V8.286a.429.429 0 0 0-.429-.429H8.286M7 8.286C7 7.576 7.576 7 8.286 7h2.428C11.424 7 12 7.576 12 8.286v2.428c0 .71-.576 1.286-1.286 1.286H8.286C7.576 12 7 11.424 7 10.714V8.286' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.857 1.286c0-.237.192-.429.429-.429h2.428c.237 0 .429.192.429.429v2.428a.429.429 0 0 1-.429.429H1.286a.429.429 0 0 1-.429-.429V1.286ZM.857 8.286c0-.237.192-.429.429-.429h2.428c.237 0 .429.192.429.429v2.428a.429.429 0 0 1-.429.429H1.286a.429.429 0 0 1-.429-.429V8.286M7.857 8.286c0-.237.192-.429.429-.429h2.428c.237 0 .429.192.429.429v2.428a.429.429 0 0 1-.429.429H8.286a.429.429 0 0 1-.429-.429V8.286M7.857 1.286c0-.237.192-.429.429-.429h2.428c.237 0 .429.192.429.429v2.428a.429.429 0 0 1-.429.429H8.286a.429.429 0 0 1-.429-.429V1.286Z'/%3e%3c/svg%3e")`,
                "grid-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zM1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5zm8 0A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-8 8a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5zm9.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 2.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5zM2 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5zM10 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5zM10 2.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5z'/%3e%3c/svg%3e")`,
                "grid-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.286.857a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V1.286a.429.429 0 0 0-.429-.429H1.286M0 1.286C0 .576.576 0 1.286 0h2.428C4.424 0 5 .576 5 1.286v2.428C5 4.424 4.424 5 3.714 5H1.286C.576 5 0 4.424 0 3.714V1.286m7 0C7 .576 7.576 0 8.286 0h2.428C11.424 0 12 .576 12 1.286v2.428C12 4.424 11.424 5 10.714 5H8.286C7.576 5 7 4.424 7 3.714V1.286M8.286.857a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V1.286a.429.429 0 0 0-.429-.429H8.286m-7 7a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V8.286a.429.429 0 0 0-.429-.429H1.286M0 8.286C0 7.576.576 7 1.286 7h2.428C4.424 7 5 7.576 5 8.286v2.428C5 11.424 4.424 12 3.714 12H1.286C.576 12 0 11.424 0 10.714V8.286m8.286-.429a.429.429 0 0 0-.429.429v2.428c0 .237.192.429.429.429h2.428a.429.429 0 0 0 .429-.429V8.286a.429.429 0 0 0-.429-.429H8.286M7 8.286C7 7.576 7.576 7 8.286 7h2.428C11.424 7 12 7.576 12 8.286v2.428c0 .71-.576 1.286-1.286 1.286H8.286C7.576 12 7 11.424 7 10.714V8.286' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "grid": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zM1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5zm8 0A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-8 8a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5zm9.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "globe-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M5.678.984 5.5.938a5.056 5.056 0 0 0-2.319.828l.091.024.13.124.087.144v.227l-.087.269c-.05.082-.151.252-.151.268 0 .017-.03.269-.044.393v.289l.044.186.021.185.065.186.065.207.022.103h.238l.174.062.065.144.195.352.065.123.282.042.216.041.174.083.216.144.196.207c.021.02.073.066.108.082a.544.544 0 0 0 .195 0c.05.028.152.087.152.104 0 .01.021.046.043.082a.376.376 0 0 1 .043.083l.004.024c.005.028.012.07-.004.1a.414.414 0 0 1-.102.085c-.037.026-.071.05-.071.06v.144l.087.31.086.165v.206c0 .013-.004.026-.009.04-.01.03-.02.062.01.105.022.033.04.071.053.104.013.028.023.051.033.06.022.022.043.042.087.063.016.008.032.012.05.018.028.008.06.018.101.044.12.068.18.093.218.108.03.012.045.018.064.036.03.028.03.028.039.043l.026.04c.018.025.032.03.042.033.015.006.023.008.023.07v.785l.195.454.152.496.043.475.195.206.217.124.108.041.109-.04v-.125l-.065-.144-.044-.124-.043-.104v-.144l.043-.083.109-.124.152-.247V8.83l.043-.227.737-.537.238-.248-.021-.598.108-.145.13-.083.087-.082v-.207l-.087-.062-.369-.103-.216-.103-.26-.165-.195-.227-.109-.166-.151-.123-.39-.124-.304-.166-.195-.062-.282-.04-.477.02-.151-.02-.087-.083-.087-.186-.195-.042-.108-.02-.108-.062.043-.269.022-.062-.022-.062h-.109l-.108.021h-.087l-.195.041h-.13l-.043-.123.022-.166.108-.227.195-.165.217-.02h.238l.217.082.217.144h.043l.087-.04.021-.063.022-.392.455-.33.282-.269.238-.186.152-.082.347-.042.152-.041.021-.041v-.083l-.021-.062-.044-.062V2.41l.044-.041h.151l.13.02.13-.04.087-.145.043-.103-.173-.083V1.83l-.043-.083h-.13l-.087-.04-.152-.063-.108-.103-.109.02-.195.125-.238.144-.282.103-.26.042-.152-.042-.086-.186.043-.185.087-.083.26-.103.195-.083.282-.082.043-.062v-.124a5.075 5.075 0 0 0-.52-.083v.041l-.152.104-.108.062h-.217l-.39-.166m1.994.31v-.099c.142.05.282.106.418.167l-.136.056H7.78l-.108-.124m1.762.954a5.104 5.104 0 0 0-.81-.605l.002.002-.044.186-.087.145-.086.165-.044.165.13.041.13.021.26-.062.412-.062.137.004' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "globe-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.3 8A7.3 7.3 0 1 1 .7 8a7.3 7.3 0 0 1 14.6 0m-5.822 5.592.264.151c.106-.032.21-.067.314-.105v-.046l-.087-.193-.058-.165-.057-.138v-.192l.057-.11.145-.166.202-.33v-.523l.058-.303.982-.716.318-.33-.029-.799.145-.192.173-.11.116-.11v-.276l-.116-.083-.491-.137-.289-.138-.347-.22-.26-.303-.144-.22-.203-.166-.52-.165-.404-.22-.26-.083-.376-.055-.636.028-.202-.028-.116-.11-.115-.248-.26-.055-.145-.027-.144-.083.058-.358.028-.082-.028-.083h-.145l-.144.028h-.116l-.26.055h-.174l-.057-.166.029-.22.144-.303.26-.22.29-.027h.317l.289.11.289.192h.058l.115-.055.03-.082.028-.523.607-.44.376-.359.318-.248.202-.11.462-.055.202-.055.03-.055v-.11l-.03-.083-.057-.082v-.083l.057-.055h.203l.173.028.173-.055.116-.193.058-.138-.231-.11v-.067a5.959 5.959 0 0 0-1.052-.403l-.046.03-.318.192-.376.138-.347.055-.202-.055-.116-.248.058-.248.078-.074a5.972 5.972 0 0 0-3.69 1.01v.028l-.116.358c-.067.11-.202.336-.202.358 0 .022-.038.358-.058.523v.385l.058.248.03.248.086.248.086.275.03.138h.317l.231.082.087.193.26.468.087.165.375.055.29.055.23.11.29.193.26.276a.74.74 0 0 0 .144.11c.046.022.193.009.26 0 .068.037.203.115.203.137 0 .014.028.062.057.11.03.049.058.097.058.11 0 .008.002.02.005.032.006.038.016.093-.005.134-.015.03-.08.074-.136.113-.05.035-.095.067-.095.08v.192l.116.413.115.22v.276a.173.173 0 0 1-.012.053c-.013.04-.027.083.012.14.03.044.053.095.072.138.017.038.03.07.044.082a.397.397 0 0 0 .115.083c.022.01.043.016.066.023.04.012.082.025.137.06.16.09.24.123.29.143.04.016.06.024.085.049.039.037.039.037.052.057l.035.053c.023.033.042.04.056.045.02.007.03.01.03.093v1.046l.26.606.203.66.058.634.26.275m2.055-10.443a6.006 6.006 0 0 0-.339-.229l-.04.154.173.056.174.027.032-.008' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "globe-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.678.984 5.5.938a5.056 5.056 0 0 0-2.319.828l.091.024.13.124.087.144v.227l-.087.269c-.05.082-.151.252-.151.268 0 .017-.03.269-.044.393v.289l.044.186.021.185.065.186.065.207.022.103h.238l.174.062.065.144.195.352.065.123.282.042.216.041.174.083.216.144.196.207c.021.02.073.066.108.082a.544.544 0 0 0 .195 0c.05.028.152.087.152.104 0 .01.021.046.043.082a.376.376 0 0 1 .043.083l.004.024c.005.028.012.07-.004.1-.011.021-.06.055-.102.085-.037.026-.071.05-.071.06v.144l.087.31.086.165v.206a.13.13 0 0 1-.009.04c-.01.03-.02.062.01.105.022.033.04.071.053.104a.228.228 0 0 0 .033.06c.022.022.043.042.087.063.016.008.032.012.05.017.028.01.06.019.101.045.12.068.18.093.218.108.03.012.045.018.064.036.03.028.03.028.039.043l.026.04c.018.025.032.03.042.033.016.006.023.008.023.07v.785l.195.454.152.496.043.475.195.206.217.124.109.041.108-.04v-.125l-.065-.144-.043-.124-.044-.104v-.144l.044-.083.108-.124.152-.247V8.83l.043-.227.737-.537.238-.248-.021-.598.108-.145.13-.083.087-.082v-.207l-.087-.062-.368-.103-.217-.103-.26-.165-.195-.227-.109-.166-.151-.123-.39-.124-.304-.166-.195-.062-.282-.04-.477.02-.151-.02-.087-.083-.087-.186-.195-.042-.108-.02-.108-.062.043-.269.022-.062-.022-.062H5.18l-.109.021h-.087l-.195.041h-.13l-.043-.123.022-.166.108-.227.195-.165.217-.02h.238l.217.082.217.144h.043l.087-.04.021-.063.022-.392.455-.33.282-.269.238-.186.152-.082.347-.042.152-.041.021-.041v-.083l-.021-.062-.044-.062V2.41l.044-.041h.151l.13.02.13-.04.087-.145.043-.103-.173-.083V1.83l-.043-.083h-.13l-.087-.04-.152-.063-.108-.103-.109.02-.195.125-.238.144-.282.103-.26.042-.151-.042-.087-.186.043-.185.087-.083.26-.103.195-.083.282-.082.043-.062v-.124a5.075 5.075 0 0 0-.52-.083v.041l-.152.104-.108.062h-.217l-.39-.166M7.672 1.294v-.099c.142.05.282.106.418.167l-.136.056H7.78l-.108-.124M9.434 2.248a5.104 5.104 0 0 0-.81-.605l.002.002-.044.186-.087.145-.086.165-.044.165.13.041.13.021.26-.062.412-.062.137.004'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "globe": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0a6.3 6.3 0 1 1-9.679-5.317l.037.061v.303l-.116.358c-.067.11-.202.336-.202.358 0 .022-.038.358-.058.523v.386l.058.247.03.248.086.248.086.275.03.138h.317l.231.083.087.192.26.468.087.166.376.055.289.055.23.11.29.193.26.275a.74.74 0 0 0 .144.11c.046.022.193.01.26 0 .068.037.203.116.203.138 0 .013.028.062.057.11a.502.502 0 0 1 .058.11c0 .007.002.018.005.032.006.037.016.093-.005.133a.553.553 0 0 1-.136.114c-.05.035-.095.066-.095.079v.193l.116.413.115.22v.275c0 .018-.006.035-.012.053-.013.04-.027.084.012.14.03.044.053.096.072.138.017.038.03.07.044.082a.397.397 0 0 0 .181.106.491.491 0 0 1 .137.06c.16.09.24.123.29.143.04.016.06.024.085.05.039.036.039.036.052.056l.035.053c.023.034.042.04.056.045.02.007.03.01.03.093v1.046l.26.606.203.66.058.634.26.275.289.165.144.056.145-.056v-.165l-.087-.193-.058-.165-.057-.137v-.193l.057-.11.145-.165.202-.33v-.524l.058-.303.982-.716.318-.33-.029-.798.145-.193.173-.11.116-.11v-.276l-.116-.082-.491-.138-.289-.138-.347-.22-.26-.303-.144-.22-.203-.165-.52-.165-.404-.22-.26-.083-.376-.055-.636.027-.202-.027-.116-.11-.115-.248-.26-.055-.145-.028-.144-.083.058-.357.028-.083-.028-.083h-.145l-.144.028h-.116l-.26.055h-.173l-.058-.165.029-.22.144-.303.26-.22.29-.028h.317l.289.11.289.193h.058l.115-.055.03-.083.028-.523.607-.44.376-.359.318-.247.202-.11.462-.056.202-.055.03-.055v-.11l-.03-.082-.057-.083v-.083l.057-.055h.203l.173.028.173-.055.116-.193.058-.138-.231-.11v-.248l-.058-.11h-.174l-.115-.055-.202-.082-.145-.138-.144.028-.26.165-.318.192-.376.138-.347.055-.202-.055-.116-.248.058-.247.116-.11.347-.138.168-.072a6.26 6.26 0 0 1 2.425.885l-.108.205-.058.22.173.056.174.027.347-.082.063-.01A6.288 6.288 0 0 1 14.294 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "gitlab-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.627.375c.157 0 .297.1.35.247L4.387 4.5h3.225L9.022.622a.375.375 0 0 1 .704-.004l2.155 5.746a.75.75 0 0 1-.234.849L6.35 11.449a.562.562 0 0 1-.702 0L.353 7.213a.75.75 0 0 1-.234-.85L2.274.619a.375.375 0 0 1 .353-.243M2.62 1.832.822 6.627 6 10.77l5.178-4.143L9.38 1.832 8.227 5.003a.375.375 0 0 1-.352.247h-3.75a.375.375 0 0 1-.352-.247L2.62 1.833' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.822 6.627 2.62 1.832l1.153 3.171a.375.375 0 0 0 .352.247h3.75a.375.375 0 0 0 .352-.247l1.153-3.17 1.798 4.794L6 10.77.822 6.627Z'/%3e%3c/svg%3e")`,
                "gitlab-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.503.5a.5.5 0 0 1 .467.33L5.85 6h4.3L12.03.83a.5.5 0 0 1 .938-.006l2.873 7.66a1 1 0 0 1-.312 1.133l-7.06 5.648a.75.75 0 0 1-.938 0L.471 9.618a1 1 0 0 1-.312-1.132L3.032.825A.5.5 0 0 1 3.502.5m-.01 1.943L1.095 8.836 8 14.36l6.905-5.524-2.398-6.393-1.537 4.228A.5.5 0 0 1 10.5 7h-5a.5.5 0 0 1-.47-.33L3.493 2.444Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m1.095 8.836 2.398-6.393L5.03 6.671A.5.5 0 0 0 5.5 7h5a.5.5 0 0 0 .47-.33l1.537-4.227 2.398 6.393L8 14.36 1.095 8.836Z'/%3e%3c/svg%3e")`,
                "gitlab-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.627.375c.157 0 .297.1.35.247L4.387 4.5h3.225L9.022.622a.375.375 0 0 1 .704-.004l2.155 5.746a.75.75 0 0 1-.234.849L6.35 11.449a.562.562 0 0 1-.702 0L.353 7.213a.75.75 0 0 1-.234-.85L2.274.619a.375.375 0 0 1 .353-.243M2.62 1.832.822 6.627 6 10.77l5.178-4.143L9.38 1.832 8.227 5.003a.375.375 0 0 1-.352.247h-3.75a.375.375 0 0 1-.352-.247L2.62 1.833' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "gitlab": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.503.5a.5.5 0 0 1 .467.33L5.85 6h4.3L12.03.83a.5.5 0 0 1 .938-.006l2.873 7.66a1 1 0 0 1-.312 1.133l-7.06 5.648a.75.75 0 0 1-.938 0L.471 9.618a1 1 0 0 1-.312-1.132L3.032.825A.5.5 0 0 1 3.502.5m-.01 1.943L1.095 8.836 8 14.36l6.905-5.524-2.398-6.393-1.537 4.228A.5.5 0 0 1 10.5 7h-5a.5.5 0 0 1-.47-.33L3.493 2.444Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "github-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.915.207A.375.375 0 0 1 2.418.04l.695.347a.75.75 0 0 1 .195.14l.333.333A3.38 3.38 0 0 1 4.5.75h3c.297 0 .585.038.86.11l.332-.332a.75.75 0 0 1 .195-.14L9.582.04a.375.375 0 0 1 .503.167l.127.254c.2.4.25.859.142 1.293l-.103.415c.393.552.624 1.227.624 1.956v.75a4.126 4.126 0 0 1-3.13 4.004c.086.207.13.43.13.651v2.095a.375.375 0 0 1-.75 0V9.53a.95.95 0 0 0-.265-.658.375.375 0 0 1 .228-.639 3.375 3.375 0 0 0 3.037-3.358v-.75c0-.62-.215-1.19-.574-1.639a.375.375 0 0 1-.071-.325l.147-.589c.057-.23.04-.473-.048-.692l-.357.178-.49.491a.375.375 0 0 1-.387.09A2.621 2.621 0 0 0 7.5 1.5h-3c-.296 0-.58.049-.845.139a.375.375 0 0 1-.386-.09l-.491-.49-.357-.18c-.088.22-.105.462-.048.693l.147.589a.375.375 0 0 1-.07.325 2.612 2.612 0 0 0-.575 1.639v.75a3.376 3.376 0 0 0 2.75 3.317.375.375 0 0 1 .197.634.692.692 0 0 0-.163.284.474.474 0 0 0-.01.274l.129.388c.064.194.097.396.097.6v1.253a.375.375 0 0 1-.75 0V10.5H3.75c-.72 0-1.195-.476-1.545-.827a33.87 33.87 0 0 0-.033-.033C1.776 9.244 1.508 9 1.125 9H.75a.375.375 0 1 1 0-.75h.375c.72 0 1.195.476 1.545.827l.033.033c.396.396.664.64 1.047.64h.23l-.043-.128a1.216 1.216 0 0 1 .004-.726c.01-.033.02-.065.032-.098a4.127 4.127 0 0 1-2.848-3.923v-.75c0-.729.231-1.404.624-1.956l-.103-.415A1.875 1.875 0 0 1 1.788.461l.127-.254Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "github": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.553.276a.5.5 0 0 1 .67-.223l.928.463a1 1 0 0 1 .26.188l.443.443C5.221 1.051 5.604 1 6 1h4c.395 0 .78.051 1.146.147l.443-.443a.999.999 0 0 1 .26-.188l.927-.463a.5.5 0 0 1 .671.223l.17.339a2.5 2.5 0 0 1 .189 1.724l-.139.553c.524.736.833 1.636.833 2.608v1a5.502 5.502 0 0 1-4.173 5.339c.114.276.173.573.173.868V15.5a.5.5 0 0 1-1 0v-2.793c0-.328-.132-.657-.354-.878a.5.5 0 0 1 .305-.851A4.5 4.5 0 0 0 13.5 6.5v-1c0-.827-.286-1.586-.766-2.185a.5.5 0 0 1-.095-.434l.197-.785a1.5 1.5 0 0 0-.064-.923l-.476.238-.654.654a.5.5 0 0 1-.515.12A3.496 3.496 0 0 0 10 2H6c-.395 0-.774.065-1.127.185a.5.5 0 0 1-.515-.12l-.654-.654-.476-.238a1.5 1.5 0 0 0-.063.923l.196.785a.5.5 0 0 1-.095.434A3.483 3.483 0 0 0 2.5 5.5v1c0 2.2 1.58 4.033 3.667 4.423a.5.5 0 0 1 .262.845.921.921 0 0 0-.217.378.632.632 0 0 0-.014.367l.172.517c.086.258.13.527.13.799V15.5a.5.5 0 0 1-1 0V14H5c-.96 0-1.593-.635-2.06-1.103l-.044-.043C2.368 12.324 2.01 12 1.5 12H1a.5.5 0 0 1 0-1h.5c.96 0 1.593.635 2.06 1.103l.044.043c.528.53.886.854 1.396.854h.306l-.057-.171a1.621 1.621 0 0 1 .005-.968c.013-.044.028-.087.044-.13A5.502 5.502 0 0 1 1.5 6.5v-1c0-.972.308-1.872.833-2.608l-.139-.553a2.5 2.5 0 0 1 .19-1.724l.169-.339' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-pull-request-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7 4 5 2l2-2v1.625h1c1.036 0 1.875.84 1.875 1.875v4.63a1.875 1.875 0 0 1-.125 3.745h-.5a1.875 1.875 0 0 1-.125-3.746V3.5c0-.621-.504-1.125-1.125-1.125H7zm2.25 4.875a1.125 1.125 0 0 0 0 2.25h.5a1.125 1.125 0 0 0 0-2.25zM2.25.125a1.875 1.875 0 0 0-.125 3.746v5.306a1.376 1.376 0 1 0 .75 0V3.87A1.875 1.875 0 0 0 2.75.125zM1.875 10.5a.625.625 0 1 1 1.25 0 .625.625 0 0 1-1.25 0m.875-7.375a1.125 1.125 0 0 0 0-2.25h-.5a1.125 1.125 0 0 0 0 2.25z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-pull-request": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M1 2.5a2.5 2.5 0 1 1 3 2.45v8.135a1.5 1.5 0 1 1-1 0V4.95A2.5 2.5 0 0 1 1 2.5M9.854.146a.5.5 0 0 1 0 .708L8.707 2H10.5A2.5 2.5 0 0 1 13 4.5v6.55a2.5 2.5 0 1 1-1 0V4.5A1.5 1.5 0 0 0 10.5 3H8.707l1.147 1.146a.5.5 0 0 1-.708.708L6.793 2.5 9.146.146a.5.5 0 0 1 .708 0ZM12.5 12a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-9 2a.5.5 0 1 0 0 1 .5.5 0 0 0 0-1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-merge-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.25.125a1.875 1.875 0 0 0-.125 3.746V8.5a.375.375 0 1 0 .75 0V5.384c.173.13.37.231.586.296l2.862.858c.476.143.802.581.802 1.078v.513a1.875 1.875 0 0 0 .125 3.746h.5a1.875 1.875 0 0 0 .125-3.746v-.513c0-.828-.543-1.558-1.336-1.796l-2.862-.858a1.125 1.125 0 0 1-.802-1.078v-.013A1.875 1.875 0 0 0 3.75.125zm5 8.75a1.125 1.125 0 0 0 0 2.25h.5a1.125 1.125 0 0 0 0-2.25zM2.125 2c0-.621.504-1.125 1.125-1.125h.5a1.125 1.125 0 0 1 0 2.25h-.5A1.125 1.125 0 0 1 2.125 2' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3.875 10.5a.375.375 0 0 0-.75 0v1a.375.375 0 0 0 .75 0z'/%3e%3c/svg%3e")`,
                "git-merge": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M2 2.5a2.5 2.5 0 1 1 3 2.45v.673l5.187 1.482A2.5 2.5 0 0 1 12 9.509v1.541a2.5 2.5 0 1 1-1 0V9.509a1.5 1.5 0 0 0-1.088-1.443L5 6.663V10.5a.5.5 0 0 1-1 0V4.95A2.5 2.5 0 0 1 2 2.5m9.5 9.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-7 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-commit-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.654 5.875H.5a.375.375 0 1 1 0-.75h3.154a2.376 2.376 0 0 1 4.692 0H11.5a.375.375 0 0 1 0 .75H8.346a2.376 2.376 0 0 1-4.692 0m.721-.375a1.625 1.625 0 1 0 3.25 0 1.625 1.625 0 0 0-3.25 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-commit": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.535 7H.5a.5.5 0 0 0 0 1h4.035a3.5 3.5 0 0 0 6.93 0H15.5a.5.5 0 0 0 0-1h-4.035a3.5 3.5 0 0 0-6.93 0m.965.5a2.5 2.5 0 1 1 5 0 2.5 2.5 0 0 1-5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-branch-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.375 2c0-1.036.84-1.875 1.875-1.875h.25a1.875 1.875 0 0 1 .375 3.712v3.206l2.944-.59A1.625 1.625 0 0 0 8.125 4.86V3.837A1.876 1.876 0 0 1 8.5.125h.25a1.875 1.875 0 0 1 .125 3.746v.99c0 1.132-.8 2.106-1.91 2.328l-3.09.618v1.37a1.376 1.376 0 1 1-.75 0V3.87A1.875 1.875 0 0 1 1.375 2M3.5 9.875a.625.625 0 1 0 0 1.25.625.625 0 0 0 0-1.25m5.25-6.75H8.5a1.125 1.125 0 0 1 0-2.25h.25a1.125 1.125 0 0 1 0 2.25M4.625 2c0 .621-.504 1.125-1.125 1.125h-.25a1.125 1.125 0 0 1 0-2.25h.25c.621 0 1.125.504 1.125 1.125' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "git-branch": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M2 2.5a2.5 2.5 0 1 1 3 2.45v4.887l3.824-1.092A3 3 0 0 0 11 5.86v-.91a2.5 2.5 0 1 1 1 0v.91a4 4 0 0 1-2.901 3.846L5 10.877v2.208a1.5 1.5 0 1 1-1 0V4.95A2.5 2.5 0 0 1 2 2.5M11.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-7 13a.5.5 0 1 0 0 1 .5.5 0 0 0 0-1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "gift-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.25 2.477a1.227 1.227 0 0 1 2.248-.68L6 2.548l.502-.753a1.227 1.227 0 0 1 2.248.681V2.5c0 .228-.06.441-.167.625H10.5a1.375 1.375 0 0 1 .375 2.698V9c0 1.036-.84 1.875-1.875 1.875H3A1.875 1.875 0 0 1 1.125 9V5.823A1.376 1.376 0 0 1 1.5 3.125h1.917A1.244 1.244 0 0 1 3.25 2.5v-.023m5 .023a.75.75 0 0 1-.335.625H6.25v-.05l.668-1.001a.727.727 0 0 1 1.332.403zm-2.5.576v.049H4.085A.75.75 0 0 1 3.75 2.5v-.023a.727.727 0 0 1 1.332-.403l.668 1.002m.5.424a.25.25 0 0 0-.5 0v1.75H2.5a.25.25 0 0 0 0 .5h3.25V9.5a.25.25 0 0 0 .5 0V5.75H9.5a.25.25 0 0 0 0-.5H6.25z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "gift-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.15 3.531a1.923 1.923 0 0 1 3.649-1.216L8 2.919l.201-.604A1.923 1.923 0 0 1 11.85 3.53l-.148.443a2.035 2.035 0 0 1-.008.026H15a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v4.75A2.25 2.25 0 0 1 12.75 15h-9.5A2.25 2.25 0 0 1 1 12.75V8a1 1 0 0 1-1-1V5a1 1 0 0 1 1-1h3.307a1.549 1.549 0 0 1-.01-.026l-.147-.443m6.604.127a.5.5 0 0 1-.475.342H8.694l.456-1.369a.923.923 0 0 1 1.751.584l-.147.443M6.85 2.631 7.306 4H5.721a.5.5 0 0 1-.475-.342L5.1 3.215A.923.923 0 1 1 6.85 2.63M8 5a.5.5 0 0 1 .5.5V7h5.25a.5.5 0 0 1 0 1H8.5v5.5a.5.5 0 0 1-1 0V8H2.25a.5.5 0 0 1 0-1H7.5V5.5A.5.5 0 0 1 8 5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "gift-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.477 1.25c-.678 0-1.227.55-1.227 1.227V2.5c0 .228.06.441.167.625H1.5a1.375 1.375 0 0 0-.375 2.698V9c0 1.036.84 1.875 1.875 1.875h6c1.036 0 1.875-.84 1.875-1.875V5.823a1.376 1.376 0 0 0-.375-2.698H8.583c.106-.184.167-.397.167-.625v-.023a1.227 1.227 0 0 0-2.248-.68L6 2.548l-.502-.753a1.227 1.227 0 0 0-1.02-.546M5.75 3.875H1.5a.625.625 0 1 0 0 1.25h4.25zm.5 1.25v-1.25h4.25a.625.625 0 1 1 0 1.25zm-.5.75H1.875V9c0 .621.504 1.125 1.125 1.125h2.75zm.5 4.25v-4.25h3.875V9c0 .621-.504 1.125-1.125 1.125zm1.665-7A.75.75 0 0 0 8.25 2.5v-.023a.727.727 0 0 0-1.332-.403L6.25 3.076v.049h1.665m-2.165 0v-.05l-.668-1.001a.727.727 0 0 0-1.332.403V2.5c0 .26.133.49.335.625z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "gift": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.15 3.531a1.923 1.923 0 0 1 3.649-1.216L8 2.919l.201-.604A1.923 1.923 0 0 1 11.85 3.53l-.148.443a2.035 2.035 0 0 1-.008.026H14.5A1.5 1.5 0 0 1 16 5.5v1a1.5 1.5 0 0 1-1 1.415V13a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V7.915A1.5 1.5 0 0 1 0 6.5v-1A1.5 1.5 0 0 1 1.5 4h2.807a1.549 1.549 0 0 1-.01-.026l-.147-.443M5.72 4h1.586L6.85 2.631a.923.923 0 0 0-1.751.584l.147.443A.5.5 0 0 0 5.721 4M7.5 5v2h-6a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5zm1 2V5h6a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5zm-1 1H2v5a1 1 0 0 0 1 1h4.5zm1 6V8H14v5a1 1 0 0 1-1 1zm1.78-10a.5.5 0 0 0 .474-.342l.147-.443A.923.923 0 1 0 9.15 2.63L8.694 4h1.585' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "frown-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M3.75 4.5a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0Zm3 0a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0M4.015 8.796C4.491 8.32 5.231 8.063 6 8.063c.77 0 1.509.257 1.985.733a.375.375 0 0 0 .53-.53C7.866 7.617 6.918 7.313 6 7.313c-.918 0-1.866.304-2.515.953a.375.375 0 0 0 .53.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "frown-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0M5 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0Zm4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0m-3.646 5.729c.635-.635 1.62-.979 2.646-.979 1.026 0 2.011.344 2.646.979a.5.5 0 0 0 .708-.708C10.489 10.156 9.224 9.75 8 9.75c-1.224 0-2.489.406-3.354 1.271a.5.5 0 0 0 .708.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "frown-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.129 7.378C4.556 7.07 5.194 6.75 6 6.75s1.444.32 1.871.628a3.704 3.704 0 0 1 .66.614l.005.005.006.009.004.004v.002s.002 0-.307.23l.309-.23a.38.38 0 0 1-.077.536.388.388 0 0 1-.54-.076l-.004-.005a2.219 2.219 0 0 0-.12-.134 2.935 2.935 0 0 0-.39-.336A2.42 2.42 0 0 0 6 7.515a2.42 2.42 0 0 0-1.417.482 2.935 2.935 0 0 0-.51.47l-.004.006a.388.388 0 0 1-.54.075.38.38 0 0 1-.077-.535l.31.23-.31-.23.001-.001.001-.002.004-.004L3.46 8l.007-.009.036-.043a3.704 3.704 0 0 1 .625-.57M4.5 3.75a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5M7.5 3.75a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-6 5.25A5.25 5.25 0 1 0 6 .75a5.25 5.25 0 0 0 0 10.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "frown": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 5a1 1 0 1 0 0 2 1 1 0 0 0 0-2M5.505 9.837C6.075 9.427 6.925 9 8 9c1.075 0 1.925.427 2.495.837a4.933 4.933 0 0 1 .833.761l.048.059.005.006.009.011.004.006.002.002v.001a.508.508 0 0 1-.102.715.518.518 0 0 1-.72-.101l-.005-.007-.03-.036a3.921 3.921 0 0 0-.65-.592c-.456-.328-1.098-.642-1.889-.642-.791 0-1.433.314-1.89.643a3.922 3.922 0 0 0-.65.591 1.53 1.53 0 0 0-.029.036l-.005.007a.517.517 0 0 1-.72.101.507.507 0 0 1-.103-.714l.001-.002.002-.002.004-.006.005-.005.01-.012c.01-.015.027-.035.047-.059a4.934 4.934 0 0 1 .833-.76M9 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-plus-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.125 1.5C.504 1.5 0 2.004 0 2.625V9a1.5 1.5 0 0 0 1.5 1.5h4.692A3.375 3.375 0 0 1 12 7.254V3.75a1.5 1.5 0 0 0-1.5-1.5H6.091a.75.75 0 0 1-.53-.22l-.091-.09a1.5 1.5 0 0 0-1.061-.44zm4.39 1.765a.375.375 0 0 0-.53-.53l-.046.045a.75.75 0 0 1-.53.22H1.125a.375.375 0 1 0 0 .75h3.284a1.5 1.5 0 0 0 1.06-.44l.046-.045' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.375a2.625 2.625 0 1 1-5.25 0 2.625 2.625 0 0 1 5.25 0M9.375 7.5c.207 0 .375.168.375.375V9h1.125a.375.375 0 0 1 0 .75H9.75v1.313a.375.375 0 0 1-.75 0V9.75H7.875a.375.375 0 1 1 0-.75H9V7.875c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-plus-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h6.256A4.5 4.5 0 0 1 16 9.671V4a2 2 0 0 0-2-2H8.121a1 1 0 0 1-.707-.293l-.121-.121A2 2 0 0 0 5.879 1zm5.854 2.354a.5.5 0 0 0-.708-.708l-.06.061A1 1 0 0 1 5.879 3H1.5a.5.5 0 1 0 0 1h4.379a2 2 0 0 0 1.414-.586l.06-.06' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-plus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.125 2.5c0-.76.616-1.375 1.375-1.375h3.155l1 1h4.673c.898 0 1.625.728 1.625 1.625V5.5a.375.375 0 0 1-.75 0V3.75a.875.875 0 0 0-.875-.875H5.655l-1 1H.875V9.25c0 .483.392.875.875.875H5.5a.375.375 0 0 1 0 .75H1.75A1.625 1.625 0 0 1 .125 9.25zm4.22-.625.625.625-.625.625H.875V2.5c0-.345.28-.625.625-.625h2.845' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0M9.5 7.6c.22 0 .4.18.4.4v1.1H11a.4.4 0 0 1 0 .8H9.9V11a.4.4 0 0 1-.8 0V9.9H8a.4.4 0 0 1 0-.8h1.1V8c0-.22.18-.4.4-.4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-plus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h5.5v-1H2a1 1 0 0 1-1-1V4h4.879a2 2 0 0 0 1.414-.586L7.707 3H14a1 1 0 0 1 1 1v4.5h1V4a2 2 0 0 0-2-2H7.707l-.414-.414A2 2 0 0 0 5.879 1zm4.379 2H1v-.5a.5.5 0 0 1 .5-.5h4.379a1 1 0 0 1 .707.293l.207.207-.207.207A1 1 0 0 1 5.879 3' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-minus-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.125 1.25C.504 1.25 0 1.754 0 2.375V9a1.5 1.5 0 0 0 1.5 1.5h4.7c.065-.111.144-.216.24-.31l.814-.815-.815-.814a1.5 1.5 0 1 1 2.122-2.122l.814.815.814-.815A1.5 1.5 0 0 1 12 6.201V3.5A1.5 1.5 0 0 0 10.5 2H6.091a.75.75 0 0 1-.53-.22l-.091-.09a1.5 1.5 0 0 0-1.061-.44zm4.39 2.015a.375.375 0 0 0-.53-.53l-.046.045a.75.75 0 0 1-.53.22H1.125a.375.375 0 1 0 0 .75h3.284a1.5 1.5 0 0 0 1.06-.44l.046-.045' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12 9c0 .254-.063.494-.175.704l-.329-.329.504-.504z'/%3e%3cpath fill='%230E1011' d='M7.765 7.235a.375.375 0 0 0-.53.53l1.61 1.61-1.61 1.61a.375.375 0 0 0 .53.53l1.61-1.61 1.61 1.61a.375.375 0 0 0 .53-.53l-1.61-1.61 1.61-1.61a.375.375 0 0 0-.53-.53l-1.61 1.61-1.61-1.61'/%3e%3c/svg%3e")`,
                "folder-minus-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h6.267c.086-.148.192-.287.319-.414L9.672 12.5l-1.086-1.086a2 2 0 1 1 2.828-2.828L12.5 9.672l1.086-1.086A2 2 0 0 1 16 8.267V4a2 2 0 0 0-2-2H8.121a1 1 0 0 1-.707-.293l-.121-.121A2 2 0 0 0 5.879 1zm5.854 2.354a.5.5 0 0 0-.708-.708l-.06.061A1 1 0 0 1 5.879 3H1.5a.5.5 0 1 0 0 1h4.379a2 2 0 0 0 1.414-.586l.06-.06' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 12c0 .34-.084.659-.233.938l-.439-.438.672-.672z'/%3e%3cpath fill='%230E1011' d='M10.354 9.646a.5.5 0 0 0-.708.708l2.147 2.146-2.147 2.146a.5.5 0 0 0 .708.708l2.146-2.147 2.146 2.147a.5.5 0 0 0 .708-.708L13.207 12.5l2.147-2.146a.5.5 0 0 0-.708-.708L12.5 11.793l-2.146-2.147'/%3e%3c/svg%3e")`,
                "folder-minus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.125 2.5c0-.76.616-1.375 1.375-1.375h3.155l1 1h4.673c.898 0 1.625.728 1.625 1.625V5.5a.375.375 0 0 1-.75 0V3.75a.875.875 0 0 0-.875-.875H5.655l-1 1H.875V9.25c0 .483.392.875.875.875H5.5a.375.375 0 0 1 0 .75H1.75A1.625 1.625 0 0 1 .125 9.25zm4.22-.625.625.625-.625.625H.875V2.5c0-.345.28-.625.625-.625h2.845' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M7.765 7.235a.375.375 0 1 0-.53.53L8.97 9.5l-1.735 1.735a.375.375 0 0 0 .53.53L9.5 10.03l1.735 1.735a.375.375 0 0 0 .53-.53L10.03 9.5l1.735-1.735a.375.375 0 0 0-.53-.53L9.5 8.97 7.765 7.235'/%3e%3c/svg%3e")`,
                "folder-minus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.5A1.5 1.5 0 0 1 1.5 1h4.379a2 2 0 0 1 1.414.586L7.707 2H14a2 2 0 0 1 2 2v3.5a.5.5 0 0 1-1 0V4a1 1 0 0 0-1-1H7.707l-.414.414A2 2 0 0 1 5.879 4H1v8a1 1 0 0 0 1 1h5.5a.5.5 0 0 1 0 1H2a2 2 0 0 1-2-2zM1 3h4.879a1 1 0 0 0 .707-.293l.207-.207-.207-.207A1 1 0 0 0 5.879 2H1.5a.5.5 0 0 0-.5.5zm8.646 6.646a.5.5 0 0 1 .708 0l2.146 2.147 2.146-2.147a.5.5 0 0 1 .708.708L13.207 12.5l2.147 2.146a.5.5 0 0 1-.708.708L12.5 13.207l-2.146 2.147a.5.5 0 0 1-.708-.708l2.147-2.146-2.147-2.146a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.2 1.15C.62 1.15.15 1.62.15 2.2v7.6c0 .58.47 1.05 1.05 1.05h9.6c.58 0 1.05-.47 1.05-1.05V3.2c0-.58-.47-1.05-1.05-1.05H5.645l-1-1H1.2Zm4.047 2.097a.35.35 0 0 0-.494-.494l-.398.397H1.5a.35.35 0 1 0 0 .7h3.145l.602-.603' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H8.121a1 1 0 0 1-.707-.293l-.121-.121A2 2 0 0 0 5.879 1zm5.854 2.354a.5.5 0 0 0-.708-.708l-.06.061A1 1 0 0 1 5.879 3H1.5a.5.5 0 1 0 0 1h4.379a2 2 0 0 0 1.414-.586l.06-.06' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1.125C.74 1.125.125 1.741.125 2.5v6.75c0 .898.728 1.625 1.625 1.625h8.578c.898 0 1.625-.727 1.625-1.625v-5.5c0-.897-.727-1.625-1.625-1.625H5.655l-1-1zM.875 2.5c0-.345.28-.625.625-.625h2.845l.625.625-.625.625H.875zm0 1.375V9.25c0 .483.392.875.875.875h8.578a.875.875 0 0 0 .875-.875v-5.5a.875.875 0 0 0-.875-.875H5.655l-1 1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "folder": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.5A1.5 1.5 0 0 1 1.5 1h4.379a2 2 0 0 1 1.414.586L7.707 2H14a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.793 0-.207-.207A1 1 0 0 0 5.879 2H1.5a.5.5 0 0 0-.5.5V3h4.879a1 1 0 0 0 .707-.293l.207-.207M1 4v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1H7.707l-.414.414A2 2 0 0 1 5.879 4z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "flag-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.541 1.291C1.863 1.134 2.366 1 3.143 1c.766 0 1.849.182 2.888.357l.028.005c1.073.18 2.099.352 2.798.352.722 0 1.144-.05 1.377-.095a1.448 1.448 0 0 0 .233-.063.357.357 0 0 1 .533.311V7.99c0 .135-.077.26-.198.32l-.16-.32.16.32H10.8l-.004.003-.012.005a2.476 2.476 0 0 1-.192.083c-.129.052-.314.12-.547.187a6.89 6.89 0 0 1-1.902.27c-.773 0-1.683-.185-2.546-.36l-.025-.005c-.893-.18-1.736-.35-2.43-.35-.72 0-1.143.05-1.376.095a2.4 2.4 0 0 0-.052.01v2.395a.357.357 0 0 1-.714 0V1.867c0-.065.018-.13.053-.186l.304.186-.304-.186V1.68l.001-.002.002-.003.004-.006a.52.52 0 0 1 .037-.05.916.916 0 0 1 .091-.095c.078-.072.192-.155.353-.233m.173.724v5.507c.296-.05.746-.093 1.429-.093.772 0 1.683.184 2.546.359l.025.005c.893.18 1.736.35 2.429.35.696 0 1.287-.12 1.703-.241a5.24 5.24 0 0 0 .44-.148V2.335c-.296.05-.746.094-1.429.094-.766 0-1.849-.183-2.888-.358l-.028-.005c-1.073-.18-2.099-.352-2.798-.352-.696 0-1.087.12-1.29.22a.924.924 0 0 0-.139.081' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.714 7.522V2.015a.924.924 0 0 1 .14-.082c.202-.098.593-.219 1.289-.219.7 0 1.725.172 2.798.352l.028.005c1.04.175 2.122.358 2.888.358.683 0 1.133-.043 1.429-.094v5.42a5.24 5.24 0 0 1-.44.147 6.176 6.176 0 0 1-1.703.24c-.693 0-1.536-.168-2.43-.35l-.024-.004c-.863-.175-1.774-.36-2.546-.36-.683 0-1.133.043-1.429.094'/%3e%3c/svg%3e")`,
                "flag-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.758 1.408C2.208 1.188 2.912 1 4 1c1.073 0 2.589.255 4.043.5l.04.007C9.585 1.76 11.021 2 12 2c1.01 0 1.601-.07 1.928-.134a2.026 2.026 0 0 0 .326-.087.5.5 0 0 1 .746.435v8.572a.5.5 0 0 1-.277.447l-.223-.447.223.447-.002.001-.002.001-.005.003-.016.008a5.388 5.388 0 0 1-.268.116c-.181.072-.441.167-.768.261A9.65 9.65 0 0 1 11 12c-1.082 0-2.356-.258-3.564-.503L7.4 11.49C6.15 11.237 4.97 11 4 11c-1.01 0-1.602.07-1.928.134a3.72 3.72 0 0 0-.072.014V14.5a.5.5 0 0 1-1 0V2.214a.5.5 0 0 1 .074-.26l.426.26c-.426-.26-.426-.262-.426-.262l.002-.002.002-.004.006-.009a.708.708 0 0 1 .052-.07c.03-.038.073-.083.127-.133.11-.1.27-.217.495-.326M2 2.422v7.708c.413-.07 1.044-.13 2-.13 1.082 0 2.356.258 3.565.503l.034.007c1.25.253 2.43.49 3.401.49a8.65 8.65 0 0 0 2.384-.337 7.35 7.35 0 0 0 .616-.207V2.87c-.413.07-1.044.13-2 .13-1.073 0-2.589-.255-4.043-.5l-.04-.007C6.415 2.24 4.979 2 4 2c-.975 0-1.521.169-1.805.307-.087.042-.15.082-.195.115' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 10.13V2.422c.044-.033.108-.073.195-.115C2.48 2.169 3.025 2 4 2c.98 0 2.415.24 3.917.493l.04.007c1.454.245 2.97.5 4.043.5.956 0 1.587-.06 2-.13v7.586a7.35 7.35 0 0 1-.616.207A8.65 8.65 0 0 1 11 11c-.97 0-2.15-.237-3.4-.49l-.035-.007C6.355 10.258 5.082 10 4 10c-.956 0-1.587.06-2 .13'/%3e%3c/svg%3e")`,
                "flag-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.541 1.291C1.863 1.134 2.366 1 3.143 1c.766 0 1.849.182 2.888.357l.028.005c1.073.18 2.099.352 2.798.352.722 0 1.144-.05 1.377-.095a1.448 1.448 0 0 0 .233-.063.357.357 0 0 1 .533.311V7.99c0 .135-.077.26-.198.32l-.16-.32.16.32H10.8l-.004.003-.012.005a2.476 2.476 0 0 1-.192.083c-.129.052-.314.12-.547.187a6.89 6.89 0 0 1-1.902.27c-.773 0-1.683-.185-2.546-.36l-.025-.005c-.893-.18-1.736-.35-2.43-.35-.72 0-1.143.05-1.376.095a2.4 2.4 0 0 0-.052.01v2.395a.357.357 0 0 1-.714 0V1.867c0-.065.018-.13.053-.186l.304.186-.304-.186V1.68l.001-.002.002-.003.004-.006a.52.52 0 0 1 .037-.05.916.916 0 0 1 .091-.095c.078-.072.192-.155.353-.233m.173.724v5.507c.296-.05.746-.093 1.429-.093.772 0 1.683.184 2.546.359l.025.005c.893.18 1.736.35 2.429.35.696 0 1.287-.12 1.703-.241a5.24 5.24 0 0 0 .44-.148V2.335c-.296.05-.746.094-1.429.094-.766 0-1.849-.183-2.888-.358l-.028-.005c-1.073-.18-2.099-.352-2.798-.352-.696 0-1.087.12-1.29.22a.924.924 0 0 0-.139.081' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "flag": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.758 1.408C2.208 1.188 2.912 1 4 1c1.073 0 2.589.255 4.043.5l.04.007C9.585 1.76 11.021 2 12 2c1.01 0 1.601-.07 1.928-.134a2.026 2.026 0 0 0 .326-.087.5.5 0 0 1 .746.435v8.572a.5.5 0 0 1-.277.447l-.223-.447.223.447-.002.001-.002.001-.005.003-.016.008a5.388 5.388 0 0 1-.268.116c-.181.072-.441.167-.768.261A9.65 9.65 0 0 1 11 12c-1.082 0-2.356-.258-3.564-.503L7.4 11.49C6.15 11.237 4.97 11 4 11c-1.01 0-1.602.07-1.928.134a3.72 3.72 0 0 0-.072.014V14.5a.5.5 0 0 1-1 0V2.214a.5.5 0 0 1 .074-.26l.426.26c-.426-.26-.426-.261-.426-.262l.002-.002.002-.004.006-.009a.708.708 0 0 1 .052-.07c.03-.038.073-.083.127-.133.11-.1.27-.217.495-.326M2 2.422v7.708c.413-.07 1.044-.13 2-.13 1.082 0 2.356.258 3.565.503l.034.007c1.25.253 2.43.49 3.401.49a8.65 8.65 0 0 0 2.384-.337 7.35 7.35 0 0 0 .616-.207V2.87c-.413.07-1.044.13-2 .13-1.073 0-2.589-.255-4.043-.5l-.04-.007C6.415 2.24 4.979 2 4 2c-.975 0-1.521.169-1.805.307-.087.042-.15.082-.195.115' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "fire-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12c2.761 0 5-2.015 5-4.5 0-1.93-1.436-3.066-2.772-4.123C6.968 2.381 5.798 1.455 6 0 2.25 1.875 1 4.125 1 7.5 1 9.985 3.239 12 6 12m0 0c-1.657 0-3-1.205-3-2.692C3 7.692 3.6 6.077 6 5c-.308 1.38.49 1.77 1.339 2.185C8.146 7.58 9 7.996 9 9.308 9 10.795 7.657 12 6 12' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "fire-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 16a6 6 0 0 0 6-6c0-2.574-1.723-4.088-3.327-5.497C9.163 3.175 7.757 1.94 8 0 3.5 2.5 2 5.5 2 10a6 6 0 0 0 6 6m0 0a3 3 0 0 1-3-3c0-2.25.75-3.75 3-5-.121.97.581 1.588 1.337 2.251C10.139 10.956 11 11.713 11 13a3 3 0 0 1-3 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "fire-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 7.5C1 4.368 2.076 2.205 5.228.411 5.473.272 5.73.135 6 0c-.041.295-.026.568.036.825.24 1.008 1.188 1.758 2.192 2.552C9.564 4.434 11 5.569 11 7.5 11 9.985 8.761 12 6 12S1 9.985 1 7.5m2.666 3.136A2.837 2.837 0 0 1 3.15 9c0-.788.131-1.6.543-2.355.413-.758 1.095-1.43 2.15-1.958l.64-.32-.14.702c-.112.559-.018.859.122 1.056.157.222.411.375.765.568l.064.034c.318.173.702.382 1.003.708.337.366.553.86.553 1.565 0 .609-.19 1.173-.516 1.636 1.17-.683 1.916-1.86 1.916-3.136 0-1.464-1.028-2.379-2.372-3.443l-.133-.105c-.592-.468-1.244-.983-1.72-1.568a3.597 3.597 0 0 1-.663-1.183c-1.247.744-2.085 1.53-2.637 2.391-.68 1.063-.975 2.315-.975 3.908 0 1.277.745 2.453 1.916 3.136M3.85 9c0-.712.119-1.4.457-2.02.264-.484.67-.944 1.29-1.348.018.356.12.65.297.899.265.372.667.594 1 .776l.036.02c.343.186.633.344.852.582.209.227.368.547.368 1.091a2.15 2.15 0 0 1-4.3 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "fire": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 16a6 6 0 0 1-6-6C2 5.86 3.27 2.99 6.976.61 7.3.405 7.64.2 8 0c-.05.403-.03.775.048 1.125.297 1.332 1.428 2.326 2.625 3.378C12.277 5.912 14 7.426 14 10a6 6 0 0 1-6 6m1.448-1.213A4.998 4.998 0 0 1 8 15c-.503 0-.99-.074-1.448-.213A2.295 2.295 0 0 1 5.7 13c0-1.048.175-1.853.563-2.525.269-.466.66-.902 1.224-1.32.085.192.192.369.312.533.3.41.71.769 1.062 1.077l.083.073c.802.706 1.356 1.264 1.356 2.162 0 .722-.332 1.366-.852 1.787m1.317-.62A2.99 2.99 0 0 0 11 13c0-1.287-.861-2.044-1.663-2.749-.538-.472-1.049-.921-1.255-1.49A1.607 1.607 0 0 1 8 8c-.253.14-.487.285-.704.432C5.591 9.597 5 11.003 5 13c0 .414.084.808.235 1.167A4.995 4.995 0 0 1 3 10c0-2.14.357-3.825 1.179-5.25.637-1.106 1.589-2.113 2.985-3.065.168.534.435 1.016.756 1.454.575.782 1.362 1.473 2.072 2.097l.16.14C11.744 6.776 13 8.002 13 10c0 1.74-.888 3.271-2.235 4.167' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-x-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.02 1.8A.469.469 0 0 1 1.35 1h9.298c.417 0 .626.505.331.8L6.75 6.03v4.125l-1.5 1.5V6.03L1.02 1.8Zm1.01-.05L6 5.72 3.22 1.75H2.03M8.235 8.235a.375.375 0 0 1 .53 0L10 9.47l1.235-1.235a.375.375 0 1 1 .53.53L10.53 10l1.235 1.235a.375.375 0 1 1-.53.53L10 10.53l-1.235 1.235a.375.375 0 0 1-.53-.53L9.47 10 8.235 8.765a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-x-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 4.293 2H2.707' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.397 10.396a.5.5 0 0 1 .707 0L13 12.293l1.896-1.897a.5.5 0 0 1 .708.708L13.707 13l1.897 1.896a.5.5 0 0 1-.707.708L13 13.707l-1.896 1.897a.5.5 0 0 1-.707-.708L12.293 13l-1.896-1.896a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-x-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.02 1.8A.469.469 0 0 1 1.35 1h9.298c.417 0 .626.505.331.8L6.75 6.03v4.125l-1.5 1.5V6.03L1.02 1.8Zm1.01-.05L6 5.72l3.97-3.97H2.03ZM8.235 8.235a.375.375 0 0 1 .53 0L10 9.47l1.235-1.235a.375.375 0 1 1 .53.53L10.53 10l1.235 1.235a.375.375 0 1 1-.53.53L10 10.53l-1.235 1.235a.375.375 0 0 1-.53-.53L9.47 10 8.235 8.765a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-x": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 13.293 2H2.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.397 10.396a.5.5 0 0 1 .707 0L13 12.293l1.896-1.897a.5.5 0 0 1 .708.708L13.707 13l1.897 1.896a.5.5 0 0 1-.707.708L13 13.707l-1.896 1.897a.5.5 0 0 1-.707-.708L12.293 13l-1.896-1.896a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.02 1.8A.469.469 0 0 1 1.35 1h9.298c.417 0 .626.505.331.8L6.75 6.03v4.125l-1.5 1.5V6.03L1.02 1.8Zm1.01-.05L6 5.72 3.22 1.75H2.03' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 4.293 2H2.707' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.02 1.8A.469.469 0 0 1 1.35 1h9.298c.417 0 .626.505.331.8L6.75 6.03v4.125l-1.5 1.5V6.03L1.02 1.8Zm1.01-.05L6 5.72l3.97-3.97H2.03' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "filter": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 13.293 2H2.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "film-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.188.375c-.932 0-1.688.756-1.688 1.688v7.874c0 .933.756 1.688 1.688 1.688h5.624c.932 0 1.688-.755 1.688-1.687V2.061c0-.931-.756-1.687-1.687-1.687H3.186M2.25 2.063c0-.518.42-.938.938-.938h.562V3h-1.5v-.937m1.5 1.687h-1.5v1.875h1.5zm-1.5 2.625h1.5V8.25h-1.5zM2.25 9h1.5v1.875h-.562a.937.937 0 0 1-.938-.937zm7.5-6.937a.937.937 0 0 0-.937-.938H8.25V3h1.5v-.937M8.25 3.75h1.5v1.875h-1.5zm1.5 2.625h-1.5V8.25h1.5zM9.75 9h-1.5v1.875h.563c.517 0 .937-.42.937-.937z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "film-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25.5A2.25 2.25 0 0 0 2 2.75v10.5a2.25 2.25 0 0 0 2.25 2.25h7.5A2.25 2.25 0 0 0 14 13.25V2.75A2.25 2.25 0 0 0 11.75.5zM3 2.75c0-.69.56-1.25 1.25-1.25H5V4H3zM5 5H3v2.5h2zM3 8.5h2V11H3zM3 12h2v2.5h-.75c-.69 0-1.25-.56-1.25-1.25zm10-9.25c0-.69-.56-1.25-1.25-1.25H11V4h2zM11 5h2v2.5h-2zm2 3.5h-2V11h2zm0 3.5h-2v2.5h.75c.69 0 1.25-.56 1.25-1.25z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "film-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.188.375c-.932 0-1.688.756-1.688 1.688v7.874c0 .933.756 1.688 1.688 1.688h5.624c.932 0 1.688-.755 1.688-1.687V2.061c0-.931-.756-1.687-1.687-1.687H3.186M2.25 2.063c0-.518.42-.938.938-.938h.656v1.969H2.25V2.063m0 1.593V5.72h1.594V3.656H2.25m0 2.625v2.063h1.594V6.28H2.25m0 2.625v1.031c0 .518.42.938.938.938h.656V8.906H2.25m2.156 1.969h3.188V6.281H4.406v4.594m3.75 0h.656c.518 0 .938-.42.938-.937V8.906H8.156v1.969M9.75 8.344V6.28H8.156v2.063H9.75m0-2.625V3.656H8.156V5.72H9.75m0-2.625V2.063a.937.937 0 0 0-.937-.938h-.657v1.969H9.75M7.594 1.125H4.406v4.594h3.188V1.125' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "film": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25.5A2.25 2.25 0 0 0 2 2.75v10.5a2.25 2.25 0 0 0 2.25 2.25h7.5A2.25 2.25 0 0 0 14 13.25V2.75A2.25 2.25 0 0 0 11.75.5zM3 2.75c0-.69.56-1.25 1.25-1.25h.875v2.625H3zm0 2.125v2.75h2.125v-2.75zm0 3.5v2.75h2.125v-2.75zm0 3.5v1.375c0 .69.56 1.25 1.25 1.25h.875v-2.625zM5.875 14.5h4.25V8.375h-4.25zm5 0h.875c.69 0 1.25-.56 1.25-1.25v-1.375h-2.125zM13 11.125v-2.75h-2.125v2.75zm0-3.5v-2.75h-2.125v2.75zm0-3.5V2.75c0-.69-.56-1.25-1.25-1.25h-.875v2.625zM10.125 1.5h-4.25v6.125h4.25z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-text-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.5 12a1.5 1.5 0 0 0 1.5-1.5V3.188L7.813 0H2.5A1.5 1.5 0 0 0 1 1.5v9A1.5 1.5 0 0 0 2.5 12zM7.625 1.125c.207 0 .375.168.375.375v1.125c0 .207.168.375.375.375H9.5a.375.375 0 1 1 0 .75H8.375A1.125 1.125 0 0 1 7.25 2.625V1.5c0-.207.168-.375.375-.375m-5.031 3.75c0-.155.126-.281.281-.281h3.25a.281.281 0 0 1 0 .562h-3.25a.281.281 0 0 1-.281-.281m0 1.5c0-.155.126-.281.281-.281h6.25a.281.281 0 0 1 0 .562h-6.25a.281.281 0 0 1-.281-.281m0 1.5c0-.155.126-.281.281-.281h6.25a.281.281 0 0 1 0 .562h-6.25a.281.281 0 0 1-.281-.281m0 1.5c0-.155.126-.281.281-.281h4.75a.281.281 0 0 1 0 .562h-4.75a.281.281 0 0 1-.281-.281' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-text-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 16a2 2 0 0 0 2-2V4.25L9.75 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2zM9.5 1.5a.5.5 0 0 1 .5.5v1.5a.5.5 0 0 0 .5.5H12a.5.5 0 0 1 0 1h-1.5A1.5 1.5 0 0 1 9 3.5V2a.5.5 0 0 1 .5-.5m-5.375 5c0-.207.168-.375.375-.375h3a.375.375 0 1 1 0 .75h-3a.375.375 0 0 1-.375-.375m0 2c0-.207.168-.375.375-.375h7a.375.375 0 0 1 0 .75h-7a.375.375 0 0 1-.375-.375m0 2c0-.207.168-.375.375-.375h7a.375.375 0 0 1 0 .75h-7a.375.375 0 0 1-.375-.375m0 2c0-.207.168-.375.375-.375h5a.375.375 0 0 1 0 .75h-5a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-text-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3 4.594a.281.281 0 0 0 0 .562h2.625a.281.281 0 0 0 0-.562H3M3 6.094a.281.281 0 0 0 0 .562h5.875a.281.281 0 0 0 0-.562H3M3 7.594a.281.281 0 0 0 0 .562h5.875a.281.281 0 0 0 0-.562H3M3 9.094a.281.281 0 0 0 0 .562h4.375a.281.281 0 0 0 0-.562H3'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.563 0H2.625a1.5 1.5 0 0 0-1.5 1.5v9a1.5 1.5 0 0 0 1.5 1.5H9.25a1.5 1.5 0 0 0 1.5-1.5V3.188L7.563 0M2.625 11.25H9.25a.75.75 0 0 0 .75-.75V3.75H8.125A1.125 1.125 0 0 1 7 2.625V.75H2.625a.75.75 0 0 0-.75.75v9c0 .414.336.75.75.75M7.75 1.248 9.502 3H8.125a.375.375 0 0 1-.375-.375V1.248Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-text": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.5 6.125a.375.375 0 1 0 0 .75h3a.375.375 0 1 0 0-.75zM4.5 8.125a.375.375 0 1 0 0 .75h7a.375.375 0 0 0 0-.75zM4.5 10.125a.375.375 0 0 0 0 .75h7a.375.375 0 0 0 0-.75zM4.5 12.125a.375.375 0 0 0 0 .75h5a.375.375 0 0 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.75 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.25zM4 15h8a1 1 0 0 0 1-1V5h-2.5A1.5 1.5 0 0 1 9 3.5V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1m6-13.336L12.336 4H10.5a.5.5 0 0 1-.5-.5V1.664Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-plus-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.5 11.5c0 .182.049.353.134.5H2.5A1.5 1.5 0 0 1 1 10.5v-9A1.5 1.5 0 0 1 2.5 0h5.313L11 3.188V8.5h-.5v-1a1 1 0 1 0-2 0v1h-1a1 1 0 0 0 0 2h1zM8 1.5a.375.375 0 1 0-.75 0v1.125c0 .621.504 1.125 1.125 1.125H9.5a.375.375 0 1 0 0-.75H8.375A.375.375 0 0 1 8 2.625z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M9.875 7.5a.375.375 0 1 0-.75 0v1.625H7.5a.375.375 0 1 0 0 .75h1.625V11.5a.375.375 0 0 0 .75 0V9.875H11.5a.375.375 0 0 0 0-.75H9.875z'/%3e%3c/svg%3e")`,
                "file-plus-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 15.5c0 .175.03.344.085.5H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.75L14 4.25V9.5a1.5 1.5 0 0 0-3 0V11H9.5a1.5 1.5 0 0 0 0 3H11zM10 2a.5.5 0 0 0-1 0v1.5A1.5 1.5 0 0 0 10.5 5H12a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 1-.5-.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13 9.5a.5.5 0 0 0-1 0V12H9.5a.5.5 0 0 0 0 1H12v2.5a.5.5 0 0 0 1 0V13h2.5a.5.5 0 0 0 0-1H13z'/%3e%3c/svg%3e")`,
                "file-plus-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1.5A1.5 1.5 0 0 1 3 0h4.28l3.22 3.22v2.972A3.375 3.375 0 0 0 7.254 12H3a1.5 1.5 0 0 1-1.5-1.5zm6 0a.375.375 0 1 0-.75 0v1.125c0 .621.504 1.125 1.125 1.125H9A.375.375 0 1 0 9 3H7.875a.375.375 0 0 1-.375-.375z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.375a2.625 2.625 0 1 1-5.25 0 2.625 2.625 0 0 1 5.25 0M9.375 7.5c.207 0 .375.168.375.375V9h1.125a.375.375 0 0 1 0 .75H9.75v1.313a.375.375 0 0 1-.75 0V9.75H7.875a.375.375 0 1 1 0-.75H9V7.875c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-plus-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2a2 2 0 0 1 2-2h5.707L14 4.293v3.963A4.5 4.5 0 0 0 9.671 16H4a2 2 0 0 1-2-2zm8 0a.5.5 0 0 0-1 0v1.5A1.5 1.5 0 0 0 10.5 5H12a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 1-.5-.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-plus-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 1.5a.75.75 0 0 1 .75-.75H7v1.5a1.5 1.5 0 0 0 1.5 1.5H10v1.875a.375.375 0 0 0 .75 0V3.22L7.53 0H2.75a1.5 1.5 0 0 0-1.5 1.5v9a1.5 1.5 0 0 0 1.5 1.5H6a.375.375 0 0 0 0-.75H2.75A.75.75 0 0 1 2 10.5zM9.47 3 7.75 1.28v.97c0 .414.336.75.75.75h.97' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0M9.5 7.714c.197 0 .357.16.357.357v1.072h1.072a.357.357 0 0 1 0 .714H9.857v1.25a.357.357 0 1 1-.714 0v-1.25H8.07a.357.357 0 1 1 0-.714h1.072V8.07c0-.197.16-.357.357-.357' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-plus-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 2a1 1 0 0 1 1-1h5v2a2 2 0 0 0 2 2h2v2.5a.5.5 0 0 0 1 0V4.293L9.707 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h4a.5.5 0 0 0 0-1H4a1 1 0 0 1-1-1zm9.293 2L10 1.707V3a1 1 0 0 0 1 1h1.293' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-plus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.75.75A.75.75 0 0 0 2 1.5v9c0 .414.336.75.75.75H6A.375.375 0 0 1 6 12H2.75a1.5 1.5 0 0 1-1.5-1.5v-9A1.5 1.5 0 0 1 2.75 0h4.78l3.22 3.22v2.405a.375.375 0 0 1-.75 0V3.75H8.5A1.5 1.5 0 0 1 7 2.25V.75zm5 .53L9.47 3H8.5a.75.75 0 0 1-.75-.75v-.97' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M9.875 7.5a.375.375 0 1 0-.75 0v1.625H7.5a.375.375 0 1 0 0 .75h1.625V11.5a.375.375 0 0 0 .75 0V9.875H11.5a.375.375 0 0 0 0-.75H9.875z'/%3e%3c/svg%3e")`,
                "file-plus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h4a.5.5 0 0 1 0 1H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.707L14 4.293V7.5a.5.5 0 0 1-1 0V5h-2a2 2 0 0 1-2-2V1zm6 .707L12.293 4H11a1 1 0 0 1-1-1V1.707' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13 9.5a.5.5 0 0 0-1 0V12H9.5a.5.5 0 0 0 0 1H12v2.5a.5.5 0 0 0 1 0V13h2.5a.5.5 0 0 0 0-1H13z'/%3e%3c/svg%3e")`,
                "file-minus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='13' fill='none' viewBox='0 0 13 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5.75a.75.75 0 0 0-.75.75v8.75c0 .414.336.75.75.75H7a.375.375 0 0 1 0 .75H2.5a1.5 1.5 0 0 1-1.5-1.5V1.5A1.5 1.5 0 0 1 2.5 0h5.03l3.22 3.22v3.155a.375.375 0 0 1-.75 0V3.75H8.5A1.5 1.5 0 0 1 7 2.25V.75zm5.25.53L9.47 3H8.5a.75.75 0 0 1-.75-.75v-.97m.297 6.517a.375.375 0 0 1 .53 0L10 9.22l1.422-1.423a.375.375 0 0 1 .53.53L10.53 9.75l1.423 1.422a.375.375 0 0 1-.53.53L10 10.28l-1.422 1.423a.375.375 0 0 1-.53-.53L9.47 9.75 8.047 8.328a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-minus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h5a.5.5 0 0 1 0 1H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.707L14 4.293V8.5a.5.5 0 0 1-1 0V5h-2a2 2 0 0 1-2-2V1zm6 .707L12.293 4H11a1 1 0 0 1-1-1V1.707m.396 8.69a.5.5 0 0 1 .708 0L13 12.292l1.896-1.897a.5.5 0 0 1 .708.708L13.707 13l1.897 1.896a.5.5 0 0 1-.708.708L13 13.707l-1.896 1.897a.5.5 0 0 1-.708-.708L12.293 13l-1.897-1.896a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.5 12a1.5 1.5 0 0 0 1.5-1.5V3.188L7.813 0H2.5A1.5 1.5 0 0 0 1 1.5v9A1.5 1.5 0 0 0 2.5 12zM8 1.5a.375.375 0 1 0-.75 0v1.125c0 .621.504 1.125 1.125 1.125H9.5a.375.375 0 1 0 0-.75H8.375A.375.375 0 0 1 8 2.625z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 16a2 2 0 0 0 2-2V4.25L9.75 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2zM10 2a.5.5 0 0 0-1 0v1.5A1.5 1.5 0 0 0 10.5 5H12a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 1-.5-.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.604 0h4.959l3.187 3.188V10.5a1.5 1.5 0 0 1-1.5 1.5H2.604a1.5 1.5 0 0 1-1.5-1.5v-9a1.5 1.5 0 0 1 1.5-1.5M9.25 11.25H2.604a.75.75 0 0 1-.75-.75v-9a.75.75 0 0 1 .75-.75H7v1.875c0 .621.504 1.125 1.125 1.125H10v6.75a.75.75 0 0 1-.75.75M9.502 3 7.75 1.248v1.377c0 .207.168.375.375.375h1.377' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "file": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 0h5.75L14 4.25V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2m8 15H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5v2.5A1.5 1.5 0 0 0 10.5 5H13v9a1 1 0 0 1-1 1m.336-11L10 1.664V3.5a.5.5 0 0 0 .5.5h1.836' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "feather-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.28 9.75h-4.5L.64 11.89a.375.375 0 0 1-.53-.53l2.14-2.14v-4.5l3.614-3.614a3.375 3.375 0 0 1 4.773 0l.257.258a3.375 3.375 0 0 1 0 4.773l-.614.613h-4.5l4.423-4.422a.375.375 0 0 0-.53-.53L2.36 9.11a.375.375 0 0 0 .53.53L5.03 7.5h4.5L7.28 9.75'/%3e%3c/svg%3e")`,
                "feather-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.707 13h-6L.854 15.853a.5.5 0 1 1-.708-.707L3 12.293v-6l4.818-4.818a4.5 4.5 0 0 1 6.364 0l.343.343a4.5 4.5 0 0 1 0 6.364L13.707 9h-6l5.897-5.897a.5.5 0 0 0-.708-.707l-9.75 9.75a.5.5 0 1 0 .708.707L6.707 10h6l-3 3'/%3e%3c/svg%3e")`,
                "feather-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.106 1.637a2.625 2.625 0 0 0-3.712 0L3 5.03v3.44l4.61-4.61a.375.375 0 1 1 .53.53L5.78 6.75h3.44l1.143-1.144a2.625 2.625 0 0 0 0-3.712l-.257-.257M8.47 7.5H5.03L3.53 9h3.44l1.5-1.5M2.78 9.75h4.5l3.614-3.613a3.375 3.375 0 0 0 0-4.773l-.258-.258a3.375 3.375 0 0 0-4.772 0L2.25 4.72v4.5L.11 11.36a.375.375 0 1 0 .53.53l2.14-2.14' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "feather": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.475 2.182a3.5 3.5 0 0 0-4.95 0L4 6.707v4.586l6.146-6.146a.5.5 0 0 1 .708.707L7.707 9h4.586l1.525-1.525a3.5 3.5 0 0 0 0-4.95l-.343-.343M11.293 10H6.707l-2 2h4.586l2-2m-7.586 3h6l4.818-4.818a4.5 4.5 0 0 0 0-6.364l-.343-.343a4.5 4.5 0 0 0-6.364 0L3 6.293v6L.146 15.147a.5.5 0 1 0 .708.707L3.707 13' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "fast-forward-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.6 8.925 5.1 6.3c.2-.15.2-.45 0-.6L1.6 3.075a.375.375 0 0 0-.6.3v5.25c0 .309.353.485.6.3M6.6 8.925 10.1 6.3c.2-.15.2-.45 0-.6L6.6 3.075a.375.375 0 0 0-.6.3v5.25c0 .309.353.485.6.3'/%3e%3c/svg%3e")`,
                "fast-forward-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m2.3 11.9 4.667-3.5a.5.5 0 0 0 0-.8L2.3 4.1a.5.5 0 0 0-.8.4v7a.5.5 0 0 0 .8.4M9.3 11.9l4.667-3.5a.5.5 0 0 0 0-.8L9.3 4.1a.5.5 0 0 0-.8.4v7a.5.5 0 0 0 .8.4'/%3e%3c/svg%3e")`,
                "fast-forward-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.457 9.71a.375.375 0 0 1-.207-.335v-6.75a.375.375 0 0 1 .6-.3l4.5 3.375a.375.375 0 0 1 0 .6l-4.5 3.375a.375.375 0 0 1-.393.035M10.5 6 7 8.625v-5.25zM.457 2.29a.375.375 0 0 1 .393.035L5.35 5.7a.375.375 0 0 1 0 .6L.85 9.675a.375.375 0 0 1-.6-.3v-6.75c0-.142.08-.272.207-.335M4.5 6 1 8.625v-5.25z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "fast-forward": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.8 3.1a.5.5 0 0 0-.8.4v9a.5.5 0 0 0 .8.4l6-4.5A.5.5 0 0 0 8 8v4.5a.5.5 0 0 0 .8.4l6-4.5a.5.5 0 0 0 0-.8l-6-4.5a.5.5 0 0 0-.8.4V8a.5.5 0 0 0-.2-.4l-6-4.5ZM6.667 8 2 11.5v-7L6.667 8m7 0L9 11.5v-7L13.667 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "facebook-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.625C4.5 1.175 5.3 0 6.75 0h2.063c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.562.562H7.5A.375.375 0 0 0 7.125 3v1.5H8.74c.384 0 .655.376.533.74l-.625 1.5a.562.562 0 0 1-.533.385h-.99v4.313c0 .31-.252.562-.562.562h-1.5a.562.562 0 0 1-.563-.562V7.125h-.937A.563.563 0 0 1 3 6.563v-1.5c0-.311.252-.563.563-.563H4.5zM6.75.75c-1.036 0-1.5.84-1.5 1.875V5.25h-1.5v1.125h1.5v4.875h1.125V6.375H7.98l.5-1.125H6.375V3c0-.621.504-1.125 1.125-1.125h1.125V.75z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M5.25 2.625c0-1.036.464-1.875 1.5-1.875h1.875v1.125H7.5c-.621 0-1.125.504-1.125 1.125v2.25H8.48l-.5 1.125H6.375v4.875H5.25V6.375h-1.5V5.25h1.5z'/%3e%3c/svg%3e")`,
                "facebook-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.5C6 1.567 7.067 0 9 0h2.75a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H10a.5.5 0 0 0-.5.5v2h2.153a.75.75 0 0 1 .712.987l-.834 2a.75.75 0 0 1-.711.513H9.5v5.75a.75.75 0 0 1-.75.75h-2a.75.75 0 0 1-.75-.75V9.5H4.75A.75.75 0 0 1 4 8.75v-2A.75.75 0 0 1 4.75 6H6zM9 1C7.62 1 7 2.12 7 3.5V7H5v1.5h2V15h1.5V8.5h2.14l.666-1.5H8.5V4A1.5 1.5 0 0 1 10 2.5h1.5V1z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M7 3.5C7 2.12 7.62 1 9 1h2.5v1.5H10A1.5 1.5 0 0 0 8.5 4v3h2.806l-.666 1.5H8.5V15H7V8.5H5V7h2z'/%3e%3c/svg%3e")`,
                "facebook-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.625A2.625 2.625 0 0 1 7.125 0h2.063c.31 0 .562.252.562.563v1.875c0 .31-.252.562-.562.562H7.875a.375.375 0 0 0-.375.375V4.5h1.615c.384 0 .655.376.533.74l-.625 1.875a.562.562 0 0 1-.533.385H7.5v3.938c0 .31-.252.562-.562.562H5.063a.562.562 0 0 1-.563-.562V7.5h-.937A.563.563 0 0 1 3 6.938V5.063c0-.311.252-.563.563-.563H4.5zM7.125.75c-1.036 0-1.875.84-1.875 1.875V5.25h-1.5v1.5h1.5v4.5h1.5v-4.5h1.605l.5-1.5H6.75V3.375c0-.621.504-1.125 1.125-1.125H9V.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "facebook": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.5A3.5 3.5 0 0 1 9.5 0h2.75a.75.75 0 0 1 .75.75v2.5a.75.75 0 0 1-.75.75H10.5a.5.5 0 0 0-.5.5V6h2.153a.75.75 0 0 1 .712.987l-.834 2.5a.75.75 0 0 1-.711.513H10v5.25a.75.75 0 0 1-.75.75h-2.5a.75.75 0 0 1-.75-.75V10H4.75A.75.75 0 0 1 4 9.25v-2.5A.75.75 0 0 1 4.75 6H6zM9.5 1A2.5 2.5 0 0 0 7 3.5V7H5v2h2v6h2V9h2.14l.666-2H9V4.5A1.5 1.5 0 0 1 10.5 3H12V1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "eye-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.828.297a.375.375 0 1 0-.53.53l2.11 2.11C.845 4.255 0 6 0 6s2.182 4.5 6 4.5c1.15 0 2.152-.408 2.99-.98l2.182 2.183a.375.375 0 0 0 .53-.53L.829.296Zm6.224 7.285L4.448 4.978a1.875 1.875 0 0 0 2.604 2.604' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12 6s-.534 1.101-1.536 2.214L7.818 5.567a1.878 1.878 0 0 0-1.355-1.355L4.125 1.875A4.931 4.931 0 0 1 6 1.5c3.818 0 6 4.5 6 4.5'/%3e%3c/svg%3e")`,
                "eye-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.104.396a.5.5 0 1 0-.708.708L3.21 3.917C1.128 5.673 0 8 0 8s2.91 6 8 6c1.534 0 2.87-.545 3.987-1.306l2.91 2.91a.5.5 0 0 0 .707-.708L1.104.396Zm8.299 9.714L5.93 6.637a2.5 2.5 0 0 0 3.472 3.472' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 8s-.712 1.468-2.048 2.952l-3.529-3.529a2.504 2.504 0 0 0-1.806-1.806L5.5 2.5C6.262 2.189 7.097 2 8 2c5.09 0 8 6 8 6'/%3e%3c/svg%3e")`,
                "eye-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.84.86a.375.375 0 0 1 .531 0l1.83 1.83 1.754 1.734L7.53 7c.031.017.06.039.086.064L9.33 8.778a.375.375 0 0 1 .065.087l1.744 1.745a.375.375 0 1 1-.53.53l-1.6-1.6c-.832.554-1.841.96-3.01.96-1.94 0-3.44-1.117-4.43-2.182A10.51 10.51 0 0 1 .068 6.22a3.676 3.676 0 0 1-.02-.039l-.006-.01-.001-.004L.374 6a68.412 68.412 0 0 1-.336-.167l.001-.002.003-.005.01-.018a7.566 7.566 0 0 1 .166-.3c.114-.199.285-.475.51-.79a9.566 9.566 0 0 1 1.643-1.797L.84 1.391a.375.375 0 0 1 0-.531m2.066 2.593a8.76 8.76 0 0 0-1.566 1.7A9.637 9.637 0 0 0 .8 6a9.761 9.761 0 0 0 1.32 1.807C3.048 8.805 4.36 9.75 6 9.75c.937 0 1.767-.308 2.481-.76L7.334 7.841A2.25 2.25 0 0 1 4.178 4.71L2.906 3.453ZM4.72 5.249A1.5 1.5 0 0 0 6.781 7.31L4.72 5.249M.375 6l-.336-.167a.377.377 0 0 0 0 .334L.375 6ZM6 2.25c-.491 0-.951.084-1.38.23a.375.375 0 0 1-.24-.712A5.046 5.046 0 0 1 6 1.5c1.94 0 3.44 1.117 4.43 2.182a10.511 10.511 0 0 1 1.503 2.097l.02.039.006.01.001.004v.001L11.626 6l.336.167v.001l-.002.003-.005.01a4.236 4.236 0 0 1-.087.162 10.6 10.6 0 0 1-1.297 1.82.375.375 0 1 1-.56-.498A9.857 9.857 0 0 0 11.2 6a9.756 9.756 0 0 0-1.32-1.807C8.953 3.195 7.64 2.25 6 2.25M11.625 6l.336.167a.376.376 0 0 0 0-.334z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "eye-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.121 1.146a.5.5 0 0 1 .707 0l2.44 2.44 2.338 2.312 3.435 3.435c.042.023.08.052.115.086l2.285 2.285a.5.5 0 0 1 .087.116l2.326 2.326a.5.5 0 0 1-.708.708l-2.133-2.133C10.904 13.458 9.558 14 8 14c-2.588 0-4.586-1.49-5.906-2.91A14.017 14.017 0 0 1 .19 8.48a8.32 8.32 0 0 1-.127-.237l-.008-.014-.002-.005v-.001L.5 8a91.22 91.22 0 0 1-.448-.222v-.001l.002-.003.003-.006.012-.024.046-.088a13.851 13.851 0 0 1 .856-1.365c.516-.724 1.25-1.614 2.191-2.396l-2.04-2.041a.5.5 0 0 1 0-.708m2.754 3.458c-.888.722-1.591 1.568-2.089 2.267A12.85 12.85 0 0 0 1.067 8a13.011 13.011 0 0 0 1.76 2.41C4.062 11.74 5.814 13 8 13c1.25 0 2.356-.41 3.309-1.014l-1.53-1.53A3 3 0 0 1 5.57 6.28L3.874 4.604m2.417 2.395a2 2 0 0 0 2.75 2.75l-2.75-2.75M.5 8l-.448-.222a.502.502 0 0 0 0 .445L.5 8ZM8 3c-.655 0-1.268.113-1.84.305a.5.5 0 0 1-.32-.947A6.728 6.728 0 0 1 8 2c2.588 0 4.586 1.49 5.906 2.91a14.007 14.007 0 0 1 1.904 2.61 8.027 8.027 0 0 1 .127.237l.008.014.002.005v.002L15.5 8l.448.222-.001.002-.002.004-.007.013a5.334 5.334 0 0 1-.115.217 14.136 14.136 0 0 1-1.729 2.427.5.5 0 1 1-.747-.666A13.148 13.148 0 0 0 14.933 8a13.019 13.019 0 0 0-1.76-2.41C11.938 4.26 10.186 3 8 3m7.5 5 .448.222a.501.501 0 0 0 0-.444z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "eye-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1.5C2.182 1.5 0 6 0 6s2.182 4.5 6 4.5S12 6 12 6 9.818 1.5 6 1.5m1.875 4.53a1.875 1.875 0 1 1-3.75 0 1.875 1.875 0 0 1 3.75 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "eye-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2C2.91 2 0 8 0 8s2.91 6 8 6 8-6 8-6-2.91-6-8-6m2.5 6.04a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "eye-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.8 6a9.76 9.76 0 0 0 1.32 1.807C3.048 8.805 4.36 9.75 6 9.75c1.639 0 2.952-.945 3.88-1.943A9.755 9.755 0 0 0 11.2 6a9.755 9.755 0 0 0-1.32-1.807C8.952 3.195 7.64 2.25 6 2.25c-1.639 0-2.952.945-3.88 1.943A9.76 9.76 0 0 0 .8 6m10.825 0 .336-.167v-.001l-.002-.003-.006-.011a9.365 9.365 0 0 0-.388-.665c-.256-.4-.637-.935-1.136-1.47C9.44 2.616 7.942 1.5 6 1.5c-1.94 0-3.44 1.117-4.43 2.182A10.51 10.51 0 0 0 .068 5.78l-.02.039-.006.01-.001.004L.374 6l-.336-.167a.376.376 0 0 0 0 .334L.375 6l-.336.167v.001l.002.003.006.011a3.678 3.678 0 0 0 .095.178A10.51 10.51 0 0 0 1.57 8.318C2.56 9.383 4.06 10.5 6 10.5c1.94 0 3.44-1.117 4.43-2.182a10.511 10.511 0 0 0 1.503-2.097l.02-.039.006-.01.001-.004v-.001zm0 0 .336.167a.376.376 0 0 0 0-.334zM6 4.53a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3m-2.25 1.5a2.25 2.25 0 1 1 4.5 0 2.25 2.25 0 0 1-4.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "eye": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.067 8a13.011 13.011 0 0 0 1.76 2.41C4.062 11.74 5.814 13 8 13s3.937-1.26 5.174-2.59A13.001 13.001 0 0 0 14.933 8a13.003 13.003 0 0 0-1.76-2.41C11.938 4.26 10.186 3 8 3S4.063 4.26 2.826 5.59A13.014 13.014 0 0 0 1.067 8M15.5 8l.448-.222-.001-.002-.002-.005-.008-.014a5.964 5.964 0 0 0-.127-.237 14.013 14.013 0 0 0-1.904-2.61C12.586 3.49 10.588 2 8 2 5.412 2 3.414 3.49 2.094 4.91A14.014 14.014 0 0 0 .19 7.52a8.32 8.32 0 0 0-.127.237l-.008.014-.002.005v.001L.5 8l-.448-.223a.502.502 0 0 0 0 .445L.5 8l-.448.222.001.002.002.005.008.014a4.859 4.859 0 0 0 .127.237 14.017 14.017 0 0 0 1.904 2.61C3.414 12.51 5.412 14 8 14c2.588 0 4.586-1.49 5.906-2.91a14.016 14.016 0 0 0 1.904-2.61 8.027 8.027 0 0 0 .127-.237l.008-.014.002-.005v-.002zm0 0 .448.222a.502.502 0 0 0 0-.444zM8 6.04a2 2 0 1 0 0 4 2 2 0 0 0 0-4m-3 2a3 3 0 1 1 6 0 3 3 0 0 1-6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "external-link-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.5.375C7.5.168 7.668 0 7.875 0H12v4.125a.375.375 0 0 1-.75 0V1.28L5.89 6.64a.375.375 0 1 1-.53-.53L10.72.75H7.875A.375.375 0 0 1 7.5.375M1 2.938c0-.932.756-1.688 1.688-1.688h2.937a.375.375 0 1 1 0 .75H2.688a.937.937 0 0 0-.938.938v6.374c0 .518.42.938.938.938h6.374c.518 0 .938-.42.938-.937V6.374a.375.375 0 0 1 .75 0v2.938c0 .931-.756 1.687-1.687 1.687H2.686A1.687 1.687 0 0 1 1 9.313V2.936' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "external-link": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 .5a.5.5 0 0 1 .5-.5H16v5.5a.5.5 0 0 1-1 0V1.707L7.854 8.854a.5.5 0 1 1-.708-.708L14.293 1H10.5a.5.5 0 0 1-.5-.5M1 4.25A2.25 2.25 0 0 1 3.25 2H7.5a.5.5 0 0 1 0 1H3.25C2.56 3 2 3.56 2 4.25v8.5c0 .69.56 1.25 1.25 1.25h8.5c.69 0 1.25-.56 1.25-1.25V8.5a.5.5 0 0 1 1 0v4.25A2.25 2.25 0 0 1 11.75 15h-8.5A2.25 2.25 0 0 1 1 12.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "edit-3-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='13' fill='none' viewBox='0 0 12 13'%3e%3cpath fill='%230E1011' d='m9.905.937.44.44a.75.75 0 0 1 0 1.06l-1.08 1.08-1.5-1.5 1.08-1.08a.75.75 0 0 1 1.06 0M7.235 2.547l-6.11 6.11v1.5h1.5l6.11-6.11-1.5-1.5M.375 11.657c0-.207.168-.375.375-.375h10.5a.375.375 0 0 1 0 .75H.75a.375.375 0 0 1-.375-.375'/%3e%3c/svg%3e")`,
                "edit-3-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='17' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' d='m13.207 1.25.586.586a1 1 0 0 1 0 1.414l-1.44 1.44-2-2 1.44-1.44a1 1 0 0 1 1.414 0M9.646 3.396 1.5 11.543v2h2l8.146-8.147-2-2M.5 15.543a.5.5 0 0 1 .5-.5h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5'/%3e%3c/svg%3e")`,
                "edit-3-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='13' fill='none' viewBox='0 0 12 13'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.17.672a1.125 1.125 0 0 0-1.59 0L.86 8.392a.375.375 0 0 0-.11.265v1.5c0 .207.168.375.375.375h1.5c.1 0 .195-.04.265-.11l7.72-7.72c.44-.439.44-1.151 0-1.59l-.44-.44m-1.06.53a.375.375 0 0 1 .53 0l.44.44a.375.375 0 0 1 0 .53L9 3.252l-.97-.97 1.08-1.08M7.5 2.813l.97.97-6 6H1.5v-.97l6-6Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 11.282a.375.375 0 0 0 0 .75h10.5a.375.375 0 0 0 0-.75H.75'/%3e%3c/svg%3e")`,
                "edit-3": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='17' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.56.896a1.5 1.5 0 0 0-2.12 0L1.145 11.19a.5.5 0 0 0-.146.354v2a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .354-.147L14.146 3.603a1.5 1.5 0 0 0 0-2.12l-.585-.587m-1.414.707a.5.5 0 0 1 .708 0l.585.586a.5.5 0 0 1 0 .707L12 4.336l-1.293-1.293 1.44-1.44M10 3.75l1.293 1.293-8 8H2V11.75l8-8' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 15.043a.5.5 0 0 0 0 1h14a.5.5 0 1 0 0-1H1'/%3e%3c/svg%3e")`,
                "edit-2-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m11.26 1.323-.583-.584a.75.75 0 0 0-1.081.022L8.13 2.35 9.65 3.87l1.589-1.466a.75.75 0 0 0 .021-1.081M9.114 4.394 7.606 2.886 1.24 9.077a.375.375 0 0 0-.114.269V10.5c0 .207.168.375.375.375h1.154a.375.375 0 0 0 .269-.114l6.19-6.367'/%3e%3c/svg%3e")`,
                "edit-2-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m15.014 1.764-.778-.778a1 1 0 0 0-1.442.029l-1.955 2.117 2.029 2.029 2.117-1.955a1 1 0 0 0 .029-1.442M12.151 5.859l-2.01-2.01-8.49 8.254a.5.5 0 0 0-.151.358v1.54a.5.5 0 0 0 .5.5h1.539a.5.5 0 0 0 .358-.152l8.254-8.49Z'/%3e%3c/svg%3e")`,
                "edit-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.33.64C9.769.2 10.48.2 10.92.64l.44.44c.44.439.44 1.151 0 1.59l-8.47 8.47a.375.375 0 0 1-.265.11h-1.5a.375.375 0 0 1-.375-.375v-1.5c0-.1.04-.195.11-.265L9.33.64Zm1.06.53a.375.375 0 0 0-.53 0L8.405 2.625l.97.97 1.454-1.455a.375.375 0 0 0 0-.53l-.439-.44M8.845 4.125l-.97-.97L1.5 9.53v.97h.97l6.375-6.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "edit-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.44.853a1.5 1.5 0 0 1 2.12 0l.586.586a1.5 1.5 0 0 1 0 2.122L3.854 14.853A.5.5 0 0 1 3.5 15h-2a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .146-.354L12.44.853Zm1.414.708a.5.5 0 0 0-.708 0L11.207 3.5 12.5 4.793l1.94-1.94a.5.5 0 0 0 0-.707l-.586-.585M11.793 5.5 10.5 4.207l-8.5 8.5V14h1.293l8.5-8.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "edit-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.672.125a.79.79 0 0 0-.559.231L4.126 6.345v1.53h1.53l5.989-5.989a.789.789 0 0 0 .231-.558c0-.664-.539-1.203-1.203-1.203m-.028.761a.04.04 0 0 1 .028-.011c.25 0 .453.203.453.453 0 .01-.004.02-.011.028l-5.77 5.769h-.469v-.47L10.644.886Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.75 1.125c-.897 0-1.625.728-1.625 1.625v6.5c0 .898.728 1.625 1.625 1.625h6.5c.898 0 1.625-.727 1.625-1.625V6a.375.375 0 0 0-.75 0v3.25a.875.875 0 0 1-.875.875h-6.5a.875.875 0 0 1-.875-.875v-6.5c0-.483.392-.875.875-.875H6a.375.375 0 1 0 0-.75z'/%3e%3c/svg%3e")`,
                "edit": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.56.44a1.5 1.5 0 0 0-2.12 0l-1.647 1.646-.707.707-5.647 5.646c-.408.409-.704 1.25-.845 2.06A5.959 5.959 0 0 0 4.5 11.5c.303 0 .65-.032 1.001-.094.81-.141 1.651-.437 2.06-.845l8-8a1.5 1.5 0 0 0 0-2.122ZM6.147 9.145 11.793 3.5l.707.707-5.646 5.647c-.11.108-.423.286-.942.434a5.52 5.52 0 0 1-.27.07c.021-.09.044-.18.07-.27.148-.52.326-.833.434-.942ZM12.5 2.793l.707.707 1.647-1.646a.5.5 0 0 0-.707-.708l-.705-.704.704.704L12.5 2.793ZM1 3.25A2.25 2.25 0 0 1 3.25 1H8.5a.5.5 0 0 1 0 1H3.25C2.56 2 2 2.56 2 3.25v9.5c0 .69.56 1.25 1.25 1.25h9.5c.69 0 1.25-.56 1.25-1.25V7.5a.5.5 0 0 1 1 0v5.25A2.25 2.25 0 0 1 12.75 15h-9.5A2.25 2.25 0 0 1 1 12.75v-9.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "droplet-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.5 7.355C10.5 9.92 8.485 12 6 12S1.5 9.92 1.5 7.355C1.5 4.789 3.375 3.097 6 0c2.625 3.097 4.5 4.79 4.5 7.355'/%3e%3c/svg%3e")`,
                "droplet-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M14 9.806C14 13.227 11.314 16 8 16s-6-2.773-6-6.194C2 6.386 4.5 4.13 8 0c3.5 4.129 6 6.386 6 9.806'/%3e%3c/svg%3e")`,
                "droplet-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 11.25c2.049 0 3.75-1.721 3.75-3.895 0-1.073-.383-1.988-1.129-3.046-.531-.754-1.205-1.528-2.014-2.457-.195-.223-.397-.456-.607-.699-.21.243-.412.476-.607.699-.81.929-1.483 1.703-2.014 2.457C2.633 5.367 2.25 6.282 2.25 7.355c0 2.174 1.701 3.895 3.75 3.895M5.506.577l-.648.747C2.848 3.632 1.5 5.18 1.5 7.354 1.5 9.92 3.515 12 6 12s4.5-2.08 4.5-4.645c0-2.175-1.348-3.723-3.358-6.031A207.891 207.891 0 0 1 6 0c-.168.198-.332.39-.494.577Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "droplet": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 15c2.732 0 5-2.295 5-5.194 0-1.43-.51-2.65-1.505-4.061-.708-1.006-1.607-2.037-2.686-3.276-.26-.298-.529-.607-.809-.932-.28.325-.55.634-.81.932-1.078 1.239-1.977 2.27-2.685 3.276C3.51 7.156 3 8.375 3 9.806 3 12.705 5.268 15 8 15M7.342.77c-.297.344-.586.675-.865.995C3.797 4.843 2 6.906 2 9.806 2 13.227 4.686 16 8 16s6-2.773 6-6.194c0-2.9-1.797-4.963-4.477-8.04-.28-.32-.568-.652-.865-.996C8.443.52 8.224.264 8 0c-.224.264-.443.52-.658.77Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "download-cloud-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='13' fill='none' viewBox='0 0 12 13'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.25a3.75 3.75 0 0 0-2.045 6.894.375.375 0 0 1-.41.628A4.5 4.5 0 1 1 8.747 4.51a3 3 0 0 1 1.967 5.452.375.375 0 0 1-.428-.615 2.25 2.25 0 0 0-1.728-4.053l-.345.068-.091-.339A3.752 3.752 0 0 0 4.5 2.25M6.375 6c.207 0 .375.168.375.375v4.345l1.61-1.61a.375.375 0 0 1 .53.53l-2.515 2.515L3.86 9.64a.375.375 0 0 1 .53-.53L6 10.72V6.375C6 6.168 6.168 6 6.375 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "download-cloud": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='17' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a5 5 0 0 0-2.727 9.192.5.5 0 1 1-.546.837 6 6 0 1 1 8.936-7.015 4 4 0 0 1 2.623 7.269.5.5 0 1 1-.572-.82 3 3 0 0 0-2.305-5.405l-.459.092-.121-.452A5.002 5.002 0 0 0 6 3m2.5 5a.5.5 0 0 1 .5.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708L8.5 16.207l-3.354-3.353a.5.5 0 0 1 .708-.708L8 14.293V8.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "download-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 .75c.207 0 .375.168.375.375V7.72l1.61-1.61a.375.375 0 0 1 .53.53L6 9.155 3.485 6.64a.375.375 0 1 1 .53-.53l1.61 1.61V1.125c0-.207.168-.375.375-.375m-4.625 6.5c.207 0 .375.168.375.375V9.5c0 .414.336.75.75.75h7a.75.75 0 0 0 .75-.75V7.625a.375.375 0 0 1 .75 0V9.5A1.5 1.5 0 0 1 9.5 11h-7A1.5 1.5 0 0 1 1 9.5V7.625c0-.207.168-.375.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "download": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 1a.5.5 0 0 1 .5.5v8.793l2.146-2.147a.5.5 0 0 1 .708.708L8 12.207 4.646 8.854a.5.5 0 1 1 .708-.708L7.5 10.293V1.5A.5.5 0 0 1 8 1m-6.5 9a.5.5 0 0 1 .5.5V13a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0V13a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "dot-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6'/%3e%3c/svg%3e")`,
                "dot-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 12a4 4 0 1 0 0-8 4 4 0 0 0 0 8'/%3e%3c/svg%3e")`,
                "dot-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 8.25a2.25 2.25 0 1 0 0-4.5 2.25 2.25 0 0 0 0 4.5M9 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "dot": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6m4-3a4 4 0 1 1-8 0 4 4 0 0 1 8 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "dollar-sign-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.375 1.125a.375.375 0 1 0-.75 0V1.5H5.25A2.25 2.25 0 0 0 3 3.75v.06a2.25 2.25 0 0 0 1.67 2.174l.955.254V9.75H5.25a1.5 1.5 0 0 1-1.5-1.5H3a2.25 2.25 0 0 0 2.25 2.25h.375v.375a.375.375 0 0 0 .75 0V10.5h.75a2.25 2.25 0 0 0 2.25-2.25v-.06a2.25 2.25 0 0 0-1.67-2.174l-1.33-.354V2.25h.375a1.5 1.5 0 0 1 1.5 1.5H9A2.25 2.25 0 0 0 6.75 1.5h-.375zm-.75 1.125H5.25a1.5 1.5 0 0 0-1.5 1.5v.06a1.5 1.5 0 0 0 1.114 1.449l.761.203zm.75 4.188V9.75h.75a1.5 1.5 0 0 0 1.5-1.5v-.06a1.5 1.5 0 0 0-1.114-1.449l-1.136-.303' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "dollar-sign": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.5 1.5a.5.5 0 0 0-1 0V2H7a3 3 0 0 0-3 3v.08a3 3 0 0 0 2.227 2.898l1.273.34V13H7a2 2 0 0 1-2-2H4a3 3 0 0 0 3 3h.5v.5a.5.5 0 0 0 1 0V14h1a3 3 0 0 0 3-3v-.08a3 3 0 0 0-2.227-2.898L8.5 7.549V3H9a2 2 0 0 1 2 2h1a3 3 0 0 0-3-3h-.5zM7.5 3H7a2 2 0 0 0-2 2v.08a2 2 0 0 0 1.485 1.932l1.015.27zm1 5.584V13h1a2 2 0 0 0 2-2v-.08a2 2 0 0 0-1.485-1.932L8.5 8.584' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "disc-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M8.25 6a2.25 2.25 0 1 1-4.5 0 2.25 2.25 0 0 1 4.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "disc-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "disc-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.375a2.625 2.625 0 1 0 0 5.25 2.625 2.625 0 0 0 0-5.25M4.125 6a1.875 1.875 0 1 1 3.75 0 1.875 1.875 0 0 1-3.75 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "disc": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0m-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "delete-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.845 2.25a2.25 2.25 0 0 0-1.506.578L.124 5.72a.375.375 0 0 0 0 .558L3.34 9.172c.413.372.95.578 1.506.578h5.468c.931 0 1.687-.756 1.687-1.687V3.936c0-.931-.755-1.687-1.687-1.687H4.845m1.42 1.985a.375.375 0 1 0-.53.53L6.97 6 5.735 7.235a.375.375 0 1 0 .53.53L7.5 6.53l1.235 1.235a.375.375 0 0 0 .53-.53L8.03 6l1.235-1.235a.375.375 0 1 0-.53-.53L7.5 5.47 6.265 4.235' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "delete-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.46 3a3 3 0 0 0-2.008.77L.166 7.628a.5.5 0 0 0 0 .744l4.286 3.858A3 3 0 0 0 6.46 13h7.291A2.25 2.25 0 0 0 16 10.75v-5.5A2.25 2.25 0 0 0 13.75 3H6.46m1.894 2.646a.5.5 0 1 0-.708.708L9.293 8 7.646 9.646a.5.5 0 0 0 .708.708L10 8.707l1.646 1.647a.5.5 0 0 0 .708-.708L10.707 8l1.647-1.646a.5.5 0 0 0-.708-.708L10 7.293 8.354 5.646' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "delete-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.845 3a1.5 1.5 0 0 0-1.004.385L.936 6 3.84 8.615A1.5 1.5 0 0 0 4.845 9h5.468c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 10.313 3H4.845m-1.506-.172a2.25 2.25 0 0 1 1.506-.578h5.468c.931 0 1.687.756 1.687 1.688v4.124c0 .932-.755 1.688-1.687 1.688H4.845a2.25 2.25 0 0 1-1.506-.578L.124 6.28a.375.375 0 0 1 0-.558L3.34 2.828m2.396 1.407a.375.375 0 0 1 .53 0L7.5 5.47l1.235-1.235a.375.375 0 0 1 .53.53L8.03 6l1.235 1.235a.375.375 0 1 1-.53.53L7.5 6.53 6.265 7.765a.375.375 0 1 1-.53-.53L6.97 6 5.735 4.765a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "delete": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.46 4a2 2 0 0 0-1.339.513L1.247 8l3.874 3.487A2 2 0 0 0 6.46 12h7.291c.69 0 1.25-.56 1.25-1.25v-5.5C15 4.56 14.44 4 13.75 4H6.46m-2.008-.23A3 3 0 0 1 6.46 3h7.291A2.25 2.25 0 0 1 16 5.25v5.5A2.25 2.25 0 0 1 13.75 13H6.46a3 3 0 0 1-2.008-.77L.166 8.372a.5.5 0 0 1 0-.744L4.452 3.77m3.194 1.876a.5.5 0 0 1 .708 0L10 7.293l1.646-1.647a.5.5 0 0 1 .708.708L10.707 8l1.647 1.646a.5.5 0 0 1-.708.708L10 8.707l-1.646 1.647a.5.5 0 0 1-.708-.708L9.293 8 7.646 6.354a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "database-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 3.857c2.761 0 5-.64 5-1.428C11 1.639 8.761 1 6 1s-5 .64-5 1.429 2.239 1.428 5 1.428'/%3e%3cpath fill='%230E1011' d='M6 4.571c2.761 0 5-.64 5-1.428v2.5c0 .986-2.239 1.786-5 1.786s-5-.8-5-1.786v-2.5C1 3.932 3.239 4.57 6 4.57'/%3e%3cpath fill='%230E1011' d='M6 8.143c2.761 0 5-.64 5-1.429v2.5C11 10.2 8.761 11 6 11s-5-.8-5-1.786v-2.5c0 .79 2.239 1.429 5 1.429'/%3e%3c/svg%3e")`,
                "database-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 3.857c2.761 0 5-.64 5-1.428C11 1.639 8.761 1 6 1s-5 .64-5 1.429 2.239 1.428 5 1.428'/%3e%3cpath fill='%230E1011' d='M6 4.571c2.761 0 5-.64 5-1.428v2.5c0 .986-2.239 1.786-5 1.786s-5-.8-5-1.786v-2.5C1 3.932 3.239 4.57 6 4.57'/%3e%3cpath fill='%230E1011' d='M6 8.143c2.761 0 5-.64 5-1.429v2.5C11 10.2 8.761 11 6 11s-5-.8-5-1.786v-2.5c0 .79 2.239 1.429 5 1.429'/%3e%3c/svg%3e")`,
                "database-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 5c3.866 0 7-.895 7-2s-3.134-2-7-2-7 .895-7 2 3.134 2 7 2'/%3e%3cpath fill='%230E1011' d='M8 6c3.866 0 7-.895 7-2v3.5c0 1.38-3.134 2.5-7 2.5S1 8.88 1 7.5V4c0 1.105 3.134 2 7 2'/%3e%3cpath fill='%230E1011' d='M8 11c3.866 0 7-.895 7-2v3.5c0 1.38-3.134 2.5-7 2.5s-7-1.12-7-2.5V9c0 1.105 3.134 2 7 2'/%3e%3c/svg%3e")`,
                "database-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 4c3.866 0 7-.895 7-2s-3.134-2-7-2-7 .895-7 2 3.134 2 7 2'/%3e%3cpath fill='%230E1011' d='M7 5c3.866 0 7-.895 7-2v3.5c0 .223-.082.44-.236.646A5.516 5.516 0 0 0 12.5 7c-1.688 0-3.198.76-4.207 1.957C7.873 8.985 7.442 9 7 9 3.134 9 0 7.88 0 6.5V3c0 1.105 3.134 2 7 2'/%3e%3cpath fill='%230E1011' d='M7 12.5c0-.903.218-1.755.603-2.507-.198.005-.4.007-.603.007-3.866 0-7-.895-7-2v3.5C0 12.88 3.134 14 7 14l.207-.001A5.504 5.504 0 0 1 7 12.5'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "database-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.637 1.323C3.51 1.121 4.699 1 6 1c1.3 0 2.49.121 3.363.323.434.1.81.224 1.086.375.138.075.268.166.367.278a.682.682 0 0 1 .184.453c0 .064-.01.125-.027.181l.027.028v3.005a.85.85 0 0 1-.126.44L11 6.21v3.005c0 .367-.24.648-.512.845-.28.204-.66.372-1.1.507C8.505 10.837 7.308 11 6 11c-1.308 0-2.505-.163-3.388-.434-.44-.135-.82-.304-1.1-.507C1.24 9.862 1 9.581 1 9.214V6.21l.126-.125A.85.85 0 0 1 1 5.643V2.638l.027-.028A.615.615 0 0 1 1 2.43c0-.186.083-.34.184-.453.1-.112.23-.203.367-.278.276-.15.652-.275 1.086-.375M1.74 2.429a.8.8 0 0 0 .153.103c.194.106.498.212.904.306.807.186 1.94.305 3.203.305s2.396-.119 3.203-.305c.406-.094.71-.2.904-.306a.797.797 0 0 0 .153-.103.797.797 0 0 0-.153-.104c-.194-.106-.498-.212-.904-.306-.807-.186-1.94-.305-3.203-.305s-2.396.119-3.203.305c-.406.094-.71.2-.904.306a.8.8 0 0 0-.153.104m-.026 4.19v2.595c0 .029.02.123.218.268.19.138.489.278.89.401.798.246 1.921.403 3.178.403s2.38-.157 3.178-.403c.401-.123.7-.263.89-.401.198-.145.218-.24.218-.268V6.62c-.25.146-.557.27-.898.375-.883.272-2.08.435-3.388.435-1.308 0-2.505-.163-3.388-.435a4.356 4.356 0 0 1-.898-.375Zm7.65-3.085c.353-.081.668-.179.922-.294v2.403c0 .028-.02.123-.218.267-.19.139-.489.278-.89.402-.798.245-1.921.402-3.178.402s-2.38-.157-3.178-.402c-.401-.124-.7-.263-.89-.402-.198-.144-.218-.239-.218-.267V3.24c.254.115.57.213.923.294.873.202 2.062.323 3.363.323 1.3 0 2.49-.121 3.363-.323' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "database": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.5.125c-1.423 0-2.699.095-3.628.274C1.41.487 1.012.6.718.746a1.356 1.356 0 0 0-.393.277c-.111.119-.2.28-.2.477V5c0 .104.018.2.05.291l-.05.049v3.535c0 .38.247.682.531.9.293.226.697.42 1.167.579.944.318 2.236.521 3.677.521a.375.375 0 0 0 0-.75c-1.38 0-2.587-.195-3.438-.482-.427-.144-.745-.305-.948-.462C.9 9.018.875 8.91.875 8.875V6.023c.266.154.593.286.959.397.942.285 2.23.455 3.666.455s2.724-.17 3.666-.455c.47-.142.874-.319 1.169-.532.288-.208.54-.503.54-.888V1.5a.697.697 0 0 0-.2-.477 1.356 1.356 0 0 0-.393-.277C9.989.6 9.59.487 9.128.399 8.2.22 6.923.125 5.5.125M1.05 1.582A.875.875 0 0 1 .914 1.5a.875.875 0 0 1 .138-.082c.204-.101.526-.199.962-.283C2.878.97 4.103.875 5.5.875c1.398 0 2.622.094 3.487.26.436.084.758.182.962.283.064.031.108.06.138.082a.878.878 0 0 1-.138.082c-.204.101-.526.199-.962.283-.865.166-2.09.26-3.487.26-1.398 0-2.622-.094-3.487-.26-.436-.084-.758-.182-.962-.283Zm9.075.743a5.345 5.345 0 0 1-.997.276c-.929.179-2.205.274-3.628.274s-2.699-.095-3.628-.274a5.345 5.345 0 0 1-.997-.276V5c0 .03.02.129.23.28.2.145.517.292.946.422.853.258 2.064.423 3.449.423 1.385 0 2.596-.165 3.45-.423.428-.13.745-.277.946-.422.209-.151.229-.25.229-.28V2.325' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0M9.5 7.6c.22 0 .4.18.4.4v1.1H11a.4.4 0 0 1 0 .8H9.9V11a.4.4 0 0 1-.8 0V9.9H8a.4.4 0 0 1 0-.8h1.1V8c0-.22.18-.4.4-.4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "database": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.291 1.452C4.514 1.17 6.18 1 8 1c1.821 0 3.486.17 4.709.452.607.14 1.133.314 1.52.525.193.105.374.233.513.389.141.16.258.374.258.634 0 .09-.014.175-.038.254l.038.039V7.5c0 .23-.067.435-.176.617l.176.176V12.5c0 .513-.336.906-.717 1.183-.39.284-.925.52-1.54.71C11.507 14.772 9.831 15 8 15c-1.83 0-3.507-.228-4.743-.608-.615-.19-1.15-.425-1.54-.71-.38-.276-.717-.67-.717-1.182V8.293l.176-.176A1.19 1.19 0 0 1 1 7.5V3.293l.038-.039A.861.861 0 0 1 1 3c0-.26.116-.474.258-.634.139-.156.32-.284.513-.389.387-.21.913-.385 1.52-.525M2.036 3c.04.038.109.087.214.145.272.148.697.297 1.266.428C4.646 3.834 6.231 4 8 4c1.769 0 3.354-.166 4.484-.427.569-.13.994-.28 1.266-.428A1.12 1.12 0 0 0 13.964 3a1.119 1.119 0 0 0-.214-.145c-.272-.148-.697-.297-1.266-.428C11.354 2.166 9.769 2 8 2c-1.769 0-3.354.166-4.484.427-.569.13-.994.28-1.266.428A1.12 1.12 0 0 0 2.036 3M2 8.867V12.5c0 .04.027.172.305.374.267.194.684.39 1.246.562C4.668 13.78 6.24 14 8 14c1.76 0 3.332-.22 4.45-.564.56-.172.979-.368 1.245-.562.278-.202.305-.335.305-.374V8.867c-.35.203-.78.378-1.257.525C11.507 9.772 9.831 10 8 10c-1.83 0-3.507-.228-4.743-.608A6.098 6.098 0 0 1 2 8.867m10.709-4.32c.495-.113.936-.25 1.291-.41V7.5c0 .04-.027.172-.305.374-.267.194-.684.39-1.246.562C11.332 8.78 9.76 9 8 9c-1.76 0-3.332-.22-4.45-.564-.56-.172-.978-.368-1.245-.562C2.027 7.672 2 7.54 2 7.5V4.136c.355.16.796.298 1.291.412C4.514 4.83 6.18 5 8 5c1.821 0 3.486-.17 4.709-.452' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "database": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7 0C5.179 0 3.514.17 2.291.452c-.607.14-1.133.314-1.52.525a1.893 1.893 0 0 0-.513.389A.954.954 0 0 0 0 2v4.5c0 .23.067.435.176.617L0 7.293V11.5c0 .513.336.906.717 1.183.39.284.925.52 1.54.71C3.493 13.772 5.169 14 7 14a.5.5 0 0 0 0-1c-1.76 0-3.332-.22-4.45-.564-.56-.172-.978-.368-1.245-.562C1.027 11.672 1 11.54 1 11.5V7.867c.35.203.78.378 1.257.525C3.493 8.772 5.169 9 7 9c1.83 0 3.507-.228 4.743-.608.615-.19 1.15-.425 1.54-.71.38-.276.717-.67.717-1.182V2a.954.954 0 0 0-.258-.634 1.893 1.893 0 0 0-.513-.389c-.387-.21-.913-.385-1.52-.525C10.486.17 8.82 0 7 0M1.25 2.145A1.12 1.12 0 0 1 1.036 2a1.12 1.12 0 0 1 .214-.145c.272-.148.697-.297 1.266-.428C3.646 1.166 5.231 1 7 1c1.769 0 3.354.166 4.484.427.569.13.994.28 1.266.428.105.058.173.107.214.145a1.12 1.12 0 0 1-.214.145c-.272.148-.697.297-1.266.428C10.354 2.834 8.769 3 7 3c-1.769 0-3.354-.166-4.484-.427-.569-.13-.994-.28-1.266-.428M13 3.136c-.355.16-.796.298-1.291.412C10.486 3.83 8.82 4 7 4c-1.821 0-3.486-.17-4.709-.452A7.046 7.046 0 0 1 1 3.136V6.5c0 .04.027.172.305.374.267.194.684.39 1.246.562C3.668 7.78 5.24 8 7 8c1.76 0 3.332-.22 4.45-.564.56-.172.979-.368 1.245-.562.278-.202.305-.334.305-.374V3.136' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0M12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cup-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m5.65 9.252-1.526-.508A4.35 4.35 0 0 1 1.15 4.617V1c0-.47.38-.85.85-.85h8c.47 0 .85.38.85.85v3.617a4.35 4.35 0 0 1-2.974 4.127l-1.526.508v1.898H8a.35.35 0 1 1 0 .7H4a.35.35 0 1 1 0-.7h1.65V9.252M.5 2.15a.35.35 0 0 1 .35.35v3a.35.35 0 1 1-.7 0v-3a.35.35 0 0 1 .35-.35Zm11 0a.35.35 0 0 1 .35.35v3a.35.35 0 1 1-.7 0v-3a.35.35 0 0 1 .35-.35' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cup-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m5.316 11.286 2.184.596V15h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2v-3.118l2.184-.596A4.5 4.5 0 0 0 14 6.945V1.5A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v5.445a4.5 4.5 0 0 0 3.316 4.341' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0zM16 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0z'/%3e%3c/svg%3e")`,
                "cup-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 .85a.15.15 0 0 0-.15.15v3.617A3.65 3.65 0 0 0 4.346 8.08L6 8.63l1.654-.551a3.65 3.65 0 0 0 2.496-3.463V1A.15.15 0 0 0 10 .85H2Zm3.65 8.402-1.526-.508A4.35 4.35 0 0 1 1.15 4.617V1c0-.47.38-.85.85-.85h8c.47 0 .85.38.85.85v3.617a4.35 4.35 0 0 1-2.974 4.127l-1.526.508v1.898H8a.35.35 0 1 1 0 .7H4a.35.35 0 1 1 0-.7h1.65V9.252M.5 2.15a.35.35 0 0 1 .35.35v3a.35.35 0 1 1-.7 0v-3a.35.35 0 0 1 .35-.35Zm11 0a.35.35 0 0 1 .35.35v3a.35.35 0 1 1-.7 0v-3a.35.35 0 0 1 .35-.35' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cup": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m5.316 11.286 2.184.596V15h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2v-3.118l2.184-.596A4.5 4.5 0 0 0 14 6.945V1.5A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v5.445a4.5 4.5 0 0 0 3.316 4.341M3 1.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v5.445a3.5 3.5 0 0 1-2.58 3.377l-2.42.66-2.42-.66A3.5 3.5 0 0 1 3 6.945z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0zM16 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0z'/%3e%3c/svg%3e")`,
                "crosshair-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.625 9.25v1.61a4.876 4.876 0 0 1-4.486-4.485H2.75a.375.375 0 1 0 0-.75H1.14a4.876 4.876 0 0 1 4.485-4.486V2.75a.375.375 0 1 0 .75 0V1.14a4.876 4.876 0 0 1 4.486 4.485H9.25a.375.375 0 1 0 0 .75h1.61a4.876 4.876 0 0 1-4.485 4.486V9.25a.375.375 0 1 0-.75 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M.75 6a5.25 5.25 0 1 0 10.5 0A5.25 5.25 0 0 0 .75 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "crosshair-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.571 11.714v1.841A5.573 5.573 0 0 1 2.445 8.43h1.84a.429.429 0 1 0 0-.858h-1.84A5.573 5.573 0 0 1 7.57 2.445v1.84a.429.429 0 1 0 .858 0v-1.84a5.573 5.573 0 0 1 5.126 5.126h-1.84a.429.429 0 1 0 0 .858h1.84a5.573 5.573 0 0 1-5.126 5.126v-1.84a.429.429 0 1 0-.858 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M2 8a6 6 0 1 0 12 0A6 6 0 0 0 2 8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "crosshair-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.763 5.625H2.25a.375.375 0 1 1 0 .75H.763a5.25 5.25 0 0 0 4.862 4.862V9.75a.375.375 0 1 1 .75 0v1.487a5.25 5.25 0 0 0 4.862-4.862H9.75a.375.375 0 1 1 0-.75h1.487A5.25 5.25 0 0 0 6.375.763V2.25a.375.375 0 1 1-.75 0V.763A5.25 5.25 0 0 0 .763 5.625ZM0 6a6 6 0 1 1 12 0A6 6 0 0 1 0 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "crosshair": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M7.5 14.28V13a.5.5 0 0 1 1 0v1.28a6.3 6.3 0 0 0 5.775-5.78H13a.5.5 0 0 1 0-1h1.275A6.3 6.3 0 0 0 8.5 1.72V3a.5.5 0 0 1-1 0V1.72A6.3 6.3 0 0 0 1.715 7.5H3a.5.5 0 1 1 0 1H1.715A6.3 6.3 0 0 0 7.5 14.28' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "crop-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1.125a.375.375 0 1 0-.75 0V2.25H1.125a.375.375 0 1 0 0 .75H2.25v5.063c0 .931.756 1.687 1.688 1.687H9v1.125a.375.375 0 0 0 .75 0V9.75h1.125a.375.375 0 0 0 0-.75H9.75V3.938c0-.932-.756-1.688-1.687-1.688H3zM3 3v5.063c0 .517.42.937.938.937H9V3.938A.937.937 0 0 0 8.063 3z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "crop": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 1.5a.5.5 0 0 0-1 0V3H1.5a.5.5 0 0 0 0 1H3v6.75A2.25 2.25 0 0 0 5.25 13H12v1.5a.5.5 0 0 0 1 0V13h1.5a.5.5 0 0 0 0-1H13V5.25A2.25 2.25 0 0 0 10.75 3H4zM4 4v6.75c0 .69.56 1.25 1.25 1.25H12V5.25C12 4.56 11.44 4 10.75 4z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "credit-card-plus-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.75 7.5A.25.25 0 0 1 2 7.25h3.5a.25.25 0 0 1 0 .5H2a.25.25 0 0 1-.25-.25M1.75 9A.25.25 0 0 1 2 8.75h1.5a.25.25 0 0 1 0 .5H2A.25.25 0 0 1 1.75 9'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5v7A1.5 1.5 0 0 0 1.5 11h4.125a.375.375 0 0 0 0-.75H1.5a.75.75 0 0 1-.75-.75v-4h10.5v1.125a.375.375 0 0 0 .75 0V2.5A1.5 1.5 0 0 0 10.5 1zm0 .75h9a.75.75 0 0 1 .75.75v1H.75v-1a.75.75 0 0 1 .75-.75' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M9.875 7.5a.375.375 0 1 0-.75 0v1.625H7.5a.375.375 0 1 0 0 .75h1.625V11.5a.375.375 0 0 0 .75 0V9.875H11.5a.375.375 0 0 0 0-.75H9.875z'/%3e%3c/svg%3e")`,
                "credit-card-plus": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 9.125a.375.375 0 1 0 0 .75h5a.375.375 0 1 0 0-.75zM2.5 11.125a.375.375 0 0 0 0 .75h2a.375.375 0 0 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.25A2.25 2.25 0 0 1 2.25 2h11.5A2.25 2.25 0 0 1 16 4.25V9.5a.5.5 0 0 1-1 0V7H1v4.75c0 .69.56 1.25 1.25 1.25H6.5a.5.5 0 0 1 0 1H2.25A2.25 2.25 0 0 1 0 11.75zm1 0C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25V5H1z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12.5 9a.5.5 0 0 1 .5.5V12h2.5a.5.5 0 0 1 0 1H13v2.5a.5.5 0 0 1-1 0V13H9.5a.5.5 0 0 1 0-1H12V9.5a.5.5 0 0 1 .5-.5'/%3e%3c/svg%3e")`,
                "credit-card-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5v7A1.5 1.5 0 0 0 1.5 11h9A1.5 1.5 0 0 0 12 9.5v-7A1.5 1.5 0 0 0 10.5 1zM11 5.5H1v-2h10zm-9.25 2A.25.25 0 0 1 2 7.25h3.5a.25.25 0 0 1 0 .5H2a.25.25 0 0 1-.25-.25m0 1.5A.25.25 0 0 1 2 8.75h1.5a.25.25 0 0 1 0 .5H2A.25.25 0 0 1 1.75 9' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "credit-card-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2zM1 7V5h14v2zm1.125 2.5c0-.207.168-.375.375-.375h5a.375.375 0 1 1 0 .75h-5a.375.375 0 0 1-.375-.375m0 2c0-.207.168-.375.375-.375h2a.375.375 0 0 1 0 .75h-2a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "credit-card-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.75 7.5A.25.25 0 0 1 2 7.25h3.5a.25.25 0 0 1 0 .5H2a.25.25 0 0 1-.25-.25M1.75 9A.25.25 0 0 1 2 8.75h1.5a.25.25 0 0 1 0 .5H2A.25.25 0 0 1 1.75 9'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5v7A1.5 1.5 0 0 0 1.5 11h9A1.5 1.5 0 0 0 12 9.5v-7A1.5 1.5 0 0 0 10.5 1zm9 .75h-9a.75.75 0 0 0-.75.75v1h10.5v-1a.75.75 0 0 0-.75-.75m.75 3.75H.75v4c0 .414.336.75.75.75h9a.75.75 0 0 0 .75-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "credit-card": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 9.125a.375.375 0 1 0 0 .75h5a.375.375 0 1 0 0-.75zM2.5 11.125a.375.375 0 0 0 0 .75h2a.375.375 0 0 0 0-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.25A2.25 2.25 0 0 1 2.25 2h11.5A2.25 2.25 0 0 1 16 4.25v7.5A2.25 2.25 0 0 1 13.75 14H2.25A2.25 2.25 0 0 1 0 11.75zM2.25 3C1.56 3 1 3.56 1 4.25V5h14v-.75C15 3.56 14.44 3 13.75 3zM1 11.75V7h14v4.75c0 .69-.56 1.25-1.25 1.25H2.25C1.56 13 1 12.44 1 11.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cpu-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.75 1.266v-1H4v1H2.938c-.932 0-1.688.755-1.688 1.687v1.063h-1v.75h1V7.25h-1V8h1v1.063c0 .931.756 1.687 1.688 1.687H4v1h.75v-1h2.5v1H8v-1h1.063c.931 0 1.687-.756 1.687-1.687V8h1v-.75h-1V4.766h1v-.75h-1V2.953c0-.932-.756-1.687-1.687-1.687H8v-1h-.75v1h-2.5M4 4.75A.75.75 0 0 1 4.75 4h2.5a.75.75 0 0 1 .75.75v2.5a.75.75 0 0 1-.75.75h-2.5A.75.75 0 0 1 4 7.25zM5 5h2v2H5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cpu-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 6h4v4H6z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1h4V0h1v1h1.5A2.5 2.5 0 0 1 15 3.5V5h1v1h-1v4h1v1h-1v1.5a2.5 2.5 0 0 1-2.5 2.5H11v1h-1v-1H6v1H5v-1H3.5A2.5 2.5 0 0 1 1 12.5V11H0v-1h1V6H0V5h1V3.5A2.5 2.5 0 0 1 3.5 1H5V0h1zm0 4a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cpu-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 4.75A.75.75 0 0 1 4.75 4h2.5a.75.75 0 0 1 .75.75v2.5a.75.75 0 0 1-.75.75h-2.5A.75.75 0 0 1 4 7.25zm3.25 0h-2.5v2.5h2.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.75.266v1h2.5v-1H8v1h1.063c.931 0 1.687.755 1.687 1.687v1.063h1v.75h-1V7.25h1V8h-1v1.063c0 .931-.756 1.687-1.687 1.687H8v1h-.75v-1h-2.5v1H4v-1H2.938A1.688 1.688 0 0 1 1.25 9.063V8h-1v-.75h1V4.766h-1v-.75h1V2.953c0-.932.756-1.687 1.688-1.687H4v-1h.75M2 9.063c0 .517.42.937.938.937h6.124c.518 0 .938-.42.938-.937v-6.11a.938.938 0 0 0-.937-.937H2.936A.938.938 0 0 0 2 2.953v6.11' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cpu": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 6a1 1 0 0 1 1-1h4a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1zm5 0H6v4h4z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1h4V0h1v1h1.5A2.5 2.5 0 0 1 15 3.5V5h1v1h-1v4h1v1h-1v1.5a2.5 2.5 0 0 1-2.5 2.5H11v1h-1v-1H6v1H5v-1H3.5A2.5 2.5 0 0 1 1 12.5V11H0v-1h1V6H0V5h1V3.5A2.5 2.5 0 0 1 3.5 1H5V0h1zm6.5 1h-9A1.5 1.5 0 0 0 2 3.5v9A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 12.5 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-up-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.205 1.36a.375.375 0 0 0 0 .53l2.36 2.36h-5.47a3 3 0 0 0-3 3v3.375a.375.375 0 0 0 .75 0V7.25A2.25 2.25 0 0 1 4.095 5h5.47l-2.36 2.36a.375.375 0 1 0 .53.53L11 4.625 7.735 1.36a.375.375 0 0 0-.53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-up-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.146 2.146a.5.5 0 0 0 0 .708L13.293 6H6a4 4 0 0 0-4 4v4.5a.5.5 0 0 0 1 0V10a3 3 0 0 1 3-3h7.293l-3.147 3.146a.5.5 0 0 0 .708.708L15.207 6.5l-4.353-4.354a.5.5 0 0 0-.708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-up-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.89 1.11a.375.375 0 0 1 0 .53L2.53 4H8a3 3 0 0 1 3 3v3.375a.375.375 0 0 1-.75 0V7A2.25 2.25 0 0 0 8 4.75H2.53l2.36 2.36a.375.375 0 1 1-.53.53L1.095 4.375 4.36 1.11a.375.375 0 0 1 .53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-up-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.854 2.146a.5.5 0 0 1 0 .708L2.707 6H10a4 4 0 0 1 4 4v4.5a.5.5 0 1 1-1 0V10a3 3 0 0 0-3-3H2.707l3.147 3.146a.5.5 0 0 1-.708.708L.793 6.5l4.353-4.354a.5.5 0 0 1 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-right-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 4.796a.375.375 0 0 1-.53 0l-2.36-2.36v5.47a3 3 0 0 1-3 3H1.735a.375.375 0 0 1 0-.75H5.11a2.25 2.25 0 0 0 2.25-2.25v-5.47L5 4.796a.375.375 0 0 1-.53-.53L7.735 1 11 4.265a.375.375 0 0 1 0 .53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-right-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 5.854a.5.5 0 0 1-.708 0L11 2.707V10a4 4 0 0 1-4 4H2.5a.5.5 0 0 1 0-1H7a3 3 0 0 0 3-3V2.707L6.854 5.854a.5.5 0 1 1-.708-.707L10.5.793l4.354 4.354a.5.5 0 0 1 0 .707' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-right-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.64 7.11a.375.375 0 0 0-.53 0L7.75 9.47V4a3 3 0 0 0-3-3H1.375a.375.375 0 1 0 0 .75H4.75A2.25 2.25 0 0 1 7 4v5.47L4.64 7.11a.375.375 0 0 0-.53.53l3.265 3.265L10.64 7.64a.375.375 0 0 0 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-right-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 10.146a.5.5 0 0 0-.708 0L11 13.293V6a4 4 0 0 0-4-4H2.5a.5.5 0 0 0 0 1H7a3 3 0 0 1 3 3v7.293l-3.146-3.147a.5.5 0 0 0-.708.708l4.354 4.353 4.354-4.353a.5.5 0 0 0 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-left-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 4.796a.375.375 0 0 0 .53 0l2.36-2.36v5.47a3 3 0 0 0 3 3h3.375a.375.375 0 0 0 0-.75H7.25A2.25 2.25 0 0 1 5 7.905v-5.47l2.36 2.36a.375.375 0 0 0 .53-.53L4.625 1 1.36 4.265a.375.375 0 0 0 0 .53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-left-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.146 5.854a.5.5 0 0 0 .708 0L5 2.707V10a4 4 0 0 0 4 4h4.5a.5.5 0 0 0 0-1H9a3 3 0 0 1-3-3V2.707l3.146 3.147a.5.5 0 1 0 .708-.707L5.5.793 1.146 5.147a.5.5 0 0 0 0 .707' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-left-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 7.205a.375.375 0 0 1 .53 0l2.36 2.36v-5.47a3 3 0 0 1 3-3h3.375a.375.375 0 0 1 0 .75H7.25A2.25 2.25 0 0 0 5 4.095v5.47l2.36-2.36a.375.375 0 1 1 .53.53L4.625 11 1.36 7.735a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-left-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.146 9.146a.5.5 0 0 1 .708 0L5 12.293V5a4 4 0 0 1 4-4h4.5a.5.5 0 0 1 0 1H9a3 3 0 0 0-3 3v7.293l3.146-3.147a.5.5 0 1 1 .708.708L5.5 14.207 1.146 9.854a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-down-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.205 10.64a.375.375 0 0 1 0-.53l2.36-2.36h-5.47a3 3 0 0 1-3-3V1.375a.375.375 0 1 1 .75 0V4.75A2.25 2.25 0 0 0 4.095 7h5.47l-2.36-2.36a.375.375 0 1 1 .53-.53L11 7.375 7.735 10.64a.375.375 0 0 1-.53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-down-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.146 13.854a.5.5 0 0 1 0-.708L13.293 10H6a4 4 0 0 1-4-4V1.5a.5.5 0 0 1 1 0V6a3 3 0 0 0 3 3h7.293l-3.147-3.146a.5.5 0 0 1 .708-.708L15.207 9.5l-4.353 4.354a.5.5 0 0 1-.708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-down-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.796 10.64a.375.375 0 0 0 0-.53l-2.36-2.36h5.47a3 3 0 0 0 3-3V1.375a.375.375 0 1 0-.75 0V4.75A2.25 2.25 0 0 1 7.905 7h-5.47l2.36-2.36a.375.375 0 1 0-.53-.53L1 7.375l3.265 3.265a.375.375 0 0 0 .53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "corner-down-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.854 13.854a.5.5 0 0 0 0-.708L2.707 10H10a4 4 0 0 0 4-4V1.5a.5.5 0 0 0-1 0V6a3 3 0 0 1-3 3H2.707l3.147-3.146a.5.5 0 0 0-.708-.708L.793 9.5l4.353 4.354a.5.5 0 0 0 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "copy-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.75 2.273c0-.286.232-.518.518-.518h4.464c.286 0 .518.232.518.518V2.5a.375.375 0 0 0 .75 0v-.227c0-.7-.568-1.268-1.268-1.268H2.268c-.7 0-1.268.568-1.268 1.268v4.464c0 .7.568 1.268 1.268 1.268H2.5a.375.375 0 1 0 0-.75h-.232a.518.518 0 0 1-.518-.518V2.273Z'/%3e%3cpath fill='%230E1011' d='M5.5 11h4A1.5 1.5 0 0 0 11 9.5v-4A1.5 1.5 0 0 0 9.5 4h-4A1.5 1.5 0 0 0 4 5.5v4A1.5 1.5 0 0 0 5.5 11'/%3e%3c/svg%3e")`,
                "copy-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h.5a.5.5 0 0 0 0-1H3a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v.5a.5.5 0 0 0 1 0V3a2 2 0 0 0-2-2z'/%3e%3cpath fill='%230E1011' d='M7 5a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2z'/%3e%3c/svg%3e")`,
                "copy-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.75 2.273c0-.286.232-.518.518-.518h4.464c.286 0 .518.232.518.518V2.5a.375.375 0 0 0 .75 0v-.227c0-.7-.568-1.268-1.268-1.268H2.268c-.7 0-1.268.568-1.268 1.268v4.464c0 .7.568 1.268 1.268 1.268H2.5a.375.375 0 1 0 0-.75h-.232a.518.518 0 0 1-.518-.518V2.273Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.5 11h4A1.5 1.5 0 0 0 11 9.5v-4A1.5 1.5 0 0 0 9.5 4h-4A1.5 1.5 0 0 0 4 5.5v4A1.5 1.5 0 0 0 5.5 11m4-.75h-4a.75.75 0 0 1-.75-.75v-4a.75.75 0 0 1 .75-.75h4a.75.75 0 0 1 .75.75v4a.75.75 0 0 1-.75.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "copy": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h.5a.5.5 0 0 0 0-1H3a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v.5a.5.5 0 0 0 1 0V3a2 2 0 0 0-2-2z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7 5a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2zM6 7a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v6a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "compass-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='m4.778 7.222.84-1.604 1.604-.84-.84 1.604-1.604.84'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-6.937-.937L9 3 6.938 6.938 3 9l2.063-3.937' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "compass-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m6.37 9.63 1.12-2.14 2.14-1.12-1.12 2.14-2.14 1.12'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0M6.75 6.75 12 4 9.25 9.25 4 12z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "compass-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.063 5.063 9 3 6.938 6.938 3 9l2.063-3.937m-.285 2.159.84-1.604 1.604-.84-.84 1.604-1.604.84' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "compass": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4 6.75 6.75 4 12l5.25-2.75L12 4M7.49 7.49 6.37 9.63l2.14-1.12 1.12-2.14-2.14 1.12' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0m-1 0A6.3 6.3 0 1 0 1.695 8a6.3 6.3 0 0 0 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "command-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.964a1.964 1.964 0 1 1 3.929 0v1.25H7.07v-1.25A1.964 1.964 0 1 1 9.036 4.93h-1.25V7.07h1.25A1.964 1.964 0 1 1 7.07 9.036v-1.25H4.93v1.25A1.964 1.964 0 1 1 2.964 7.07h1.25V4.93h-1.25A1.964 1.964 0 0 1 1 2.964m3.214 1.25v-1.25a1.25 1.25 0 1 0-1.25 1.25h1.25m.715.715V7.07H7.07V4.93H4.93m-.715 2.857h-1.25a1.25 1.25 0 1 0 1.25 1.25v-1.25m3.572 0v1.25a1.25 1.25 0 1 0 1.25-1.25h-1.25m0-3.572h1.25a1.25 1.25 0 1 0-1.25-1.25v1.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "command": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.75a2.75 2.75 0 0 1 5.5 0V5.5h3V3.75a2.75 2.75 0 1 1 2.75 2.75H10.5v3h1.75a2.75 2.75 0 1 1-2.75 2.75V10.5h-3v1.75A2.75 2.75 0 1 1 3.75 9.5H5.5v-3H3.75A2.75 2.75 0 0 1 1 3.75M5.5 5.5V3.75A1.75 1.75 0 1 0 3.75 5.5zm1 1v3h3v-3zm-1 4H3.75a1.75 1.75 0 1 0 1.75 1.75zm5 0v1.75a1.75 1.75 0 1 0 1.75-1.75zm0-5h1.75a1.75 1.75 0 1 0-1.75-1.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "columns-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M2.5 0A1.5 1.5 0 0 0 1 1.5v9A1.5 1.5 0 0 0 2.5 12h1A1.5 1.5 0 0 0 5 10.5v-9A1.5 1.5 0 0 0 3.5 0zM8.5 0A1.5 1.5 0 0 0 7 1.5v9A1.5 1.5 0 0 0 8.5 12h1a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 9.5 0z'/%3e%3c/svg%3e")`,
                "columns-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.923 15H2.077A1.077 1.077 0 0 1 1 13.923V2.077C1 1.482 1.482 1 2.077 1h3.846C6.518 1 7 1.482 7 2.077v11.846C7 14.518 6.518 15 5.923 15M13.923 15h-3.846A1.077 1.077 0 0 1 9 13.923V2.077C9 1.482 9.482 1 10.077 1h3.846C14.518 1 15 1.482 15 2.077v11.846c0 .595-.482 1.077-1.077 1.077'/%3e%3c/svg%3e")`,
                "columns-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 1.5A1.5 1.5 0 0 1 2.5 0h1A1.5 1.5 0 0 1 5 1.5v9A1.5 1.5 0 0 1 3.5 12h-1A1.5 1.5 0 0 1 1 10.5zM2.5 1h1a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5M7 1.5A1.5 1.5 0 0 1 8.5 0h1A1.5 1.5 0 0 1 11 1.5v9A1.5 1.5 0 0 1 9.5 12h-1A1.5 1.5 0 0 1 7 10.5zM8.5 1h1a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "columns": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 13.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5zm.5 1.5A1.5 1.5 0 0 1 1 13.5v-11A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v11A1.5 1.5 0 0 1 5.5 15zm7.5-1.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5zm.5 1.5A1.5 1.5 0 0 1 9 13.5v-11A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v11a1.5 1.5 0 0 1-1.5 1.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "coffee-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.625 1.125c.207 0 .375.168.375.375V3a.375.375 0 1 1-.75 0V1.5c0-.207.168-.375.375-.375m2.25 0c.207 0 .375.168.375.375V3a.375.375 0 1 1-.75 0V1.5c0-.207.168-.375.375-.375m2.25 0c.207 0 .375.168.375.375V3a.375.375 0 1 1-.75 0V1.5c0-.207.168-.375.375-.375M1.5 5.25A.75.75 0 0 0 .75 6v3a1.5 1.5 0 0 0 1.5 1.5H7.5A1.5 1.5 0 0 0 9 9V5.25zm8.25 0v2.768l1.085-.542a.75.75 0 0 0 .415-.671V6a.75.75 0 0 0-.75-.75zm0 3.607 1.42-.71A1.5 1.5 0 0 0 12 6.804V6a1.5 1.5 0 0 0-1.5-1.5h-9A1.5 1.5 0 0 0 0 6v3a2.25 2.25 0 0 0 2.25 2.25H7.5A2.25 2.25 0 0 0 9.75 9v-.143' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.75 6a.75.75 0 0 1 .75-.75H9V9a1.5 1.5 0 0 1-1.5 1.5H2.25A1.5 1.5 0 0 1 .75 9z'/%3e%3c/svg%3e")`,
                "coffee-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5.5A.5.5 0 0 1 4 1v2a.5.5 0 0 1-1 0V1a.5.5 0 0 1 .5-.5m3 0A.5.5 0 0 1 7 1v2a.5.5 0 0 1-1 0V1a.5.5 0 0 1 .5-.5m3 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0V1a.5.5 0 0 1 .5-.5M2 6a1 1 0 0 0-1 1v4a2 2 0 0 0 2 2h7a2 2 0 0 0 2-2V6zm11 0v3.691l1.447-.724A1 1 0 0 0 15 8.073V7a1 1 0 0 0-1-1zm0 4.809 1.894-.947A2 2 0 0 0 16 8.073V7a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v4a3 3 0 0 0 3 3h7a3 3 0 0 0 3-3z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 7a1 1 0 0 1 1-1h10v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2z'/%3e%3c/svg%3e")`,
                "coffee-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3 .5a.375.375 0 1 0-.75 0v2.125a.375.375 0 1 0 .75 0zM5 .5a.375.375 0 1 0-.75 0v2.125a.375.375 0 1 0 .75 0zM7 .5a.375.375 0 1 0-.75 0v2.125a.375.375 0 1 0 .75 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m11.17 8.146-1.42.46v.144A2.25 2.25 0 0 1 7.5 11H2.25A2.25 2.25 0 0 1 0 8.75v-3a1.5 1.5 0 0 1 1.5-1.5h9a1.5 1.5 0 0 1 1.5 1.5v1.055a1.5 1.5 0 0 1-.83 1.341M.75 5.75A.75.75 0 0 1 1.5 5H9v3.75a1.5 1.5 0 0 1-1.5 1.5H2.25a1.5 1.5 0 0 1-1.5-1.5zm9 2.268V5h.75a.75.75 0 0 1 .75.75v1.055a.75.75 0 0 1-.415.67l-1.085.543' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "coffee": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4 1a.5.5 0 0 0-1 0v2a.5.5 0 0 0 1 0zM7 1a.5.5 0 0 0-1 0v2a.5.5 0 0 0 1 0zM10 1a.5.5 0 0 0-1 0v2a.5.5 0 0 0 1 0z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.894 9.862 13 10.809V11a3 3 0 0 1-3 3H3a3 3 0 0 1-3-3V7a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1.073a2 2 0 0 1-1.106 1.789M1 7a1 1 0 0 1 1-1h10v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2zm12 2.691V6h1a1 1 0 0 1 1 1v1.073a1 1 0 0 1-.553.894L13 9.691' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "codepen-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.82 1.17a.375.375 0 0 1 .36 0l5.5 3c.12.067.195.193.195.33v3a.375.375 0 0 1-.195.33l-5.5 3a.375.375 0 0 1-.36 0l-5.5-3a.375.375 0 0 1-.195-.33v-3c0-.137.075-.263.195-.33l5.5-3ZM.875 6.955V5.046L2.624 6l-1.749.954m.33.503L5.7 9.91V7.68L3.25 6.341 1.205 7.457ZM3.877 6 6 7.158 8.124 6 6 4.842 3.877 6m4.873.342L6.3 7.678V9.91l4.495-2.452L8.75 6.342m2.375.612L9.377 6l1.748-.954v1.908M8.75 5.658 6.3 4.322V2.09l4.495 2.452L8.75 5.658M5.7 2.091 1.205 4.543 3.25 5.658 5.7 4.322V2.09' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "codepen": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.654 1.084a.75.75 0 0 1 .708 0l7.225 3.867a.75.75 0 0 1 .396.66v4.701a.75.75 0 0 1-.396.662L8.362 14.84a.75.75 0 0 1-.708 0L.43 10.974a.75.75 0 0 1-.396-.662v-4.7A.75.75 0 0 1 .43 4.95l7.225-3.867M1.545 5.488l5.963-3.191v3.382l-2.822 1.7-3.14-1.891Zm-.512.859v3.23l2.684-1.615-2.684-1.615m3.653 2.199-3.14 1.89 5.962 3.191v-3.382l-2.822-1.7m3.822 5.081 5.963-3.19-3.14-1.891-2.823 1.699v3.382M12.3 7.962l2.683 1.615v-3.23L12.3 7.962m2.171-2.474-3.14 1.89L8.507 5.68V2.297l5.963 3.19m-4.11 2.474L8.008 9.378 5.655 7.962l2.353-1.416 2.353 1.416' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "code-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.265 3.265a.375.375 0 0 0-.53-.53l-3 3a.375.375 0 0 0 0 .53l3 3a.375.375 0 0 0 .53-.53L1.53 6l2.735-2.735M8.265 2.735a.375.375 0 0 0-.53.53L10.469 6 7.736 8.735a.375.375 0 0 0 .53.53l3-3a.375.375 0 0 0 0-.53l-3-3'/%3e%3c/svg%3e")`,
                "code": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.687 4.354a.5.5 0 1 0-.708-.708l-4 4a.5.5 0 0 0 0 .708l4 4a.5.5 0 0 0 .708-.708L2.04 8l3.647-3.646M11.02 3.646a.5.5 0 1 0-.707.708L13.959 8l-3.646 3.646a.5.5 0 0 0 .707.708l4-4a.5.5 0 0 0 0-.708l-4-4'/%3e%3c/svg%3e")`,
                "cloud-snow-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' height='13' fill='none' viewBox='0 0 12 13'%3e%3cpath fill='%230E1011' d='M.875 5.5a3.625 3.625 0 0 1 6.788-1.773l.13.23.26-.044a2.625 2.625 0 1 1 .885 5.176l.124.74a3.376 3.376 0 0 0-.878-6.69 4.375 4.375 0 1 0-4.23 6.702l.092-.744A3.626 3.626 0 0 1 .875 5.5'/%3e%3cpath fill='%230E1011' d='M5.75 8.5a.25.25 0 0 0-.5 0V9a.25.25 0 0 0 .5 0zM7.75 8.5a.25.25 0 0 0-.5 0V9a.25.25 0 0 0 .5 0zM6.75 9.5a.25.25 0 0 0-.5 0v.5a.25.25 0 1 0 .5 0zM5.75 10.5a.25.25 0 1 0-.5 0v.5a.25.25 0 1 0 .5 0zM7.75 10.5a.25.25 0 1 0-.5 0v.5a.25.25 0 1 0 .5 0zM6.75 11.5a.25.25 0 1 0-.5 0v.75h.5z'/%3e%3c/svg%3e")`,
                "cloud-snow": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 1.234 5.873.5.5 0 1 0 .213.977 4.001 4.001 0 0 0-1.194-7.894A6.002 6.002 0 0 0 0 8a6.002 6.002 0 0 0 3.818 5.59.5.5 0 1 0 .364-.93A5.002 5.002 0 0 1 1 8'/%3e%3cpath fill='%230E1011' d='M6.875 10.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM10.875 10.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM8.875 11a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM6.875 12.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM10.875 12.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM8.875 13a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM6.875 14.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM10.875 14.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0zM8.875 15a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0z'/%3e%3c/svg%3e")`,
                "cloud-rain-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.875 5.5a3.625 3.625 0 0 1 6.788-1.773l.13.23.26-.044a2.625 2.625 0 1 1 .885 5.176l.124.74a3.376 3.376 0 0 0-.878-6.69 4.375 4.375 0 1 0-4.23 6.702l.092-.744A3.626 3.626 0 0 1 .875 5.5'/%3e%3cpath fill='%230E1011' d='M5.25 8v3h.5V8zM7.25 9v3h.5V9z'/%3e%3c/svg%3e")`,
                "cloud-rain": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 1.234 5.873.5.5 0 1 0 .213.977 4.001 4.001 0 0 0-1.194-7.894A6.002 6.002 0 0 0 0 8a6.002 6.002 0 0 0 3.818 5.59.5.5 0 1 0 .364-.93A5.002 5.002 0 0 1 1 8'/%3e%3cpath fill='%230E1011' d='M6.875 10.5a.375.375 0 0 0-.75 0v4a.375.375 0 0 0 .75 0zM10.875 10.5a.375.375 0 0 0-.75 0v4a.375.375 0 0 0 .75 0zM8.875 11.5a.375.375 0 0 0-.75 0v4a.375.375 0 0 0 .75 0z'/%3e%3c/svg%3e")`,
                "cloud-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.765.235a.375.375 0 1 0-.53.53l1.768 1.768A3.998 3.998 0 0 0 0 6v.5A4.5 4.5 0 0 0 4.5 11H8v-.036a3.524 3.524 0 0 0 2.089-.345l1.146 1.146a.375.375 0 0 0 .53-.53l-11-11ZM12 7.5c0 .58-.141 1.127-.391 1.609L4.536 2.036a4.003 4.003 0 0 1 3.003 2.098A3.502 3.502 0 0 1 12 7.5'/%3e%3c/svg%3e")`,
                "cloud-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.396.396a.5.5 0 0 1 .708 0l14.5 14.5a.5.5 0 0 1-.708.708l-1.765-1.766A4.002 4.002 0 0 1 12 14H6A6 6 0 0 1 2.453 3.16L.396 1.104a.5.5 0 0 1 0-.708m5.082 1.626a6.002 6.002 0 0 1 6.186 3.992 4 4 0 0 1 3.678 6.185l-.338.512L4.408 2.115l1.07-.093' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cloud-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.765.235a.375.375 0 1 0-.53.53l1.637 1.637A4.368 4.368 0 0 0 .125 5.9v.3A4.675 4.675 0 0 0 4.8 10.875h3.7a3.36 3.36 0 0 0 1.496-.349l1.239 1.24a.375.375 0 0 0 .53-.531l-11-11Zm8.661 9.722L2.41 2.939A3.62 3.62 0 0 0 .875 5.9v.3A3.925 3.925 0 0 0 4.8 10.125h3.7c.326 0 .638-.06.926-.168' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.5 1.525c-.153 0-.303.008-.452.023l.738.738A3.628 3.628 0 0 1 7.9 4.64l.1.267.283-.023a2.625 2.625 0 0 1 2.666 3.565l.567.567A3.375 3.375 0 0 0 8.5 4.125a4.376 4.376 0 0 0-4-2.6Z'/%3e%3c/svg%3e")`,
                "cloud-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.854.146a.5.5 0 1 0-.707.708L2.453 3.16A6 6 0 0 0 6 14h6c.393 0 .772-.057 1.131-.162l2.016 2.016a.5.5 0 0 0 .707-.708l-15-15ZM12.28 12.987l-9.11-9.11A5 5 0 0 0 6 13h6c.095 0 .188-.004.28-.013' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 10c0 .85-.265 1.636-.716 2.284l-.722-.722a3 3 0 0 0-2.815-4.551l-.771.064-.256-.73A5.002 5.002 0 0 0 6 3l-.929-.929a6.002 6.002 0 0 1 6.592 3.943A4 4 0 0 1 16 10'/%3e%3c/svg%3e")`,
                "cloud-lightning-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.875 5.5a3.625 3.625 0 0 1 6.788-1.773l.13.23.26-.044a2.625 2.625 0 1 1 .885 5.176l.124.74a3.376 3.376 0 0 0-.878-6.69 4.375 4.375 0 1 0-4.23 6.702l.092-.744A3.626 3.626 0 0 1 .875 5.5'/%3e%3cpath fill='%230E1011' d='M6.724 7.612a.25.25 0 0 0-.448-.224L5.096 9.75h2l-.82 1.638a.25.25 0 1 0 .448.224l1.18-2.362h-2l.82-1.638'/%3e%3c/svg%3e")`,
                "cloud-lightning": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8.8 8.5-1.2 3.086 2.4.625L6.8 16l1.6-3.086L6 12.29z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 1.234 5.873.5.5 0 1 0 .213.977 4.001 4.001 0 0 0-1.194-7.894A6.002 6.002 0 0 0 0 8a6.002 6.002 0 0 0 3.818 5.59.5.5 0 1 0 .364-.93A5.002 5.002 0 0 1 1 8'/%3e%3c/svg%3e")`,
                "cloud-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.25 1.5A4.25 4.25 0 0 0 0 5.75v.5A4.75 4.75 0 0 0 4.75 11H8.5v-.008c.075.005.15.008.227.008C10.535 11 12 9.579 12 7.826c0-1.754-1.465-3.175-3.273-3.175a3.41 3.41 0 0 0-.365.02A4.252 4.252 0 0 0 4.25 1.5'/%3e%3c/svg%3e")`,
                "cloud-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 14a6 6 0 1 1 5.663-7.986A4 4 0 1 1 12 14z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cloud-drizzle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.875 5.5a3.625 3.625 0 0 1 6.788-1.773l.13.23.26-.044a2.625 2.625 0 1 1 .885 5.176l.124.74a3.376 3.376 0 0 0-.878-6.69 4.375 4.375 0 1 0-4.23 6.702l.092-.744A3.626 3.626 0 0 1 .875 5.5'/%3e%3cpath fill='%230E1011' d='M6.75 7.5a.25.25 0 0 0-.5 0V9a.25.25 0 0 0 .5 0zM5.5 8.5a.25.25 0 0 0-.5 0V9a.25.25 0 1 0 .5 0v-.5M8 8.5a.25.25 0 0 0-.5 0V9A.25.25 0 0 0 8 9zM5.5 10a.25.25 0 0 0-.5 0v.5a.25.25 0 1 0 .5 0V10M6.75 10a.25.25 0 0 0-.5 0v1.5a.25.25 0 1 0 .5 0zM8 10a.25.25 0 0 0-.5 0v.5a.25.25 0 1 0 .5 0z'/%3e%3c/svg%3e")`,
                "cloud-drizzle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a5 5 0 0 0-2.086 9.546l-.417.908a6 6 0 1 1 8.166-7.44 4 4 0 0 1 1.48 7.82l-.286-.958a3.002 3.002 0 0 0-1.448-5.818l-.459.092-.121-.452A5.002 5.002 0 0 0 6 3m2.5 6a.5.5 0 0 1 .5.5V12a.5.5 0 0 1-1 0V9.5a.5.5 0 0 1 .5-.5m-2 1a.5.5 0 0 1 .5.5V12a.5.5 0 0 1-1 0v-1.5a.5.5 0 0 1 .5-.5m4 0a.5.5 0 0 1 .5.5V12a.5.5 0 0 1-1 0v-1.5a.5.5 0 0 1 .5-.5m-4 2.855a.5.5 0 0 1 .5.5V14.5a.5.5 0 0 1-1 0v-1.145a.5.5 0 0 1 .5-.5m2 0a.5.5 0 0 1 .5.5V15.5a.5.5 0 0 1-1 0v-2.145a.5.5 0 0 1 .5-.5m2 0a.5.5 0 0 1 .5.5V14.5a.5.5 0 0 1-1 0v-1.145a.5.5 0 0 1 .5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cloud-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.275A3.625 3.625 0 0 0 .875 5.9v.3A3.925 3.925 0 0 0 4.8 10.125h3.7a2.625 2.625 0 1 0-.217-5.241l-.284.023L7.9 4.64a3.627 3.627 0 0 0-3.4-2.365M.125 5.9A4.375 4.375 0 0 1 8.5 4.125a3.375 3.375 0 0 1 0 6.75H4.8A4.675 4.675 0 0 1 .125 6.2v-.3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cloud": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a5 5 0 0 0 0 10h6a3 3 0 1 0-.59-5.942l-.46.092-.121-.452A5.002 5.002 0 0 0 6 3M0 8a6 6 0 0 1 11.663-1.986A4 4 0 1 1 12 14H6a6 6 0 0 1-6-6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "clock-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a6 6 0 1 0 0 12A6 6 0 0 0 6 0m1.118 2.324a.375.375 0 0 0-.736-.148l-.75 3.75a.375.375 0 0 0 .103.34l2.25 2.25a.375.375 0 0 0 .53-.531L6.407 5.877l.71-3.553' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "clock-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .7a7.3 7.3 0 1 0 0 14.6A7.3 7.3 0 0 0 8 .7Zm1.36 2.827a.456.456 0 1 0-.895-.179L7.553 7.91c-.03.15.017.305.124.413l2.738 2.737a.456.456 0 0 0 .645-.645L8.495 7.85l.865-4.323' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "clock-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.118 2.324a.375.375 0 0 0-.736-.148l-.75 3.75a.375.375 0 0 0 .103.34l2.25 2.25a.375.375 0 0 0 .53-.531L6.407 5.877l.71-3.553'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "clock": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.098 2.51a.5.5 0 0 1 .392.588l-.947 4.738 2.81 2.81a.5.5 0 0 1-.707.708l-3-3a.5.5 0 0 1-.136-.452l1-5a.5.5 0 0 1 .588-.392'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "clipboard-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.5 0a.75.75 0 0 0-.75.75v.375c0 .414.336.75.75.75h3a.75.75 0 0 0 .75-.75V.75A.75.75 0 0 0 7.5 0z'/%3e%3cpath fill='%230E1011' d='M1.5 2.25A1.5 1.5 0 0 1 3 .75v.375a1.5 1.5 0 0 0 1.5 1.5h3a1.5 1.5 0 0 0 1.5-1.5V.75a1.5 1.5 0 0 1 1.5 1.5v8.25A1.5 1.5 0 0 1 9 12H3a1.5 1.5 0 0 1-1.5-1.5z'/%3e%3c/svg%3e")`,
                "clipboard-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 0a1 1 0 0 0-1 1v.5a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1z'/%3e%3cpath fill='%230E1011' d='M2 3a2 2 0 0 1 2-2v.5a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2V1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2z'/%3e%3c/svg%3e")`,
                "clipboard-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.688 1a.188.188 0 0 0-.188.188v.375c0 .103.084.187.188.187h2.625a.188.188 0 0 0 .187-.187v-.375A.188.188 0 0 0 7.313 1H4.688m-.92 0a.938.938 0 0 1 .92-.75h2.625c.453 0 .831.322.918.75H9.25a1.5 1.5 0 0 1 1.5 1.5v8a1.5 1.5 0 0 1-1.5 1.5h-6.5a1.5 1.5 0 0 1-1.5-1.5v-8A1.5 1.5 0 0 1 2.75 1h1.019m0 .75H2.75A.75.75 0 0 0 2 2.5v8c0 .414.336.75.75.75h6.5a.75.75 0 0 0 .75-.75v-8a.75.75 0 0 0-.75-.75H8.231a.938.938 0 0 1-.918.75H4.688a.938.938 0 0 1-.92-.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "clipboard": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.25 1a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h3.5a.25.25 0 0 0 .25-.25v-.5A.25.25 0 0 0 9.75 1zM5.025 1c.116-.57.62-1 1.225-1h3.5c.605 0 1.11.43 1.225 1H12a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2zm0 1H4a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1h-1.025c-.116.57-.62 1-1.225 1h-3.5a1.25 1.25 0 0 1-1.225-1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12'/%3e%3c/svg%3e")`,
                "circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 15.3A7.3 7.3 0 1 0 8 .7a7.3 7.3 0 0 0 0 14.6'/%3e%3c/svg%3e")`,
                "circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 11.25A5.25 5.25 0 1 0 6 .75a5.25 5.25 0 0 0 0 10.5M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.995 14.3a6.3 6.3 0 1 0 0-12.6 6.3 6.3 0 0 0 0 12.6m0 1a7.3 7.3 0 1 0 0-14.6 7.3 7.3 0 0 0 0 14.6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chrome-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 7.8a1.8 1.8 0 0 1-1.559-.9l-.019-.032a1.8 1.8 0 1 1 3.135.036l-.007.013A1.8 1.8 0 0 1 6 7.8'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M2.152 2.922a.375.375 0 1 0-.65.374L3.765 7.23a2.55 2.55 0 0 0 2.916 1.23l-1.37 2.433a.375.375 0 1 0 .653.368l2.233-3.963c.224-.38.353-.824.353-1.297 0-.703-.284-1.339-.744-1.8h2.781a.375.375 0 0 0 0-.75H6A2.551 2.551 0 0 0 3.538 5.33L2.152 2.922' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chrome-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 10.4a2.4 2.4 0 0 1-2.078-1.2l-.026-.043a2.4 2.4 0 1 1 4.18.048l-.01.017A2.4 2.4 0 0 1 8 10.4'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0M2.87 3.896a.5.5 0 1 0-.867.5L5.02 9.638a3.4 3.4 0 0 0 3.889 1.639L7.08 14.522a.5.5 0 0 0 .871.491l2.977-5.284c.3-.507.471-1.098.471-1.729a3.39 3.39 0 0 0-.992-2.4h3.708a.5.5 0 1 0 0-1H8a3.402 3.402 0 0 0-3.282 2.508L2.87 3.896Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chrome-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6c0 2.9-2.35 5.25-5.25 5.25h-.03l2.227-3.953c.224-.38.353-.824.353-1.297 0-.703-.284-1.339-.744-1.8h2.781a.374.374 0 0 0 .293-.14c.239.6.37 1.255.37 1.94m-.66-2.55H6A2.551 2.551 0 0 0 3.538 5.33L2.152 2.922a.374.374 0 0 0-.267-.183 5.248 5.248 0 0 1 8.705.71M1.5 3.293a5.251 5.251 0 0 0 3.784 7.908.374.374 0 0 1 .027-.31l1.37-2.433A2.553 2.553 0 0 1 3.765 7.23L1.502 3.296l-.001-.003ZM6 7.8a1.8 1.8 0 0 1-1.559-.9l-.019-.032a1.8 1.8 0 1 1 3.135.036l-.007.013A1.8 1.8 0 0 1 6 7.8' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chrome": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-8.062 6.254 1.677-2.976a3.404 3.404 0 0 1-3.89-1.64L2.406 5.094a6.3 6.3 0 0 0 4.828 9.16Zm1.128.035a6.3 6.3 0 0 0 5.46-8.69H10.41A3.39 3.39 0 0 1 11.4 8c0 .631-.172 1.222-.471 1.729l-2.569 4.56m4.939-9.69H8a3.402 3.402 0 0 0-3.282 2.51L3.013 4.144A6.289 6.289 0 0 1 7.995 1.7a6.295 6.295 0 0 1 5.304 2.9ZM8 10.4a2.4 2.4 0 0 1-2.07-1.184l-.008-.015-.026-.044a2.4 2.4 0 1 1 4.18.048l-.01.017A2.4 2.4 0 0 1 8 10.4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevrons-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.64 8.89a.375.375 0 0 1-.53-.53l2.625-2.625a.375.375 0 0 1 .53 0L8.89 8.36a.375.375 0 1 1-.53.53L6 6.53 3.64 8.89'/%3e%3cpath fill='%230E1011' d='M3.64 5.89a.375.375 0 0 1-.53-.53l2.625-2.625a.375.375 0 0 1 .53 0L8.89 5.36a.375.375 0 1 1-.53.53L6 3.53 3.64 5.89'/%3e%3c/svg%3e")`,
                "chevrons-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.854 11.854a.5.5 0 0 1-.708-.708l3.5-3.5a.5.5 0 0 1 .708 0l3.5 3.5a.5.5 0 0 1-.708.708L8 8.707l-3.146 3.147'/%3e%3cpath fill='%230E1011' d='M4.854 7.854a.5.5 0 1 1-.708-.708l3.5-3.5a.5.5 0 0 1 .708 0l3.5 3.5a.5.5 0 0 1-.708.708L8 4.707 4.854 7.854'/%3e%3c/svg%3e")`,
                "chevrons-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.11 3.64a.375.375 0 0 1 .53-.53l2.625 2.625a.375.375 0 0 1 0 .53L3.64 8.89a.375.375 0 1 1-.53-.53L5.47 6 3.11 3.64'/%3e%3cpath fill='%230E1011' d='M6.11 3.64a.375.375 0 0 1 .53-.53l2.625 2.625a.375.375 0 0 1 0 .53L6.64 8.89a.375.375 0 0 1-.53-.53L8.47 6 6.11 3.64'/%3e%3c/svg%3e")`,
                "chevrons-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.146 4.854a.5.5 0 1 1 .708-.708l3.5 3.5a.5.5 0 0 1 0 .708l-3.5 3.5a.5.5 0 0 1-.708-.708L7.293 8 4.146 4.854'/%3e%3cpath fill='%230E1011' d='M8.146 4.854a.5.5 0 1 1 .708-.708l3.5 3.5a.5.5 0 0 1 0 .708l-3.5 3.5a.5.5 0 0 1-.708-.708L11.293 8 8.146 4.854'/%3e%3c/svg%3e")`,
                "chevrons-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.89 3.64a.375.375 0 0 0-.53-.53L5.735 5.735a.375.375 0 0 0 0 .53L8.36 8.89a.375.375 0 0 0 .53-.53L6.53 6l2.36-2.36'/%3e%3cpath fill='%230E1011' d='M5.89 3.64a.375.375 0 0 0-.53-.53L2.735 5.735a.375.375 0 0 0 0 .53L5.36 8.89a.375.375 0 0 0 .53-.53L3.53 6l2.36-2.36'/%3e%3c/svg%3e")`,
                "chevrons-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.854 4.854a.5.5 0 0 0-.708-.708l-3.5 3.5a.5.5 0 0 0 0 .708l3.5 3.5a.5.5 0 0 0 .708-.708L8.707 8l3.147-3.146'/%3e%3cpath fill='%230E1011' d='M7.854 4.854a.5.5 0 1 0-.708-.708l-3.5 3.5a.5.5 0 0 0 0 .708l3.5 3.5a.5.5 0 0 0 .708-.708L4.707 8l3.147-3.146'/%3e%3c/svg%3e")`,
                "chevrons-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.64 3.11a.375.375 0 0 0-.53.53l2.625 2.625a.375.375 0 0 0 .53 0L8.89 3.64a.375.375 0 0 0-.53-.53L6 5.47 3.64 3.11'/%3e%3cpath fill='%230E1011' d='M3.64 6.11a.375.375 0 0 0-.53.53l2.625 2.625a.375.375 0 0 0 .53 0L8.89 6.64a.375.375 0 1 0-.53-.53L6 8.47 3.64 6.11'/%3e%3c/svg%3e")`,
                "chevrons-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.854 4.146a.5.5 0 1 0-.708.708l3.5 3.5a.5.5 0 0 0 .708 0l3.5-3.5a.5.5 0 0 0-.708-.708L8 7.293 4.854 4.146'/%3e%3cpath fill='%230E1011' d='M4.854 8.146a.5.5 0 1 0-.708.708l3.5 3.5a.5.5 0 0 0 .708 0l3.5-3.5a.5.5 0 0 0-.708-.708L8 11.293 4.854 8.146'/%3e%3c/svg%3e")`,
                "chevron-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.235 7.765a.375.375 0 0 0 .53 0L6 4.53l3.235 3.235a.375.375 0 1 0 .53-.53L6 3.47 2.235 7.235a.375.375 0 0 0 0 .53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.396 10.604a.5.5 0 0 0 .708 0L8 6.707l3.896 3.897a.5.5 0 0 0 .708-.708l-4.25-4.25a.5.5 0 0 0-.708 0l-4.25 4.25a.5.5 0 0 0 0 .708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.235 9.765a.375.375 0 0 1 0-.53L7.47 6 4.235 2.765a.375.375 0 1 1 .53-.53L8.53 6 4.765 9.765a.375.375 0 0 1-.53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.396 12.604a.5.5 0 0 1 0-.708L9.293 8 5.396 4.104a.5.5 0 1 1 .708-.708l4.25 4.25a.5.5 0 0 1 0 .708l-4.25 4.25a.5.5 0 0 1-.708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.765 2.235a.375.375 0 0 1 0 .53L4.53 6l3.235 3.235a.375.375 0 1 1-.53.53L3.47 6l3.765-3.765a.375.375 0 0 1 .53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.604 12.604a.5.5 0 0 0 0-.708L5.707 8l3.897-3.896a.5.5 0 1 0-.708-.708l-4.25 4.25a.5.5 0 0 0 0 .708l4.25 4.25a.5.5 0 0 0 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.235 4.235a.375.375 0 0 1 .53 0L6 7.47l3.235-3.235a.375.375 0 1 1 .53.53L6 8.53 2.235 4.765a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "chevron-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.396 5.396a.5.5 0 0 1 .708 0L8 9.293l3.896-3.897a.5.5 0 0 1 .708.708l-4.25 4.25a.5.5 0 0 1-.708 0l-4.25-4.25a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-stamp-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.993.392a1.453 1.453 0 0 0-1.986 0l-.56.524c-.257.24-.592.38-.944.391l-.766.026a1.453 1.453 0 0 0-1.404 1.404l-.026.766c-.011.352-.15.687-.391.945l-.524.56a1.453 1.453 0 0 0 0 1.985l.524.56c.24.257.38.592.391.944l.026.766c.025.765.639 1.379 1.404 1.404l.766.026c.352.011.687.15.945.391l.56.524a1.453 1.453 0 0 0 1.985 0l.56-.524c.257-.24.592-.38.944-.391l.766-.026a1.453 1.453 0 0 0 1.404-1.404l.026-.766c.011-.352.15-.687.391-.945l.524-.56a1.453 1.453 0 0 0 0-1.985l-.524-.56a1.452 1.452 0 0 1-.391-.944l-.026-.766a1.453 1.453 0 0 0-1.404-1.404l-.766-.026a1.453 1.453 0 0 1-.945-.391l-.56-.524m1.772 4.373a.375.375 0 1 0-.53-.53L5.5 6.97 4.265 5.735a.375.375 0 0 0-.53.53L5.5 8.03l3.265-3.265' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-stamp-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.324.523a1.937 1.937 0 0 0-2.648 0l-.746.698c-.343.321-.79.507-1.26.522l-1.021.034a1.937 1.937 0 0 0-1.872 1.872L1.743 4.67c-.015.469-.2.916-.522 1.259l-.698.746a1.937 1.937 0 0 0 0 2.648l.698.746c.321.343.507.79.522 1.26l.034 1.021a1.937 1.937 0 0 0 1.872 1.872l1.022.034c.469.015.916.2 1.259.522l.746.698a1.937 1.937 0 0 0 2.648 0l.746-.698c.343-.321.79-.507 1.26-.522l1.021-.034a1.937 1.937 0 0 0 1.872-1.872l.034-1.022c.015-.469.2-.916.522-1.259l.698-.746a1.937 1.937 0 0 0 0-2.648l-.698-.746a1.937 1.937 0 0 1-.522-1.26l-.034-1.021a1.937 1.937 0 0 0-1.872-1.872l-1.022-.034c-.469-.015-.916-.2-1.259-.522L9.324.523m3.03 5.83a.5.5 0 0 0-.708-.707L7.5 9.793 5.354 7.646a.5.5 0 1 0-.708.708L7.5 11.207l4.854-4.853' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-stamp-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M8.765 4.765a.375.375 0 1 0-.53-.53L5.5 6.97 4.265 5.735a.375.375 0 0 0-.53.53L5.5 8.03l3.265-3.265'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.392 6.993a1.453 1.453 0 0 1 0-1.986l.524-.56c.24-.257.38-.592.391-.944l.026-.766a1.453 1.453 0 0 1 1.404-1.404l.766-.026c.352-.011.687-.15.945-.391l.56-.524a1.453 1.453 0 0 1 1.985 0l.56.524c.257.24.592.38.944.391l.766.026c.765.025 1.379.639 1.404 1.404l.026.766c.011.352.15.687.391.945l.524.56a1.453 1.453 0 0 1 0 1.985l-.524.56c-.24.257-.38.592-.391.944l-.026.766a1.453 1.453 0 0 1-1.404 1.404l-.766.026c-.352.011-.687.15-.945.391l-.56.524a1.453 1.453 0 0 1-1.985 0l-.56-.524a1.452 1.452 0 0 0-.944-.391l-.766-.026a1.453 1.453 0 0 1-1.404-1.404l-.026-.766a1.453 1.453 0 0 0-.391-.945l-.524-.56M6.48.94l.56.524c.39.364.899.575 1.432.593l.767.025c.37.013.666.31.679.68l.025.766c.018.533.229 1.042.593 1.432l.524.56c.253.27.253.69 0 .96l-.524.56c-.364.39-.575.899-.593 1.432l-.025.767a.703.703 0 0 1-.68.679l-.766.025a2.203 2.203 0 0 0-1.432.593l-.56.524a.703.703 0 0 1-.96 0l-.56-.524a2.203 2.203 0 0 0-1.432-.593l-.767-.025a.703.703 0 0 1-.679-.68l-.025-.766a2.203 2.203 0 0 0-.593-1.432L.94 6.48a.703.703 0 0 1 0-.96l.524-.56c.364-.39.575-.899.593-1.432l.025-.767a.703.703 0 0 1 .68-.679l.766-.025a2.203 2.203 0 0 0 1.432-.593L5.52.94a.703.703 0 0 1 .96 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-stamp": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.354 6.354a.5.5 0 0 0-.708-.708L7.5 9.793 5.354 7.646a.5.5 0 1 0-.708.708L7.5 11.207l4.854-4.853'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.676.523a1.937 1.937 0 0 1 2.648 0l.746.698c.343.321.79.507 1.26.522l1.021.034a1.937 1.937 0 0 1 1.872 1.872l.034 1.022c.015.469.2.916.522 1.259l.698.746a1.937 1.937 0 0 1 0 2.648l-.698.746c-.321.343-.507.79-.522 1.26l-.034 1.021a1.937 1.937 0 0 1-1.872 1.872l-1.022.034c-.469.015-.916.2-1.259.522l-.746.698a1.937 1.937 0 0 1-2.648 0l-.746-.698a1.937 1.937 0 0 0-1.26-.522l-1.021-.034a1.937 1.937 0 0 1-1.872-1.872l-.034-1.022c-.015-.469-.2-.916-.522-1.259l-.698-.746a1.937 1.937 0 0 1 0-2.648l.698-.746c.321-.343.507-.79.522-1.26l.034-1.021a1.937 1.937 0 0 1 1.872-1.872l1.022-.034c.469-.015.916-.2 1.259-.522l.746-.698m1.964.73.747.698c.52.487 1.198.768 1.91.792l1.021.033c.493.017.89.413.906.906l.034 1.022c.023.711.304 1.39.79 1.91l.7.746c.336.36.336.92 0 1.28l-.7.747a2.937 2.937 0 0 0-.79 1.91l-.034 1.021a.937.937 0 0 1-.906.906l-1.022.034a2.937 2.937 0 0 0-1.91.79l-.746.7a.937.937 0 0 1-1.28 0l-.747-.7a2.937 2.937 0 0 0-1.91-.79l-1.021-.034a.937.937 0 0 1-.906-.906l-.033-1.022a2.937 2.937 0 0 0-.792-1.91l-.698-.746a.937.937 0 0 1 0-1.28l.698-.747c.487-.52.768-1.198.792-1.91l.033-1.021a.937.937 0 0 1 .906-.906l1.022-.033a2.937 2.937 0 0 0 1.91-.792l.746-.698a.937.937 0 0 1 1.28 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-square-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.563.75H2.436C1.507.75.75 1.506.75 2.438v7.124c0 .933.756 1.688 1.688 1.688h7.124c.933 0 1.688-.755 1.688-1.687V2.436c0-.931-.755-1.687-1.687-1.687m-.298 3.64a.375.375 0 1 0-.53-.53L5.25 7.345l-1.61-1.61a.375.375 0 1 0-.53.53L4.985 8.14a.375.375 0 0 0 .53 0l3.75-3.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-square-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1zm8.854 4.147a.5.5 0 0 1 0 .707l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.707L7 9.793l4.646-4.646a.5.5 0 0 1 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-square-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9.11 4.467a.357.357 0 1 0-.505-.505L5.285 7.28 3.754 5.747a.357.357 0 0 0-.506.506l1.786 1.785c.14.14.366.14.505 0L9.11 4.467'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.607 1C1.72 1 1 1.72 1 2.607v6.786C1 10.28 1.72 11 2.607 11h6.786C10.28 11 11 10.28 11 9.393V2.607C11 1.72 10.28 1 9.393 1H2.607Zm-.893 1.607c0-.493.4-.893.893-.893h6.786c.493 0 .893.4.893.893v6.786c0 .493-.4.893-.893.893H2.607a.893.893 0 0 1-.893-.893V2.607Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-square": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.354 5.147a.5.5 0 0 1 0 .707l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.707L7 9.793l4.646-4.646a.5.5 0 0 1 .708 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5zM3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.53 2.47a.75.75 0 0 1 0 1.06L4.5 9.56l-3-3A.75.75 0 0 1 2.56 5.5L4.5 7.44l4.97-4.97a.75.75 0 0 1 1.06 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.207 3.793a1 1 0 0 1 0 1.414L6.5 12.914l-4-4A1 1 0 1 1 3.914 7.5L6.5 10.086l6.293-6.293a1 1 0 0 1 1.414 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M9.265 4.39a.375.375 0 1 0-.53-.53L5.25 7.345l-1.61-1.61a.375.375 0 1 0-.53.53L4.985 8.14a.375.375 0 0 0 .53 0l3.75-3.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-2.94-2.854a.5.5 0 0 1 0 .708l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.708L7 9.793l4.646-4.647a.5.5 0 0 1 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9.265 4.39a.375.375 0 1 0-.53-.53L5.25 7.345l-1.61-1.61a.375.375 0 1 0-.53.53L4.985 8.14a.375.375 0 0 0 .53 0l3.75-3.75'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.354 5.146a.5.5 0 0 1 0 .708l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.708L7 9.793l4.646-4.647a.5.5 0 0 1 .708 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.265 2.735a.375.375 0 0 1 0 .53L4.5 9.03 1.235 5.765a.375.375 0 0 1 .53-.53L4.5 7.97l5.235-5.235a.375.375 0 0 1 .53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "check": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.854 4.146a.5.5 0 0 1 0 .708L6.5 12.207 2.146 7.854a.5.5 0 1 1 .708-.708L6.5 10.793l6.646-6.647a.5.5 0 0 1 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cast-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 1C.756 1 0 1.756 0 2.688v6.624C0 10.246.756 11 1.688 11h8.625C11.244 11 12 10.245 12 9.313V2.686C12 1.757 11.245 1 10.313 1H1.688m.187 2.75a.375.375 0 1 0 0 .75h.375A3.75 3.75 0 0 1 6 8.25v.375a.375.375 0 1 0 .75 0V8.25a4.5 4.5 0 0 0-4.5-4.5zm0 2.25a.375.375 0 1 0 0 .75h.375a1.5 1.5 0 0 1 1.5 1.5v.375a.375.375 0 1 0 .75 0V8.25A2.25 2.25 0 0 0 2.25 6z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cast-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2zm.25 3a.5.5 0 0 0 0 1H3a5 5 0 0 1 5 5v.5a.5.5 0 0 0 1 0V11a6 6 0 0 0-6-6zm0 3a.5.5 0 0 0 0 1H3a2 2 0 0 1 2 2v.5a.5.5 0 0 0 1 0V11a3 3 0 0 0-3-3z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cast-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.875 3.75a.375.375 0 1 0 0 .75h.375A3.75 3.75 0 0 1 6 8.25v.375a.375.375 0 1 0 .75 0V8.25a4.5 4.5 0 0 0-4.5-4.5z'/%3e%3cpath fill='%230E1011' d='M1.875 6a.375.375 0 1 0 0 .75h.375a1.5 1.5 0 0 1 1.5 1.5v.375a.375.375 0 1 0 .75 0V8.25A2.25 2.25 0 0 0 2.25 6z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 1.25C.756 1.25 0 2.006 0 2.938v6.124c0 .932.756 1.688 1.688 1.688h8.625c.931 0 1.687-.756 1.687-1.687V2.936c0-.931-.755-1.687-1.687-1.687H1.688M.75 2.938c0-.518.42-.938.938-.938h8.625c.517 0 .937.42.937.938v6.124c0 .518-.42.938-.937.938H1.688a.937.937 0 0 1-.938-.937V2.936' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "cast": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 5a.5.5 0 0 0 0 1H3a5 5 0 0 1 5 5v.5a.5.5 0 0 0 1 0V11a6 6 0 0 0-6-6z'/%3e%3cpath fill='%230E1011' d='M2.5 8a.5.5 0 0 0 0 1H3a2 2 0 0 1 2 2v.5a.5.5 0 0 0 1 0V11a3 3 0 0 0-3-3z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2zM1 4.25C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25v7.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 13 1 12.44 1 11.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-up-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3 2.266 7.267a.375.375 0 0 0 .283.622H9.45c.323 0 .495-.38.283-.622L6 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-up-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 4.481-4.978 5.69a.5.5 0 0 0 .376.829h9.204a.5.5 0 0 0 .376-.83L8 4.482' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3 2.266 7.267a.375.375 0 0 0 .283.622H9.45c.323 0 .495-.38.283-.622L6 3m0 1.139 2.625 3h-5.25l2.625-3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 4.481-4.978 5.69a.5.5 0 0 0 .376.829h9.204a.5.5 0 0 0 .376-.83L8 4.482M8 6l3.5 4h-7L8 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-down-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 9 2.266 4.733a.375.375 0 0 1 .283-.622H9.45c.323 0 .495.38.283.622L6 9' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-down-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11.52 3.022 5.83a.5.5 0 0 1 .376-.829h9.204a.5.5 0 0 1 .376.83L8 11.52' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 9 2.266 4.733a.375.375 0 0 1 .283-.622H9.45c.323 0 .495.38.283.622L6 9m0-1.139 2.625-3h-5.25l2.625 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "caret-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11.52 3.022 5.83a.5.5 0 0 1 .376-.829h9.204a.5.5 0 0 1 .376.83L8 11.52m0-1.518 3.5-4h-7l3.5 4' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "camera-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.828.297a.375.375 0 1 0-.53.53l.784.785A1.688 1.688 0 0 0 0 3.188v5.624C0 9.745.756 10.5 1.688 10.5H9.97l1.202 1.203a.375.375 0 0 0 .53-.53L.829.296ZM7.84 8.37l-.536-.536a2.25 2.25 0 0 1-3.138-3.138L3.63 4.16a3 3 0 0 0 4.21 4.21M4.589 5.12a1.4 1.4 0 0 0-.183.692V6h.563v-.187c0-.095.015-.185.044-.27l-.424-.424' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12 8.813c0 .272-.065.53-.18.758L8.925 6.674a3 3 0 0 0-3.598-3.598L3.485 1.235 3.75.97a.75.75 0 0 1 .53-.22h3.44a.75.75 0 0 1 .53.22l.53.53h1.533c.931 0 1.687.756 1.687 1.688v5.624'/%3e%3cpath fill='%230E1011' d='M8.25 6A2.25 2.25 0 0 0 6 3.75z'/%3e%3c/svg%3e")`,
                "camera-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.104.396a.5.5 0 1 0-.708.708l1.046 1.045A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.043l1.603 1.604a.5.5 0 0 0 .708-.708L1.104.396Zm9.349 10.764-.715-.715a3 3 0 0 1-4.184-4.184l-.714-.714a4 4 0 0 0 5.613 5.613M6.118 6.826a1.866 1.866 0 0 0-.243.924V8h.75v-.25c0-.126.02-.246.059-.36l-.566-.564' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 11.75c0 .364-.086.707-.24 1.01L11.9 8.9a4 4 0 0 0-4.797-4.797L4.645 1.645 5 1.293A1 1 0 0 1 5.707 1h4.586a1 1 0 0 1 .707.293l.707.707h2.043A2.25 2.25 0 0 1 16 4.25z'/%3e%3cpath fill='%230E1011' d='M11 8a3 3 0 0 0-3-3z'/%3e%3c/svg%3e")`,
                "camera-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.828.297a.375.375 0 1 0-.53.53l.784.785A1.688 1.688 0 0 0 0 3.188v5.624C0 9.745.756 10.5 1.688 10.5H9.97l1.202 1.203a.375.375 0 0 0 .53-.53L.829.296Zm.86 1.953h.032l1.977 1.977a2.906 2.906 0 0 0 4.076 4.076L9.22 9.75H1.687a.937.937 0 0 1-.937-.937V3.186c0-.517.42-.937.938-.937M7.37 7.901 4.099 4.63A2.344 2.344 0 0 0 7.37 7.901' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.28.75a.75.75 0 0 0-.53.22l-.265.265a.375.375 0 1 0 .53.53L4.28 1.5h3.44l.53.53c.14.141.331.22.53.22h1.533c.517 0 .937.42.937.938v5.624c0 .12-.022.235-.063.34a.375.375 0 1 0 .7.27c.073-.19.113-.395.113-.61V3.189c0-.932-.755-1.688-1.687-1.688H8.78L8.25.97a.75.75 0 0 0-.53-.22H4.28'/%3e%3cpath fill='%230E1011' d='M5.686 3.677a2.344 2.344 0 0 1 2.637 2.637.281.281 0 1 0 .557.075 2.906 2.906 0 0 0-3.27-3.27.281.281 0 1 0 .076.558'/%3e%3c/svg%3e")`,
                "camera-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.104.396a.5.5 0 1 0-.708.708l1.046 1.045A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.043l1.603 1.604a.5.5 0 0 0 .708-.708L1.104.396ZM2.25 3h.043l2.636 2.636a3.875 3.875 0 0 0 5.435 5.434L12.293 13H2.25C1.56 13 1 12.44 1 11.75v-7.5C1 3.56 1.56 3 2.25 3m7.578 7.535L5.465 6.172a3.125 3.125 0 0 0 4.363 4.363' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M5.707 1A1 1 0 0 0 5 1.293l-.354.353a.5.5 0 1 0 .708.708L5.707 2h4.586l.707.707a1 1 0 0 0 .707.293h2.043c.69 0 1.25.56 1.25 1.25v7.5c0 .16-.03.312-.084.452a.5.5 0 0 0 .932.361c.098-.253.152-.527.152-.813v-7.5A2.25 2.25 0 0 0 13.75 2h-2.043L11 1.293A1 1 0 0 0 10.293 1H5.707'/%3e%3cpath fill='%230E1011' d='M7.58 4.903a3.125 3.125 0 0 1 3.516 3.516.375.375 0 1 0 .745.1 3.875 3.875 0 0 0-4.36-4.36.375.375 0 0 0 .1.744'/%3e%3c/svg%3e")`,
                "camera-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.75a2.25 2.25 0 1 0 0 4.5 2.25 2.25 0 0 0 0-4.5M4.406 5.813c0-.777.63-1.407 1.407-1.407H6v.563h-.187a.844.844 0 0 0-.844.843V6h-.563v-.187' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.28.25a.75.75 0 0 0-.53.22L3.22 1H1.687C.757 1 0 1.756 0 2.688v6.624C0 10.246.756 11 1.688 11h8.625C11.244 11 12 10.245 12 9.313V2.686C12 1.757 11.245 1 10.313 1H8.78L8.25.47a.75.75 0 0 0-.53-.22H4.28M3 6a3 3 0 1 1 6 0 3 3 0 0 1-6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "camera-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 5a3 3 0 1 0 0 6 3 3 0 0 0 0-6M5.875 7.75c0-1.036.84-1.875 1.875-1.875H8v.75h-.25c-.621 0-1.125.504-1.125 1.125V8h-.75z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.707 1A1 1 0 0 0 5 1.293L4.293 2H2.25A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2h-2.043L11 1.293A1 1 0 0 0 10.293 1H5.707M4 8a4 4 0 1 1 8 0 4 4 0 0 1-8 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "camera-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.406 5.813c0-.777.63-1.407 1.407-1.407H6v.563h-.187a.844.844 0 0 0-.844.843V6h-.563v-.187'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a3 3 0 1 0 0 6 3 3 0 0 0 0-6M3.75 6a2.25 2.25 0 1 1 4.5 0 2.25 2.25 0 0 1-4.5 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.75.47a.75.75 0 0 1 .53-.22h3.44a.75.75 0 0 1 .53.22l.53.53h1.533C11.244 1 12 1.756 12 2.688v6.624c0 .933-.755 1.688-1.687 1.688H1.688A1.687 1.687 0 0 1 0 9.313V2.686C0 1.757.756 1 1.688 1H3.22l.53-.53ZM7.72 1H4.28l-.53.53a.75.75 0 0 1-.53.22H1.687a.937.937 0 0 0-.937.938v6.624c0 .518.42.938.938.938h8.625c.517 0 .937-.42.937-.937V2.686a.937.937 0 0 0-.937-.937H8.78a.75.75 0 0 1-.53-.22L7.72 1' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "camera": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.875 7.75c0-1.036.84-1.875 1.875-1.875H8v.75h-.25c-.621 0-1.125.504-1.125 1.125V8h-.75z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 4a4 4 0 1 0 0 8 4 4 0 0 0 0-8M5 8a3 3 0 1 1 6 0 3 3 0 0 1-6 0' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 1.293A1 1 0 0 1 5.707 1h4.586a1 1 0 0 1 .707.293l.707.707h2.043A2.25 2.25 0 0 1 16 4.25v7.5A2.25 2.25 0 0 1 13.75 14H2.25A2.25 2.25 0 0 1 0 11.75v-7.5A2.25 2.25 0 0 1 2.25 2h2.043L5 1.293M10.293 2H5.707L5 2.707A1 1 0 0 1 4.293 3H2.25C1.56 3 1 3.56 1 4.25v7.5c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25v-7.5C15 3.56 14.44 3 13.75 3h-2.043A1 1 0 0 1 11 2.707L10.293 2' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "calendar-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.5.625a.375.375 0 1 1 .75 0V1h2.063C11.244 1 12 1.756 12 2.688v7.624c0 .933-.755 1.688-1.687 1.688H1.688A1.687 1.687 0 0 1 0 10.313V2.686C0 1.757.756 1 1.688 1H3.75V.625a.375.375 0 1 1 .75 0V1h3zm3.656 3.75a.281.281 0 0 0-.281-.281h-9.75a.281.281 0 0 0 0 .562h9.75a.281.281 0 0 0 .281-.281' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "calendar-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 .5a.5.5 0 0 1 1 0V1h2.75A2.25 2.25 0 0 1 16 3.25v9.5A2.25 2.25 0 0 1 13.75 15H2.25A2.25 2.25 0 0 1 0 12.75v-9.5A2.25 2.25 0 0 1 2.25 1H5V.5a.5.5 0 0 1 1 0V1h4zm4.875 5a.375.375 0 0 0-.375-.375h-13a.375.375 0 1 0 0 .75h13a.375.375 0 0 0 .375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "calendar-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.5.625a.375.375 0 1 1 .75 0v1.5a.375.375 0 1 1-.75 0zM3.75.625a.375.375 0 1 1 .75 0v1.5a.375.375 0 1 1-.75 0z'/%3e%3cpath fill='%230E1011' d='M11.25 2.688a.937.937 0 0 0-.937-.938h-.938a.375.375 0 1 1 0-.75h.938C11.244 1 12 1.756 12 2.688v7.624c0 .933-.755 1.688-1.687 1.688H1.688A1.687 1.687 0 0 1 0 10.313V2.686C0 1.757.756 1 1.688 1h.937a.375.375 0 1 1 0 .75h-.937a.937.937 0 0 0-.938.938v7.624c0 .518.42.938.938.938h8.625c.517 0 .937-.42.937-.937V2.686'/%3e%3cpath fill='%230E1011' d='M6.75 1.75h-1.5V1h1.5zM10.125 4a.281.281 0 0 1 0 .563h-8.25a.281.281 0 0 1 0-.563z'/%3e%3c/svg%3e")`,
                "calendar": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M10 .5a.5.5 0 0 1 1 0v2a.5.5 0 0 1-1 0zM5 .5a.5.5 0 0 1 1 0v2a.5.5 0 0 1-1 0z'/%3e%3cpath fill='%230E1011' d='M15 3.25C15 2.56 14.44 2 13.75 2H12.5a.5.5 0 0 1 0-1h1.25A2.25 2.25 0 0 1 16 3.25v9.5A2.25 2.25 0 0 1 13.75 15H2.25A2.25 2.25 0 0 1 0 12.75v-9.5A2.25 2.25 0 0 1 2.25 1H3.5a.5.5 0 0 1 0 1H2.25C1.56 2 1 2.56 1 3.25v9.5c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25z'/%3e%3cpath fill='%230E1011' d='M9 2H7V1h2zM13.5 5.125a.375.375 0 0 1 0 .75h-11a.375.375 0 1 1 0-.75z'/%3e%3c/svg%3e")`,
                "briefcase-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M4.969 6.375v-.469H7.03v.469c0 .259-.21.469-.468.469H5.438a.469.469 0 0 1-.47-.469'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5.5a.75.75 0 0 0-.75.75V2H.938A.937.937 0 0 0 0 2.938v6.124C0 9.58.42 10 .938 10h10.125c.517 0 .937-.42.937-.937V2.936A.937.937 0 0 0 11.063 2H8.25v-.75A.75.75 0 0 0 7.5.5zm3 1.5h-3v-.75h3zM1.125 5.344a.281.281 0 0 0 0 .562h3.281v.469c0 .57.462 1.031 1.032 1.031h1.125c.569 0 1.03-.461 1.03-1.031v-.469h3.282a.281.281 0 0 0 0-.562h-9.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "briefcase-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.625 8.5v-.625h2.75V8.5c0 .345-.28.625-.625.625h-1.5a.625.625 0 0 1-.625-.625'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1a1 1 0 0 0-1 1v1H1.25C.56 3 0 3.56 0 4.25v8.5C0 13.44.56 14 1.25 14h13.5c.69 0 1.25-.56 1.25-1.25v-8.5C16 3.56 15.44 3 14.75 3H11V2a1 1 0 0 0-1-1zm4 2H6V2h4zM1.5 7.125a.375.375 0 1 0 0 .75h4.375V8.5c0 .76.616 1.375 1.375 1.375h1.5c.76 0 1.375-.616 1.375-1.375v-.625H14.5a.375.375 0 0 0 0-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "briefcase-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5.5a.75.75 0 0 0-.75.75V2H1.5A1.5 1.5 0 0 0 0 3.5v5.75a1.5 1.5 0 0 0 1.5 1.5h9a1.5 1.5 0 0 0 1.5-1.5V3.5A1.5 1.5 0 0 0 10.5 2H8.25v-.75A.75.75 0 0 0 7.5.5zm3 1.5h-3v-.75h3zM.75 3.5a.75.75 0 0 1 .75-.75h9a.75.75 0 0 1 .75.75v1.938H.75zm0 2.5v3.25c0 .414.336.75.75.75h9a.75.75 0 0 0 .75-.75V6H7.594v.469c0 .57-.462 1.031-1.032 1.031H5.438c-.569 0-1.03-.462-1.03-1.031V6zm4.219.469V6H7.03v.469c0 .259-.21.468-.468.468H5.438a.469.469 0 0 1-.47-.468' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "briefcase": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1a1 1 0 0 0-1 1v1H2a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2h-3V2a1 1 0 0 0-1-1zm4 2H6V2h4zM1 5a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v2.125H1zm0 2.875V12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V7.875h-4.875V8.5c0 .76-.616 1.375-1.375 1.375h-1.5c-.76 0-1.375-.616-1.375-1.375v-.625zm5.625.625v-.625h2.75V8.5c0 .345-.28.625-.625.625h-1.5a.625.625 0 0 1-.625-.625' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "box-wire-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.144.113A.374.374 0 0 0 6 .123a.374.374 0 0 0-.144-.01 1.125 1.125 0 0 0-.28.074L3.994.829a.375.375 0 0 0 .282.695L5.86.881a.375.375 0 0 1 .093-.024A.378.378 0 0 0 6 .847a.379.379 0 0 0 .048.01.375.375 0 0 1 .093.024l1.583.643A.375.375 0 1 0 8.007.83L6.423.187a1.125 1.125 0 0 0-.279-.074M9.59 1.472a.375.375 0 1 0-.282.695l1.195.485-.977.396a.375.375 0 0 0 .282.695l1.318-.534v1.843a.375.375 0 0 0 .75 0V3.157c0-.152-.03-.299-.087-.433a.373.373 0 0 0-.142-.17.374.374 0 0 0-.104-.196 1.124 1.124 0 0 0-.37-.244L9.59 1.472M2.692 2.167a.375.375 0 0 0-.282-.695l-1.584.642c-.14.057-.265.14-.369.244a.373.373 0 0 0-.104.195.373.373 0 0 0-.142.17 1.124 1.124 0 0 0-.087.434v1.895a.375.375 0 1 0 .75 0V3.21l1.318.534a.375.375 0 1 0 .282-.695l-.978-.396 1.196-.485M.874 6.948a.375.375 0 1 0-.75 0v1.895c0 .152.03.299.087.433.03.073.08.13.142.17.014.072.048.141.104.196.104.103.229.187.369.244l1.584.642a.375.375 0 0 0 .282-.695l-1.584-.642a.374.374 0 0 1-.123-.081.377.377 0 0 0-.06-.049.377.377 0 0 0-.022-.074.374.374 0 0 1-.029-.144V6.948M11.876 6.948a.375.375 0 0 0-.75 0v1.895c0 .05-.01.1-.03.144a.38.38 0 0 0-.021.074.374.374 0 0 0-.06.049.374.374 0 0 1-.123.08l-1.584.643a.375.375 0 1 0 .282.695l1.584-.642c.14-.057.265-.14.369-.244a.374.374 0 0 0 .104-.195.373.373 0 0 0 .142-.17c.056-.135.087-.282.087-.434V6.948M4.275 10.476a.375.375 0 0 0-.282.695l1.584.642c.09.037.184.061.279.074.05.006.098.002.144-.01a.375.375 0 0 0 .144.01c.095-.013.189-.037.279-.074l1.584-.642a.375.375 0 0 0-.283-.695l-1.35.547V9.349a.375.375 0 1 0-.75 0v1.675l-1.349-.547M7.974 4.487a.375.375 0 0 0-.282-.695L6 4.48l-1.693-.687a.375.375 0 0 0-.282.695l1.6.65v1.979a.375.375 0 0 0 .75 0v-1.98l1.6-.649'/%3e%3c/svg%3e")`,
                "box-wire": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.142.084A.5.5 0 0 0 8 .09a.5.5 0 0 0-.142-.007 1.5 1.5 0 0 0-.415.1l-2.438.975a.5.5 0 0 0 .372.929l2.437-.975a.5.5 0 0 1 .138-.034A.508.508 0 0 0 8 1.073a.508.508 0 0 0 .047.006.5.5 0 0 1 .139.034l2.437.975a.5.5 0 1 0 .372-.929L8.557.184a1.5 1.5 0 0 0-.415-.1M3.752 2.738a.5.5 0 1 0-.372-.929l-2.437.975a1.499 1.499 0 0 0-.547.377.498.498 0 0 0-.11.194.498.498 0 0 0-.139.174A1.498 1.498 0 0 0 0 4.177v2.867a.5.5 0 1 0 1 0V4.24l2.127.85a.5.5 0 0 0 .371-.928L1.846 3.5l1.906-.762M12.62 1.81a.5.5 0 1 0-.372.928l1.906.762-1.652.66a.5.5 0 1 0 .371.93L15 4.238v2.805a.5.5 0 0 0 1 0V4.177c0-.229-.052-.45-.147-.648a.498.498 0 0 0-.139-.174.5.5 0 0 0-.11-.194 1.5 1.5 0 0 0-.547-.377L12.62 1.81M16 8.956a.5.5 0 0 0-1 0v2.867c0 .076-.017.15-.049.216a.486.486 0 0 0-.027.07.504.504 0 0 0-.056.053.498.498 0 0 1-.182.125l-2.438.975a.5.5 0 0 0 .372.929l2.437-.975a1.5 1.5 0 0 0 .547-.377.5.5 0 0 0 .11-.194.497.497 0 0 0 .139-.174c.095-.199.147-.42.147-.648V8.956M1 8.956a.5.5 0 1 0-1 0v2.867c0 .229.052.45.147.648.034.07.082.129.139.174.02.07.057.136.11.194a1.5 1.5 0 0 0 .547.377l2.437.975a.5.5 0 1 0 .372-.929l-2.438-.975a.499.499 0 0 1-.182-.125.507.507 0 0 0-.055-.052.503.503 0 0 0-.028-.071.498.498 0 0 1-.049-.216V8.956M5.377 13.912a.5.5 0 0 0-.372.929l2.438.975c.134.053.273.087.415.1A.5.5 0 0 0 8 15.91a.5.5 0 0 0 .142.007c.142-.013.281-.047.415-.1l2.438-.975a.5.5 0 1 0-.372-.929l-2.123.85v-2.637a.5.5 0 0 0-1 0v2.637l-2.123-.85M5.373 4.91a.5.5 0 0 0-.371.93l2.498.999v3.036a.5.5 0 1 0 1 0V6.839l2.498-1a.5.5 0 1 0-.371-.928L8 5.96l-2.627-1.05'/%3e%3c/svg%3e")`,
                "box-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.853.475.463 2.29A.75.75 0 0 0 0 2.984v6.032a.75.75 0 0 0 .463.693l4.39 1.816a3 3 0 0 0 2.294 0l4.39-1.816A.75.75 0 0 0 12 9.016V2.984a.75.75 0 0 0-.463-.693L7.147.475a3 3 0 0 0-2.294 0m-3.39 2.37a.375.375 0 1 0-.302.686l4.464 1.964V10.5a.375.375 0 0 0 .75 0V5.495l4.464-1.964a.375.375 0 1 0-.303-.687L6 4.84 1.464 2.844Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "box-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.47.633.619 3.055A1 1 0 0 0 0 3.979v8.042a1 1 0 0 0 .618.924l5.853 2.422a4 4 0 0 0 3.058 0l5.853-2.422a1 1 0 0 0 .618-.924V3.98a1 1 0 0 0-.618-.924L9.53.633a4 4 0 0 0-3.058 0m-4.519 3.16a.5.5 0 1 0-.402.915L7.5 7.326V14a.5.5 0 1 0 1 0V7.326l5.951-2.618a.5.5 0 0 0-.402-.916L8 6.454 1.951 3.792' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "box-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.423.187a1.125 1.125 0 0 0-.846 0L.826 2.114a1.125 1.125 0 0 0-.702 1.043v5.686c0 .458.278.87.702 1.043l4.75 1.928c.272.11.576.11.847 0l4.75-1.928c.425-.173.703-.585.703-1.043V3.157c0-.458-.278-.87-.702-1.043L6.423.187Zm-.564.695a.375.375 0 0 1 .282 0l4.362 1.77L6 4.479 1.496 2.652 5.86.882M.874 3.209v5.634c0 .153.093.29.234.348l4.517 1.832V5.137L.874 3.21m5.5 7.815 4.518-1.833a.375.375 0 0 0 .234-.348V3.21L6.375 5.136v5.888' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "box": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.557.184a1.5 1.5 0 0 0-1.114 0l-6.5 2.6A1.5 1.5 0 0 0 0 4.177v7.646a1.5 1.5 0 0 0 .943 1.393l6.5 2.6a1.5 1.5 0 0 0 1.114 0l6.5-2.6A1.5 1.5 0 0 0 16 11.823V4.177a1.5 1.5 0 0 0-.943-1.393l-6.5-2.6Zm-.743.929a.5.5 0 0 1 .372 0l6.102 2.441L8 6.069 1.712 3.554l6.102-2.441ZM1.002 4.132A.499.499 0 0 0 1 4.177v7.646a.5.5 0 0 0 .314.464L7.6 14.802V6.77L1.002 4.13M8.4 14.802l6.286-2.515a.5.5 0 0 0 .314-.464V4.177c0-.015 0-.03-.002-.045L8.4 6.77v8.03' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bookmark-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 1.688C2 .756 2.756 0 3.688 0h4.624C9.245 0 10 .756 10 1.688v9.937a.375.375 0 0 1-.58.315L6 9.394 2.58 11.94a.375.375 0 0 1-.58-.315V1.688' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bookmark-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 1C3.56 1 3 1.56 3 2.25v12.33l4.728-3.07a.5.5 0 0 1 .544 0L13 14.58V2.25C13 1.56 12.44 1 11.75 1zM2 2.25A2.25 2.25 0 0 1 4.25 0h7.5A2.25 2.25 0 0 1 14 2.25V15.5a.5.5 0 0 1-.772.42L8 12.524l-5.228 3.394A.5.5 0 0 1 2 15.5z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3 2.25C3 1.56 3.56 1 4.25 1h7.5c.69 0 1.25.56 1.25 1.25v12.33l-4.728-3.07a.5.5 0 0 0-.544 0L3 14.58z'/%3e%3c/svg%3e")`,
                "bookmark-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.688.75a.937.937 0 0 0-.938.938v9.246l3.046-2.302a.375.375 0 0 1 .408 0l3.046 2.302V1.688A.937.937 0 0 0 8.313.75H3.686M2 1.688C2 .756 2.756 0 3.688 0h4.624C9.245 0 10 .756 10 1.688v9.937a.375.375 0 0 1-.58.315L6 9.394 2.58 11.94a.375.375 0 0 1-.58-.315V1.688' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bookmark": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 1C3.56 1 3 1.56 3 2.25v12.33l4.728-3.07a.5.5 0 0 1 .544 0L13 14.58V2.25C13 1.56 12.44 1 11.75 1zM2 2.25A2.25 2.25 0 0 1 4.25 0h7.5A2.25 2.25 0 0 1 14 2.25V15.5a.5.5 0 0 1-.772.42L8 12.524l-5.228 3.394A.5.5 0 0 1 2 15.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-open-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.833 1.563c.104.07.167.187.167.312v8.25a.375.375 0 0 1-.552.33h-.002l-.01-.005a7.475 7.475 0 0 0-.655-.287v.712a.281.281 0 0 1-.343.274l-3.887-.883a7.226 7.226 0 0 0-.365.167l-.01.005h-.002a.375.375 0 0 1-.348 0h-.002l-.01-.005a5.732 5.732 0 0 0-.365-.167l-3.887.883a.281.281 0 0 1-.343-.274v-.713a7.476 7.476 0 0 0-.656.288l-.01.005H.553a.375.375 0 0 1-.552-.33v-8.25c0-.125.063-.242.167-.312h.001L.17 1.56l.004-.002.013-.009a3.728 3.728 0 0 1 .214-.123c.144-.077.351-.177.614-.277.525-.2 1.273-.4 2.173-.4.927 0 1.695.309 2.225.612.246.14.444.282.587.394.143-.112.34-.253.587-.394A4.499 4.499 0 0 1 8.813.75c.899 0 1.647.2 2.172.4a5.39 5.39 0 0 1 .782.372c.02.011.035.021.046.028l.013.009.005.002.001.001.001.001M7.571 9.921l2.648.602v-.55a5.175 5.175 0 0 0-1.407-.223c-.425 0-.853.071-1.241.17M3.188 9.75c.425 0 .853.071 1.241.17l-2.648.603v-.55c.43-.124.921-.222 1.407-.223Zm3.187-7.125c0-.362-.168-.656-.375-.656s-.375.294-.375.656V9c0 .362.168.656.375.656s.375-.294.375-.656z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-open-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.777 2.084A.5.5 0 0 1 16 2.5v11a.5.5 0 0 1-.735.441l-.003-.001-.013-.007a4.84 4.84 0 0 0-.278-.134 9.907 9.907 0 0 0-.596-.25v.951a.375.375 0 0 1-.458.366l-5.182-1.178a9.28 9.28 0 0 0-.487.222l-.013.007-.003.001a.5.5 0 0 1-.464 0l-.003-.001-.013-.007a7.272 7.272 0 0 0-.487-.222l-5.182 1.178a.375.375 0 0 1-.458-.366v-.95a9.908 9.908 0 0 0-.874.383l-.013.007H.736A.5.5 0 0 1 0 13.5v-11a.5.5 0 0 1 .223-.416l.001-.001.002-.001.006-.004.017-.011.062-.038a7.19 7.19 0 0 1 1.042-.496A8.169 8.169 0 0 1 4.25 1c1.237 0 2.26.412 2.967.816.329.188.593.376.783.525.19-.149.454-.337.783-.525C9.49 1.412 10.513 1 11.75 1c1.199 0 2.197.266 2.897.533a7.19 7.19 0 0 1 1.042.496l.062.038.017.011.006.004.002.001.001.001m-5.682 11.144 3.53.802v-.732c-.572-.167-1.228-.297-1.876-.298a6.714 6.714 0 0 0-1.655.228ZM4.25 13a6.714 6.714 0 0 1 1.655.228l-3.531.802v-.732C2.947 13.13 3.603 13 4.251 13M8.5 3.5c0-.483-.224-.875-.5-.875s-.5.392-.5.875V12c0 .483.224.875.5.875s.5-.392.5-.875z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-open-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.825 10.438h-.001l-.01-.005a5.732 5.732 0 0 0-.365-.167l-3.887.883a.281.281 0 0 1-.343-.274v-.713a7.476 7.476 0 0 0-.656.288l-.01.005H.553a.375.375 0 0 1-.552-.33v-8.25c0-.125.063-.242.167-.312l.208.312-.208-.312h.001L.17 1.56l.004-.002.013-.009a3.728 3.728 0 0 1 .214-.123c.144-.077.351-.177.614-.277.525-.2 1.273-.4 2.173-.4.927 0 1.695.309 2.225.612.246.14.444.282.587.394.143-.112.34-.253.587-.394A4.499 4.499 0 0 1 8.813.75c.899 0 1.647.2 2.172.4a5.39 5.39 0 0 1 .782.372c.02.011.035.021.046.028l.013.009.005.002.001.001s.001.001-.207.313l.208-.312c.104.07.167.187.167.312v8.25a.375.375 0 0 1-.552.33h-.002l-.01-.005a7.475 7.475 0 0 0-.655-.287v.712a.281.281 0 0 1-.343.274l-3.887-.883a7.226 7.226 0 0 0-.365.167l-.01.005h-.001a.377.377 0 0 1-.35 0M.75 9.541v-7.45l.004-.002c.12-.064.298-.151.528-.239a5.377 5.377 0 0 1 1.906-.35c.76 0 1.398.254 1.853.513a4.104 4.104 0 0 1 .584.404v7.11a8.445 8.445 0 0 0-.378-.141c-.546-.19-1.294-.387-2.06-.386-.767.001-1.516.203-2.062.398a8.424 8.424 0 0 0-.375.143m6.82.38 2.649.602v-.55a5.175 5.175 0 0 0-1.407-.223c-.425 0-.853.071-1.241.17M3.189 9.75c.425 0 .853.071 1.241.17l-2.648.603v-.55c.43-.124.921-.222 1.407-.223Zm3.187-.223c.112-.045.24-.093.378-.141.546-.19 1.294-.387 2.06-.386.767.001 1.516.203 2.062.398.137.049.263.097.375.143v-7.45l-.004-.002a4.656 4.656 0 0 0-.528-.239 5.377 5.377 0 0 0-1.905-.35 3.75 3.75 0 0 0-1.854.513 4.104 4.104 0 0 0-.584.404v7.11' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-open": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m7.767 13.918-.002-.001-.013-.007a7.272 7.272 0 0 0-.487-.222l-5.182 1.178a.375.375 0 0 1-.458-.366v-.95a9.908 9.908 0 0 0-.874.383l-.013.007H.736A.5.5 0 0 1 0 13.5v-11a.5.5 0 0 1 .223-.416L.5 2.5l-.277-.416.001-.001.002-.001.006-.004.017-.011.062-.038a7.19 7.19 0 0 1 1.042-.496A8.169 8.169 0 0 1 4.25 1c1.237 0 2.26.412 2.967.816.329.188.593.376.783.525.19-.149.454-.337.783-.525C9.49 1.412 10.513 1 11.75 1c1.199 0 2.197.266 2.897.533a7.19 7.19 0 0 1 1.042.496l.062.038.017.011.006.004.002.001s.001.001-.276.417l.277-.416A.5.5 0 0 1 16 2.5v11a.5.5 0 0 1-.736.441l-.002-.001-.013-.007a4.84 4.84 0 0 0-.278-.134 9.907 9.907 0 0 0-.596-.25v.951a.375.375 0 0 1-.458.366l-5.182-1.178a9.28 9.28 0 0 0-.487.222l-.013.007h-.002a.503.503 0 0 1-.466 0M1 12.722V2.788l.005-.003c.16-.085.398-.201.704-.318A7.169 7.169 0 0 1 4.25 2c1.013 0 1.865.338 2.47.684a5.47 5.47 0 0 1 .78.54v9.48c-.15-.061-.319-.126-.503-.19-.728-.253-1.726-.516-2.748-.514-1.023.002-2.02.271-2.749.53-.183.065-.351.13-.5.192m9.095.506 3.53.802v-.732c-.572-.167-1.228-.297-1.876-.298a6.714 6.714 0 0 0-1.655.228M4.25 13a6.714 6.714 0 0 1 1.655.228l-3.531.802v-.732C2.947 13.13 3.603 13 4.251 13m4.249-.297c.15-.06.319-.124.503-.189.728-.253 1.726-.516 2.748-.514 1.023.002 2.02.271 2.749.53.183.065.351.13.5.192V2.788l-.005-.003a6.201 6.201 0 0 0-.704-.318A7.17 7.17 0 0 0 11.75 2c-1.013 0-1.865.338-2.47.684a5.47 5.47 0 0 0-.78.54v9.48' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 1.688C1 .756 1.756 0 2.688 0H11v9.375a.375.375 0 0 1-.477.36v1.515h.102a.375.375 0 0 1 0 .75H2.688A1.687 1.687 0 0 1 1 10.313V1.688m1.688 9.562a.938.938 0 0 1-.933-.841.844.844 0 0 1 .839-.753H9.96v1.594H2.687' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2.25A2.25 2.25 0 0 1 4.25 0H14v12.5a.5.5 0 0 1-.637.481V15h.137a.5.5 0 0 1 0 1H4.25A2.25 2.25 0 0 1 2 13.75zM4.25 15a1.25 1.25 0 0 1-1.243-1.122 1.125 1.125 0 0 1 1.118-1.003h8.488V15z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.688 0C1.756 0 1 .756 1 1.688v8.625C1 11.244 1.756 12 2.688 12h7.937a.375.375 0 0 0 0-.75h-.102V9.736A.376.376 0 0 0 11 9.375V0H2.688m7.562 9.094V.75H2.688a.937.937 0 0 0-.938.938v7.687a1.4 1.4 0 0 1 .844-.281h7.656m-8.495 1.315a.938.938 0 0 0 .933.841H9.96V9.656H2.594a.844.844 0 0 0-.84.753' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "book": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 0A2.25 2.25 0 0 0 2 2.25v11.5A2.25 2.25 0 0 0 4.25 16h9.25a.5.5 0 0 0 0-1h-.137v-2.019A.5.5 0 0 0 14 12.5V0zM13 12.125V1H4.25C3.56 1 3 1.56 3 2.25V12.5a1.867 1.867 0 0 1 1.125-.375zm-9.993 1.753A1.25 1.25 0 0 0 4.25 15h8.363v-2.125H4.125c-.58 0-1.058.44-1.118 1.003Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bold-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.625 1h4.5C8.161 1 9 1.84 9 2.875v1.25c0 .57-.254 1.08-.656 1.425A2.625 2.625 0 0 1 9.75 7.875v.875A2.25 2.25 0 0 1 7.5 11H2.625v-.75H3v-8.5h-.375zm1.125.75v3.5h3.375c.621 0 1.125-.504 1.125-1.125v-1.25c0-.621-.504-1.125-1.125-1.125zM7.125 6H3.75v4.25H7.5A1.5 1.5 0 0 0 9 8.75v-.875C9 6.839 8.16 6 7.125 6' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bold": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1.875a.625.625 0 1 0 0 1.25h.375v9.75H3.5a.625.625 0 1 0 0 1.25h6a3.625 3.625 0 0 0 1.648-6.855A3.125 3.125 0 0 0 9 1.875zm5.5 5a1.875 1.875 0 0 0 0-3.75H5.125v3.75zm-3.875 1.25v4.75H9.5a2.375 2.375 0 1 0 0-4.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bluetooth-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.481.029a.375.375 0 0 1 .41.08l3 3a.375.375 0 0 1 0 .531L6.53 6l2.36 2.36a.375.375 0 0 1 0 .53l-3 3a.375.375 0 0 1-.641-.265V7.28L3.64 8.89a.375.375 0 0 1-.53-.53l2.14-2.14v-.44L3.11 3.64a.375.375 0 0 1 .53-.53l1.61 1.61V.375c0-.152.091-.288.231-.346ZM6 6.53v4.19l2.095-2.095L6 6.53m0-1.06 2.095-2.095L6 1.28v4.19' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bluetooth": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.309.038a.5.5 0 0 1 .545.108l4 4a.5.5 0 0 1 0 .708L8.707 8l3.147 3.146a.5.5 0 0 1 0 .708l-4 4A.5.5 0 0 1 7 15.5V9.707l-2.146 2.147a.5.5 0 0 1-.708-.707L7 8.293v-.586L4.146 4.854a.5.5 0 1 1 .708-.708L7 6.293V.5a.5.5 0 0 1 .309-.462ZM8 8.708v5.585l2.793-2.793L8 8.707m0-1.415L10.793 4.5 8 1.707v5.586' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-off-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='black' fill-rule='evenodd' d='M.733.267a.33.33 0 1 0-.466.466l2.171 2.172a3.823 3.823 0 0 0-.275 1.428v1.03c0 .712-.282 1.394-.786 1.897l-.41.411a1.15 1.15 0 0 0-.337.813v.45c0 .423.343.766.767.766h7.836l2.034 2.033a.33.33 0 0 0 .466-.466l-11-11Zm3.49 4.422-.52-.52c-.004.055-.006.11-.006.164a.383.383 0 0 0 .526.356m7.14 4.244c0 .125-.03.243-.082.347L5.094 3.094c.26-.19.576-.294.903-.294a.383.383 0 0 0 0-.767 2.3 2.3 0 0 0-1.45.514L3.46 1.46a3.833 3.833 0 0 1 6.37 2.874v1.029c0 .712.283 1.394.786 1.897l.41.411c.216.216.337.508.337.813v.45M5.997 12a1.917 1.917 0 0 1-1.917-1.917h.767a1.15 1.15 0 0 0 2.3 0h.766A1.917 1.917 0 0 1 5.997 12' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-off-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='black' fill-rule='evenodd' d='M.854.146a.5.5 0 1 0-.708.708L3.38 4.086A4.985 4.985 0 0 0 3 6v1.343a3.5 3.5 0 0 1-1.025 2.475l-.536.536A1.5 1.5 0 0 0 1 11.414V12a1 1 0 0 0 1 1h10.293l2.853 2.854a.5.5 0 0 0 .708-.708l-15-15Zm4.88 6.296-.72-.722A3.003 3.003 0 0 0 5 6a.5.5 0 0 0 .735.442M15 12a.997.997 0 0 1-.293.707L6.586 4.586A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-2.121.879L4.464 2.464A5 5 0 0 1 13 6v1.343a3.5 3.5 0 0 0 1.025 2.475l.536.536a1.5 1.5 0 0 1 .439 1.06zm-7 4a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-off-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='black' fill-rule='evenodd' d='M.733.267a.33.33 0 1 0-.466.466l2.171 2.172a3.823 3.823 0 0 0-.275 1.428v1.03c0 .712-.282 1.394-.786 1.897l-.41.411a1.15 1.15 0 0 0-.337.813v.45c0 .423.343.766.767.766h7.836l2.034 2.033a.33.33 0 0 0 .466-.466l-11-11Zm7.734 8.666L4.223 4.69a.382.382 0 0 1-.526-.356c0-.055.002-.11.006-.164l-.66-.66a3.07 3.07 0 0 0-.113.824v1.03a3.45 3.45 0 0 1-1.01 2.44l-.411.41a.383.383 0 0 0-.112.271v.45h7.07M5.997.5c-.973 0-1.861.362-2.537.96l.543.543a3.067 3.067 0 0 1 5.06 2.33v1.03a3.45 3.45 0 0 0 1.01 2.44l.411.41c.072.072.113.17.113.271v.113l.684.683a.764.764 0 0 0 .082-.347v-.449a1.15 1.15 0 0 0-.336-.813l-.411-.41a2.683 2.683 0 0 1-.786-1.898v-1.03A3.833 3.833 0 0 0 5.997.5m-1.45 2.047.547.547c.26-.19.576-.294.903-.294a.383.383 0 0 0 0-.767 2.3 2.3 0 0 0-1.45.514M5.997 12a1.917 1.917 0 0 1-1.917-1.917h.767a1.15 1.15 0 0 0 2.3 0h.766A1.917 1.917 0 0 1 5.997 12' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-off": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='black' fill-rule='evenodd' d='M.854.146a.5.5 0 1 0-.708.708L3.38 4.086A4.985 4.985 0 0 0 3 6v1.343a3.5 3.5 0 0 1-1.025 2.475l-.536.536A1.5 1.5 0 0 0 1 11.414V12a1 1 0 0 0 1 1h10.293l2.853 2.854a.5.5 0 0 0 .708-.708l-15-15ZM11.293 12 5.735 6.442A.5.5 0 0 1 5 6c0-.094.004-.187.013-.28l-.85-.85A4.001 4.001 0 0 0 4 6v1.343a4.5 4.5 0 0 1-1.318 3.182l-.536.536a.5.5 0 0 0-.146.353V12h9.293M8 1c-1.38 0-2.63.56-3.536 1.464l.708.708A4 4 0 0 1 12 6v1.343a4.5 4.5 0 0 0 1.318 3.182l.536.536a.5.5 0 0 1 .146.353V12l.707.707A.997.997 0 0 0 15 12v-.586a1.5 1.5 0 0 0-.44-1.06l-.535-.536A3.5 3.5 0 0 1 13 7.343V6a5 5 0 0 0-5-5M5.879 3.879l.707.707A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-2.121.879M8 16a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.997 12a1.917 1.917 0 0 1-1.917-1.917h.767a1.15 1.15 0 1 0 2.3 0h.766A1.917 1.917 0 0 1 5.997 12'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.997.5a3.833 3.833 0 0 0-3.834 3.833v1.03c0 .712-.282 1.394-.786 1.897l-.41.411a1.15 1.15 0 0 0-.337.813v.45c0 .423.343.766.767.766h9.2a.767.767 0 0 0 .766-.767v-.449a1.15 1.15 0 0 0-.336-.813l-.411-.41a2.683 2.683 0 0 1-.786-1.898v-1.03A3.833 3.833 0 0 0 5.997.5M4.912 3.25c.288-.288.678-.45 1.085-.45a.383.383 0 1 0 0-.767 2.3 2.3 0 0 0-2.3 2.3.383.383 0 0 0 .766 0c0-.406.162-.796.45-1.084' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 16a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 1a5 5 0 0 0-5 5v1.343a3.5 3.5 0 0 1-1.025 2.475l-.536.536A1.5 1.5 0 0 0 1 11.414V12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-.586a1.5 1.5 0 0 0-.44-1.06l-.535-.536A3.5 3.5 0 0 1 13 7.343V6a5 5 0 0 0-5-5M6.586 4.586A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-3 3 .5.5 0 0 0 1 0 2 2 0 0 1 .586-1.414' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.163 4.333a3.833 3.833 0 1 1 7.667 0v1.03c0 .712.283 1.394.786 1.897l.41.411c.216.216.337.508.337.813v.45a.767.767 0 0 1-.766.766h-9.2a.767.767 0 0 1-.767-.767v-.449c0-.305.121-.597.337-.813l.41-.41a2.683 2.683 0 0 0 .786-1.898v-1.03m3.834-3.066A3.067 3.067 0 0 0 2.93 4.333v1.03a3.45 3.45 0 0 1-1.01 2.44l-.411.41a.383.383 0 0 0-.112.271v.45h9.2v-.45c0-.101-.04-.199-.113-.27l-.41-.411a3.45 3.45 0 0 1-1.01-2.44v-1.03a3.067 3.067 0 0 0-3.067-3.066m0 10.733a1.917 1.917 0 0 1-1.917-1.917h.767a1.15 1.15 0 1 0 2.3 0h.766A1.917 1.917 0 0 1 5.997 12M4.912 3.25c.288-.288.678-.45 1.085-.45a.383.383 0 1 0 0-.767 2.3 2.3 0 0 0-2.3 2.3.383.383 0 0 0 .766 0c0-.406.162-.796.45-1.084Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bell": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 6a5 5 0 0 1 10 0v1.343a3.5 3.5 0 0 0 1.025 2.475l.536.536a1.5 1.5 0 0 1 .439 1.06V12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-.586c0-.398.158-.78.44-1.06l.535-.536A3.5 3.5 0 0 0 3 7.343zm5-4a4 4 0 0 0-4 4v1.343a4.5 4.5 0 0 1-1.318 3.182l-.536.536a.5.5 0 0 0-.146.353V12h12v-.586a.5.5 0 0 0-.146-.353l-.536-.536A4.5 4.5 0 0 1 12 7.343V6a4 4 0 0 0-4-4m0 14a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16M6.586 4.586A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-3 3 .5.5 0 0 0 1 0 2 2 0 0 1 .586-1.414Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "battery-charging-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5.625 5.25 6.75 1.5 3.938 6 6 6.75 4.875 10.5 7.688 6zM.75 3.938c0-.518.42-.938.938-.938h1.687a.375.375 0 1 0 0-.75H1.688C.756 2.25 0 3.006 0 3.938v4.124C0 8.995.756 9.75 1.688 9.75h1.687a.375.375 0 1 0 0-.75H1.688a.937.937 0 0 1-.938-.937V3.936'/%3e%3cpath fill='%230E1011' d='M7.875 2.25a.375.375 0 1 0 0 .75h1.688c.517 0 .937.42.937.938v4.124c0 .518-.42.938-.937.938H7.875a.375.375 0 1 0 0 .75h1.688c.931 0 1.687-.756 1.687-1.687V7.5h.188c.31 0 .562-.252.562-.562v-1.5a.562.562 0 0 0-.562-.563h-.188v-.937c0-.932-.755-1.688-1.687-1.688z'/%3e%3c/svg%3e")`,
                "battery-charging": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.5 7 9 2 5.25 8 8 9l-1.5 5 3.75-6zM1 5.25C1 4.56 1.56 4 2.25 4H4.5a.5.5 0 0 0 0-1H2.25A2.25 2.25 0 0 0 0 5.25v5.5A2.25 2.25 0 0 0 2.25 13H4.5a.5.5 0 0 0 0-1H2.25C1.56 12 1 11.44 1 10.75z'/%3e%3cpath fill='%230E1011' d='M10.5 3a.5.5 0 0 0 0 1h2.25c.69 0 1.25.56 1.25 1.25v5.5c0 .69-.56 1.25-1.25 1.25H10.5a.5.5 0 0 0 0 1h2.25A2.25 2.25 0 0 0 15 10.75V10h.25a.75.75 0 0 0 .75-.75v-2a.75.75 0 0 0-.75-.75H15V5.25A2.25 2.25 0 0 0 12.75 3z'/%3e%3c/svg%3e")`,
                "battery-50%-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 9.563 3H1.686M0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.562.562h-.188v.563c0 .931-.755 1.687-1.687 1.687H1.686A1.688 1.688 0 0 1 0 8.063V3.936' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 4.125c0-.207.168-.375.375-.375h3.75c.207 0 .375.168.375.375v3.75a.375.375 0 0 1-.375.375h-3.75a.375.375 0 0 1-.375-.375z'/%3e%3c/svg%3e")`,
                "battery-50%": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4zM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5z'/%3e%3c/svg%3e")`,
                "battery-33%-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 9.563 3H1.686M0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.562.562h-.188v.563c0 .931-.755 1.687-1.687 1.687H1.686A1.688 1.688 0 0 1 0 8.063V3.936' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 4.125c0-.207.168-.375.375-.375h1.5c.207 0 .375.168.375.375v3.75a.375.375 0 0 1-.375.375h-1.5a.375.375 0 0 1-.375-.375z'/%3e%3c/svg%3e")`,
                "battery-33%": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4zM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 5.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5z'/%3e%3c/svg%3e")`,
                "battery-100%-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 9.563 3H1.686M0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.562.562h-.188v.563c0 .931-.755 1.687-1.687 1.687H1.686A1.688 1.688 0 0 1 0 8.063V3.936' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 4.125c0-.207.168-.375.375-.375h7.5c.207 0 .375.168.375.375v3.75a.375.375 0 0 1-.375.375h-7.5a.375.375 0 0 1-.375-.375z'/%3e%3c/svg%3e")`,
                "battery-100%": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4zM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 5.5a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-10a.5.5 0 0 1-.5-.5z'/%3e%3c/svg%3e")`,
                "battery-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.937V3.936A.937.937 0 0 0 9.563 3H1.686M0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.562.562h-.188v.563c0 .931-.755 1.687-1.687 1.687H1.686A1.688 1.688 0 0 1 0 8.063V3.936' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "battery": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4zM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bar-chart-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M9 2a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1zM1 7a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1zM6 4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V5a1 1 0 0 0-1-1z'/%3e%3c/svg%3e")`,
                "bar-chart-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11 2v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1M6 6v8a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1M1 10v4a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-4a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1'/%3e%3c/svg%3e")`,
                "bar-chart-2-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5 2a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1zM1 7a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1zM10 4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V5a1 1 0 0 0-1-1z'/%3e%3c/svg%3e")`,
                "bar-chart-2-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11 6.5V14a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V6.5a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1M6 2v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1M1 9v5a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1'/%3e%3c/svg%3e")`,
                "bar-chart-2-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1zm1 .75H6a.25.25 0 0 0-.25.25v8c0 .138.112.25.25.25h1a.25.25 0 0 0 .25-.25V2A.25.25 0 0 0 7 1.75M2 6a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V7a1 1 0 0 0-1-1zm1 .75H2a.25.25 0 0 0-.25.25v3c0 .138.112.25.25.25h1a.25.25 0 0 0 .25-.25V7A.25.25 0 0 0 3 6.75M9 5a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1zm1-.25h1a.25.25 0 0 1 .25.25v5a.25.25 0 0 1-.25.25h-1a.25.25 0 0 1-.25-.25V5a.25.25 0 0 1 .25-.25' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bar-chart-2": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.5 2a.5.5 0 0 0-.5.5v11a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5zM6 2.5A1.5 1.5 0 0 1 7.5 1h1A1.5 1.5 0 0 1 10 2.5v11A1.5 1.5 0 0 1 8.5 15h-1A1.5 1.5 0 0 1 6 13.5zm6.5 4a.5.5 0 0 0-.5.5v6.5a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5V7a.5.5 0 0 0-.5-.5h-1M11 7a1.5 1.5 0 0 1 1.5-1.5h1A1.5 1.5 0 0 1 15 7v6.5a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5V7M2.5 9a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5zM1 9.5A1.5 1.5 0 0 1 2.5 8h1A1.5 1.5 0 0 1 5 9.5v4A1.5 1.5 0 0 1 3.5 15h-1A1.5 1.5 0 0 1 1 13.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bar-chart-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1zm1 .75h-1a.25.25 0 0 0-.25.25v8c0 .138.112.25.25.25h1a.25.25 0 0 0 .25-.25V2a.25.25 0 0 0-.25-.25M2 6a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V7a1 1 0 0 0-1-1zm1 .75H2a.25.25 0 0 0-.25.25v3c0 .138.112.25.25.25h1a.25.25 0 0 0 .25-.25V7A.25.25 0 0 0 3 6.75M5 5a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1zm1-.25h1a.25.25 0 0 1 .25.25v5a.25.25 0 0 1-.25.25H6a.25.25 0 0 1-.25-.25V5A.25.25 0 0 1 6 4.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "bar-chart": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.5 2a.5.5 0 0 0-.5.5v11a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 12.5 1h1A1.5 1.5 0 0 1 15 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5zM7.5 6a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-1M6 6.5A1.5 1.5 0 0 1 7.5 5h1A1.5 1.5 0 0 1 10 6.5v7A1.5 1.5 0 0 1 8.5 15h-1A1.5 1.5 0 0 1 6 13.5v-7M2.5 10a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5zm-1.5.5A1.5 1.5 0 0 1 2.5 9h1A1.5 1.5 0 0 1 5 10.5v3A1.5 1.5 0 0 1 3.5 15h-1A1.5 1.5 0 0 1 1 13.5z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "award-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 7.5A3.75 3.75 0 1 0 6 0a3.75 3.75 0 0 0 0 7.5M3.004 11.568 3.62 7.57c.69.43 1.506.68 2.38.68.874 0 1.69-.25 2.38-.68l.616 3.998a.375.375 0 0 1-.557.383L6 10.557 3.561 11.95a.375.375 0 0 1-.557-.383'/%3e%3c/svg%3e")`,
                "award-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 10A5 5 0 1 0 8 0a5 5 0 0 0 0 10M4.006 15.424l.82-5.331C5.746 10.668 6.835 11 8 11a5.972 5.972 0 0 0 3.174-.907l.82 5.331a.5.5 0 0 1-.742.51L8 14.076l-3.252 1.858a.5.5 0 0 1-.742-.51'/%3e%3c/svg%3e")`,
                "award-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a3.75 3.75 0 0 0-2.254 6.747l-.742 4.821a.375.375 0 0 0 .557.383L6 10.557l2.439 1.394a.375.375 0 0 0 .557-.383l-.742-4.82A3.75 3.75 0 0 0 6 0M3 3.75a3 3 0 1 1 6 0 3 3 0 0 1-6 0m4.559 3.412A3.736 3.736 0 0 1 6 7.5a3.736 3.736 0 0 1-1.559-.338l-.577 3.752 1.95-1.115a.375.375 0 0 1 .372 0l1.95 1.115-.577-3.752' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "award": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a5 5 0 0 0-3.005 8.996l-.99 6.428a.5.5 0 0 0 .743.51L8 14.076l3.252 1.858a.5.5 0 0 0 .742-.51l-.989-6.428A5 5 0 0 0 8 0M4 5a4 4 0 1 1 8 0 4 4 0 0 1-8 0m6.079 4.549A4.982 4.982 0 0 1 8 10a4.982 4.982 0 0 1-2.079-.451l-.77 5.003 2.6-1.486a.5.5 0 0 1 .497 0l2.6 1.486-.77-5.003' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "at-sign-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0a5.982 5.982 0 0 0-4.243 1.757 6 6 0 1 0 8.485 8.485.375.375 0 1 0-.53-.53A5.25 5.25 0 1 1 11.25 6v.563a1.312 1.312 0 1 1-2.625 0V3.75a.375.375 0 1 0-.75 0v.413a2.625 2.625 0 1 0 .248 3.381A2.062 2.062 0 0 0 12 6.563V6a6 6 0 0 0-6-6m1.875 6a1.875 1.875 0 1 0-3.75 0 1.875 1.875 0 0 0 3.75 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "at-sign": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0C5.791 0 3.79.896 2.343 2.343a8 8 0 1 0 11.314 11.314.5.5 0 0 0-.707-.707A7 7 0 1 1 15 8v.75a1.75 1.75 0 1 1-3.5 0V5a.5.5 0 0 0-1 0v.55a3.5 3.5 0 1 0 .33 4.508A2.75 2.75 0 0 0 16 8.75V8a8 8 0 0 0-8-8m2.5 8a2.5 2.5 0 1 0-5 0 2.5 2.5 0 0 0 5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 3.375A.375.375 0 0 0 8.625 3h-4.5a.375.375 0 1 0 0 .75H7.72L3.11 8.36a.375.375 0 1 0 .53.53l4.61-4.61v3.595a.375.375 0 1 0 .75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4.5a.5.5 0 0 0-.5-.5h-6a.5.5 0 0 0 0 1h4.793l-6.147 6.146a.5.5 0 0 0 .708.708L11 5.707V10.5a.5.5 0 0 0 1 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 3.375C3 3.168 3.168 3 3.375 3h4.5a.375.375 0 1 1 0 .75H4.28l4.61 4.61a.375.375 0 1 1-.53.53L3.75 4.28v3.595a.375.375 0 1 1-.75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 4.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1H5.707l6.147 6.146a.5.5 0 0 1-.708.708L5 5.707V10.5a.5.5 0 0 1-1 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.5.909.732 3.738a.375.375 0 1 0 .536.524l1.857-1.897V9.5a.375.375 0 0 0 .75 0V2.365l1.857 1.897a.375.375 0 0 0 .536-.524L3.5.908ZM8.5 11.03 5.735 8.265a.375.375 0 1 1 .53-.53l1.86 1.86v-7.15a.375.375 0 0 1 .75 0v7.15l1.86-1.86a.375.375 0 0 1 .53.53L8.5 11.03'/%3e%3c/svg%3e")`,
                "arrow-up-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.146 14.854a.5.5 0 0 0 .708 0l4-4a.5.5 0 0 0-.708-.708L12 13.293V3.5a.5.5 0 0 0-1 0v9.793l-3.146-3.147a.5.5 0 0 0-.708.708l4 4M4.146 1.146a.5.5 0 0 1 .708 0l4 4a.5.5 0 1 1-.708.708L5 2.707V12.5a.5.5 0 0 1-1 0V2.707L.854 5.854a.5.5 0 1 1-.708-.708l4-4Z'/%3e%3c/svg%3e")`,
                "arrow-up-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-4.015.265a.375.375 0 0 0 .53-.53l-2.25-2.25a.375.375 0 0 0-.53 0l-2.25 2.25a.375.375 0 1 0 .53.53l1.61-1.61V8.25a.375.375 0 1 0 .75 0V4.655l1.61 1.61' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-3.94.354a.5.5 0 0 1-.708 0L8.5 6.207V11a.5.5 0 0 1-1 0V6.207L5.354 8.354a.5.5 0 0 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M7.985 6.265a.375.375 0 0 0 .53-.53l-2.25-2.25a.375.375 0 0 0-.53 0l-2.25 2.25a.375.375 0 1 0 .53.53l1.61-1.61V8.25a.375.375 0 1 0 .75 0V4.655l1.61 1.61'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.354 8.354a.5.5 0 0 1-.708 0L8.5 6.207V11a.5.5 0 0 1-1 0V6.207L5.354 8.354a.5.5 0 0 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.985 5.515a.375.375 0 0 1 0-.53l3.75-3.75a.375.375 0 0 1 .53 0l3.75 3.75a.375.375 0 0 1-.53.53l-3.11-3.11V10.5a.375.375 0 0 1-.75 0V2.405l-3.11 3.11a.375.375 0 0 1-.53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-up": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.646 7.354a.5.5 0 0 1 0-.708l5-5a.5.5 0 0 1 .708 0l5 5a.5.5 0 0 1-.708.708L8.5 3.207V14a.5.5 0 0 1-1 0V3.207L3.354 7.354a.5.5 0 0 1-.708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-right-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0m-8.25-.375a.375.375 0 1 0 0 .75h3.595l-1.61 1.61a.375.375 0 1 0 .53.53l2.25-2.25a.375.375 0 0 0 0-.53l-2.25-2.25a.375.375 0 1 0-.53.53l1.61 1.61z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-right-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 0 0 14.599 7.3 7.3 0 0 0 0-14.6Zm-.354 3.94a.5.5 0 0 0 0 .708L9.793 7.5H5a.5.5 0 1 0 0 1h4.793l-2.147 2.146a.5.5 0 1 0 .708.708l3-3a.5.5 0 0 0 0-.707l-3-3a.5.5 0 0 0-.708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-right-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M3.75 5.625a.375.375 0 1 0 0 .75h3.595l-1.61 1.61a.375.375 0 1 0 .53.53l2.25-2.25a.375.375 0 0 0 0-.53l-2.25-2.25a.375.375 0 1 0-.53.53l1.61 1.61z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-right-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.646 4.647a.5.5 0 0 0 0 .707L9.793 7.5H5a.5.5 0 1 0 0 1h4.793l-2.147 2.146a.5.5 0 1 0 .708.708l3-3a.5.5 0 0 0 0-.707l-3-3a.5.5 0 0 0-.708 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 0 0 14.599 7.3 7.3 0 0 0 0-14.6Zm0 1a6.3 6.3 0 1 0 0 12.599 6.3 6.3 0 0 0 0-12.6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.485 1.985a.375.375 0 0 1 .53 0l3.75 3.75a.375.375 0 0 1 0 .53l-3.75 3.75a.375.375 0 0 1-.53-.53l3.11-3.11H1.5a.375.375 0 1 1 0-.75h8.095l-3.11-3.11a.375.375 0 0 1 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.646 2.646a.5.5 0 0 1 .708 0l5 5a.5.5 0 0 1 0 .708l-5 5a.5.5 0 0 1-.708-.708L12.793 8.5H2a.5.5 0 0 1 0-1h10.793L8.646 3.354a.5.5 0 0 1 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-left-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M.94 3.47 3.767.702a.375.375 0 0 1 .525.536L2.395 3.095H9.53a.375.375 0 1 1 0 .75H2.395l1.898 1.857a.375.375 0 1 1-.525.536L.94 3.47M11.06 8.47 8.297 5.705a.375.375 0 0 0-.53.53l1.86 1.86h-7.15a.375.375 0 1 0 0 .75h7.15l-1.86 1.86a.375.375 0 1 0 .53.53L11.06 8.47'/%3e%3c/svg%3e")`,
                "arrow-left-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.146 4.854a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 4H12.5a.5.5 0 0 1 0 1H2.707l3.147 3.146a.5.5 0 1 1-.708.708l-4-4ZM14.854 11.854a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 11H3.5a.5.5 0 0 0 0 1h9.793l-3.147 3.146a.5.5 0 0 0 .708.708l4-4'/%3e%3c/svg%3e")`,
                "arrow-left-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M6.265 4.015a.375.375 0 0 0-.53-.53l-2.25 2.25a.375.375 0 0 0 0 .53l2.25 2.25a.375.375 0 0 0 .53-.53l-1.61-1.61H8.25a.375.375 0 1 0 0-.75H4.655l1.61-1.61' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-left-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 1 0 14.599 7.3 7.3 0 0 1 0-14.6Zm.354 3.94a.5.5 0 0 1 0 .708L6.207 7.5H11a.5.5 0 0 1 0 1H6.207l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.707l3-3a.5.5 0 0 1 .708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-left-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.265 4.015a.375.375 0 0 0-.53-.53l-2.25 2.25a.375.375 0 0 0 0 .53l2.25 2.25a.375.375 0 0 0 .53-.53l-1.61-1.61H8.25a.375.375 0 1 0 0-.75H4.655l1.61-1.61'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-left-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.354 4.647a.5.5 0 0 1 0 .707L6.207 7.5H11a.5.5 0 0 1 0 1H6.207l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.707l3-3a.5.5 0 0 1 .708 0'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 1 0 14.599 7.3 7.3 0 0 1 0-14.6Zm0 1a6.3 6.3 0 1 1 0 12.599 6.3 6.3 0 0 1 0-12.6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.89 1.985a.375.375 0 0 0-.53 0l-3.75 3.75a.375.375 0 0 0 0 .53l3.75 3.75a.375.375 0 0 0 .53-.53l-3.11-3.11h8.095a.375.375 0 0 0 0-.75H2.78l3.11-3.11a.375.375 0 0 0 0-.53' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.854 2.646a.5.5 0 0 0-.708 0l-5 5a.5.5 0 0 0 0 .708l5 5a.5.5 0 0 0 .708-.708L3.707 8.5H14.5a.5.5 0 0 0 0-1H3.707l4.147-4.146a.5.5 0 0 0 0-.708' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 8.625A.375.375 0 0 1 8.625 9h-4.5a.375.375 0 1 1 0-.75H7.72L3.11 3.64a.375.375 0 1 1 .53-.53l4.61 4.61V4.125a.375.375 0 1 1 .75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 11.5a.5.5 0 0 1-.5.5h-6a.5.5 0 0 1 0-1h4.793L4.146 4.854a.5.5 0 1 1 .708-.708L11 10.293V5.5a.5.5 0 0 1 1 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 8.625c0 .207.168.375.375.375h4.5a.375.375 0 1 0 0-.75H4.28l4.61-4.61a.375.375 0 1 0-.53-.53L3.75 7.72V4.125a.375.375 0 1 0-.75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 11.5a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 0-1H5.707l6.147-6.146a.5.5 0 0 0-.708-.708L5 10.293V5.5a.5.5 0 0 0-1 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M6.375 3.75a.375.375 0 1 0-.75 0v3.595l-1.61-1.61a.375.375 0 1 0-.53.53l2.25 2.25a.375.375 0 0 0 .53 0l2.25-2.25a.375.375 0 0 0-.53-.53l-1.61 1.61z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.706 8a7.3 7.3 0 1 1 14.599 0 7.3 7.3 0 0 1-14.6 0Zm3.94-.353a.5.5 0 0 1 .708 0L7.5 9.793V5a.5.5 0 0 1 1 0v4.793l2.146-2.146a.5.5 0 1 1 .707.707l-3 3a.5.5 0 0 1-.707 0l-3-3a.5.5 0 0 1 0-.707' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.375 3.75a.375.375 0 1 0-.75 0v3.595l-1.61-1.61a.375.375 0 1 0-.53.53l2.25 2.25a.375.375 0 0 0 .53 0l2.25-2.25a.375.375 0 0 0-.53-.53l-1.61 1.61z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.354 7.647a.5.5 0 0 0-.708 0L8.5 9.793V5a.5.5 0 0 0-1 0v4.793L5.354 7.647a.5.5 0 1 0-.708.707l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0 0-.707'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0m-1 0A6.3 6.3 0 1 0 1.695 8a6.3 6.3 0 0 0 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.985 6.485a.375.375 0 0 0 0 .53l3.75 3.75a.375.375 0 0 0 .53 0l3.75-3.75a.375.375 0 0 0-.53-.53l-3.11 3.11V1.5a.375.375 0 1 0-.75 0v8.095l-3.11-3.11a.375.375 0 0 0-.53 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "arrow-down": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.646 8.646a.5.5 0 0 0 0 .708l5 5a.5.5 0 0 0 .708 0l5-5a.5.5 0 0 0-.708-.708L8.5 12.793V2a.5.5 0 0 0-1 0v10.793L3.354 8.646a.5.5 0 0 0-.708 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "archive-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 1.875C0 1.392.392 1 .875 1h10c.483 0 .875.392.875.875v2a.875.875 0 0 1-.875.875v4.125c0 1.036-.84 1.875-1.875 1.875H2.75A1.875 1.875 0 0 1 .875 8.875V4.75A.875.875 0 0 1 0 3.875zm4.625 4.5a.25.25 0 0 1 .25-.25h2a.25.25 0 0 1 0 .5h-2a.25.25 0 0 1-.25-.25M2.5 4.125a.375.375 0 1 0 0 .75h7a.375.375 0 1 0 0-.75z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "archive-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v5.75A2.25 2.25 0 0 1 12.75 14h-9.5A2.25 2.25 0 0 1 1 11.75V6a1 1 0 0 1-1-1zm1.75 2.5a.5.5 0 0 1 .5-.5h11.5a.5.5 0 0 1 0 1H2.25a.5.5 0 0 1-.5-.5m4.375 2.75c0-.207.168-.375.375-.375h3a.375.375 0 1 1 0 .75h-3a.375.375 0 0 1-.375-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "archive-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M5 6.25a.25.25 0 0 0 0 .5h2a.25.25 0 0 0 0-.5z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.125 2c0-.483.392-.875.875-.875h10c.483 0 .875.392.875.875v2a.875.875 0 0 1-.875.875V9c0 1.036-.84 1.875-1.875 1.875h-6.25A1.875 1.875 0 0 1 1 9V4.875A.875.875 0 0 1 .125 4zM1.75 4.875h8.5V9c0 .621-.504 1.125-1.125 1.125h-6.25A1.125 1.125 0 0 1 1.75 9zm9.25-.75H1A.125.125 0 0 1 .875 4V2c0-.069.056-.125.125-.125h10c.069 0 .125.056.125.125v2a.125.125 0 0 1-.125.125' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "archive": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 8a.25.25 0 0 0 0 .5h3a.25.25 0 0 0 0-.5z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1v5.75A2.25 2.25 0 0 0 3.25 14h9.5A2.25 2.25 0 0 0 15 11.75V6a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1zm1 9.75V6h12v5.75c0 .69-.56 1.25-1.25 1.25h-9.5C2.56 13 2 12.44 2 11.75M1 3h14v2H1z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "appearance-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6a6 6 0 1 1 12 0A6 6 0 0 1 0 6m11.25 0C11.25 3.1 8.9.75 6 .75V3a3 3 0 0 0 0 6v2.25c2.9 0 5.25-2.35 5.25-5.25M6 9a3 3 0 0 0 0-6z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "appearance": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.294 8a6.3 6.3 0 0 1-6.3 6.3V11H8a3 3 0 1 0 0-6h-.005V1.7a6.3 6.3 0 0 1 6.3 6.3Zm-6.3-3a3 3 0 0 0 0 6V5m7.3 3A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "aperture-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12M6.769.544c.134.077.18.25.103.384L5.296 3.656h5.533a.281.281 0 1 1 0 .563H7.678l2.766 4.79a.281.281 0 0 1-.487.282L8.382 6.563l-2.766 4.79a.28.28 0 1 1-.488-.28l1.576-2.73H1.17a.281.281 0 0 1 0-.562h3.151l-2.766-4.79a.281.281 0 1 1 .487-.282l1.575 2.728L6.384.647A.281.281 0 0 1 6.77.544Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "aperture-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-7.907 6.408a.356.356 0 0 1-.13-.486l1.67-2.892H2.5a.356.356 0 1 1 0-.713h3.34L2.625 4.752a.356.356 0 1 1 .617-.357l1.67 2.892 3.213-5.565a.356.356 0 0 1 .617.356L7.073 4.97H13.5a.356.356 0 0 1 0 .712h-3.34l3.214 5.566a.356.356 0 1 1-.617.356l-1.67-2.892-3.213 5.566a.356.356 0 0 1-.487.13' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "aperture-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.002 5.998a6 6 0 1 1-12 0 6 6 0 0 1 12 0m-1.976 3.373a5.239 5.239 0 0 1-4.344 1.867l2.7-4.675L9.957 9.29a.281.281 0 0 0 .069.08m.353-.473-2.701-4.68h3.151a.28.28 0 0 0 .106-.02 5.24 5.24 0 0 1 .317 1.8 5.226 5.226 0 0 1-.873 2.9m.323-5.242H5.296L6.872.928a.28.28 0 0 0 .035-.102 5.257 5.257 0 0 1 3.795 2.83M6.321.758A5.239 5.239 0 0 0 1.975 2.63a.28.28 0 0 1 .068.08L3.62 5.437 6.32.758m-4.7 2.346c-.549.83-.869 1.824-.869 2.894 0 .633.112 1.24.318 1.802a.28.28 0 0 1 .1-.019h3.152l-2.7-4.677Zm-.317 5.24a5.257 5.257 0 0 0 3.79 2.826.28.28 0 0 1 .034-.098l1.576-2.728h-5.4Zm3.668-.563-1.029-1.78 1.029-1.782h2.057L8.057 6 7.029 7.781H4.972' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "aperture": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-2.34 3.886a6.289 6.289 0 0 1-5.091 2.412l3.225-5.586 1.77 3.065c.024.044.057.08.095.109m.43-.622L10.16 5.682H13.7c.05 0 .099-.01.142-.03.292.726.452 1.518.452 2.348a6.27 6.27 0 0 1-.91 3.264m.135-6.294H7.073l1.77-3.065a.355.355 0 0 0 .046-.142 6.304 6.304 0 0 1 4.63 3.207M8.137 1.702A6.288 6.288 0 0 0 3.04 4.109c.04.03.076.067.103.113l1.77 3.065 3.224-5.585M2.611 4.727A6.27 6.27 0 0 0 1.695 8c0 .831.161 1.625.454 2.351a.354.354 0 0 1 .151-.034h3.54L2.61 4.728Zm-.14 6.303a6.304 6.304 0 0 0 4.64 3.208.355.355 0 0 1 .046-.143l1.77-3.065H2.47m6.867-5.348L10.676 8l-1.338 2.317H6.662L5.324 8l1.338-2.318h2.676' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "anchor-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1.125a1.125 1.125 0 1 0 0 2.25 1.125 1.125 0 0 0 0-2.25M4.125 2.25a1.875 1.875 0 1 1 2.25 1.837v6.776c2.216-.15 3.928-1.615 4.11-3.738H9.75a.375.375 0 1 1 0-.75h1.5v.375c0 2.938-2.391 4.875-5.25 4.875S.75 9.688.75 6.75v-.375h1.5a.375.375 0 1 1 0 .75h-.734c.18 2.123 1.893 3.589 4.109 3.738V4.087a1.876 1.876 0 0 1-1.5-1.837' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "anchor": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 1.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3M5.5 3a2.5 2.5 0 1 1 3 2.45v9.033c2.954-.198 5.238-2.152 5.479-4.983H13a.5.5 0 0 1 0-1h2V9c0 3.917-3.188 6.5-7 6.5S1 12.917 1 9v-.5h2a.5.5 0 0 1 0 1h-.979c.241 2.831 2.525 4.785 5.479 4.983V5.45A2.5 2.5 0 0 1 5.5 3' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "align-right-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.5 3.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75zM4.125 5.5c0-.207.168-.375.375-.375h6a.375.375 0 0 1 0 .75h-6a.375.375 0 0 1-.375-.375M1.5 7.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75zM4.5 9.125a.375.375 0 1 0 0 .75h6a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "align-right": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m4 3A.5.5 0 0 1 6 6h8a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5m-4 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m4 3A.5.5 0 0 1 6 12h8a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "align-left-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M10.5 3.125a.375.375 0 0 1 0 .75h-9a.375.375 0 1 1 0-.75zM7.875 5.5a.375.375 0 0 0-.375-.375h-6a.375.375 0 1 0 0 .75h6a.375.375 0 0 0 .375-.375M10.5 7.125a.375.375 0 0 1 0 .75h-9a.375.375 0 1 1 0-.75zM7.5 9.125a.375.375 0 1 1 0 .75h-6a.375.375 0 1 1 0-.75z'/%3e%3c/svg%3e")`,
                "align-left": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 2 6h8a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 2 12h8a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "align-justify-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.5 3.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75zM1.125 5.5c0-.207.168-.375.375-.375h9a.375.375 0 0 1 0 .75h-9a.375.375 0 0 1-.375-.375M1.5 7.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75zM1.5 9.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75z'/%3e%3c/svg%3e")`,
                "align-justify": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 2 6h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m0 3A.5.5 0 0 1 2 12h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "align-center-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M1.5 3.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75zM3.125 5.5c0-.207.168-.375.375-.375h5a.375.375 0 1 1 0 .75h-5a.375.375 0 0 1-.375-.375M1.5 7.125a.375.375 0 1 0 0 .75h9a.375.375 0 0 0 0-.75zM2.5 9.125a.375.375 0 1 0 0 .75h7a.375.375 0 1 0 0-.75z'/%3e%3c/svg%3e")`,
                "align-center": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m2 3A.5.5 0 0 1 4 6h8a.5.5 0 0 1 0 1H4a.5.5 0 0 1-.5-.5m-2 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5m2 3A.5.5 0 0 1 4 12h8a.5.5 0 0 1 0 1H4a.5.5 0 0 1-.5-.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-triangle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.154 10.011 5.018.638c.102-.195.247-.356.419-.467C5.609.059 5.803 0 6 0c.197 0 .391.059.563.17.172.112.317.273.419.468l4.864 9.373c.1.2.153.428.154.66 0 .231-.051.459-.15.66-.1.201-.243.369-.416.486-.173.117-.37.18-.57.183H1.136a1.035 1.035 0 0 1-.57-.183 1.255 1.255 0 0 1-.415-.486A1.487 1.487 0 0 1 0 10.67c0-.232.054-.46.154-.66M6.656 4.5a.656.656 0 1 0-1.312 0v2.625a.656.656 0 1 0 1.312 0V4.5m0 4.125a.656.656 0 1 0-1.312 0V9a.656.656 0 0 0 1.312 0v-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-triangle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.547.921C8.889-.32 7.11-.32 6.453.921L.36 12.431A1.75 1.75 0 0 0 1.907 15h12.186a1.75 1.75 0 0 0 1.547-2.569L9.547.921ZM8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 1 1-1 0V5a.5.5 0 0 1 .5-.5M8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-triangle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.375 4.5a.375.375 0 1 0-.75 0v2.625a.375.375 0 1 0 .75 0zM6.375 8.625a.375.375 0 1 0-.75 0V9a.375.375 0 0 0 .75 0v-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 0c-.26 0-.513.078-.733.22a1.54 1.54 0 0 0-.52.579l.332.174-.332-.172-4.56 8.787-.003.005c-.12.241-.183.512-.184.785 0 .273.06.543.18.786.12.242.295.45.515.6.22.15.475.233.74.236h9.13c.264-.003.52-.087.74-.236.22-.15.395-.358.515-.6s.18-.513.18-.786-.063-.544-.184-.785l-.002-.005L7.254.8 7.252.799a1.54 1.54 0 0 0-.52-.579A1.342 1.342 0 0 0 6 0m-.589 1.148a.795.795 0 0 1 .265-.299A.592.592 0 0 1 6 .75c.11 0 .221.032.324.1a.791.791 0 0 1 .264.297l4.559 8.784c.066.134.103.289.103.449 0 .16-.036.317-.102.452a.803.803 0 0 1-.264.311.597.597 0 0 1-.327.107H1.443a.597.597 0 0 1-.327-.107.803.803 0 0 1-.263-.311 1.02 1.02 0 0 1-.103-.452c0-.16.037-.315.104-.45L5.41 1.149Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-triangle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 1 1-1 0V5a.5.5 0 0 1 .5-.5M8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.453.921C7.111-.32 8.89-.32 9.547.921l6.093 11.51A1.75 1.75 0 0 1 14.093 15H1.907A1.75 1.75 0 0 1 .36 12.431L6.453.921Zm2.21.468 6.093 11.51A.75.75 0 0 1 14.093 14H1.907a.75.75 0 0 1-.663-1.1L7.337 1.39a.75.75 0 0 1 1.326 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-octagon-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.484 0H3.516L0 3.516v4.968L3.516 12h4.968L12 8.484V3.516zM6.656 3.75a.656.656 0 1 0-1.312 0v2.625a.656.656 0 1 0 1.312 0V3.75m0 4.125a.656.656 0 1 0-1.312 0v.375a.656.656 0 0 0 1.312 0v-.375' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-octagon-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.312 0H4.688L0 4.688v6.624L4.688 16h6.624L16 11.312V4.688zM8.875 5a.875.875 0 1 0-1.75 0v3.5a.875.875 0 1 0 1.75 0zm0 5.5a.875.875 0 0 0-1.75 0v.5a.875.875 0 1 0 1.75 0z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-octagon-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.375 3.75a.375.375 0 1 0-.75 0v2.625a.375.375 0 1 0 .75 0zM6.375 7.875a.375.375 0 1 0-.75 0v.375a.375.375 0 0 0 .75 0v-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.671 0c-.1 0-.195.04-.265.11L.11 3.406a.375.375 0 0 0-.11.265V8.33c0 .1.04.195.11.265l3.296 3.296c.07.07.166.11.265.11H8.33c.1 0 .195-.04.265-.11l3.296-3.296c.07-.07.11-.166.11-.265V3.67c0-.1-.04-.195-.11-.265L8.594.11A.375.375 0 0 0 8.329 0H3.67ZM.75 3.827 3.827.75h4.346l3.077 3.077v4.346L8.173 11.25H3.827L.75 8.173V3.827' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-octagon": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 0 1-1 0V5a.5.5 0 0 1 .5-.5M8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m11.003.75 4.247 4.247v6.006l-4.247 4.247H4.997L.75 11.003V4.997L4.997.75zm-5.592 1h5.178l3.661 3.661v5.178l-3.661 3.661H5.41L1.75 10.589V5.41L5.411 1.75' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-circle-filled-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 6A6 6 0 1 1 0 6a6 6 0 0 1 12 0M6.656 3.677a.656.656 0 1 0-1.312 0v2.71a.656.656 0 0 0 1.312 0v-2.71m0 4.259a.656.656 0 1 0-1.312 0v.387a.656.656 0 0 0 1.312 0v-.388Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-circle-filled": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 0 1-1 0V5a.5.5 0 0 1 .5-.5M8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-circle-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6.375 3.75a.375.375 0 1 0-.75 0v2.625a.375.375 0 1 0 .75 0zM6.375 7.875a.375.375 0 1 0-.75 0v.375a.375.375 0 0 0 .75 0v-.375'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 12A6 6 0 1 0 6 0a6 6 0 0 0 0 12m5.25-6A5.25 5.25 0 1 1 .75 6a5.25 5.25 0 0 1 10.5 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "alert-circle": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 0 1-1 0V5a.5.5 0 0 1 .5-.5M8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0m-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "airplay-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 1.75a.937.937 0 0 0-.938.938v5.374c0 .518.42.938.938.938h.937a.375.375 0 1 1 0 .75h-.937A1.688 1.688 0 0 1 0 8.063V2.686C0 1.757.756 1 1.688 1h8.625C11.244 1 12 1.756 12 2.688v5.374c0 .932-.755 1.688-1.687 1.688h-.938a.375.375 0 1 1 0-.75h.938c.517 0 .937-.42.937-.937V2.686a.937.937 0 0 0-.937-.937H1.688M6 6.89l3.392 4.36H2.608L6 6.89M4.142 10.5h3.716L6 8.11 4.142 10.5' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "airplay": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 3C1.56 3 1 3.56 1 4.25v6.5c0 .69.56 1.25 1.25 1.25H3.5a.5.5 0 0 1 0 1H2.25A2.25 2.25 0 0 1 0 10.75v-6.5A2.25 2.25 0 0 1 2.25 2h11.5A2.25 2.25 0 0 1 16 4.25v6.5A2.25 2.25 0 0 1 13.75 13H12.5a.5.5 0 0 1 0-1h1.25c.69 0 1.25-.56 1.25-1.25v-6.5C15 3.56 14.44 3 13.75 3zM8 9.186 12.522 15H3.478L8 9.186M5.522 14h4.956L8 10.814 5.522 14' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "activity-sm": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.898 1.126c.163.01.301.124.34.283l1.963 7.849L8.65 5.49A.375.375 0 0 1 9 5.25h2.625a.375.375 0 0 1 0 .75H9.258l-1.783 4.635a.375.375 0 0 1-.714-.044L4.8 2.742 3.35 6.51a.375.375 0 0 1-.35.24H.375a.375.375 0 1 1 0-.75h2.367l1.783-4.635a.375.375 0 0 1 .373-.24' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                "activity": `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.53 1.5a.5.5 0 0 1 .455.379l2.616 10.465 1.932-5.023A.5.5 0 0 1 12 7h3.5a.5.5 0 0 1 0 1h-3.157l-2.376 6.18a.5.5 0 0 1-.952-.059L6.399 3.656 4.467 8.68A.5.5 0 0 1 4 9H.5a.5.5 0 0 1 0-1h3.157l2.376-6.18a.5.5 0 0 1 .498-.32' clip-rule='evenodd'/%3e%3c/svg%3e")`,
            }
        }
    )

    matchUtilities(
        {
            'icon': (value) => ({
                '--icon-size': value
            })
        },
        {
            values: {
                'sm': 'var(--icon-size-sm)',
                'base': 'var(--icon-size-base)',
                'md': 'var(--icon-size-md)',
                'lg': 'var(--icon-size-lg)',
                'xl': 'var(--icon-size-xl)',
                'xl2': 'var(--icon-size-xl2)',
                'xl3': 'var(--icon-size-xl3)',
                'xl4': 'var(--icon-size-xl4)',
                'xl5': 'var(--icon-size-xl5)',
            }
        }
    )
});